@@ -11,12 +11,11 @@
 // UNSUPPORTED: pre-sm-70
 // UNSUPPORTED: !nvcc
 
-
 #include "utils.h"
 
-template<typename T, typename P>
-__host__ __device__ __noinline__
-void test_ctor() {
+template <typename T, typename P>
+__host__ __device__ __noinline__ void test_ctor()
+{
   // default ctor, cpy and cpy assignment
   cuda::annotated_ptr<T, P> def;
   def = def;
@@ -35,18 +34,18 @@ void test_ctor() {
   d = d; // FAIL
 }
 
-template<typename T, typename P>
-__host__ __device__ __noinline__
-void test_global_ctor() {
+template <typename T, typename P>
+__host__ __device__ __noinline__ void test_global_ctor()
+{
   test_ctor<T, P>();
 }
 
-__host__ __device__ __noinline__
-void test_global_ctors() {
+__host__ __device__ __noinline__ void test_global_ctors()
+{
   test_global_ctor<int, cuda::access_property::normal>();
 }
 
-int main(int argc, char ** argv)
+int main(int argc, char** argv)
 {
   test_global_ctors();
   return 0;
