@@ -14,14 +14,15 @@
 
 #include "utils.h"
 
-__device__ __host__
-static void fails_from_host() {
-    int a;
-    __nv_associate_access_property(&a, uint64_t{0});
+__device__ __host__ static void fails_from_host()
+{
+  int a;
+  __nv_associate_access_property(&a, uint64_t{0});
 }
 
-int main(int argc, char ** argv) {
-    //calling from host needs to fail and kill the app
-    fails_from_host();
-    return 0;
+int main(int argc, char** argv)
+{
+  // calling from host needs to fail and kill the app
+  fails_from_host();
+  return 0;
 }
