@@ -17,23 +17,21 @@
 #define ARR_SZ 128
 
 template <typename T, typename P>
-__device__ __host__ __noinline__
-void test(P ap, bool shared = false)
+__device__ __host__ __noinline__ void test(P ap, bool shared = false)
 {
-
   T* arr = alloc<T, ARR_SZ>(shared);
 
   arr = cuda::associate_access_property(arr, ap);
 
-  for (int i = 0; i < ARR_SZ; ++i) {
+  for (int i = 0; i < ARR_SZ; ++i)
+  {
     assert(arr[i] == i);
   }
 
   dealloc<T>(arr, shared);
 }
 
-__device__ __host__ __noinline__
-void test_all()
+__device__ __host__ __noinline__ void test_all()
 {
   test<int>(cuda::access_property::normal{});
   test<int>(cuda::access_property::persisting{});
@@ -43,13 +41,13 @@ void test_all()
   test<int>(cuda::access_property::shared{}, true);
 }
 
-__global__ void test_kernel() {
+__global__ void test_kernel()
+{
   test_all();
 }
 
-int main(int argc, char ** argv)
+int main(int argc, char** argv)
 {
-
   test_all();
   return 0;
 }
