@@ -16,6 +16,7 @@
 // <cuda/barrier>
 
 #include <cuda/barrier>
+
 #include "test_macros.h"
 
 // Suppress warning about barrier in shared memory
@@ -23,19 +24,16 @@ TEST_NV_DIAG_SUPPRESS(static_var_with_dynamic_init)
 
 __device__ uint64_t bar_storage;
 
-int main(int, char**){
-    NV_IF_TARGET(
-        NV_IS_DEVICE, (
-            cuda::barrier<cuda::thread_scope_block> *bar_ptr;
-            bar_ptr = reinterpret_cast<cuda::barrier<cuda::thread_scope_block> *>(bar_storage);
+int main(int, char**)
+{
+  NV_IF_TARGET(
+    NV_IS_DEVICE,
+    (cuda::barrier<cuda::thread_scope_block> * bar_ptr;
+     bar_ptr = reinterpret_cast<cuda::barrier<cuda::thread_scope_block>*>(bar_storage);
 
-            if (threadIdx.x == 0) {
-                init(bar_ptr, blockDim.x);
-            }
-            __syncthreads();
+     if (threadIdx.x == 0) { init(bar_ptr, blockDim.x); } __syncthreads();
 
-            // Should fail because the barrier is in device memory.
-            auto token = cuda::device::barrier_arrive_tx(*bar_ptr, 1, 0);
-    ));
-    return 0;
+     // Should fail because the barrier is in device memory.
+     auto token = cuda::device::barrier_arrive_tx(*bar_ptr, 1, 0);));
+  return 0;
 }
