@@ -18,18 +18,15 @@
 
 int main(int, char**)
 {
-    NV_DISPATCH_TARGET(
-        NV_IS_HOST, (
-        // Required by concurrent_agents_launch to know how many we're
-        // launching. This can only be an int, because the nvrtc tests use grep
-        // to figure out how many threads to launch.
-        cuda_thread_count = 256;
-        ),
-        NV_IS_DEVICE, (
-            constexpr bool split_arrive_and_expect = true;
-            test<split_arrive_and_expect>();
-        )
-    );
+  NV_DISPATCH_TARGET(
+    NV_IS_HOST,
+    (
+      // Required by concurrent_agents_launch to know how many we're
+      // launching. This can only be an int, because the nvrtc tests use grep
+      // to figure out how many threads to launch.
+      cuda_thread_count = 256;),
+    NV_IS_DEVICE,
+    (constexpr bool split_arrive_and_expect = true; test<split_arrive_and_expect>();));
 
-    return 0;
+  return 0;
 }
