@@ -13,19 +13,15 @@
 
 // static time_point from_time_t(time_t t);
 
-#include <nv/target>
-
 #include <cuda/std/chrono>
 
 #include "test_macros.h"
+#include <nv/target>
 
 int main(int, char**)
 {
-NV_IF_TARGET(
-NV_IS_HOST, (
-    typedef ::std::chrono::system_clock C;
-    C::time_point t1 = C::from_time_t(C::to_time_t(C::now()));
-    unused(t1);
-));
-    return 0;
+  NV_IF_TARGET(
+    NV_IS_HOST,
+    (typedef ::std::chrono::system_clock C; C::time_point t1 = C::from_time_t(C::to_time_t(C::now())); unused(t1);));
+  return 0;
 }
