@@ -8,28 +8,26 @@
 //===----------------------------------------------------------------------===//
 
 // UNSUPPORTED: nvrtc
-#include <nv/target>
+#include <cuda/std/cassert>
+#include <cuda/std/utility>
 
 #include <utility>
 
-#include <cuda/std/utility>
-#include <cuda/std/cassert>
+#include <nv/target>
 
 template <class T1, class U1>
-void test_conversion() {
-    const ::cuda::std::pair<T1, U1> input{T1{42}, U1{1337}};
-    const ::std::pair<T1, U1> from_input{input};
-
-    assert(from_input.first == T1{42});
-    assert(from_input.second == U1{1337});
-}
-
-int main(int arg, char ** argv)
+void test_conversion()
 {
-NV_IF_TARGET(
-NV_IS_HOST, (
-    test_conversion<int, float>();
-));
+  const ::cuda::std::pair<T1, U1> input{T1{42}, U1{1337}};
+  const ::std::pair<T1, U1> from_input{input};
 
-    return 0;
+  assert(from_input.first == T1{42});
+  assert(from_input.second == U1{1337});
+}
+
+int main(int arg, char** argv)
+{
+  NV_IF_TARGET(NV_IS_HOST, (test_conversion<int, float>();));
+
+  return 0;
 }
