@@ -18,10 +18,11 @@
 #include "test_macros.h"
 
 template <class Iter>
-__host__ __device__ TEST_CONSTEXPR_CXX14 bool tests() {
-  int array[]                           = {0, 1, 2, 3, 4};
-  int* b                                = array + 0;
-  int* e                                = array + 5;
+__host__ __device__ TEST_CONSTEXPR_CXX14 bool tests()
+{
+  int array[]                                 = {0, 1, 2, 3, 4};
+  int* b                                      = array + 0;
+  int* e                                      = array + 5;
   cuda::std::__bounded_iter<Iter> const iter1 = cuda::std::__make_bounded_iter(Iter(b), Iter(b), Iter(e));
   cuda::std::__bounded_iter<Iter> const iter2 = cuda::std::__make_bounded_iter(Iter(e), Iter(b), Iter(e));
 
@@ -63,15 +64,16 @@ __host__ __device__ TEST_CONSTEXPR_CXX14 bool tests() {
   return true;
 }
 
-int main(int, char**) {
+int main(int, char**)
+{
   tests<int*>();
 #if TEST_STD_VER > 2011
   static_assert(tests<int*>(), "");
 #endif
 
 #if TEST_STD_VER > 2017
-  tests<contiguous_iterator<int*> >();
-  static_assert(tests<contiguous_iterator<int*> >(), "");
+  tests<contiguous_iterator<int*>>();
+  static_assert(tests<contiguous_iterator<int*>>(), "");
 #endif
 
   return 0;
