@@ -14,13 +14,14 @@
 // See llvm.org/PR39713
 
 #include <cuda/std/type_traits>
+
 #include "test_macros.h"
 
 TEST_NV_DIAG_SUPPRESS(cuda_demote_unsupported_floating_point)
 
 template <class T>
-__host__ __device__
-void test() {
+__host__ __device__ void test()
+{
   static_assert(_LIBCUDACXX_ALIGNOF(T) == cuda::std::alignment_of<T>::value, "");
   static_assert(_LIBCUDACXX_ALIGNOF(T) == TEST_ALIGNOF(T), "");
   static_assert(_LIBCUDACXX_ALIGNOF(T) == alignof(T), "");
@@ -29,7 +30,8 @@ void test() {
 #endif
 }
 
-int main(int, char**) {
+int main(int, char**)
+{
   test<int>();
   test<long long>();
   test<double>();
