@@ -15,27 +15,27 @@
 //   void
 //   iter_swap(Iter1 a, Iter2 b);
 
-#include <cuda/std/__algorithm>
+#include <cuda/std/__algorithm_>
 #include <cuda/std/cassert>
 
 #include "test_macros.h"
 
 __host__ __device__ TEST_CONSTEXPR_CXX14 bool test()
 {
-    int i = 1;
-    int j = 2;
-    cuda::std::iter_swap(&i, &j);
-    assert(i == 2);
-    assert(j == 1);
+  int i = 1;
+  int j = 2;
+  cuda::std::iter_swap(&i, &j);
+  assert(i == 2);
+  assert(j == 1);
 
-    return true;
+  return true;
 }
 
 int main(int, char**)
 {
-    test();
+  test();
 #if TEST_STD_VER >= 2014
-    static_assert(test(), "");
+  static_assert(test(), "");
 #endif // TEST_STD_VER >= 2014
 
   return 0;
