@@ -22,7 +22,8 @@
 using cuda::std::invocable;
 
 template <class R, class... Args>
-__host__ __device__ constexpr bool check_invocable() {
+__host__ __device__ constexpr bool check_invocable()
+{
   constexpr bool result = invocable<R(Args...), Args...>;
   static_assert(invocable<R(Args...) noexcept, Args...> == result, "");
   static_assert(invocable<R (*)(Args...), Args...> == result, "");
@@ -61,8 +62,10 @@ static_assert(!invocable<int>, "");
 static_assert(!invocable<int&>, "");
 static_assert(!invocable<int&&>, "");
 
-namespace function_objects {
-struct function_object {
+namespace function_objects
+{
+struct function_object
+{
   __host__ __device__ void operator()();
 };
 static_assert(invocable<function_object>, "");
@@ -74,7 +77,8 @@ static_assert(!invocable<function_object const&>, "");
 static_assert(!invocable<function_object volatile&>, "");
 static_assert(!invocable<function_object const volatile&>, "");
 
-struct const_function_object {
+struct const_function_object
+{
   __host__ __device__ void operator()(int) const;
 };
 static_assert(invocable<const_function_object, int>, "");
@@ -86,21 +90,21 @@ static_assert(invocable<const_function_object const&, int>, "");
 static_assert(!invocable<const_function_object volatile&, int>, "");
 static_assert(!invocable<const_function_object const volatile&, int>, "");
 
-struct volatile_function_object {
+struct volatile_function_object
+{
   __host__ __device__ void operator()(int, int) volatile;
 };
 static_assert(invocable<volatile_function_object, int, int>, "");
 static_assert(!invocable<volatile_function_object const, int, int>, "");
 static_assert(invocable<volatile_function_object volatile, int, int>, "");
-static_assert(
-    !invocable<volatile_function_object const volatile, int, int>, "");
+static_assert(!invocable<volatile_function_object const volatile, int, int>, "");
 static_assert(invocable<volatile_function_object&, int, int>, "");
 static_assert(!invocable<volatile_function_object const&, int, int>, "");
 static_assert(invocable<volatile_function_object volatile&, int, int>, "");
-static_assert(
-    !invocable<volatile_function_object const volatile&, int, int>, "");
+static_assert(!invocable<volatile_function_object const volatile&, int, int>, "");
 
-struct cv_function_object {
+struct cv_function_object
+{
   __host__ __device__ void operator()(int[]) const volatile;
 };
 static_assert(invocable<cv_function_object, int*>, "");
@@ -112,7 +116,8 @@ static_assert(invocable<cv_function_object const&, int*>, "");
 static_assert(invocable<cv_function_object volatile&, int*>, "");
 static_assert(invocable<cv_function_object const volatile&, int*>, "");
 
-struct lvalue_function_object {
+struct lvalue_function_object
+{
   __host__ __device__ void operator()() &;
 };
 static_assert(!invocable<lvalue_function_object>, "");
@@ -124,38 +129,34 @@ static_assert(!invocable<lvalue_function_object const&>, "");
 static_assert(!invocable<lvalue_function_object volatile&>, "");
 static_assert(!invocable<lvalue_function_object const volatile&>, "");
 
-struct lvalue_const_function_object {
+struct lvalue_const_function_object
+{
   __host__ __device__ void operator()(int) const&;
 };
 static_assert(invocable<lvalue_const_function_object, int>, "");
 static_assert(invocable<lvalue_const_function_object const, int>, "");
 static_assert(!invocable<lvalue_const_function_object volatile, int>, "");
-static_assert(
-    !invocable<lvalue_const_function_object const volatile, int>, "");
+static_assert(!invocable<lvalue_const_function_object const volatile, int>, "");
 static_assert(invocable<lvalue_const_function_object&, int>, "");
 static_assert(invocable<lvalue_const_function_object const&, int>, "");
 static_assert(!invocable<lvalue_const_function_object volatile&, int>, "");
-static_assert(
-    !invocable<lvalue_const_function_object const volatile&, int>, "");
+static_assert(!invocable<lvalue_const_function_object const volatile&, int>, "");
 
-struct lvalue_volatile_function_object {
+struct lvalue_volatile_function_object
+{
   __host__ __device__ void operator()(int, int) volatile&;
 };
 static_assert(!invocable<lvalue_volatile_function_object, int, int>, "");
 static_assert(!invocable<lvalue_volatile_function_object const, int, int>, "");
-static_assert(
-    !invocable<lvalue_volatile_function_object volatile, int, int>, "");
-static_assert(
-    !invocable<lvalue_volatile_function_object const volatile, int, int>, "");
+static_assert(!invocable<lvalue_volatile_function_object volatile, int, int>, "");
+static_assert(!invocable<lvalue_volatile_function_object const volatile, int, int>, "");
 static_assert(invocable<lvalue_volatile_function_object&, int, int>, "");
-static_assert(
-    !invocable<lvalue_volatile_function_object const&, int, int>, "");
-static_assert(
-    invocable<lvalue_volatile_function_object volatile&, int, int>, "");
-static_assert(
-    !invocable<lvalue_volatile_function_object const volatile&, int, int>, "");
+static_assert(!invocable<lvalue_volatile_function_object const&, int, int>, "");
+static_assert(invocable<lvalue_volatile_function_object volatile&, int, int>, "");
+static_assert(!invocable<lvalue_volatile_function_object const volatile&, int, int>, "");
 
-struct lvalue_cv_function_object {
+struct lvalue_cv_function_object
+{
   __host__ __device__ void operator()(int[]) const volatile&;
 };
 static_assert(!invocable<lvalue_cv_function_object, int*>, "");
@@ -167,7 +168,8 @@ static_assert(invocable<lvalue_cv_function_object const&, int*>, "");
 static_assert(invocable<lvalue_cv_function_object volatile&, int*>, "");
 static_assert(invocable<lvalue_cv_function_object const volatile&, int*>, "");
 //
-struct rvalue_function_object {
+struct rvalue_function_object
+{
   __host__ __device__ void operator()() &&;
 };
 static_assert(invocable<rvalue_function_object>, "");
@@ -179,38 +181,34 @@ static_assert(!invocable<rvalue_function_object const&>, "");
 static_assert(!invocable<rvalue_function_object volatile&>, "");
 static_assert(!invocable<rvalue_function_object const volatile&>, "");
 
-struct rvalue_const_function_object {
+struct rvalue_const_function_object
+{
   __host__ __device__ void operator()(int) const&&;
 };
 static_assert(invocable<rvalue_const_function_object, int>, "");
 static_assert(invocable<rvalue_const_function_object const, int>, "");
 static_assert(!invocable<rvalue_const_function_object volatile, int>, "");
-static_assert(
-    !invocable<rvalue_const_function_object const volatile, int>, "");
+static_assert(!invocable<rvalue_const_function_object const volatile, int>, "");
 static_assert(!invocable<rvalue_const_function_object&, int>, "");
 static_assert(!invocable<rvalue_const_function_object const&, int>, "");
 static_assert(!invocable<rvalue_const_function_object volatile&, int>, "");
-static_assert(
-    !invocable<rvalue_const_function_object const volatile&, int>, "");
+static_assert(!invocable<rvalue_const_function_object const volatile&, int>, "");
 
-struct rvalue_volatile_function_object {
+struct rvalue_volatile_function_object
+{
   __host__ __device__ void operator()(int, int) volatile&&;
 };
 static_assert(invocable<rvalue_volatile_function_object, int, int>, "");
 static_assert(!invocable<rvalue_volatile_function_object const, int, int>, "");
-static_assert(
-    invocable<rvalue_volatile_function_object volatile, int, int>, "");
-static_assert(
-    !invocable<rvalue_volatile_function_object const volatile, int, int>, "");
+static_assert(invocable<rvalue_volatile_function_object volatile, int, int>, "");
+static_assert(!invocable<rvalue_volatile_function_object const volatile, int, int>, "");
 static_assert(!invocable<rvalue_volatile_function_object&, int, int>, "");
-static_assert(
-    !invocable<rvalue_volatile_function_object const&, int, int>, "");
-static_assert(
-    !invocable<rvalue_volatile_function_object volatile&, int, int>, "");
-static_assert(
-    !invocable<rvalue_volatile_function_object const volatile&, int, int>, "");
+static_assert(!invocable<rvalue_volatile_function_object const&, int, int>, "");
+static_assert(!invocable<rvalue_volatile_function_object volatile&, int, int>, "");
+static_assert(!invocable<rvalue_volatile_function_object const volatile&, int, int>, "");
 
-struct rvalue_cv_function_object {
+struct rvalue_cv_function_object
+{
   __host__ __device__ void operator()(int[]) const volatile&&;
 };
 static_assert(invocable<rvalue_cv_function_object, int*>, "");
@@ -222,11 +220,20 @@ static_assert(!invocable<rvalue_cv_function_object const&, int*>, "");
 static_assert(!invocable<rvalue_cv_function_object volatile&, int*>, "");
 static_assert(!invocable<rvalue_cv_function_object const volatile&, int*>, "");
 
-struct multiple_overloads {
-  struct A {};
-  struct B { __host__ __device__ B(int); };
-  struct AB : A, B {};
-  struct O {};
+struct multiple_overloads
+{
+  struct A
+  {};
+  struct B
+  {
+    __host__ __device__ B(int);
+  };
+  struct AB
+      : A
+      , B
+  {};
+  struct O
+  {};
   __host__ __device__ void operator()(A) const;
   __host__ __device__ void operator()(B) const;
 };
@@ -237,22 +244,24 @@ static_assert(!invocable<multiple_overloads, multiple_overloads::AB>, "");
 static_assert(!invocable<multiple_overloads, multiple_overloads::O>, "");
 } // namespace function_objects
 
-namespace pointer_to_member_functions {
-  template<class Member, class T, class... Args>
-  __host__ __device__ constexpr bool check_member_is_invocable()
-  {
-    constexpr bool result = invocable<Member, T&&, Args...>;
-    using uncv_t = cuda::std::remove_cvref_t<T>;
-    static_assert(invocable<Member, uncv_t*, Args...> == result, "");
-    static_assert(invocable<Member, cuda::std::reference_wrapper<uncv_t>, Args...> == result, "");
-    static_assert(!invocable<Member, cuda::std::nullptr_t, Args...>, "");
-    static_assert(!invocable<Member, int, Args...>, "");
-    static_assert(!invocable<Member, int*, Args...>, "");
-    static_assert(!invocable<Member, double*, Args...>, "");
-    struct S2 {};
-    static_assert(!invocable<Member, S2*, Args...>, "");
-    return result;
-  }
+namespace pointer_to_member_functions
+{
+template <class Member, class T, class... Args>
+__host__ __device__ constexpr bool check_member_is_invocable()
+{
+  constexpr bool result = invocable<Member, T&&, Args...>;
+  using uncv_t          = cuda::std::remove_cvref_t<T>;
+  static_assert(invocable<Member, uncv_t*, Args...> == result, "");
+  static_assert(invocable<Member, cuda::std::reference_wrapper<uncv_t>, Args...> == result, "");
+  static_assert(!invocable<Member, cuda::std::nullptr_t, Args...>, "");
+  static_assert(!invocable<Member, int, Args...>, "");
+  static_assert(!invocable<Member, int*, Args...>, "");
+  static_assert(!invocable<Member, double*, Args...>, "");
+  struct S2
+  {};
+  static_assert(!invocable<Member, S2*, Args...>, "");
+  return result;
+}
 
 static_assert(check_member_is_invocable<int S::*, S>(), "");
 static_assert(invocable<int S::*, S&>, "");
@@ -287,8 +296,7 @@ static_assert(invocable<const_qualified, S const&&>, "");
 static_assert(!invocable<const_qualified, S volatile&&>, "");
 static_assert(!invocable<const_qualified, S const volatile&&>, "");
 
-static_assert(
-    check_member_is_invocable<int (S::*)(double[]) volatile, S, double*>(), "");
+static_assert(check_member_is_invocable<int (S::*)(double[]) volatile, S, double*>(), "");
 using volatile_qualified = void (S::*)() volatile;
 static_assert(invocable<volatile_qualified, S&>, "");
 static_assert(!invocable<volatile_qualified, S const&>, "");
@@ -299,8 +307,7 @@ static_assert(!invocable<volatile_qualified, S const&&>, "");
 static_assert(invocable<volatile_qualified, S volatile&&>, "");
 static_assert(!invocable<volatile_qualified, S const volatile&&>, "");
 
-static_assert(check_member_is_invocable<int (S::*)(int, S&) const volatile, S,
-                                        int, S&>(), "");
+static_assert(check_member_is_invocable<int (S::*)(int, S&) const volatile, S, int, S&>(), "");
 using cv_qualified = void (S::*)() const volatile;
 static_assert(invocable<cv_qualified, S&>, "");
 static_assert(invocable<cv_qualified, S const&>, "");
@@ -415,8 +422,9 @@ static_assert(invocable<rvalue_cv_unqualified, S const volatile&&>, "");
 } // namespace pointer_to_member_functions
 
 // Check the concept with closure types
-template<class F, class... Args>
-__host__ __device__ constexpr bool is_invocable(F, Args&&...) {
+template <class F, class... Args>
+__host__ __device__ constexpr bool is_invocable(F, Args&&...)
+{
   return invocable<F, Args...>;
 }
 
@@ -430,4 +438,7 @@ int i = 0;
 static_assert(is_invocable([](int&) {}, i), "");
 #endif // TEST_STD_VER > 2014
 
-int main(int, char**) { return 0; }
+int main(int, char**)
+{
+  return 0;
+}
