@@ -18,7 +18,8 @@
 #include "test_macros.h"
 #if TEST_STD_VER > 2017
 
-__host__ __device__ constexpr bool check_subsumption(cuda::std::regular_invocable auto) {
+__host__ __device__ constexpr bool check_subsumption(cuda::std::regular_invocable auto)
+{
   return false;
 }
 
@@ -30,12 +31,17 @@ __host__ __device__ constexpr bool check_subsumption(F)
   return true;
 }
 // clang-format on
-struct not_predicate {
+struct not_predicate
+{
   __host__ __device__ constexpr void operator()() const {}
 };
 
-struct predicate {
-  __host__ __device__ constexpr bool operator()() const { return true; }
+struct predicate
+{
+  __host__ __device__ constexpr bool operator()() const
+  {
+    return true;
+  }
 };
 
 static_assert(!check_subsumption(not_predicate{}), "");
