@@ -22,15 +22,14 @@
 using cuda::std::regular_invocable;
 
 template <class R, class... Args>
-__host__ __device__ constexpr bool check_invocable() {
+__host__ __device__ constexpr bool check_invocable()
+{
   constexpr bool result = regular_invocable<R(Args...), Args...>;
   static_assert(regular_invocable<R(Args...) noexcept, Args...> == result, "");
   static_assert(regular_invocable<R (*)(Args...), Args...> == result, "");
-  static_assert(regular_invocable<R (*)(Args...) noexcept, Args...> ==
-                result, "");
+  static_assert(regular_invocable<R (*)(Args...) noexcept, Args...> == result, "");
   static_assert(regular_invocable<R (&)(Args...), Args...> == result, "");
-  static_assert(regular_invocable<R (&)(Args...) noexcept, Args...> ==
-                result, "");
+  static_assert(regular_invocable<R (&)(Args...) noexcept, Args...> == result, "");
 
   return result;
 }
@@ -63,8 +62,10 @@ static_assert(!regular_invocable<int>, "");
 static_assert(!regular_invocable<int&>, "");
 static_assert(!regular_invocable<int&&>, "");
 
-namespace function_objects {
-struct function_object {
+namespace function_objects
+{
+struct function_object
+{
   __host__ __device__ void operator()();
 };
 static_assert(regular_invocable<function_object>, "");
@@ -76,39 +77,34 @@ static_assert(!regular_invocable<function_object const&>, "");
 static_assert(!regular_invocable<function_object volatile&>, "");
 static_assert(!regular_invocable<function_object const volatile&>, "");
 
-struct const_function_object {
+struct const_function_object
+{
   __host__ __device__ void operator()(int) const;
 };
 static_assert(regular_invocable<const_function_object, int>, "");
 static_assert(regular_invocable<const_function_object const, int>, "");
 static_assert(!regular_invocable<const_function_object volatile, int>, "");
-static_assert(
-    !regular_invocable<const_function_object const volatile, int>, "");
+static_assert(!regular_invocable<const_function_object const volatile, int>, "");
 static_assert(regular_invocable<const_function_object&, int>, "");
 static_assert(regular_invocable<const_function_object const&, int>, "");
 static_assert(!regular_invocable<const_function_object volatile&, int>, "");
-static_assert(
-    !regular_invocable<const_function_object const volatile&, int>, "");
+static_assert(!regular_invocable<const_function_object const volatile&, int>, "");
 
-struct volatile_function_object {
+struct volatile_function_object
+{
   __host__ __device__ void operator()(int, int) volatile;
 };
 static_assert(regular_invocable<volatile_function_object, int, int>, "");
-static_assert(
-    !regular_invocable<volatile_function_object const, int, int>, "");
-static_assert(
-    regular_invocable<volatile_function_object volatile, int, int>, "");
-static_assert(
-    !regular_invocable<volatile_function_object const volatile, int, int>, "");
+static_assert(!regular_invocable<volatile_function_object const, int, int>, "");
+static_assert(regular_invocable<volatile_function_object volatile, int, int>, "");
+static_assert(!regular_invocable<volatile_function_object const volatile, int, int>, "");
 static_assert(regular_invocable<volatile_function_object&, int, int>, "");
-static_assert(
-    !regular_invocable<volatile_function_object const&, int, int>, "");
-static_assert(
-    regular_invocable<volatile_function_object volatile&, int, int>, "");
-static_assert(!regular_invocable<volatile_function_object const volatile&,
-                                      int, int>, "");
+static_assert(!regular_invocable<volatile_function_object const&, int, int>, "");
+static_assert(regular_invocable<volatile_function_object volatile&, int, int>, "");
+static_assert(!regular_invocable<volatile_function_object const volatile&, int, int>, "");
 
-struct cv_function_object {
+struct cv_function_object
+{
   __host__ __device__ void operator()(int[]) const volatile;
 };
 static_assert(regular_invocable<cv_function_object, int*>, "");
@@ -120,7 +116,8 @@ static_assert(regular_invocable<cv_function_object const&, int*>, "");
 static_assert(regular_invocable<cv_function_object volatile&, int*>, "");
 static_assert(regular_invocable<cv_function_object const volatile&, int*>, "");
 
-struct lvalue_function_object {
+struct lvalue_function_object
+{
   __host__ __device__ void operator()() &;
 };
 static_assert(!regular_invocable<lvalue_function_object>, "");
@@ -132,59 +129,47 @@ static_assert(!regular_invocable<lvalue_function_object const&>, "");
 static_assert(!regular_invocable<lvalue_function_object volatile&>, "");
 static_assert(!regular_invocable<lvalue_function_object const volatile&>, "");
 
-struct lvalue_const_function_object {
+struct lvalue_const_function_object
+{
   __host__ __device__ void operator()(int) const&;
 };
 static_assert(regular_invocable<lvalue_const_function_object, int>, "");
 static_assert(regular_invocable<lvalue_const_function_object const, int>, "");
-static_assert(
-    !regular_invocable<lvalue_const_function_object volatile, int>, "");
-static_assert(
-    !regular_invocable<lvalue_const_function_object const volatile, int>, "");
+static_assert(!regular_invocable<lvalue_const_function_object volatile, int>, "");
+static_assert(!regular_invocable<lvalue_const_function_object const volatile, int>, "");
 static_assert(regular_invocable<lvalue_const_function_object&, int>, "");
 static_assert(regular_invocable<lvalue_const_function_object const&, int>, "");
-static_assert(
-    !regular_invocable<lvalue_const_function_object volatile&, int>, "");
-static_assert(
-    !regular_invocable<lvalue_const_function_object const volatile&, int>, "");
+static_assert(!regular_invocable<lvalue_const_function_object volatile&, int>, "");
+static_assert(!regular_invocable<lvalue_const_function_object const volatile&, int>, "");
 
-struct lvalue_volatile_function_object {
+struct lvalue_volatile_function_object
+{
   __host__ __device__ void operator()(int, int) volatile&;
 };
-static_assert(
-    !regular_invocable<lvalue_volatile_function_object, int, int>, "");
-static_assert(
-    !regular_invocable<lvalue_volatile_function_object const, int, int>, "");
-static_assert(!regular_invocable<lvalue_volatile_function_object volatile,
-                                      int, int>, "");
-static_assert(!regular_invocable<
-              lvalue_volatile_function_object const volatile, int, int>, "");
-static_assert(
-    regular_invocable<lvalue_volatile_function_object&, int, int>, "");
-static_assert(
-    !regular_invocable<lvalue_volatile_function_object const&, int, int>, "");
-static_assert(regular_invocable<lvalue_volatile_function_object volatile&,
-                                     int, int>, "");
-static_assert(!regular_invocable<
-              lvalue_volatile_function_object const volatile&, int, int>, "");
+static_assert(!regular_invocable<lvalue_volatile_function_object, int, int>, "");
+static_assert(!regular_invocable<lvalue_volatile_function_object const, int, int>, "");
+static_assert(!regular_invocable<lvalue_volatile_function_object volatile, int, int>, "");
+static_assert(!regular_invocable<lvalue_volatile_function_object const volatile, int, int>, "");
+static_assert(regular_invocable<lvalue_volatile_function_object&, int, int>, "");
+static_assert(!regular_invocable<lvalue_volatile_function_object const&, int, int>, "");
+static_assert(regular_invocable<lvalue_volatile_function_object volatile&, int, int>, "");
+static_assert(!regular_invocable<lvalue_volatile_function_object const volatile&, int, int>, "");
 
-struct lvalue_cv_function_object {
+struct lvalue_cv_function_object
+{
   __host__ __device__ void operator()(int[]) const volatile&;
 };
 static_assert(!regular_invocable<lvalue_cv_function_object, int*>, "");
 static_assert(!regular_invocable<lvalue_cv_function_object const, int*>, "");
-static_assert(
-    !regular_invocable<lvalue_cv_function_object volatile, int*>, "");
-static_assert(
-    !regular_invocable<lvalue_cv_function_object const volatile, int*>, "");
+static_assert(!regular_invocable<lvalue_cv_function_object volatile, int*>, "");
+static_assert(!regular_invocable<lvalue_cv_function_object const volatile, int*>, "");
 static_assert(regular_invocable<lvalue_cv_function_object&, int*>, "");
 static_assert(regular_invocable<lvalue_cv_function_object const&, int*>, "");
-static_assert(
-    regular_invocable<lvalue_cv_function_object volatile&, int*>, "");
-static_assert(
-    regular_invocable<lvalue_cv_function_object const volatile&, int*>, "");
+static_assert(regular_invocable<lvalue_cv_function_object volatile&, int*>, "");
+static_assert(regular_invocable<lvalue_cv_function_object const volatile&, int*>, "");
 //
-struct rvalue_function_object {
+struct rvalue_function_object
+{
   __host__ __device__ void operator()() &&;
 };
 static_assert(regular_invocable<rvalue_function_object>, "");
@@ -196,63 +181,59 @@ static_assert(!regular_invocable<rvalue_function_object const&>, "");
 static_assert(!regular_invocable<rvalue_function_object volatile&>, "");
 static_assert(!regular_invocable<rvalue_function_object const volatile&>, "");
 
-struct rvalue_const_function_object {
+struct rvalue_const_function_object
+{
   __host__ __device__ void operator()(int) const&&;
 };
 static_assert(regular_invocable<rvalue_const_function_object, int>, "");
 static_assert(regular_invocable<rvalue_const_function_object const, int>, "");
-static_assert(
-    !regular_invocable<rvalue_const_function_object volatile, int>, "");
-static_assert(
-    !regular_invocable<rvalue_const_function_object const volatile, int>, "");
+static_assert(!regular_invocable<rvalue_const_function_object volatile, int>, "");
+static_assert(!regular_invocable<rvalue_const_function_object const volatile, int>, "");
 static_assert(!regular_invocable<rvalue_const_function_object&, int>, "");
-static_assert(
-    !regular_invocable<rvalue_const_function_object const&, int>, "");
-static_assert(
-    !regular_invocable<rvalue_const_function_object volatile&, int>, "");
-static_assert(
-    !regular_invocable<rvalue_const_function_object const volatile&, int>, "");
+static_assert(!regular_invocable<rvalue_const_function_object const&, int>, "");
+static_assert(!regular_invocable<rvalue_const_function_object volatile&, int>, "");
+static_assert(!regular_invocable<rvalue_const_function_object const volatile&, int>, "");
 
-struct rvalue_volatile_function_object {
+struct rvalue_volatile_function_object
+{
   __host__ __device__ void operator()(int, int) volatile&&;
 };
-static_assert(
-    regular_invocable<rvalue_volatile_function_object, int, int>, "");
-static_assert(
-    !regular_invocable<rvalue_volatile_function_object const, int, int>, "");
-static_assert(
-    regular_invocable<rvalue_volatile_function_object volatile, int, int>, "");
-static_assert(!regular_invocable<
-              rvalue_volatile_function_object const volatile, int, int>, "");
-static_assert(
-    !regular_invocable<rvalue_volatile_function_object&, int, int>, "");
-static_assert(
-    !regular_invocable<rvalue_volatile_function_object const&, int, int>, "");
-static_assert(!regular_invocable<rvalue_volatile_function_object volatile&,
-                                      int, int>, "");
-static_assert(!regular_invocable<
-              rvalue_volatile_function_object const volatile&, int, int>, "");
+static_assert(regular_invocable<rvalue_volatile_function_object, int, int>, "");
+static_assert(!regular_invocable<rvalue_volatile_function_object const, int, int>, "");
+static_assert(regular_invocable<rvalue_volatile_function_object volatile, int, int>, "");
+static_assert(!regular_invocable<rvalue_volatile_function_object const volatile, int, int>, "");
+static_assert(!regular_invocable<rvalue_volatile_function_object&, int, int>, "");
+static_assert(!regular_invocable<rvalue_volatile_function_object const&, int, int>, "");
+static_assert(!regular_invocable<rvalue_volatile_function_object volatile&, int, int>, "");
+static_assert(!regular_invocable<rvalue_volatile_function_object const volatile&, int, int>, "");
 
-struct rvalue_cv_function_object {
+struct rvalue_cv_function_object
+{
   __host__ __device__ void operator()(int[]) const volatile&&;
 };
 static_assert(regular_invocable<rvalue_cv_function_object, int*>, "");
 static_assert(regular_invocable<rvalue_cv_function_object const, int*>, "");
 static_assert(regular_invocable<rvalue_cv_function_object volatile, int*>, "");
-static_assert(
-    regular_invocable<rvalue_cv_function_object const volatile, int*>, "");
+static_assert(regular_invocable<rvalue_cv_function_object const volatile, int*>, "");
 static_assert(!regular_invocable<rvalue_cv_function_object&, int*>, "");
 static_assert(!regular_invocable<rvalue_cv_function_object const&, int*>, "");
-static_assert(
-    !regular_invocable<rvalue_cv_function_object volatile&, int*>, "");
-static_assert(
-    !regular_invocable<rvalue_cv_function_object const volatile&, int*>, "");
+static_assert(!regular_invocable<rvalue_cv_function_object volatile&, int*>, "");
+static_assert(!regular_invocable<rvalue_cv_function_object const volatile&, int*>, "");
 
-struct multiple_overloads {
-  struct A {};
-  struct B { __host__ __device__ B(int); };
-  struct AB : A, B {};
-  struct O {};
+struct multiple_overloads
+{
+  struct A
+  {};
+  struct B
+  {
+    __host__ __device__ B(int);
+  };
+  struct AB
+      : A
+      , B
+  {};
+  struct O
+  {};
   __host__ __device__ void operator()(A) const;
   __host__ __device__ void operator()(B) const;
 };
@@ -263,22 +244,24 @@ static_assert(!regular_invocable<multiple_overloads, multiple_overloads::AB>, ""
 static_assert(!regular_invocable<multiple_overloads, multiple_overloads::O>, "");
 } // namespace function_objects
 
-namespace pointer_to_member_functions {
-  template<class Member, class T, class... Args>
-  __host__ __device__ constexpr bool check_member_is_invocable()
-  {
-    constexpr bool result = regular_invocable<Member, T&&, Args...>;
-    using uncv_t = cuda::std::remove_cvref_t<T>;
-    static_assert(regular_invocable<Member, uncv_t*, Args...> == result, "");
-    static_assert(regular_invocable<Member, cuda::std::reference_wrapper<uncv_t>, Args...> == result, "");
-    static_assert(!regular_invocable<Member, cuda::std::nullptr_t, Args...>, "");
-    static_assert(!regular_invocable<Member, int, Args...>, "");
-    static_assert(!regular_invocable<Member, int*, Args...>, "");
-    static_assert(!regular_invocable<Member, double*, Args...>, "");
-    struct S2 {};
-    static_assert(!regular_invocable<Member, S2*, Args...>, "");
-    return result;
-  }
+namespace pointer_to_member_functions
+{
+template <class Member, class T, class... Args>
+__host__ __device__ constexpr bool check_member_is_invocable()
+{
+  constexpr bool result = regular_invocable<Member, T&&, Args...>;
+  using uncv_t          = cuda::std::remove_cvref_t<T>;
+  static_assert(regular_invocable<Member, uncv_t*, Args...> == result, "");
+  static_assert(regular_invocable<Member, cuda::std::reference_wrapper<uncv_t>, Args...> == result, "");
+  static_assert(!regular_invocable<Member, cuda::std::nullptr_t, Args...>, "");
+  static_assert(!regular_invocable<Member, int, Args...>, "");
+  static_assert(!regular_invocable<Member, int*, Args...>, "");
+  static_assert(!regular_invocable<Member, double*, Args...>, "");
+  struct S2
+  {};
+  static_assert(!regular_invocable<Member, S2*, Args...>, "");
+  return result;
+}
 
 static_assert(check_member_is_invocable<int S::*, S>(), "");
 static_assert(regular_invocable<int S::*, S&>, "");
@@ -313,8 +296,7 @@ static_assert(regular_invocable<const_qualified, S const&&>, "");
 static_assert(!regular_invocable<const_qualified, S volatile&&>, "");
 static_assert(!regular_invocable<const_qualified, S const volatile&&>, "");
 
-static_assert(
-    check_member_is_invocable<int (S::*)(double[]) volatile, S, double*>(), "");
+static_assert(check_member_is_invocable<int (S::*)(double[]) volatile, S, double*>(), "");
 using volatile_qualified = void (S::*)() volatile;
 static_assert(regular_invocable<volatile_qualified, S&>, "");
 static_assert(!regular_invocable<volatile_qualified, S const&>, "");
@@ -325,8 +307,7 @@ static_assert(!regular_invocable<volatile_qualified, S const&&>, "");
 static_assert(regular_invocable<volatile_qualified, S volatile&&>, "");
 static_assert(!regular_invocable<volatile_qualified, S const volatile&&>, "");
 
-static_assert(check_member_is_invocable<int (S::*)(int, S&) const volatile, S,
-                                        int, S&>(), "");
+static_assert(check_member_is_invocable<int (S::*)(int, S&) const volatile, S, int, S&>(), "");
 using cv_qualified = void (S::*)() const volatile;
 static_assert(regular_invocable<cv_qualified, S&>, "");
 static_assert(regular_invocable<cv_qualified, S const&>, "");
@@ -442,25 +423,29 @@ static_assert(regular_invocable<rvalue_cv_unqualified, S const volatile&&>, "");
 
 // Check the concept with closure types (and also check for subsumption)
 #if TEST_STD_VER > 2017
-template<class F, class... Args>
-__host__ __device__ constexpr bool is_regular_invocable(F, Args&&...) {
+template <class F, class... Args>
+__host__ __device__ constexpr bool is_regular_invocable(F, Args&&...)
+{
   return false;
 }
 
-template<class F, class... Args>
-requires cuda::std::invocable<F, Args...>
-__host__ __device__ constexpr bool is_regular_invocable(F, Args&&...) {
+template <class F, class... Args>
+  requires cuda::std::invocable<F, Args...>
+__host__ __device__ constexpr bool is_regular_invocable(F, Args&&...)
+{
   return false;
 }
 
-template<class F, class... Args>
-requires cuda::std::regular_invocable<F, Args...> && true
-__host__ __device__ constexpr bool is_regular_invocable(F, Args&&...) {
+template <class F, class... Args>
+  requires cuda::std::regular_invocable<F, Args...> && true
+__host__ __device__ constexpr bool is_regular_invocable(F, Args&&...)
+{
   return true;
 }
 #else
-template<class F, class... Args>
-__host__ __device__ constexpr bool is_regular_invocable(F, Args&&...) {
+template <class F, class... Args>
+__host__ __device__ constexpr bool is_regular_invocable(F, Args&&...)
+{
   return regular_invocable<F, Args...>;
 }
 #endif // TEST_STD_VER > 2017
@@ -476,4 +461,7 @@ int i = 0;
 static_assert(is_regular_invocable([](int&) {}, i), "");
 #endif // TEST_STD_VER > 2014
 
-int main(int, char**) { return 0; }
+int main(int, char**)
+{
+  return 0;
+}
