@@ -12,22 +12,23 @@
 // template<class T>
 // concept swappable = // see below
 
+#include "type_classification/swappable.h"
 
 #include <cuda/std/cassert>
 #include <cuda/std/concepts>
 
 #include "test_macros.h"
 #include "type_classification/moveconstructible.h"
-#include "type_classification/swappable.h"
 
 #ifdef TEST_COMPILER_MSVC_2017
-#pragma warning(disable: 4239)
+#  pragma warning(disable : 4239)
 #endif // TEST_COMPILER_MSVC_2017
 
 using cuda::std::swappable;
 
 template <class T>
-struct expected {
+struct expected
+{
   T x;
   T y;
 };
@@ -72,7 +73,8 @@ __host__ __device__ constexpr bool check_swap_23(T x, T y) {
   return x == e.x && y == e.y;
 }
 // clang-format on
-__host__ __device__ constexpr bool check_lvalue_adl_swappable() {
+__host__ __device__ constexpr bool check_lvalue_adl_swappable()
+{
   auto x = lvalue_adl_swappable(0);
   auto y = lvalue_adl_swappable(1);
   ASSERT_NOEXCEPT(cuda::std::ranges::swap(x, y));
@@ -80,7 +82,8 @@ __host__ __device__ constexpr bool check_lvalue_adl_swappable() {
   return true;
 }
 
-__host__ __device__ constexpr bool check_rvalue_adl_swappable() {
+__host__ __device__ constexpr bool check_rvalue_adl_swappable()
+{
   ASSERT_NOEXCEPT(cuda::std::ranges::swap(rvalue_adl_swappable(0), rvalue_adl_swappable(1)));
 #if (!defined(TEST_COMPILER_GCC) || __GNUC__ >= 10)
   assert(check_swap_21(rvalue_adl_swappable(0), rvalue_adl_swappable(1)));
@@ -88,32 +91,35 @@ __host__ __device__ constexpr bool check_rvalue_adl_swappable() {
   return true;
 }
 
-__host__ __device__ constexpr bool check_lvalue_rvalue_adl_swappable() {
+__host__ __device__ constexpr bool check_lvalue_rvalue_adl_swappable()
+{
   auto x = lvalue_rvalue_adl_swappable(0);
   ASSERT_NOEXCEPT(cuda::std::ranges::swap(x, lvalue_rvalue_adl_swappable(1)));
   assert(check_swap_21(x, lvalue_rvalue_adl_swappable(1)));
   return true;
 }
 
-__host__ __device__ constexpr bool check_rvalue_lvalue_adl_swappable() {
+__host__ __device__ constexpr bool check_rvalue_lvalue_adl_swappable()
+{
   auto x = rvalue_lvalue_adl_swappable(0);
   ASSERT_NOEXCEPT(cuda::std::ranges::swap(rvalue_lvalue_adl_swappable(1), x));
   assert(check_swap_21(rvalue_lvalue_adl_swappable(1), x));
   return true;
 }
 
-__host__ __device__ constexpr bool check_throwable_swappable() {
+__host__ __device__ constexpr bool check_throwable_swappable()
+{
   auto x = throwable_adl_swappable{0};
   auto y = throwable_adl_swappable{1};
-#if !defined(TEST_COMPILER_BROKEN_SMF_NOEXCEPT) \
- && !defined(TEST_COMPILER_MSVC_2017)
+#if !defined(TEST_COMPILER_BROKEN_SMF_NOEXCEPT) && !defined(TEST_COMPILER_MSVC_2017)
   ASSERT_NOT_NOEXCEPT(cuda::std::ranges::swap(x, y));
 #endif // !TEST_COMPILER_BROKEN_SMF_NOEXCEPT && !TEST_COMPILER_MSVC_2017
   assert(check_swap_21(x, y));
   return true;
 }
 
-__host__ __device__ constexpr bool check_non_move_constructible_adl_swappable() {
+__host__ __device__ constexpr bool check_non_move_constructible_adl_swappable()
+{
   auto x = non_move_constructible_adl_swappable{0};
   auto y = non_move_constructible_adl_swappable{1};
   ASSERT_NOEXCEPT(cuda::std::ranges::swap(x, y));
@@ -122,30 +128,40 @@ __host__ __device__ constexpr bool check_non_move_constructible_adl_swappable()
 }
 
 #if TEST_STD_VER > 2014
-#ifndef TEST_COMPILER_MSVC_2017
-__host__ __device__ constexpr bool check_non_move_assignable_adl_swappable() {
+#  ifndef TEST_COMPILER_MSVC_2017
+__host__ __device__ constexpr bool check_non_move_assignable_adl_swappable()
+{
   auto x = non_move_assignable_adl_swappable{0};
   auto y = non_move_assignable_adl_swappable{1};
   ASSERT_NOEXCEPT(cuda::std::ranges::swap(x, y));
   assert(check_swap_21(x, y));
   return true;
 }
-#endif // !TEST_COMPILER_MSVC_2017
+#  endif // !TEST_COMPILER_MSVC_2017
 #endif // TEST_STD_VER > 2014
 
-namespace swappable_namespace {
-enum unscoped { hello, world };
+namespace swappable_namespace
+{
+enum unscoped
+{
+  hello,
+  world
+};
 __host__ __device__ void swap(unscoped&, unscoped&);
 
-enum class scoped { hello, world };
-__host__ __device__
-void swap(scoped&, scoped&);
+enum class scoped
+{
+  hello,
+  world
+};
+__host__ __device__ void swap(scoped&, scoped&);
 } // namespace swappable_namespace
 
 static_assert(swappable<swappable_namespace::unscoped>, "");
 static_assert(swappable<swappable_namespace::scoped>, "");
 
-__host__ __device__ constexpr bool check_swap_arrays() {
+__host__ __device__ constexpr bool check_swap_arrays()
+{
   int x[] = {0, 1, 2, 3, 4};
   int y[] = {5, 6, 7, 8, 9};
   ASSERT_NOEXCEPT(cuda::std::ranges::swap(x, y));
@@ -153,7 +169,8 @@ __host__ __device__ constexpr bool check_swap_arrays() {
   return true;
 }
 
-__host__ __device__ constexpr bool check_lvalue_adl_swappable_arrays() {
+__host__ __device__ constexpr bool check_lvalue_adl_swappable_arrays()
+{
   lvalue_adl_swappable x[] = {{0}, {1}, {2}, {3}};
   lvalue_adl_swappable y[] = {{4}, {5}, {6}, {7}};
   ASSERT_NOEXCEPT(cuda::std::ranges::swap(x, y));
@@ -161,11 +178,11 @@ __host__ __device__ constexpr bool check_lvalue_adl_swappable_arrays() {
   return true;
 }
 
-__host__ __device__ constexpr bool check_throwable_adl_swappable_arrays() {
+__host__ __device__ constexpr bool check_throwable_adl_swappable_arrays()
+{
   throwable_adl_swappable x[] = {{0}, {1}, {2}, {3}};
   throwable_adl_swappable y[] = {{4}, {5}, {6}, {7}};
-#if !defined(TEST_COMPILER_BROKEN_SMF_NOEXCEPT) \
- && !defined(TEST_COMPILER_MSVC_2017)
+#if !defined(TEST_COMPILER_BROKEN_SMF_NOEXCEPT) && !defined(TEST_COMPILER_MSVC_2017)
   ASSERT_NOT_NOEXCEPT(cuda::std::ranges::swap(x, y));
 #endif // !TEST_COMPILER_BROKEN_SMF_NOEXCEPT && !TEST_COMPILER_MSVC_2017
   assert(check_swap_22(x, y));
@@ -178,7 +195,8 @@ static_assert(check_swap_23(0, 0), "");
 static_assert(check_swap_23(0, 1), "");
 static_assert(check_swap_23(1, 0), "");
 
-__host__ __device__ constexpr bool check_swappable_references() {
+__host__ __device__ constexpr bool check_swappable_references()
+{
   int x = 42;
   int y = 64;
   ASSERT_NOEXCEPT(cuda::std::ranges::swap(x, y));
@@ -186,14 +204,17 @@ __host__ __device__ constexpr bool check_swappable_references() {
   return true;
 }
 
-__host__ __device__ constexpr bool check_swappable_pointers() {
+__host__ __device__ constexpr bool check_swappable_pointers()
+{
   char const* x = "hello";
   ASSERT_NOEXCEPT(cuda::std::ranges::swap(x, x));
   assert(check_swap_23(x, {}));
   return true;
 }
-namespace union_swap {
-union adl_swappable {
+namespace union_swap
+{
+union adl_swappable
+{
   int x;
   double y;
 };
@@ -239,7 +260,8 @@ static_assert(cuda::std::assignable_from<swap_type&, swap_type const&>, "");
 static_assert(cuda::std::assignable_from<swap_type&, swap_type const>, "");
 static_assert(swappable<swap_type>, "");
 
-int main(int, char**) {
+int main(int, char**)
+{
   assert(check_lvalue_adl_swappable());
 #if (!defined(__GNUC__) || __GNUC__ >= 10)
   assert(check_rvalue_adl_swappable());
@@ -249,9 +271,9 @@ int main(int, char**) {
   assert(check_throwable_swappable());
   assert(check_non_move_constructible_adl_swappable());
 #if TEST_STD_VER > 2014
-#ifndef TEST_COMPILER_MSVC_2017
+#  ifndef TEST_COMPILER_MSVC_2017
   assert(check_non_move_assignable_adl_swappable());
-#endif // TEST_COMPILER_MSVC_2017
+#  endif // TEST_COMPILER_MSVC_2017
 #endif // TEST_STD_VER > 2014
   assert(check_swap_arrays());
   assert(check_lvalue_adl_swappable_arrays());
@@ -266,11 +288,11 @@ int main(int, char**) {
   static_assert(check_rvalue_lvalue_adl_swappable(), "");
   static_assert(check_throwable_swappable(), "");
   static_assert(check_non_move_constructible_adl_swappable(), "");
-#if TEST_STD_VER > 2014
-#ifndef TEST_COMPILER_MSVC_2017
+#  if TEST_STD_VER > 2014
+#    ifndef TEST_COMPILER_MSVC_2017
   static_assert(check_non_move_assignable_adl_swappable(), "");
-#endif // TEST_COMPILER_MSVC_2017
-#endif // TEST_STD_VER > 2014
+#    endif // TEST_COMPILER_MSVC_2017
+#  endif // TEST_STD_VER > 2014
   static_assert(check_swap_arrays(), "");
   static_assert(check_lvalue_adl_swappable_arrays(), "");
   static_assert(check_throwable_adl_swappable_arrays(), "");
