@@ -12,13 +12,12 @@
 // template<class T>
 // concept regular = see below;
 
-
 #include <cuda/std/concepts>
 #include <cuda/std/type_traits>
 
+#include "test_macros.h"
 #include "type_classification/moveconstructible.h"
 #include "type_classification/semiregular.h"
-#include "test_macros.h"
 
 using cuda::std::regular;
 
@@ -34,7 +33,8 @@ static_assert(regular<int volatile*>, "");
 static_assert(regular<int volatile const*>, "");
 static_assert(regular<int (*)()>, "");
 
-struct S {};
+struct S
+{};
 static_assert(!regular<S>, "");
 static_assert(regular<int S::*>, "");
 static_assert(regular<int (S::*)()>, "");
@@ -42,27 +42,28 @@ static_assert(regular<int (S::*)() noexcept>, "");
 static_assert(regular<int (S::*)() &>, "");
 static_assert(regular<int (S::*)() & noexcept>, "");
 static_assert(regular<int (S::*)() &&>, "");
-static_assert(regular<int (S::*)() && noexcept>, "");
+static_assert(regular < int(S::*)() && noexcept >, "");
 static_assert(regular<int (S::*)() const>, "");
 static_assert(regular<int (S::*)() const noexcept>, "");
 static_assert(regular<int (S::*)() const&>, "");
 static_assert(regular<int (S::*)() const & noexcept>, "");
 static_assert(regular<int (S::*)() const&&>, "");
-static_assert(regular<int (S::*)() const && noexcept>, "");
+static_assert(regular < int(S::*)() const&& noexcept >, "");
 static_assert(regular<int (S::*)() volatile>, "");
 static_assert(regular<int (S::*)() volatile noexcept>, "");
 static_assert(regular<int (S::*)() volatile&>, "");
 static_assert(regular<int (S::*)() volatile & noexcept>, "");
 static_assert(regular<int (S::*)() volatile&&>, "");
-static_assert(regular<int (S::*)() volatile && noexcept>, "");
+static_assert(regular < int(S::*)() volatile&& noexcept >, "");
 static_assert(regular<int (S::*)() const volatile>, "");
 static_assert(regular<int (S::*)() const volatile noexcept>, "");
 static_assert(regular<int (S::*)() const volatile&>, "");
 static_assert(regular<int (S::*)() const volatile & noexcept>, "");
 static_assert(regular<int (S::*)() const volatile&&>, "");
-static_assert(regular<int (S::*)() const volatile && noexcept>, "");
+static_assert(regular < int(S::*)() const volatile&& noexcept >, "");
 
-union U {};
+union U
+{};
 static_assert(!regular<U>, "");
 static_assert(regular<int U::*>, "");
 static_assert(regular<int (U::*)()>, "");
@@ -70,25 +71,25 @@ static_assert(regular<int (U::*)() noexcept>, "");
 static_assert(regular<int (U::*)() &>, "");
 static_assert(regular<int (U::*)() & noexcept>, "");
 static_assert(regular<int (U::*)() &&>, "");
-static_assert(regular<int (U::*)() && noexcept>, "");
+static_assert(regular < int(U::*)() && noexcept >, "");
 static_assert(regular<int (U::*)() const>, "");
 static_assert(regular<int (U::*)() const noexcept>, "");
 static_assert(regular<int (U::*)() const&>, "");
 static_assert(regular<int (U::*)() const & noexcept>, "");
 static_assert(regular<int (U::*)() const&&>, "");
-static_assert(regular<int (U::*)() const && noexcept>, "");
+static_assert(regular < int(U::*)() const&& noexcept >, "");
 static_assert(regular<int (U::*)() volatile>, "");
 static_assert(regular<int (U::*)() volatile noexcept>, "");
 static_assert(regular<int (U::*)() volatile&>, "");
 static_assert(regular<int (U::*)() volatile & noexcept>, "");
 static_assert(regular<int (U::*)() volatile&&>, "");
-static_assert(regular<int (U::*)() volatile && noexcept>, "");
+static_assert(regular < int(U::*)() volatile&& noexcept >, "");
 static_assert(regular<int (U::*)() const volatile>, "");
 static_assert(regular<int (U::*)() const volatile noexcept>, "");
 static_assert(regular<int (U::*)() const volatile&>, "");
 static_assert(regular<int (U::*)() const volatile & noexcept>, "");
 static_assert(regular<int (U::*)() const volatile&&>, "");
-static_assert(regular<int (U::*)() const volatile && noexcept>, "");
+static_assert(regular < int(U::*)() const volatile&& noexcept >, "");
 
 static_assert(!regular<has_volatile_member>, "");
 static_assert(!regular<has_array_member>, "");
@@ -129,8 +130,7 @@ static_assert(!regular<deleted_assignment_from_const_rvalue>, "");
 static_assert(!regular<no_copy_constructor>, "");
 static_assert(!regular<no_copy_assignment>, "");
 #if !defined(TEST_COMPILER_MSVC) || TEST_STD_VER > 2017 // MSVC chokes on multiple definitions of SMF
-static_assert(cuda::std::is_copy_assignable_v<no_copy_assignment_mutable> &&
-              !regular<no_copy_assignment_mutable>, "");
+static_assert(cuda::std::is_copy_assignable_v<no_copy_assignment_mutable> && !regular<no_copy_assignment_mutable>, "");
 #endif // !defined(TEST_COMPILER_MSVC) || TEST_STD_VER > 2017
 static_assert(!regular<derived_from_noncopyable>, "");
 static_assert(!regular<has_noncopyable>, "");
@@ -142,10 +142,20 @@ static_assert(!regular<has_non_default_initializable>, "");
 static_assert(!regular<const_copy_assignment const>, "");
 static_assert(!regular<cv_copy_assignment const volatile>, "");
 
-struct is_equality_comparable {
-  __host__ __device__ bool operator==(is_equality_comparable const&) const { return true; }
-  __host__ __device__ bool operator!=(is_equality_comparable const&) const { return false; }
+struct is_equality_comparable
+{
+  __host__ __device__ bool operator==(is_equality_comparable const&) const
+  {
+    return true;
+  }
+  __host__ __device__ bool operator!=(is_equality_comparable const&) const
+  {
+    return false;
+  }
 };
 static_assert(regular<is_equality_comparable>, "");
 
-int main(int, char**) { return 0; }
+int main(int, char**)
+{
+  return 0;
+}
