@@ -15,7 +15,6 @@
 //
 //  Requires: (is_same_v<T, U> && ...) is true. Otherwise the program is ill-formed.
 
-
 #include <cuda/std/array>
 #include <cuda/std/cassert>
 #include <cuda/std/cstddef>
@@ -24,9 +23,10 @@
 
 int main(int, char**)
 {
-    {
-    cuda::std::array arr{1,2,3L}; // expected-error {{no viable constructor or deduction guide for deduction of template arguments of 'array'}}
-    }
+  {
+    cuda::std::array arr{1, 2, 3L}; // expected-error {{no viable constructor or deduction guide for deduction of
+                                    // template arguments of 'array'}}
+  }
 
   return 0;
 }
