@@ -16,15 +16,15 @@
 // bool operator>(array<T, N> const&, array<T, N> const&);
 // bool operator>=(array<T, N> const&, array<T, N> const&);
 
-
 #include <cuda/std/array>
-#include <cuda/std/vector>
 #include <cuda/std/cassert>
+#include <cuda/std/vector>
 
 #include "test_macros.h"
 
 template <class Array>
-void test_compare(const Array& LHS, const Array& RHS) {
+void test_compare(const Array& LHS, const Array& RHS)
+{
   typedef cuda::std::vector<typename Array::value_type> Vector;
   const Vector LHSV(LHS.begin(), LHS.end());
   const Vector RHSV(RHS.begin(), RHS.end());
@@ -36,7 +36,9 @@ void test_compare(const Array& LHS, const Array& RHS) {
   assert((LHS >= RHS) == (LHSV >= RHSV));
 }
 
-template <int Dummy> struct NoCompare {};
+template <int Dummy>
+struct NoCompare
+{};
 
 int main(int, char**)
 {
@@ -45,24 +47,24 @@ int main(int, char**)
     typedef cuda::std::array<T, 3> C;
     C c1 = {{}};
     // expected-error@*:* 2 {{invalid operands to binary expression}}
-    TEST_IGNORE_NODISCARD (c1 == c1);
-    TEST_IGNORE_NODISCARD (c1 < c1);
+    TEST_IGNORE_NODISCARD(c1 == c1);
+    TEST_IGNORE_NODISCARD(c1 < c1);
   }
   {
     typedef NoCompare<1> T;
     typedef cuda::std::array<T, 3> C;
     C c1 = {{}};
     // expected-error@*:* 2 {{invalid operands to binary expression}}
-    TEST_IGNORE_NODISCARD (c1 != c1);
-    TEST_IGNORE_NODISCARD (c1 > c1);
+    TEST_IGNORE_NODISCARD(c1 != c1);
+    TEST_IGNORE_NODISCARD(c1 > c1);
   }
   {
     typedef NoCompare<2> T;
     typedef cuda::std::array<T, 0> C;
     C c1 = {{}};
     // expected-error@*:* 2 {{invalid operands to binary expression}}
-    TEST_IGNORE_NODISCARD (c1 == c1);
-    TEST_IGNORE_NODISCARD (c1 < c1);
+    TEST_IGNORE_NODISCARD(c1 == c1);
+    TEST_IGNORE_NODISCARD(c1 < c1);
   }
 
   return 0;
