@@ -20,9 +20,10 @@
 
 #include <cuda/std/array>
 
-void f() {
-    cuda::std::array<int, 1> c;
-    c.empty(); // expected-warning {{ignoring return value of function declared with 'nodiscard' attribute}}
-    cuda::std::array<int, 0> c0;
-    c0.empty(); // expected-warning {{ignoring return value of function declared with 'nodiscard' attribute}}
+void f()
+{
+  cuda::std::array<int, 1> c;
+  c.empty(); // expected-warning {{ignoring return value of function declared with 'nodiscard' attribute}}
+  cuda::std::array<int, 0> c0;
+  c0.empty(); // expected-warning {{ignoring return value of function declared with 'nodiscard' attribute}}
 }
