@@ -14,25 +14,33 @@
 #include "test_macros.h"
 
 struct Incomplete;
-template<class T> struct Holder { T t; };
-
-template<class>
-struct Intable {
-    __host__ __device__
-    operator int() const { return 1; }
+template <class T>
+struct Holder
+{
+  T t;
 };
 
-int main(int, char**) {
-    Holder<Incomplete> *a[2] = {};
-    Holder<Incomplete> **p = a;
-#if TEST_STD_VER > 2011
-    p = cuda::std::next(p);
-    p = cuda::std::prev(p);
-    p = cuda::std::next(p, 2);
-    p = cuda::std::prev(p, 2);
-#endif
-    cuda::std::advance(p, Intable<Holder<Incomplete> >());
-    (void)cuda::std::distance(p, p);
+template <class>
+struct Intable
+{
+  __host__ __device__ operator int() const
+  {
+    return 1;
+  }
+};
 
-    return 0;
+int main(int, char**)
+{
+  Holder<Incomplete>* a[2] = {};
+  Holder<Incomplete>** p   = a;
+#if TEST_STD_VER > 2011
+  p = cuda::std::next(p);
+  p = cuda::std::prev(p);
+  p = cuda::std::next(p, 2);
+  p = cuda::std::prev(p, 2);
+#endif
+  cuda::std::advance(p, Intable<Holder<Incomplete>>());
+  (void) cuda::std::distance(p, p);
+
+  return 0;
 }
