@@ -25,24 +25,23 @@
 #include "test_macros.h"
 
 #if defined(TEST_COMPILER_MSVC)
-#pragma warning(disable: 4324) // structure was padded due to alignment specifier
+#  pragma warning(disable : 4324) // structure was padded due to alignment specifier
 #endif // TEST_COMPILER_MSVC
 
 #if !defined(TEST_COMPILER_NVRTC)
-#define THRUST_IGNORE_DEPRECATED_CPP_DIALECT
-#include <thrust/iterator/counting_iterator.h>
-#include <vector>
+#  include <vector>
 #endif // !TEST_COMPILER_NVRTC
 
-struct A {};
+struct A
+{};
 
 struct test_iterator
 {
-    typedef int                       difference_type;
-    typedef A                         value_type;
-    typedef A*                        pointer;
-    typedef A&                        reference;
-    typedef cuda::std::forward_iterator_tag iterator_category;
+  typedef int difference_type;
+  typedef A value_type;
+  typedef A* pointer;
+  typedef A& reference;
+  typedef cuda::std::forward_iterator_tag iterator_category;
 };
 
 int main(int, char**)
@@ -57,21 +56,6 @@ int main(int, char**)
   }
 
 #if !defined(TEST_COMPILER_NVRTC)
-  { // thrust iterator
-    typedef cuda::std::iterator_traits<thrust::counting_iterator<int>> It;
-    using category = thrust::detail::iterator_category_with_system_and_traversal<std::random_access_iterator_tag,
-                                                                                 thrust::any_system_tag,
-                                                                                 thrust::random_access_traversal_tag>;
-
-    static_assert(cuda::std::is_same<It::difference_type, ptrdiff_t>::value, "");
-    static_assert(cuda::std::is_same<It::value_type, int>::value, "");
-    static_assert(cuda::std::is_same<It::pointer, void>::value, "");
-    static_assert(cuda::std::is_same<It::reference, signed int>::value, "");
-    static_assert(cuda::std::is_same<It::iterator_category, category>::value, "");
-
-    static_assert(cuda::std::__is_cpp17_random_access_iterator<thrust::counting_iterator<int>>::value, "");
-  }
-
   { // std::vector
     typedef cuda::std::iterator_traits<typename std::vector<int>::iterator> It;
     static_assert((cuda::std::is_same<It::difference_type, std::ptrdiff_t>::value), "");
