@@ -13,19 +13,21 @@
 // ranges::prev
 // Make sure we're SFINAE-friendly when the template argument constraints are not met.
 
-#include <cuda/std/iterator>
-
 #include <cuda/std/cstddef>
+#include <cuda/std/iterator>
 #include <cuda/std/utility>
+
 #include "test_iterators.h"
 
 #if TEST_STD_VER > 2017
-template <class ...Args>
-concept has_ranges_prev = requires (Args&& ...args) {
-  { cuda::std::ranges::prev(cuda::std::forward<Args>(args)...) };
+template <class... Args>
+concept has_ranges_prev = requires(Args&&... args) {
+  {
+    cuda::std::ranges::prev(cuda::std::forward<Args>(args)...)
+  };
 };
 #else
-template <class ...Args>
+template <class... Args>
 constexpr bool has_ranges_prev = cuda::std::invocable<cuda::std::ranges::__prev::__fn, Args...>;
 #endif
 
@@ -40,6 +42,7 @@ static_assert(has_ranges_prev<It2>);
 static_assert(has_ranges_prev<It2, cuda::std::ptrdiff_t>);
 static_assert(has_ranges_prev<It2, cuda::std::ptrdiff_t, It2>);
 
-int main(int, char**) {
+int main(int, char**)
+{
   return 0;
-}
\ No newline at end of file
+}
