@@ -13,7 +13,6 @@
 
 // UNSUPPORTED: c++03, c++11, c++14
 
-
 #include <cuda/std/iterator>
 #include <cuda/std/type_traits>
 
@@ -21,12 +20,11 @@
 
 int main(int, char**)
 {
-    cuda::std::contiguous_iterator_tag tag;
-    ((void)tag); // Prevent unused warning
-    static_assert((cuda::std::is_base_of<cuda::std::random_access_iterator_tag,
-                                   cuda::std::contiguous_iterator_tag>::value));
-    static_assert((!cuda::std::is_base_of<cuda::std::output_iterator_tag,
-                                    cuda::std::contiguous_iterator_tag>::value));
+  cuda::std::contiguous_iterator_tag tag;
+  ((void) tag); // Prevent unused warning
+  static_assert(
+    (cuda::std::is_base_of<cuda::std::random_access_iterator_tag, cuda::std::contiguous_iterator_tag>::value));
+  static_assert((!cuda::std::is_base_of<cuda::std::output_iterator_tag, cuda::std::contiguous_iterator_tag>::value));
 
   return 0;
 }
