@@ -18,12 +18,10 @@
 
 int main(int, char**)
 {
-    cuda::std::forward_iterator_tag tag;
-    ((void)tag); // Prevent unused warning
-    static_assert((cuda::std::is_base_of<cuda::std::input_iterator_tag,
-                                   cuda::std::forward_iterator_tag>::value), "");
-    static_assert((!cuda::std::is_base_of<cuda::std::output_iterator_tag,
-                                    cuda::std::forward_iterator_tag>::value), "");
+  cuda::std::forward_iterator_tag tag;
+  ((void) tag); // Prevent unused warning
+  static_assert((cuda::std::is_base_of<cuda::std::input_iterator_tag, cuda::std::forward_iterator_tag>::value), "");
+  static_assert((!cuda::std::is_base_of<cuda::std::output_iterator_tag, cuda::std::forward_iterator_tag>::value), "");
 
   return 0;
 }
