@@ -18,10 +18,9 @@
 
 int main(int, char**)
 {
-    cuda::std::input_iterator_tag tag;
-    ((void)tag); // Prevent unused warning
-    static_assert((!cuda::std::is_base_of<cuda::std::output_iterator_tag,
-                                    cuda::std::input_iterator_tag>::value), "");
+  cuda::std::input_iterator_tag tag;
+  ((void) tag); // Prevent unused warning
+  static_assert((!cuda::std::is_base_of<cuda::std::output_iterator_tag, cuda::std::input_iterator_tag>::value), "");
 
   return 0;
 }
