@@ -11,10 +11,9 @@
 
 // projected
 
-#include <cuda/std/iterator>
-
 #include <cuda/std/concepts>
 #include <cuda/std/functional>
+#include <cuda/std/iterator>
 
 #include "test_iterators.h"
 
@@ -23,7 +22,8 @@ static_assert(cuda::std::same_as<IntPtr::value_type, int>);
 static_assert(cuda::std::same_as<decltype(*cuda::std::declval<IntPtr>()), int const&>);
 static_assert(cuda::std::same_as<cuda::std::iter_difference_t<IntPtr>, cuda::std::ptrdiff_t>);
 
-struct S { };
+struct S
+{};
 
 using Cpp17InputIterator = cuda::std::projected<cpp17_input_iterator<S*>, int S::*>;
 static_assert(cuda::std::same_as<Cpp17InputIterator::value_type, int>);
@@ -40,40 +40,37 @@ static_assert(cuda::std::same_as<ForwardIterator::value_type, int>);
 static_assert(cuda::std::same_as<decltype(*cuda::std::declval<ForwardIterator>()), int>);
 static_assert(cuda::std::same_as<cuda::std::iter_difference_t<ForwardIterator>, cuda::std::ptrdiff_t>);
 
-using BidirectionalIterator = cuda::std::projected<bidirectional_iterator<S*>, S* (S::*)() const>;
+using BidirectionalIterator = cuda::std::projected<bidirectional_iterator<S*>, S* (S::*) () const>;
 static_assert(cuda::std::same_as<BidirectionalIterator::value_type, S*>);
 static_assert(cuda::std::same_as<decltype(*cuda::std::declval<BidirectionalIterator>()), S*>);
 static_assert(cuda::std::same_as<cuda::std::iter_difference_t<BidirectionalIterator>, cuda::std::ptrdiff_t>);
 
-using RandomAccessIterator = cuda::std::projected<random_access_iterator<S*>, S && (S::*)()>;
+using RandomAccessIterator = cuda::std::projected<random_access_iterator<S*>, S && (S::*) ()>;
 static_assert(cuda::std::same_as<RandomAccessIterator::value_type, S>);
 static_assert(cuda::std::same_as<decltype(*cuda::std::declval<RandomAccessIterator>()), S&&>);
 static_assert(cuda::std::same_as<cuda::std::iter_difference_t<RandomAccessIterator>, cuda::std::ptrdiff_t>);
 
-using ContiguousIterator = cuda::std::projected<contiguous_iterator<S*>, S& (S::*)() const>;
+using ContiguousIterator = cuda::std::projected<contiguous_iterator<S*>, S& (S::*) () const>;
 static_assert(cuda::std::same_as<ContiguousIterator::value_type, S>);
 static_assert(cuda::std::same_as<decltype(*cuda::std::declval<ContiguousIterator>()), S&>);
 static_assert(cuda::std::same_as<cuda::std::iter_difference_t<ContiguousIterator>, cuda::std::ptrdiff_t>);
 
 #if TEST_STD_VER > 2017
 template <class I, class F>
-constexpr bool projectable = requires {
-  typename cuda::std::projected<I, F>;
-};
+constexpr bool projectable = requires { typename cuda::std::projected<I, F>; };
 #else
 template <class I, class F>
-_LIBCUDACXX_CONCEPT_FRAGMENT(
-  projectable_,
-  requires() //
-  (typename(cuda::std::projected<I, F>)));
+_LIBCUDACXX_CONCEPT_FRAGMENT(projectable_,
+                             requires() //
+                             (typename(cuda::std::projected<I, F>)));
 
 template <class I, class F>
 _LIBCUDACXX_CONCEPT projectable = _LIBCUDACXX_FRAGMENT(projectable_, I, F);
 #endif
 
 static_assert(!projectable<int, void (*)(int)>); // int isn't indirectly_readable
-static_assert(!projectable<S, void (*)(int)>);   // S isn't weakly_incrementable
-static_assert(!projectable<int*, void(int)>);    // void(int) doesn't satisfy indirectly_regular_unary_invcable
+static_assert(!projectable<S, void (*)(int)>); // S isn't weakly_incrementable
+static_assert(!projectable<int*, void(int)>); // void(int) doesn't satisfy indirectly_regular_unary_invcable
 
 int main(int, char**)
 {
