@@ -12,28 +12,27 @@
 // template<class T>
 // concept bidirectional_iterator;
 
-#include <cuda/std/iterator>
-
 #include <cuda/std/concepts>
+#include <cuda/std/iterator>
 
 #include "test_iterators.h"
 
-static_assert(!cuda::std::bidirectional_iterator<cpp17_input_iterator<int*> >);
-static_assert(!cuda::std::bidirectional_iterator<cpp20_input_iterator<int*> >);
-static_assert(!cuda::std::bidirectional_iterator<forward_iterator<int*> >);
-static_assert(cuda::std::bidirectional_iterator<bidirectional_iterator<int*> >);
-static_assert(cuda::std::bidirectional_iterator<random_access_iterator<int*> >);
-static_assert(cuda::std::bidirectional_iterator<contiguous_iterator<int*> >);
-
+static_assert(!cuda::std::bidirectional_iterator<cpp17_input_iterator<int*>>);
+static_assert(!cuda::std::bidirectional_iterator<cpp20_input_iterator<int*>>);
+static_assert(!cuda::std::bidirectional_iterator<forward_iterator<int*>>);
+static_assert(cuda::std::bidirectional_iterator<bidirectional_iterator<int*>>);
+static_assert(cuda::std::bidirectional_iterator<random_access_iterator<int*>>);
+static_assert(cuda::std::bidirectional_iterator<contiguous_iterator<int*>>);
 
 static_assert(cuda::std::bidirectional_iterator<int*>);
 static_assert(cuda::std::bidirectional_iterator<int const*>);
 static_assert(cuda::std::bidirectional_iterator<int volatile*>);
 static_assert(cuda::std::bidirectional_iterator<int const volatile*>);
 
-struct not_forward_iterator {
-  using value_type = int;
-  using difference_type = cuda::std::ptrdiff_t;
+struct not_forward_iterator
+{
+  using value_type       = int;
+  using difference_type  = cuda::std::ptrdiff_t;
   using iterator_concept = cuda::std::bidirectional_iterator_tag;
 
   __host__ __device__ value_type operator*() const;
@@ -44,12 +43,13 @@ struct not_forward_iterator {
   __host__ __device__ not_forward_iterator& operator--();
   __host__ __device__ not_forward_iterator& operator--(int);
 };
-static_assert(cuda::std::input_iterator<not_forward_iterator> && !cuda::std::forward_iterator<not_forward_iterator> &&
-              !cuda::std::bidirectional_iterator<not_forward_iterator>);
+static_assert(cuda::std::input_iterator<not_forward_iterator> && !cuda::std::forward_iterator<not_forward_iterator>
+              && !cuda::std::bidirectional_iterator<not_forward_iterator>);
 
-struct wrong_iterator_category {
-  using value_type = int;
-  using difference_type = cuda::std::ptrdiff_t;
+struct wrong_iterator_category
+{
+  using value_type        = int;
+  using difference_type   = cuda::std::ptrdiff_t;
   using iterator_category = cuda::std::forward_iterator_tag;
 
   __host__ __device__ value_type& operator*() const;
@@ -62,15 +62,22 @@ struct wrong_iterator_category {
 #if TEST_STD_VER > 2017
   bool operator==(wrong_iterator_category const&) const = default;
 #else
-  __host__ __device__ bool operator==(const wrong_iterator_category&) const { return true; };
-  __host__ __device__ bool operator!=(const wrong_iterator_category&) const { return false; };
+  __host__ __device__ bool operator==(const wrong_iterator_category&) const
+  {
+    return true;
+  };
+  __host__ __device__ bool operator!=(const wrong_iterator_category&) const
+  {
+    return false;
+  };
 #endif
 };
 static_assert(!cuda::std::bidirectional_iterator<wrong_iterator_category>);
 
-struct wrong_iterator_concept {
-  using value_type = int;
-  using difference_type = cuda::std::ptrdiff_t;
+struct wrong_iterator_concept
+{
+  using value_type       = int;
+  using difference_type  = cuda::std::ptrdiff_t;
   using iterator_concept = cuda::std::forward_iterator_tag;
 
   __host__ __device__ value_type& operator*() const;
@@ -84,15 +91,22 @@ struct wrong_iterator_concept {
 #if TEST_STD_VER > 2017
   bool operator==(wrong_iterator_concept const&) const = default;
 #else
-  __host__ __device__ bool operator==(const wrong_iterator_concept&) const { return true; };
-  __host__ __device__ bool operator!=(const wrong_iterator_concept&) const { return false; };
+  __host__ __device__ bool operator==(const wrong_iterator_concept&) const
+  {
+    return true;
+  };
+  __host__ __device__ bool operator!=(const wrong_iterator_concept&) const
+  {
+    return false;
+  };
 #endif
 };
 static_assert(!cuda::std::bidirectional_iterator<wrong_iterator_concept>);
 
-struct no_predecrement {
-  using value_type = int;
-  using difference_type = cuda::std::ptrdiff_t;
+struct no_predecrement
+{
+  using value_type       = int;
+  using difference_type  = cuda::std::ptrdiff_t;
   using iterator_concept = cuda::std::bidirectional_iterator_tag;
 
   __host__ __device__ value_type& operator*() const;
@@ -105,15 +119,22 @@ struct no_predecrement {
 #if TEST_STD_VER > 2017
   bool operator==(no_predecrement const&) const = default;
 #else
-  __host__ __device__ bool operator==(const no_predecrement&) const { return true; };
-  __host__ __device__ bool operator!=(const no_predecrement&) const { return false; };
+  __host__ __device__ bool operator==(const no_predecrement&) const
+  {
+    return true;
+  };
+  __host__ __device__ bool operator!=(const no_predecrement&) const
+  {
+    return false;
+  };
 #endif
 };
 static_assert(!cuda::std::bidirectional_iterator<no_predecrement>);
 
-struct bad_predecrement {
-  using value_type = int;
-  using difference_type = cuda::std::ptrdiff_t;
+struct bad_predecrement
+{
+  using value_type       = int;
+  using difference_type  = cuda::std::ptrdiff_t;
   using iterator_concept = cuda::std::bidirectional_iterator_tag;
 
   __host__ __device__ value_type& operator*() const;
@@ -127,15 +148,22 @@ struct bad_predecrement {
 #if TEST_STD_VER > 2017
   bool operator==(bad_predecrement const&) const = default;
 #else
-  __host__ __device__ bool operator==(const bad_predecrement&) const { return true; };
-  __host__ __device__ bool operator!=(const bad_predecrement&) const { return false; };
+  __host__ __device__ bool operator==(const bad_predecrement&) const
+  {
+    return true;
+  };
+  __host__ __device__ bool operator!=(const bad_predecrement&) const
+  {
+    return false;
+  };
 #endif
 };
 static_assert(!cuda::std::bidirectional_iterator<bad_predecrement>);
 
-struct no_postdecrement {
-  using value_type = int;
-  using difference_type = cuda::std::ptrdiff_t;
+struct no_postdecrement
+{
+  using value_type       = int;
+  using difference_type  = cuda::std::ptrdiff_t;
   using iterator_concept = cuda::std::bidirectional_iterator_tag;
 
   __host__ __device__ value_type& operator*() const;
@@ -151,15 +179,22 @@ struct no_postdecrement {
 #if TEST_STD_VER > 2017
   bool operator==(no_postdecrement const&) const = default;
 #else
-  __host__ __device__ bool operator==(const no_postdecrement&) const { return true; };
-  __host__ __device__ bool operator!=(const no_postdecrement&) const { return false; };
+  __host__ __device__ bool operator==(const no_postdecrement&) const
+  {
+    return true;
+  };
+  __host__ __device__ bool operator!=(const no_postdecrement&) const
+  {
+    return false;
+  };
 #endif
 };
 static_assert(!cuda::std::bidirectional_iterator<no_postdecrement>);
 
-struct bad_postdecrement {
-  using value_type = int;
-  using difference_type = cuda::std::ptrdiff_t;
+struct bad_postdecrement
+{
+  using value_type       = int;
+  using difference_type  = cuda::std::ptrdiff_t;
   using iterator_concept = cuda::std::bidirectional_iterator_tag;
 
   __host__ __device__ value_type& operator*() const;
@@ -173,12 +208,19 @@ struct bad_postdecrement {
 #if TEST_STD_VER > 2017
   bool operator==(bad_postdecrement const&) const = default;
 #else
-  __host__ __device__ bool operator==(const bad_postdecrement&) const { return true; };
-  __host__ __device__ bool operator!=(const bad_postdecrement&) const { return false; };
+  __host__ __device__ bool operator==(const bad_postdecrement&) const
+  {
+    return true;
+  };
+  __host__ __device__ bool operator!=(const bad_postdecrement&) const
+  {
+    return false;
+  };
 #endif
 };
 static_assert(!cuda::std::bidirectional_iterator<bad_postdecrement>);
 
-int main(int, char**) {
+int main(int, char**)
+{
   return 0;
 }
