@@ -8,23 +8,24 @@
 //===----------------------------------------------------------------------===//
 
 // UNSUPPORTED: c++03, c++11, c++14, c++17
-// XFAIL: nvrtc || nvcc-12.0 || nvcc-12.1 || nvcc-12.2 || nvcc-12.3
+// XFAIL: nvcc-12.0 || nvcc-12.1 || nvcc-12.2 || nvcc-12.3
 // nvbug 3885350
 
 // template<class T>
 // concept bidirectional_iterator;
 
+#include <cuda/std/concepts>
 #include <cuda/std/iterator>
 
-#include <cuda/std/concepts>
-
-template<cuda::std::forward_iterator I>
-__host__ __device__ constexpr bool check_subsumption() {
+template <cuda::std::forward_iterator I>
+__host__ __device__ constexpr bool check_subsumption()
+{
   return false;
 }
 
-template<cuda::std::bidirectional_iterator>
-__host__ __device__ constexpr bool check_subsumption() {
+template <cuda::std::bidirectional_iterator>
+__host__ __device__ constexpr bool check_subsumption()
+{
   return true;
 }
 
