@@ -11,27 +11,27 @@
 
 // cuda::std::forward_iterator;
 
-#include <cuda/std/iterator>
-
 #include <cuda/std/concepts>
+#include <cuda/std/iterator>
 
 #include "test_iterators.h"
 
-static_assert(!cuda::std::forward_iterator<cpp17_input_iterator<int*> >);
-static_assert(!cuda::std::forward_iterator<cpp20_input_iterator<int*> >);
-static_assert(cuda::std::forward_iterator<forward_iterator<int*> >);
-static_assert(cuda::std::forward_iterator<bidirectional_iterator<int*> >);
-static_assert(cuda::std::forward_iterator<random_access_iterator<int*> >);
-static_assert(cuda::std::forward_iterator<contiguous_iterator<int*> >);
+static_assert(!cuda::std::forward_iterator<cpp17_input_iterator<int*>>);
+static_assert(!cuda::std::forward_iterator<cpp20_input_iterator<int*>>);
+static_assert(cuda::std::forward_iterator<forward_iterator<int*>>);
+static_assert(cuda::std::forward_iterator<bidirectional_iterator<int*>>);
+static_assert(cuda::std::forward_iterator<random_access_iterator<int*>>);
+static_assert(cuda::std::forward_iterator<contiguous_iterator<int*>>);
 
 static_assert(cuda::std::forward_iterator<int*>);
 static_assert(cuda::std::forward_iterator<int const*>);
 static_assert(cuda::std::forward_iterator<int volatile*>);
 static_assert(cuda::std::forward_iterator<int const volatile*>);
 
-struct not_input_iterator {
+struct not_input_iterator
+{
   // using value_type = int;
-  using difference_type = cuda::std::ptrdiff_t;
+  using difference_type  = cuda::std::ptrdiff_t;
   using iterator_concept = cuda::std::forward_iterator_tag;
 
   __host__ __device__ int operator*() const;
@@ -42,17 +42,24 @@ struct not_input_iterator {
 #if TEST_STD_VER > 2017
   bool operator==(not_input_iterator const&) const = default;
 #else
-    __host__ __device__ bool operator==(const not_input_iterator&) const { return true; };
-    __host__ __device__ bool operator!=(const not_input_iterator&) const { return false; };
+  __host__ __device__ bool operator==(const not_input_iterator&) const
+  {
+    return true;
+  };
+  __host__ __device__ bool operator!=(const not_input_iterator&) const
+  {
+    return false;
+  };
 #endif
 };
 static_assert(cuda::std::input_or_output_iterator<not_input_iterator>);
 static_assert(!cuda::std::input_iterator<not_input_iterator>);
 static_assert(!cuda::std::forward_iterator<not_input_iterator>);
 
-struct bad_iterator_tag {
-  using value_type = int;
-  using difference_type = cuda::std::ptrdiff_t;
+struct bad_iterator_tag
+{
+  using value_type       = int;
+  using difference_type  = cuda::std::ptrdiff_t;
   using iterator_concept = cuda::std::input_iterator_tag;
 
   __host__ __device__ int operator*() const;
@@ -63,15 +70,22 @@ struct bad_iterator_tag {
 #if TEST_STD_VER > 2017
   bool operator==(bad_iterator_tag const&) const = default;
 #else
-    __host__ __device__ bool operator==(const bad_iterator_tag&) const { return true; };
-    __host__ __device__ bool operator!=(const bad_iterator_tag&) const { return false; };
+  __host__ __device__ bool operator==(const bad_iterator_tag&) const
+  {
+    return true;
+  };
+  __host__ __device__ bool operator!=(const bad_iterator_tag&) const
+  {
+    return false;
+  };
 #endif
 };
 static_assert(!cuda::std::forward_iterator<bad_iterator_tag>);
 
-struct not_incrementable {
-  using value_type = int;
-  using difference_type = cuda::std::ptrdiff_t;
+struct not_incrementable
+{
+  using value_type       = int;
+  using difference_type  = cuda::std::ptrdiff_t;
   using iterator_concept = cuda::std::forward_iterator_tag;
 
   __host__ __device__ int operator*() const;
@@ -82,15 +96,22 @@ struct not_incrementable {
 #if TEST_STD_VER > 2017
   bool operator==(not_incrementable const&) const = default;
 #else
-    __host__ __device__ bool operator==(const not_incrementable&) const { return true; };
-    __host__ __device__ bool operator!=(const not_incrementable&) const { return false; };
+  __host__ __device__ bool operator==(const not_incrementable&) const
+  {
+    return true;
+  };
+  __host__ __device__ bool operator!=(const not_incrementable&) const
+  {
+    return false;
+  };
 #endif
 };
 static_assert(!cuda::std::forward_iterator<not_incrementable>);
 
-struct not_equality_comparable {
-  using value_type = int;
-  using difference_type = cuda::std::ptrdiff_t;
+struct not_equality_comparable
+{
+  using value_type       = int;
+  using difference_type  = cuda::std::ptrdiff_t;
   using iterator_concept = cuda::std::forward_iterator_tag;
 
   __host__ __device__ int operator*() const;
