@@ -11,43 +11,49 @@
 
 // iter_common_reference_t
 
+#include <cuda/std/concepts>
 #include <cuda/std/iterator>
 
-#include <cuda/std/concepts>
-
-struct X { };
+struct X
+{};
 
 // value_type and dereferencing are the same
-struct T1 {
+struct T1
+{
   using value_type = X;
   __host__ __device__ X operator*() const;
 };
 static_assert(cuda::std::same_as<cuda::std::iter_common_reference_t<T1>, X>);
 
 // value_type and dereferencing are the same (modulo qualifiers)
-struct T2 {
+struct T2
+{
   using value_type = X;
   __host__ __device__ X& operator*() const;
 };
 static_assert(cuda::std::same_as<cuda::std::iter_common_reference_t<T2>, X&>);
 
 // There's a custom common reference between value_type and the type of dereferencing
-struct A { };
-struct B { };
-struct Common {
+struct A
+{};
+struct B
+{};
+struct Common
+{
   __host__ __device__ Common(A);
   __host__ __device__ Common(B);
 };
 template <template <class> class TQual, template <class> class QQual>
-struct cuda::std::basic_common_reference<A, B, TQual, QQual> {
+struct cuda::std::basic_common_reference<A, B, TQual, QQual>
+{
   using type = Common;
 };
 template <template <class> class TQual, template <class> class QQual>
-struct cuda::std::basic_common_reference<B, A, TQual, QQual>
-  : cuda::std::basic_common_reference<A, B, TQual, QQual>
-{ };
+struct cuda::std::basic_common_reference<B, A, TQual, QQual> : cuda::std::basic_common_reference<A, B, TQual, QQual>
+{};
 
-struct T3 {
+struct T3
+{
   using value_type = A;
   __host__ __device__ B&& operator*() const;
 };
@@ -56,20 +62,18 @@ static_assert(cuda::std::same_as<cuda::std::iter_common_reference_t<T3>, Common>
 // Make sure we're SFINAE-friendly
 #if TEST_STD_VER > 2017
 template <class T>
-constexpr bool has_common_reference = requires {
-  typename cuda::std::iter_common_reference_t<T>;
-};
+constexpr bool has_common_reference = requires { typename cuda::std::iter_common_reference_t<T>; };
 #else
 template <class T>
-_LIBCUDACXX_CONCEPT_FRAGMENT(
-  has_common_reference_,
-  requires() //
-  (typename(cuda::std::iter_common_reference_t<T>)));
+_LIBCUDACXX_CONCEPT_FRAGMENT(has_common_reference_,
+                             requires() //
+                             (typename(cuda::std::iter_common_reference_t<T>)));
 
 template <class T>
 _LIBCUDACXX_CONCEPT has_common_reference = _LIBCUDACXX_FRAGMENT(has_common_reference_, T);
 #endif
-struct NotIndirectlyReadable { };
+struct NotIndirectlyReadable
+{};
 static_assert(!has_common_reference<NotIndirectlyReadable>);
 
 int main(int, char**)
