@@ -17,39 +17,42 @@
 
 #include <cuda/std/iterator>
 #if defined(_LIBCUDACXX_HAS_VECTOR)
-#include <cuda/std/vector>
-#include <cuda/std/cassert>
+#  include <cuda/std/cassert>
+#  include <cuda/std/vector>
 
-#include "test_macros.h"
+#  include "test_macros.h"
 
 template <class C>
-__host__ __device__
-void
-test(C c)
+__host__ __device__ void test(C c)
 {
-    const typename C::value_type v = typename C::value_type();
-    cuda::std::back_insert_iterator<C> i(c);
-    i = v;
-    assert(c.back() == v);
+  const typename C::value_type v = typename C::value_type();
+  cuda::std::back_insert_iterator<C> i(c);
+  i = v;
+  assert(c.back() == v);
 }
 
 class Copyable
 {
-    int data_;
-public:
-__host__ __device__
-    Copyable() : data_(0) {}
-__host__ __device__
-    ~Copyable() {data_ = -1;}
+  int data_;
 
-__host__ __device__
-    friend bool operator==(const Copyable& x, const Copyable& y)
-        {return x.data_ == y.data_;}
+public:
+  __host__ __device__ Copyable()
+      : data_(0)
+  {}
+  __host__ __device__ ~Copyable()
+  {
+    data_ = -1;
+  }
+
+  __host__ __device__ friend bool operator==(const Copyable& x, const Copyable& y)
+  {
+    return x.data_ == y.data_;
+  }
 };
 
 int main(int, char**)
 {
-    test(cuda::std::vector<Copyable>());
+  test(cuda::std::vector<Copyable>());
 
   return 0;
 }
@@ -58,4 +61,4 @@ int main(int, char**)
 {
   return 0;
 }
-#endif
\ No newline at end of file
+#endif
