@@ -18,27 +18,25 @@
 
 #include <cuda/std/iterator>
 #if defined(_LIBCUDACXX_HAS_LIST)
-#include <cuda/std/list>
-#include <cuda/std/memory>
+#  include <cuda/std/list>
+#  include <cuda/std/memory>
 #endif
 #include <cuda/std/cassert>
 
 #include "test_macros.h"
 
 template <class C>
-__host__ __device__
-void
-test(C c)
+__host__ __device__ void test(C c)
 {
-    cuda::std::front_insert_iterator<C> i(c);
-    i = typename C::value_type();
-    assert(c.front() == typename C::value_type());
+  cuda::std::front_insert_iterator<C> i(c);
+  i = typename C::value_type();
+  assert(c.front() == typename C::value_type());
 }
 
 int main(int, char**)
 {
 #if defined(_LIBCUDACXX_HAS_LIST)
-    test(cuda::std::list<cuda::std::unique_ptr<int> >());
+  test(cuda::std::list<cuda::std::unique_ptr<int>>());
 #endif
 
   return 0;
