@@ -13,31 +13,29 @@
 
 // front_insert_iterator<Cont>& operator*();
 
-#include <cuda/std/iterator>
-
 #include <cuda/std/cassert>
+#include <cuda/std/iterator>
 #if defined(_LIBCUDACXX_HAS_LIST)
-#include <cuda/std/list>
-#include "nasty_containers.h"
+#  include <cuda/std/list>
+
+#  include "nasty_containers.h"
 #endif // _LIBCUDACXX_HAS_LIST
 
 #include "test_macros.h"
 
 template <class C>
-__host__ __device__
-void
-test(C c)
+__host__ __device__ void test(C c)
 {
-    cuda::std::front_insert_iterator<C> i(c);
-    cuda::std::front_insert_iterator<C>& r = *i;
-    assert(&r == &i);
+  cuda::std::front_insert_iterator<C> i(c);
+  cuda::std::front_insert_iterator<C>& r = *i;
+  assert(&r == &i);
 }
 
 int main(int, char**)
 {
 #if defined(_LIBCUDACXX_HAS_LIST)
-    test(cuda::std::list<int>());
-    test(nasty_list<int>());
+  test(cuda::std::list<int>());
+  test(nasty_list<int>());
 #endif
 
   return 0;
