@@ -16,37 +16,43 @@
 //
 //  constexpr in C++17
 
-#include <cuda/std/iterator>
 #include <cuda/std/cassert>
+#include <cuda/std/iterator>
 
-#include "test_macros.h"
 #include "test_iterators.h"
+#include "test_macros.h"
 
 // move_iterator's operator<= calls the underlying iterator's operator<=
-struct CustomIt {
-  using value_type = int;
-  using difference_type = int;
-  using reference = int&;
-  using pointer = int*;
+struct CustomIt
+{
+  using value_type        = int;
+  using difference_type   = int;
+  using reference         = int&;
+  using pointer           = int*;
   using iterator_category = cuda::std::input_iterator_tag;
-  CustomIt() = default;
-  __host__ __device__ TEST_CONSTEXPR_CXX14 explicit CustomIt(int* p) : p_(p) {}
+  CustomIt()              = default;
+  __host__ __device__ TEST_CONSTEXPR_CXX14 explicit CustomIt(int* p)
+      : p_(p)
+  {}
   __host__ __device__ int& operator*() const;
   __host__ __device__ CustomIt& operator++();
   __host__ __device__ CustomIt operator++(int);
-  __host__ __device__ TEST_CONSTEXPR_CXX14 friend bool operator<=(const CustomIt& a, const CustomIt& b) { return a.p_ <= b.p_; }
-  int *p_ = nullptr;
+  __host__ __device__ TEST_CONSTEXPR_CXX14 friend bool operator<=(const CustomIt& a, const CustomIt& b)
+  {
+    return a.p_ <= b.p_;
+  }
+  int* p_ = nullptr;
 };
 
 template <class It>
 __host__ __device__ TEST_CONSTEXPR_CXX14 void test_one()
 {
-  int a[] = {3, 1, 4};
+  int a[]                               = {3, 1, 4};
   const cuda::std::move_iterator<It> r1 = cuda::std::move_iterator<It>(It(a));
   const cuda::std::move_iterator<It> r2 = cuda::std::move_iterator<It>(It(a + 2));
   ASSERT_SAME_TYPE(decltype(r1 <= r2), bool);
-  assert( (r1 <= r1));
-  assert( (r1 <= r2));
+  assert((r1 <= r1));
+  assert((r1 <= r2));
   assert(!(r2 <= r1));
 }
 
@@ -55,7 +61,7 @@ __host__ __device__ TEST_CONSTEXPR_CXX14 bool test()
   test_one<CustomIt>();
   test_one<int*>();
   test_one<const int*>();
-  test_one<random_access_iterator<int*> >();
+  test_one<random_access_iterator<int*>>();
 #if TEST_STD_VER > 2014
   test_one<contiguous_iterator<int*>>();
 #endif
