@@ -18,38 +18,47 @@
 //
 //  constexpr in C++17
 
-#include <cuda/std/iterator>
 #include <cuda/std/cassert>
+#include <cuda/std/iterator>
 
-#include "test_macros.h"
 #include "test_iterators.h"
+#include "test_macros.h"
 
 // In C++17, move_iterator's operator!= calls the underlying iterator's operator!=
 // In C++20, move_iterator's operator== calls the underlying iterator's operator==
-struct CustomIt {
-  using value_type = int;
-  using difference_type = int;
-  using reference = int&;
-  using pointer = int*;
+struct CustomIt
+{
+  using value_type        = int;
+  using difference_type   = int;
+  using reference         = int&;
+  using pointer           = int*;
   using iterator_category = cuda::std::input_iterator_tag;
-  CustomIt() = default;
-  __host__ __device__ TEST_CONSTEXPR_CXX14 explicit CustomIt(int* p) : p_(p) {}
+  CustomIt()              = default;
+  __host__ __device__ TEST_CONSTEXPR_CXX14 explicit CustomIt(int* p)
+      : p_(p)
+  {}
   __host__ __device__ int& operator*() const;
   __host__ __device__ CustomIt& operator++();
   __host__ __device__ CustomIt operator++(int);
 #if TEST_STD_VER > 2017
-  __host__ __device__ friend constexpr bool operator==(const CustomIt& a, const CustomIt& b) { return a.p_ == b.p_; }
+  __host__ __device__ friend constexpr bool operator==(const CustomIt& a, const CustomIt& b)
+  {
+    return a.p_ == b.p_;
+  }
   __host__ __device__ friend bool operator!=(const CustomIt& a, const CustomIt& b) = delete;
 #else
-  __host__ __device__ friend TEST_CONSTEXPR_CXX14 bool operator!=(const CustomIt& a, const CustomIt& b) { return a.p_ != b.p_; }
+  __host__ __device__ friend TEST_CONSTEXPR_CXX14 bool operator!=(const CustomIt& a, const CustomIt& b)
+  {
+    return a.p_ != b.p_;
+  }
 #endif
-  int *p_ = nullptr;
+  int* p_ = nullptr;
 };
 
 template <class It>
 __host__ __device__ TEST_CONSTEXPR_CXX14 void test_one()
 {
-  int a[] = {3, 1, 4};
+  int a[]                               = {3, 1, 4};
   const cuda::std::move_iterator<It> r1 = cuda::std::move_iterator<It>(It(a));
   const cuda::std::move_iterator<It> r2 = cuda::std::move_iterator<It>(It(a));
   const cuda::std::move_iterator<It> r3 = cuda::std::move_iterator<It>(It(a + 2));
@@ -57,17 +66,17 @@ __host__ __device__ TEST_CONSTEXPR_CXX14 void test_one()
   assert(!(r1 != r1));
   assert(!(r1 != r2));
   assert(!(r2 != r1));
-  assert( (r1 != r3));
-  assert( (r3 != r1));
+  assert((r1 != r3));
+  assert((r3 != r1));
 }
 
 __host__ __device__ TEST_CONSTEXPR_CXX14 bool test()
 {
   test_one<CustomIt>();
-  test_one<cpp17_input_iterator<int*> >();
-  test_one<forward_iterator<int*> >();
-  test_one<bidirectional_iterator<int*> >();
-  test_one<random_access_iterator<int*> >();
+  test_one<cpp17_input_iterator<int*>>();
+  test_one<forward_iterator<int*>>();
+  test_one<bidirectional_iterator<int*>>();
+  test_one<random_access_iterator<int*>>();
   test_one<int*>();
   test_one<const int*>();
 
