@@ -17,8 +17,10 @@
 
 #include <cuda/std/>
 
-int main(int, char**) {
-    char const* it = "";
-    cuda::std::move_iterator<char const*> r = it; // expected-error{{no viable conversion from 'const char *' to 'std::move_iterator<const char *>'}}
-    return 0;
+int main(int, char**)
+{
+  char const* it                          = "";
+  cuda::std::move_iterator<char const*> r = it; // expected-error{{no viable conversion from 'const char *' to
+                                                // 'std::move_iterator<const char *>'}}
+  return 0;
 }
