@@ -15,10 +15,10 @@
 //
 //  constexpr in C++17
 
-#include <cuda/std/iterator>
 #include <cuda/std/cassert>
+#include <cuda/std/iterator>
 #if defined(_LIBCUDACXX_HAS_MEMORY)
-#include <cuda/std/memory>
+#  include <cuda/std/memory>
 #endif
 
 #include "test_iterators.h"
@@ -26,32 +26,39 @@
 
 class A
 {
-    int data_;
-public:
-    __host__ __device__ A() : data_(1) {}
-    __host__ __device__ ~A() {data_ = -1;}
+  int data_;
 
-    __host__ __device__ friend bool operator==(const A& x, const A& y)
-        {return x.data_ == y.data_;}
+public:
+  __host__ __device__ A()
+      : data_(1)
+  {}
+  __host__ __device__ ~A()
+  {
+    data_ = -1;
+  }
+
+  __host__ __device__ friend bool operator==(const A& x, const A& y)
+  {
+    return x.data_ == y.data_;
+  }
 };
 
 template <class It>
-__host__ __device__ void
-test(It i, typename cuda::std::iterator_traits<It>::value_type x)
+__host__ __device__ void test(It i, typename cuda::std::iterator_traits<It>::value_type x)
 {
-    cuda::std::move_iterator<It> r(i);
-    assert(*r == x);
-    typename cuda::std::iterator_traits<It>::value_type x2 = *r;
-    assert(x2 == x);
+  cuda::std::move_iterator<It> r(i);
+  assert(*r == x);
+  typename cuda::std::iterator_traits<It>::value_type x2 = *r;
+  assert(x2 == x);
 }
 
 struct do_nothing
 {
-    __host__ __device__ void operator()(void*) const {}
+  __host__ __device__ void operator()(void*) const {}
 };
 
-
-int main(int, char**) {
+int main(int, char**)
+{
   {
     A a;
     test(&a, A());
@@ -65,10 +72,10 @@ int main(int, char**) {
 #endif
 #if TEST_STD_VER > 2011
   {
-    constexpr const char *p = "123456789";
-    typedef cuda::std::move_iterator<const char *> MI;
+    constexpr const char* p = "123456789";
+    typedef cuda::std::move_iterator<const char*> MI;
     constexpr MI it1 = cuda::std::make_move_iterator(p);
-    constexpr MI it2 = cuda::std::make_move_iterator(p+1);
+    constexpr MI it2 = cuda::std::make_move_iterator(p + 1);
     static_assert(*it1 == p[0], "");
     static_assert(*it2 == p[1], "");
   }
@@ -79,7 +86,7 @@ int main(int, char**) {
   {
     int a[] = {0, 1, 2};
 
-    int iter_moves = 0;
+    int iter_moves  = 0;
     adl::Iterator i = adl::Iterator::TrackMoves(a, iter_moves);
     cuda::std::move_iterator<adl::Iterator> mi(i);
 
