@@ -13,30 +13,33 @@
 
 // explicit reverse_iterator(Iter x); // constexpr since C++17
 
-#include <cuda/std/iterator>
 #include <cuda/std/cassert>
+#include <cuda/std/iterator>
 
-#include "test_macros.h"
 #include "test_iterators.h"
+#include "test_macros.h"
 
 template <class It>
-__host__ __device__ TEST_CONSTEXPR_CXX14 void test(It i) {
-    cuda::std::reverse_iterator<It> r(i);
-    assert(r.base() == i);
+__host__ __device__ TEST_CONSTEXPR_CXX14 void test(It i)
+{
+  cuda::std::reverse_iterator<It> r(i);
+  assert(r.base() == i);
 }
 
-__host__ __device__ TEST_CONSTEXPR_CXX14 bool tests() {
-    const char s[] = "123";
-    test(bidirectional_iterator<const char*>(s));
-    test(random_access_iterator<const char*>(s));
-    test(s);
-    return true;
+__host__ __device__ TEST_CONSTEXPR_CXX14 bool tests()
+{
+  const char s[] = "123";
+  test(bidirectional_iterator<const char*>(s));
+  test(random_access_iterator<const char*>(s));
+  test(s);
+  return true;
 }
 
-int main(int, char**) {
-    tests();
+int main(int, char**)
+{
+  tests();
 #if TEST_STD_VER > 2011
-    static_assert(tests(), "");
+  static_assert(tests(), "");
 #endif
-    return 0;
+  return 0;
 }
