@@ -14,31 +14,35 @@
 // requires RandomAccessIterator<Iter>
 // reverse_iterator& operator+=(difference_type n); // constexpr in C++17
 
-#include <cuda/std/iterator>
 #include <cuda/std/cassert>
+#include <cuda/std/iterator>
 
-#include "test_macros.h"
 #include "test_iterators.h"
+#include "test_macros.h"
 
 template <class It>
-__host__ __device__ TEST_CONSTEXPR_CXX14 void test(It i, typename cuda::std::iterator_traits<It>::difference_type n, It x) {
-    cuda::std::reverse_iterator<It> r(i);
-    cuda::std::reverse_iterator<It>& rr = r += n;
-    assert(r.base() == x);
-    assert(&rr == &r);
+__host__ __device__ TEST_CONSTEXPR_CXX14 void
+test(It i, typename cuda::std::iterator_traits<It>::difference_type n, It x)
+{
+  cuda::std::reverse_iterator<It> r(i);
+  cuda::std::reverse_iterator<It>& rr = r += n;
+  assert(r.base() == x);
+  assert(&rr == &r);
 }
 
-__host__ __device__ TEST_CONSTEXPR_CXX14 bool tests() {
-    char const* s = "1234567890";
-    test(random_access_iterator<const char*>(s+5), 5, random_access_iterator<const char*>(s));
-    test(s+5, 5, s);
-    return true;
+__host__ __device__ TEST_CONSTEXPR_CXX14 bool tests()
+{
+  char const* s = "1234567890";
+  test(random_access_iterator<const char*>(s + 5), 5, random_access_iterator<const char*>(s));
+  test(s + 5, 5, s);
+  return true;
 }
 
-int main(int, char**) {
-    tests();
+int main(int, char**)
+{
+  tests();
 #if TEST_STD_VER > 2011
-    static_assert(tests(), "");
+  static_assert(tests(), "");
 #endif
-    return 0;
+  return 0;
 }
