@@ -16,31 +16,36 @@
 // template <class Iterator>
 // reverse_iterator<Iterator> make_reverse_iterator(Iterator i); // constexpr in C++17
 
-#include <cuda/std/iterator>
 #include <cuda/std/cassert>
+#include <cuda/std/iterator>
 
-#include "test_macros.h"
 #include "test_iterators.h"
+#include "test_macros.h"
 
 template <class It>
-__host__ __device__ TEST_CONSTEXPR_CXX14 void test(It i) {
-    const cuda::std::reverse_iterator<It> r = cuda::std::make_reverse_iterator(i);
-    assert(r.base() == i);
+__host__ __device__ TEST_CONSTEXPR_CXX14 void test(It i)
+{
+  const cuda::std::reverse_iterator<It> r = cuda::std::make_reverse_iterator(i);
+  assert(r.base() == i);
 }
 
-__host__ __device__ TEST_CONSTEXPR_CXX14 bool tests() {
-    const char* s = "1234567890";
-    random_access_iterator<const char*> b(s);
-    random_access_iterator<const char*> e(s+10);
-    while (b != e)
-        test (b++);
-    return true;
+__host__ __device__ TEST_CONSTEXPR_CXX14 bool tests()
+{
+  const char* s = "1234567890";
+  random_access_iterator<const char*> b(s);
+  random_access_iterator<const char*> e(s + 10);
+  while (b != e)
+  {
+    test(b++);
+  }
+  return true;
 }
 
-int main(int, char**) {
-    tests();
+int main(int, char**)
+{
+  tests();
 #if TEST_STD_VER > 2011
-    static_assert(tests(), "");
+  static_assert(tests(), "");
 #endif
-    return 0;
+  return 0;
 }
