@@ -15,23 +15,21 @@
 #include "test_macros.h"
 
 typedef char one;
-struct two {one _[2];};
+struct two
+{
+  one _[2];
+};
 
 __host__ __device__ one test(cuda::std::float_denorm_style);
 __host__ __device__ two test(int);
 
 int main(int, char**)
 {
-    static_assert(cuda::std::denorm_indeterminate == -1,
-                 "cuda::std::denorm_indeterminate == -1");
-    static_assert(cuda::std::denorm_absent == 0,
-                 "cuda::std::denorm_absent == 0");
-    static_assert(cuda::std::denorm_present == 1,
-                 "cuda::std::denorm_present == 1");
-    static_assert(sizeof(test(cuda::std::denorm_present)) == 1,
-                 "sizeof(test(cuda::std::denorm_present)) == 1");
-    static_assert(sizeof(test(1)) == 2,
-                 "sizeof(test(1)) == 2");
+  static_assert(cuda::std::denorm_indeterminate == -1, "cuda::std::denorm_indeterminate == -1");
+  static_assert(cuda::std::denorm_absent == 0, "cuda::std::denorm_absent == 0");
+  static_assert(cuda::std::denorm_present == 1, "cuda::std::denorm_present == 1");
+  static_assert(sizeof(test(cuda::std::denorm_present)) == 1, "sizeof(test(cuda::std::denorm_present)) == 1");
+  static_assert(sizeof(test(1)) == 2, "sizeof(test(1)) == 2");
 
   return 0;
 }
