@@ -7,6 +7,7 @@
 //===----------------------------------------------------------------------===//
 
 #include <cuda/std/cstddef>
+
 #include <test_macros.h>
 
 // UNSUPPORTED: c++98, c++03, c++11, c++14
@@ -16,9 +17,10 @@
 // These functions shall not participate in overload resolution unless
 //   is_integral_v<IntegerType> is true.
 
-int main(int, char**) {
-    constexpr cuda::std::byte b1{static_cast<cuda::std::byte>(1)};
-    constexpr cuda::std::byte b2 = b1 >> 2.0f;
+int main(int, char**)
+{
+  constexpr cuda::std::byte b1{static_cast<cuda::std::byte>(1)};
+  constexpr cuda::std::byte b2 = b1 >> 2.0f;
 
   return 0;
 }
