@@ -13,38 +13,37 @@
 //   complex<T>
 //   operator/(const T& lhs, const complex<T>& rhs);
 
-#include <cuda/std/complex>
 #include <cuda/std/cassert>
+#include <cuda/std/complex>
 
 #include "test_macros.h"
 
 template <class T>
-__host__ __device__ TEST_CONSTEXPR_CXX14 bool
-test()
+__host__ __device__ TEST_CONSTEXPR_CXX14 bool test()
 {
-    T lhs(-8.5);
-    cuda::std::complex<T> rhs(1.5, 2.5);
-    cuda::std::complex<T>   x(-1.5, 2.5);
-    assert(lhs / rhs == x);
+  T lhs(-8.5);
+  cuda::std::complex<T> rhs(1.5, 2.5);
+  cuda::std::complex<T> x(-1.5, 2.5);
+  assert(lhs / rhs == x);
 
-    return true;
+  return true;
 }
 
 int main(int, char**)
 {
-    test<float>();
-    test<double>();
+  test<float>();
+  test<double>();
 #ifdef _LIBCUDACXX_HAS_NVFP16
-    test<__half>();
+  test<__half>();
 #endif
 #ifdef _LIBCUDACXX_HAS_NVBF16
-    test<__nv_bfloat16>();
+  test<__nv_bfloat16>();
 #endif
 // CUDA treats long double as double
 //  test<long double>();
 #if TEST_STD_VER > 2011 && !defined(_LIBCUDACXX_HAS_NO_CONSTEXPR_COMPLEX_OPERATIONS)
-    static_assert(test<float>(), "");
-    static_assert(test<double>(), "");
+  static_assert(test<float>(), "");
+  static_assert(test<double>(), "");
 // CUDA treats long double as double
 //  static_assert(test<long double>(), "");
 #endif
