@@ -13,40 +13,39 @@
 //   complex<T>
 //   operator-(const complex<T>& lhs);
 
-#include <cuda/std/complex>
 #include <cuda/std/cassert>
+#include <cuda/std/complex>
 
 #include "test_macros.h"
 
 template <class T>
-__host__ __device__ TEST_CONSTEXPR_CXX14 bool
-test()
+__host__ __device__ TEST_CONSTEXPR_CXX14 bool test()
 {
-    cuda::std::complex<T> z(1.5, 2.5);
-    assert(z.real() == T(1.5));
-    assert(z.imag() == T(2.5));
-    cuda::std::complex<T> c = -z;
-    assert(c.real() == T(-1.5));
-    assert(c.imag() == T(-2.5));
+  cuda::std::complex<T> z(1.5, 2.5);
+  assert(z.real() == T(1.5));
+  assert(z.imag() == T(2.5));
+  cuda::std::complex<T> c = -z;
+  assert(c.real() == T(-1.5));
+  assert(c.imag() == T(-2.5));
 
-    return true;
+  return true;
 }
 
 int main(int, char**)
 {
-    test<float>();
-    test<double>();
+  test<float>();
+  test<double>();
 #ifdef _LIBCUDACXX_HAS_NVFP16
-    test<__half>();
+  test<__half>();
 #endif
 #ifdef _LIBCUDACXX_HAS_NVBF16
-    test<__nv_bfloat16>();
+  test<__nv_bfloat16>();
 #endif
 // CUDA treats long double as double
 //  test<long double>();
 #if TEST_STD_VER > 2011
-    static_assert(test<float>(), "");
-    static_assert(test<double>(), "");
+  static_assert(test<float>(), "");
+  static_assert(test<double>(), "");
 // CUDA treats long double as double
 //  static_assert(test<long double>(), "");
 #endif
