@@ -13,68 +13,67 @@
 //   T
 //   abs(const complex<T>& x);
 
-#include <cuda/std/complex>
 #include <cuda/std/cassert>
+#include <cuda/std/complex>
 
-#include "test_macros.h"
 #include "../cases.h"
+#include "test_macros.h"
 
 template <class T>
-__host__ __device__ void
-test()
+__host__ __device__ void test()
 {
-    cuda::std::complex<T> z(3, 4);
-    assert(abs(z) == T(5));
+  cuda::std::complex<T> z(3, 4);
+  assert(abs(z) == T(5));
 }
 
 template <class T>
 __host__ __device__ void test_edges()
 {
-    auto testcases = get_testcases<T>();
-    const unsigned N = sizeof(testcases) / sizeof(testcases[0]);
-    for (unsigned i = 0; i < N; ++i)
+  auto testcases   = get_testcases<T>();
+  const unsigned N = sizeof(testcases) / sizeof(testcases[0]);
+  for (unsigned i = 0; i < N; ++i)
+  {
+    T r = abs(testcases[i]);
+    switch (classify(testcases[i]))
     {
-        T r = abs(testcases[i]);
-        switch (classify(testcases[i]))
-        {
-        case zero:
-            assert(r == T(0));
-            assert(!cuda::std::signbit(r));
-            break;
-        case non_zero:
-            assert(cuda::std::isfinite(r) && r > T(0));
-            break;
-        case inf:
-            assert(cuda::std::isinf(r) && r > T(0));
-            break;
-        case NaN:
-            assert(cuda::std::isnan(r));
-            break;
-        case non_zero_nan:
-            assert(cuda::std::isnan(r));
-            break;
-        }
+      case zero:
+        assert(r == T(0));
+        assert(!cuda::std::signbit(r));
+        break;
+      case non_zero:
+        assert(cuda::std::isfinite(r) && r > T(0));
+        break;
+      case inf:
+        assert(cuda::std::isinf(r) && r > T(0));
+        break;
+      case NaN:
+        assert(cuda::std::isnan(r));
+        break;
+      case non_zero_nan:
+        assert(cuda::std::isnan(r));
+        break;
     }
+  }
 }
 
 int main(int, char**)
 {
-    test<float>();
-    test<double>();
+  test<float>();
+  test<double>();
 // CUDA treats long double as double
 //  test<long double>();
 #ifdef _LIBCUDACXX_HAS_NVFP16
-    test<__half>();
+  test<__half>();
 #endif
 #ifdef _LIBCUDACXX_HAS_NVBF16
-    test<__nv_bfloat16>();
+  test<__nv_bfloat16>();
 #endif
-    test_edges<double>();
+  test_edges<double>();
 #ifdef _LIBCUDACXX_HAS_NVFP16
-    test_edges<__half>();
+  test_edges<__half>();
 #endif
 #ifdef _LIBCUDACXX_HAS_NVBF16
-    test_edges<__nv_bfloat16>();
+  test_edges<__nv_bfloat16>();
 #endif
 
   return 0;
