@@ -22,26 +22,25 @@
 #include "test_macros.h"
 
 template <class T>
-__host__ __device__ void
-test()
+__host__ __device__ void test()
 {
-    typedef cuda::std::complex<T> C;
+  typedef cuda::std::complex<T> C;
 
-    static_assert(sizeof(C) == (sizeof(T)*2), "wrong size");
-    static_assert(alignof(C) == (alignof(T)*2), "misaligned");
+  static_assert(sizeof(C) == (sizeof(T) * 2), "wrong size");
+  static_assert(alignof(C) == (alignof(T) * 2), "misaligned");
 }
 
 int main(int, char**)
 {
-    test<float>();
-    test<double>();
+  test<float>();
+  test<double>();
 // CUDA treats long double as double
 //  test<long double>();
 #ifdef _LIBCUDACXX_HAS_NVFP16
-    test<__half>();
+  test<__half>();
 #endif
 #ifdef _LIBCUDACXX_HAS_NVBF16
-    test<__nv_bfloat16>();
+  test<__nv_bfloat16>();
 #endif
 
   return 0;
