@@ -13,15 +13,14 @@
 // cuda::std::ranges::rend
 // cuda::std::ranges::crend
 
-#include <cuda/std/ranges>
-
 #include <cuda/std/cassert>
+#include <cuda/std/ranges>
 #include <cuda/std/utility>
 
-#include "test_macros.h"
 #include "test_iterators.h"
+#include "test_macros.h"
 
-using RangeREndT = decltype(cuda::std::ranges::rend);
+using RangeREndT  = decltype(cuda::std::ranges::rend);
 using RangeCREndT = decltype(cuda::std::ranges::crend);
 
 STATIC_TEST_GLOBAL_VAR int globalBuff[8];
@@ -29,44 +28,50 @@ STATIC_TEST_GLOBAL_VAR int globalBuff[8];
 static_assert(!cuda::std::is_invocable_v<RangeREndT, int (&&)[]>);
 static_assert(!cuda::std::is_invocable_v<RangeREndT, int (&)[]>);
 static_assert(!cuda::std::is_invocable_v<RangeREndT, int (&&)[10]>);
-static_assert( cuda::std::is_invocable_v<RangeREndT, int (&)[10]>);
+static_assert(cuda::std::is_invocable_v<RangeREndT, int (&)[10]>);
 static_assert(!cuda::std::is_invocable_v<RangeCREndT, int (&&)[]>);
 static_assert(!cuda::std::is_invocable_v<RangeCREndT, int (&)[]>);
 static_assert(!cuda::std::is_invocable_v<RangeCREndT, int (&&)[10]>);
-static_assert( cuda::std::is_invocable_v<RangeCREndT, int (&)[10]>);
+static_assert(cuda::std::is_invocable_v<RangeCREndT, int (&)[10]>);
 
 struct Incomplete;
-static_assert(!cuda::std::is_invocable_v<RangeREndT, Incomplete(&&)[]>);
-static_assert(!cuda::std::is_invocable_v<RangeREndT, Incomplete(&&)[42]>);
-static_assert(!cuda::std::is_invocable_v<RangeCREndT, Incomplete(&&)[]>);
-static_assert(!cuda::std::is_invocable_v<RangeCREndT, Incomplete(&&)[42]>);
+static_assert(!cuda::std::is_invocable_v<RangeREndT, Incomplete (&&)[]>);
+static_assert(!cuda::std::is_invocable_v<RangeREndT, Incomplete (&&)[42]>);
+static_assert(!cuda::std::is_invocable_v<RangeCREndT, Incomplete (&&)[]>);
+static_assert(!cuda::std::is_invocable_v<RangeCREndT, Incomplete (&&)[42]>);
 
-struct REndMember {
+struct REndMember
+{
   int x;
   __host__ __device__ const int* rbegin() const;
-  __host__ __device__ constexpr const int* rend() const { return &x; }
+  __host__ __device__ constexpr const int* rend() const
+  {
+    return &x;
+  }
 };
 
 // Ensure that we can't call with rvalues with borrowing disabled.
-static_assert( cuda::std::is_invocable_v<RangeREndT, REndMember&>);
-static_assert(!cuda::std::is_invocable_v<RangeREndT, REndMember &&>);
-static_assert( cuda::std::is_invocable_v<RangeREndT, REndMember const&>);
+static_assert(cuda::std::is_invocable_v<RangeREndT, REndMember&>);
+static_assert(!cuda::std::is_invocable_v<RangeREndT, REndMember&&>);
+static_assert(cuda::std::is_invocable_v<RangeREndT, REndMember const&>);
 static_assert(!cuda::std::is_invocable_v<RangeREndT, REndMember const&&>);
-static_assert( cuda::std::is_invocable_v<RangeCREndT, REndMember &>);
-static_assert(!cuda::std::is_invocable_v<RangeCREndT, REndMember &&>);
-static_assert( cuda::std::is_invocable_v<RangeCREndT, REndMember const&>);
+static_assert(cuda::std::is_invocable_v<RangeCREndT, REndMember&>);
+static_assert(!cuda::std::is_invocable_v<RangeCREndT, REndMember&&>);
+static_assert(cuda::std::is_invocable_v<RangeCREndT, REndMember const&>);
 static_assert(!cuda::std::is_invocable_v<RangeCREndT, REndMember const&&>);
 
-struct Different {
+struct Different
+{
   __host__ __device__ char* rbegin();
   __host__ __device__ sentinel_wrapper<char*>& rend();
   __host__ __device__ short* rbegin() const;
   __host__ __device__ sentinel_wrapper<short*>& rend() const;
 };
 
-__host__ __device__ constexpr bool testReturnTypes() {
+__host__ __device__ constexpr bool testReturnTypes()
+{
   {
-    int *x[2] = {};
+    int* x[2] = {};
     unused(x);
     ASSERT_SAME_TYPE(decltype(cuda::std::ranges::rend(x)), cuda::std::reverse_iterator<int**>);
     ASSERT_SAME_TYPE(decltype(cuda::std::ranges::crend(x)), cuda::std::reverse_iterator<int* const*>);
@@ -89,7 +94,8 @@ __host__ __device__ constexpr bool testReturnTypes() {
   return true;
 }
 
-__host__ __device__ TEST_CONSTEXPR_CXX17 bool testArray() {
+__host__ __device__ TEST_CONSTEXPR_CXX17 bool testArray()
+{
   int a[2] = {};
   assert(cuda::std::ranges::rend(a).base() == a);
   assert(cuda::std::ranges::crend(a).base() == a);
@@ -105,70 +111,106 @@ __host__ __device__ TEST_CONSTEXPR_CXX17 bool testArray() {
   return true;
 }
 
-struct REndMemberReturnsInt {
+struct REndMemberReturnsInt
+{
   __host__ __device__ int rbegin() const;
   __host__ __device__ int rend() const;
 };
 static_assert(!cuda::std::is_invocable_v<RangeREndT, REndMemberReturnsInt const&>);
 
-struct REndMemberReturnsVoidPtr {
-  __host__ __device__ const void *rbegin() const;
-  __host__ __device__ const void *rend() const;
+struct REndMemberReturnsVoidPtr
+{
+  __host__ __device__ const void* rbegin() const;
+  __host__ __device__ const void* rend() const;
 };
 static_assert(!cuda::std::is_invocable_v<RangeREndT, REndMemberReturnsVoidPtr const&>);
 
-struct PtrConvertible {
+struct PtrConvertible
+{
   __host__ __device__ operator int*() const;
 };
-struct PtrConvertibleREndMember {
+struct PtrConvertibleREndMember
+{
   __host__ __device__ PtrConvertible rbegin() const;
   __host__ __device__ PtrConvertible rend() const;
 };
 static_assert(!cuda::std::is_invocable_v<RangeREndT, PtrConvertibleREndMember const&>);
 
-struct NoRBeginMember {
+struct NoRBeginMember
+{
   __host__ __device__ constexpr const int* rend();
 };
 static_assert(!cuda::std::is_invocable_v<RangeREndT, NoRBeginMember const&>);
 
-struct NonConstREndMember {
+struct NonConstREndMember
+{
   int x;
-  __host__ __device__ constexpr int* rbegin() { return nullptr; }
-  __host__ __device__ constexpr int* rend() { return &x; }
+  __host__ __device__ constexpr int* rbegin()
+  {
+    return nullptr;
+  }
+  __host__ __device__ constexpr int* rend()
+  {
+    return &x;
+  }
 };
-static_assert( cuda::std::is_invocable_v<RangeREndT,  NonConstREndMember &>);
-static_assert(!cuda::std::is_invocable_v<RangeREndT,  NonConstREndMember const&>);
-static_assert(!cuda::std::is_invocable_v<RangeCREndT, NonConstREndMember &>);
+static_assert(cuda::std::is_invocable_v<RangeREndT, NonConstREndMember&>);
+static_assert(!cuda::std::is_invocable_v<RangeREndT, NonConstREndMember const&>);
+static_assert(!cuda::std::is_invocable_v<RangeCREndT, NonConstREndMember&>);
 static_assert(!cuda::std::is_invocable_v<RangeCREndT, NonConstREndMember const&>);
 
-struct EnabledBorrowingREndMember {
-  __host__ __device__ constexpr int* rbegin() const { return nullptr; }
-  __host__ __device__ constexpr int* rend() const { return &globalBuff[0]; }
+struct EnabledBorrowingREndMember
+{
+  __host__ __device__ constexpr int* rbegin() const
+  {
+    return nullptr;
+  }
+  __host__ __device__ constexpr int* rend() const
+  {
+    return &globalBuff[0];
+  }
 };
-template<>
+template <>
 inline constexpr bool cuda::std::ranges::enable_borrowed_range<EnabledBorrowingREndMember> = true;
 
-struct REndMemberFunction {
+struct REndMemberFunction
+{
   int x;
-  __host__ __device__ constexpr const int* rbegin() const { return nullptr; }
-  __host__ __device__ constexpr const int* rend() const { return &x; }
+  __host__ __device__ constexpr const int* rbegin() const
+  {
+    return nullptr;
+  }
+  __host__ __device__ constexpr const int* rend() const
+  {
+    return &x;
+  }
   __host__ __device__ friend constexpr int* rend(REndMemberFunction const&);
 };
 
-struct Empty { };
-struct EmptyEndMember {
+struct Empty
+{};
+struct EmptyEndMember
+{
   __host__ __device__ Empty rbegin() const;
   __host__ __device__ Empty rend() const;
 };
 static_assert(!cuda::std::is_invocable_v<RangeREndT, EmptyEndMember const&>);
 
-struct EmptyPtrREndMember {
+struct EmptyPtrREndMember
+{
   Empty x;
-  __host__ __device__ constexpr const Empty* rbegin() const { return nullptr; }
-  __host__ __device__ constexpr const Empty* rend() const { return &x; }
+  __host__ __device__ constexpr const Empty* rbegin() const
+  {
+    return nullptr;
+  }
+  __host__ __device__ constexpr const Empty* rend() const
+  {
+    return &x;
+  }
 };
 
-__host__ __device__ constexpr bool testREndMember() {
+__host__ __device__ constexpr bool testREndMember()
+{
   REndMember a{};
   assert(cuda::std::ranges::rend(a) == &a.x);
   assert(cuda::std::ranges::crend(a) == &a.x);
@@ -192,89 +234,144 @@ __host__ __device__ constexpr bool testREndMember() {
   return true;
 }
 
-struct REndFunction {
+struct REndFunction
+{
   int x;
-  __host__ __device__ friend constexpr const int* rbegin(REndFunction const&) { return nullptr; }
-  __host__ __device__ friend constexpr const int* rend(REndFunction const& bf) { return &bf.x; }
+  __host__ __device__ friend constexpr const int* rbegin(REndFunction const&)
+  {
+    return nullptr;
+  }
+  __host__ __device__ friend constexpr const int* rend(REndFunction const& bf)
+  {
+    return &bf.x;
+  }
 };
 
-static_assert( cuda::std::is_invocable_v<RangeREndT, REndFunction const&>);
-static_assert(!cuda::std::is_invocable_v<RangeREndT, REndFunction &&>);
+static_assert(cuda::std::is_invocable_v<RangeREndT, REndFunction const&>);
+static_assert(!cuda::std::is_invocable_v<RangeREndT, REndFunction&&>);
 
-static_assert( cuda::std::is_invocable_v<RangeREndT,  REndFunction const&>);
-static_assert(!cuda::std::is_invocable_v<RangeREndT,  REndFunction &&>);
-static_assert(!cuda::std::is_invocable_v<RangeREndT,  REndFunction &>);
-static_assert( cuda::std::is_invocable_v<RangeCREndT, REndFunction const&>);
-static_assert( cuda::std::is_invocable_v<RangeCREndT, REndFunction &>);
+static_assert(cuda::std::is_invocable_v<RangeREndT, REndFunction const&>);
+static_assert(!cuda::std::is_invocable_v<RangeREndT, REndFunction&&>);
+static_assert(!cuda::std::is_invocable_v<RangeREndT, REndFunction&>);
+static_assert(cuda::std::is_invocable_v<RangeCREndT, REndFunction const&>);
+static_assert(cuda::std::is_invocable_v<RangeCREndT, REndFunction&>);
 
-struct REndFunctionReturnsInt {
+struct REndFunctionReturnsInt
+{
   __host__ __device__ friend constexpr int rbegin(REndFunctionReturnsInt const&);
   __host__ __device__ friend constexpr int rend(REndFunctionReturnsInt const&);
 };
 static_assert(!cuda::std::is_invocable_v<RangeREndT, REndFunctionReturnsInt const&>);
 
-struct REndFunctionReturnsVoidPtr {
+struct REndFunctionReturnsVoidPtr
+{
   __host__ __device__ friend constexpr void* rbegin(REndFunctionReturnsVoidPtr const&);
   __host__ __device__ friend constexpr void* rend(REndFunctionReturnsVoidPtr const&);
 };
 static_assert(!cuda::std::is_invocable_v<RangeREndT, REndFunctionReturnsVoidPtr const&>);
 
-struct REndFunctionReturnsEmpty {
+struct REndFunctionReturnsEmpty
+{
   __host__ __device__ friend constexpr Empty rbegin(REndFunctionReturnsEmpty const&);
   __host__ __device__ friend constexpr Empty rend(REndFunctionReturnsEmpty const&);
 };
 static_assert(!cuda::std::is_invocable_v<RangeREndT, REndFunctionReturnsEmpty const&>);
 
-struct REndFunctionReturnsPtrConvertible {
+struct REndFunctionReturnsPtrConvertible
+{
   __host__ __device__ friend constexpr PtrConvertible rbegin(REndFunctionReturnsPtrConvertible const&);
   __host__ __device__ friend constexpr PtrConvertible rend(REndFunctionReturnsPtrConvertible const&);
 };
 static_assert(!cuda::std::is_invocable_v<RangeREndT, REndFunctionReturnsPtrConvertible const&>);
 
-struct NoRBeginFunction {
+struct NoRBeginFunction
+{
   __host__ __device__ friend constexpr const int* rend(NoRBeginFunction const&);
 };
 static_assert(!cuda::std::is_invocable_v<RangeREndT, NoRBeginFunction const&>);
 
-struct REndFunctionByValue {
-  __host__ __device__ friend constexpr int* rbegin(REndFunctionByValue) { return nullptr; }
-  __host__ __device__ friend constexpr int* rend(REndFunctionByValue) { return &globalBuff[1]; }
+struct REndFunctionByValue
+{
+  __host__ __device__ friend constexpr int* rbegin(REndFunctionByValue)
+  {
+    return nullptr;
+  }
+  __host__ __device__ friend constexpr int* rend(REndFunctionByValue)
+  {
+    return &globalBuff[1];
+  }
 };
 static_assert(!cuda::std::is_invocable_v<RangeCREndT, REndFunctionByValue>);
 
-struct REndFunctionEnabledBorrowing {
-  __host__ __device__ friend constexpr int* rbegin(REndFunctionEnabledBorrowing) { return nullptr; }
-  __host__ __device__ friend constexpr int* rend(REndFunctionEnabledBorrowing) { return &globalBuff[2]; }
+struct REndFunctionEnabledBorrowing
+{
+  __host__ __device__ friend constexpr int* rbegin(REndFunctionEnabledBorrowing)
+  {
+    return nullptr;
+  }
+  __host__ __device__ friend constexpr int* rend(REndFunctionEnabledBorrowing)
+  {
+    return &globalBuff[2];
+  }
 };
-template<>
+template <>
 inline constexpr bool cuda::std::ranges::enable_borrowed_range<REndFunctionEnabledBorrowing> = true;
 
-struct REndFunctionReturnsEmptyPtr {
+struct REndFunctionReturnsEmptyPtr
+{
   Empty x;
-  __host__ __device__ friend constexpr const Empty* rbegin(REndFunctionReturnsEmptyPtr const&) { return nullptr; }
-  __host__ __device__ friend constexpr const Empty* rend(REndFunctionReturnsEmptyPtr const& bf) { return &bf.x; }
+  __host__ __device__ friend constexpr const Empty* rbegin(REndFunctionReturnsEmptyPtr const&)
+  {
+    return nullptr;
+  }
+  __host__ __device__ friend constexpr const Empty* rend(REndFunctionReturnsEmptyPtr const& bf)
+  {
+    return &bf.x;
+  }
 };
 
-struct REndFunctionWithDataMember {
+struct REndFunctionWithDataMember
+{
   int x;
   int rend;
-  __host__ __device__ friend constexpr const int* rbegin(REndFunctionWithDataMember const&) { return nullptr; }
-  __host__ __device__ friend constexpr const int* rend(REndFunctionWithDataMember const& bf) { return &bf.x; }
+  __host__ __device__ friend constexpr const int* rbegin(REndFunctionWithDataMember const&)
+  {
+    return nullptr;
+  }
+  __host__ __device__ friend constexpr const int* rend(REndFunctionWithDataMember const& bf)
+  {
+    return &bf.x;
+  }
 };
 
-struct REndFunctionWithPrivateEndMember : private REndMember {
+struct REndFunctionWithPrivateEndMember : private REndMember
+{
   int y;
-  __host__ __device__ friend constexpr const int* rbegin(REndFunctionWithPrivateEndMember const&) { return nullptr; }
-  __host__ __device__ friend constexpr const int* rend(REndFunctionWithPrivateEndMember const& bf) { return &bf.y; }
+  __host__ __device__ friend constexpr const int* rbegin(REndFunctionWithPrivateEndMember const&)
+  {
+    return nullptr;
+  }
+  __host__ __device__ friend constexpr const int* rend(REndFunctionWithPrivateEndMember const& bf)
+  {
+    return &bf.y;
+  }
 };
 
-struct RBeginMemberEndFunction {
+struct RBeginMemberEndFunction
+{
   int x;
-  __host__ __device__ constexpr const int* rbegin() const { return nullptr; }
-  __host__ __device__ friend constexpr const int* rend(RBeginMemberEndFunction const& bf) { return &bf.x; }
+  __host__ __device__ constexpr const int* rbegin() const
+  {
+    return nullptr;
+  }
+  __host__ __device__ friend constexpr const int* rend(RBeginMemberEndFunction const& bf)
+  {
+    return &bf.x;
+  }
 };
 
-__host__ __device__ constexpr bool testREndFunction() {
+__host__ __device__ constexpr bool testREndFunction()
+{
   const REndFunction a{};
   assert(cuda::std::ranges::rend(a) == &a.x);
   assert(cuda::std::ranges::crend(a) == &a.x);
@@ -321,115 +418,161 @@ __host__ __device__ constexpr bool testREndFunction() {
   return true;
 }
 
-struct MemberBeginEnd {
+struct MemberBeginEnd
+{
   int b, e;
   char cb, ce;
-  __host__ __device__ constexpr bidirectional_iterator<int*> begin() { return bidirectional_iterator<int*>(&b); }
-  __host__ __device__ constexpr bidirectional_iterator<int*> end() { return bidirectional_iterator<int*>(&e); }
-  __host__ __device__ constexpr bidirectional_iterator<const char*> begin() const { return bidirectional_iterator<const char*>(&cb); }
-  __host__ __device__ constexpr bidirectional_iterator<const char*> end() const { return bidirectional_iterator<const char*>(&ce); }
+  __host__ __device__ constexpr bidirectional_iterator<int*> begin()
+  {
+    return bidirectional_iterator<int*>(&b);
+  }
+  __host__ __device__ constexpr bidirectional_iterator<int*> end()
+  {
+    return bidirectional_iterator<int*>(&e);
+  }
+  __host__ __device__ constexpr bidirectional_iterator<const char*> begin() const
+  {
+    return bidirectional_iterator<const char*>(&cb);
+  }
+  __host__ __device__ constexpr bidirectional_iterator<const char*> end() const
+  {
+    return bidirectional_iterator<const char*>(&ce);
+  }
 };
-static_assert( cuda::std::is_invocable_v<RangeREndT, MemberBeginEnd&>);
-static_assert( cuda::std::is_invocable_v<RangeREndT, MemberBeginEnd const&>);
-static_assert( cuda::std::is_invocable_v<RangeCREndT, MemberBeginEnd const&>);
+static_assert(cuda::std::is_invocable_v<RangeREndT, MemberBeginEnd&>);
+static_assert(cuda::std::is_invocable_v<RangeREndT, MemberBeginEnd const&>);
+static_assert(cuda::std::is_invocable_v<RangeCREndT, MemberBeginEnd const&>);
 
-struct FunctionBeginEnd {
+struct FunctionBeginEnd
+{
   int b, e;
   char cb, ce;
-  __host__ __device__ friend constexpr bidirectional_iterator<int*> begin(FunctionBeginEnd& v) {
+  __host__ __device__ friend constexpr bidirectional_iterator<int*> begin(FunctionBeginEnd& v)
+  {
     return bidirectional_iterator<int*>(&v.b);
   }
-  __host__ __device__ friend constexpr bidirectional_iterator<int*> end(FunctionBeginEnd& v) { return bidirectional_iterator<int*>(&v.e); }
-  __host__ __device__ friend constexpr bidirectional_iterator<const char*> begin(const FunctionBeginEnd& v) {
-    return bidirectional_iterator<const char*>(&v.cb);
-  }
-  __host__ __device__ friend constexpr bidirectional_iterator<const char*> end(const FunctionBeginEnd& v) {
-    return bidirectional_iterator<const char*>(&v.ce);
-  }
-};
-static_assert( cuda::std::is_invocable_v<RangeREndT, FunctionBeginEnd&>);
-static_assert( cuda::std::is_invocable_v<RangeREndT, FunctionBeginEnd const&>);
-static_assert( cuda::std::is_invocable_v<RangeCREndT, FunctionBeginEnd const&>);
-
-struct MemberBeginFunctionEnd {
-  int b, e;
-  char cb, ce;
-  __host__ __device__ constexpr bidirectional_iterator<int*> begin() { return bidirectional_iterator<int*>(&b); }
-  __host__ __device__ friend constexpr bidirectional_iterator<int*> end(MemberBeginFunctionEnd& v) {
+  __host__ __device__ friend constexpr bidirectional_iterator<int*> end(FunctionBeginEnd& v)
+  {
     return bidirectional_iterator<int*>(&v.e);
   }
-  __host__ __device__ constexpr bidirectional_iterator<const char*> begin() const { return bidirectional_iterator<const char*>(&cb); }
-  __host__ __device__ friend constexpr bidirectional_iterator<const char*> end(const MemberBeginFunctionEnd& v) {
+  __host__ __device__ friend constexpr bidirectional_iterator<const char*> begin(const FunctionBeginEnd& v)
+  {
+    return bidirectional_iterator<const char*>(&v.cb);
+  }
+  __host__ __device__ friend constexpr bidirectional_iterator<const char*> end(const FunctionBeginEnd& v)
+  {
     return bidirectional_iterator<const char*>(&v.ce);
   }
 };
-static_assert( cuda::std::is_invocable_v<RangeREndT, MemberBeginFunctionEnd&>);
-static_assert( cuda::std::is_invocable_v<RangeREndT, MemberBeginFunctionEnd const&>);
-static_assert( cuda::std::is_invocable_v<RangeCREndT, MemberBeginFunctionEnd const&>);
+static_assert(cuda::std::is_invocable_v<RangeREndT, FunctionBeginEnd&>);
+static_assert(cuda::std::is_invocable_v<RangeREndT, FunctionBeginEnd const&>);
+static_assert(cuda::std::is_invocable_v<RangeCREndT, FunctionBeginEnd const&>);
 
-struct FunctionBeginMemberEnd {
+struct MemberBeginFunctionEnd
+{
   int b, e;
   char cb, ce;
-  __host__ __device__ friend constexpr bidirectional_iterator<int*> begin(FunctionBeginMemberEnd& v) {
+  __host__ __device__ constexpr bidirectional_iterator<int*> begin()
+  {
+    return bidirectional_iterator<int*>(&b);
+  }
+  __host__ __device__ friend constexpr bidirectional_iterator<int*> end(MemberBeginFunctionEnd& v)
+  {
+    return bidirectional_iterator<int*>(&v.e);
+  }
+  __host__ __device__ constexpr bidirectional_iterator<const char*> begin() const
+  {
+    return bidirectional_iterator<const char*>(&cb);
+  }
+  __host__ __device__ friend constexpr bidirectional_iterator<const char*> end(const MemberBeginFunctionEnd& v)
+  {
+    return bidirectional_iterator<const char*>(&v.ce);
+  }
+};
+static_assert(cuda::std::is_invocable_v<RangeREndT, MemberBeginFunctionEnd&>);
+static_assert(cuda::std::is_invocable_v<RangeREndT, MemberBeginFunctionEnd const&>);
+static_assert(cuda::std::is_invocable_v<RangeCREndT, MemberBeginFunctionEnd const&>);
+
+struct FunctionBeginMemberEnd
+{
+  int b, e;
+  char cb, ce;
+  __host__ __device__ friend constexpr bidirectional_iterator<int*> begin(FunctionBeginMemberEnd& v)
+  {
     return bidirectional_iterator<int*>(&v.b);
   }
-  __host__ __device__ constexpr bidirectional_iterator<int*> end() { return bidirectional_iterator<int*>(&e); }
-  __host__ __device__ friend constexpr bidirectional_iterator<const char*> begin(const FunctionBeginMemberEnd& v) {
+  __host__ __device__ constexpr bidirectional_iterator<int*> end()
+  {
+    return bidirectional_iterator<int*>(&e);
+  }
+  __host__ __device__ friend constexpr bidirectional_iterator<const char*> begin(const FunctionBeginMemberEnd& v)
+  {
     return bidirectional_iterator<const char*>(&v.cb);
   }
-  __host__ __device__ constexpr bidirectional_iterator<const char*> end() const { return bidirectional_iterator<const char*>(&ce); }
+  __host__ __device__ constexpr bidirectional_iterator<const char*> end() const
+  {
+    return bidirectional_iterator<const char*>(&ce);
+  }
 };
-static_assert( cuda::std::is_invocable_v<RangeREndT, FunctionBeginMemberEnd&>);
-static_assert( cuda::std::is_invocable_v<RangeREndT, FunctionBeginMemberEnd const&>);
-static_assert( cuda::std::is_invocable_v<RangeCREndT, FunctionBeginMemberEnd const&>);
+static_assert(cuda::std::is_invocable_v<RangeREndT, FunctionBeginMemberEnd&>);
+static_assert(cuda::std::is_invocable_v<RangeREndT, FunctionBeginMemberEnd const&>);
+static_assert(cuda::std::is_invocable_v<RangeCREndT, FunctionBeginMemberEnd const&>);
 
-struct MemberBeginEndDifferentTypes {
+struct MemberBeginEndDifferentTypes
+{
   __host__ __device__ bidirectional_iterator<int*> begin();
   __host__ __device__ bidirectional_iterator<const int*> end();
 };
 static_assert(!cuda::std::is_invocable_v<RangeREndT, MemberBeginEndDifferentTypes&>);
 static_assert(!cuda::std::is_invocable_v<RangeCREndT, MemberBeginEndDifferentTypes&>);
 
-struct FunctionBeginEndDifferentTypes {
+struct FunctionBeginEndDifferentTypes
+{
   __host__ __device__ friend bidirectional_iterator<int*> begin(FunctionBeginEndDifferentTypes&);
   __host__ __device__ friend bidirectional_iterator<const int*> end(FunctionBeginEndDifferentTypes&);
 };
 static_assert(!cuda::std::is_invocable_v<RangeREndT, FunctionBeginEndDifferentTypes&>);
 static_assert(!cuda::std::is_invocable_v<RangeCREndT, FunctionBeginEndDifferentTypes&>);
 
-struct MemberBeginEndForwardIterators {
+struct MemberBeginEndForwardIterators
+{
   __host__ __device__ forward_iterator<int*> begin();
   __host__ __device__ forward_iterator<int*> end();
 };
 static_assert(!cuda::std::is_invocable_v<RangeREndT, MemberBeginEndForwardIterators&>);
 static_assert(!cuda::std::is_invocable_v<RangeCREndT, MemberBeginEndForwardIterators&>);
 
-struct FunctionBeginEndForwardIterators {
+struct FunctionBeginEndForwardIterators
+{
   __host__ __device__ friend forward_iterator<int*> begin(FunctionBeginEndForwardIterators&);
   __host__ __device__ friend forward_iterator<int*> end(FunctionBeginEndForwardIterators&);
 };
 static_assert(!cuda::std::is_invocable_v<RangeREndT, FunctionBeginEndForwardIterators&>);
 static_assert(!cuda::std::is_invocable_v<RangeCREndT, FunctionBeginEndForwardIterators&>);
 
-struct MemberBeginOnly {
+struct MemberBeginOnly
+{
   __host__ __device__ bidirectional_iterator<int*> begin() const;
 };
 static_assert(!cuda::std::is_invocable_v<RangeREndT, MemberBeginOnly&>);
 static_assert(!cuda::std::is_invocable_v<RangeCREndT, MemberBeginOnly&>);
 
-struct FunctionBeginOnly {
+struct FunctionBeginOnly
+{
   __host__ __device__ friend bidirectional_iterator<int*> begin(FunctionBeginOnly&);
 };
 static_assert(!cuda::std::is_invocable_v<RangeREndT, FunctionBeginOnly&>);
 static_assert(!cuda::std::is_invocable_v<RangeCREndT, FunctionBeginOnly&>);
 
-struct MemberEndOnly {
+struct MemberEndOnly
+{
   __host__ __device__ bidirectional_iterator<int*> end() const;
 };
 static_assert(!cuda::std::is_invocable_v<RangeREndT, MemberEndOnly&>);
 static_assert(!cuda::std::is_invocable_v<RangeCREndT, MemberEndOnly&>);
 
-struct FunctionEndOnly {
+struct FunctionEndOnly
+{
   __host__ __device__ friend bidirectional_iterator<int*> end(FunctionEndOnly&);
 };
 static_assert(!cuda::std::is_invocable_v<RangeREndT, FunctionEndOnly&>);
@@ -438,18 +581,20 @@ static_assert(!cuda::std::is_invocable_v<RangeCREndT, FunctionEndOnly&>);
 // Make sure there is no clash between the following cases:
 // - the case that handles classes defining member `rbegin` and `rend` functions;
 // - the case that handles classes defining `begin` and `end` functions returning reversible iterators.
-struct MemberBeginAndRBegin {
+struct MemberBeginAndRBegin
+{
   __host__ __device__ int* begin() const;
   __host__ __device__ int* end() const;
   __host__ __device__ int* rbegin() const;
   __host__ __device__ int* rend() const;
 };
-static_assert( cuda::std::is_invocable_v<RangeREndT, MemberBeginAndRBegin&>);
-static_assert( cuda::std::is_invocable_v<RangeCREndT, MemberBeginAndRBegin&>);
-static_assert( cuda::std::same_as<cuda::std::invoke_result_t<RangeREndT, MemberBeginAndRBegin&>, int*>);
-static_assert( cuda::std::same_as<cuda::std::invoke_result_t<RangeCREndT, MemberBeginAndRBegin&>, int*>);
+static_assert(cuda::std::is_invocable_v<RangeREndT, MemberBeginAndRBegin&>);
+static_assert(cuda::std::is_invocable_v<RangeCREndT, MemberBeginAndRBegin&>);
+static_assert(cuda::std::same_as<cuda::std::invoke_result_t<RangeREndT, MemberBeginAndRBegin&>, int*>);
+static_assert(cuda::std::same_as<cuda::std::invoke_result_t<RangeCREndT, MemberBeginAndRBegin&>, int*>);
 
-__host__ __device__ TEST_CONSTEXPR_CXX17 bool testBeginEnd() {
+__host__ __device__ TEST_CONSTEXPR_CXX17 bool testBeginEnd()
+{
   MemberBeginEnd a{};
   const MemberBeginEnd aa{};
   assert(base(cuda::std::ranges::rend(a).base()) == &a.b);
@@ -484,16 +629,18 @@ ASSERT_NOEXCEPT(cuda::std::ranges::rend(cuda::std::declval<int (&)[10]>()));
 ASSERT_NOEXCEPT(cuda::std::ranges::crend(cuda::std::declval<int (&)[10]>()));
 
 #if !defined(TEST_COMPILER_MSVC_2019)
-_LIBCUDACXX_CPO_ACCESSIBILITY struct NoThrowMemberREnd {
+_LIBCUDACXX_CPO_ACCESSIBILITY struct NoThrowMemberREnd
+{
   __host__ __device__ ThrowingIterator<int> rbegin() const;
   __host__ __device__ ThrowingIterator<int> rend() const noexcept; // auto(t.rend()) doesn't throw
 } ntmre;
 static_assert(noexcept(cuda::std::ranges::rend(ntmre)));
 static_assert(noexcept(cuda::std::ranges::crend(ntmre)));
 
-_LIBCUDACXX_CPO_ACCESSIBILITY struct NoThrowADLREnd {
+_LIBCUDACXX_CPO_ACCESSIBILITY struct NoThrowADLREnd
+{
   __host__ __device__ ThrowingIterator<int> rbegin() const;
-  __host__ __device__ friend ThrowingIterator<int> rend(NoThrowADLREnd&) noexcept;  // auto(rend(t)) doesn't throw
+  __host__ __device__ friend ThrowingIterator<int> rend(NoThrowADLREnd&) noexcept; // auto(rend(t)) doesn't throw
   __host__ __device__ friend ThrowingIterator<int> rend(const NoThrowADLREnd&) noexcept;
 } ntare;
 static_assert(noexcept(cuda::std::ranges::rend(ntare)));
@@ -501,7 +648,8 @@ static_assert(noexcept(cuda::std::ranges::crend(ntare)));
 #endif // !TEST_COMPILER_MSVC_2019
 
 #if !defined(TEST_COMPILER_ICC)
-_LIBCUDACXX_CPO_ACCESSIBILITY struct NoThrowMemberREndReturnsRef {
+_LIBCUDACXX_CPO_ACCESSIBILITY struct NoThrowMemberREndReturnsRef
+{
   __host__ __device__ ThrowingIterator<int> rbegin() const;
   __host__ __device__ ThrowingIterator<int>& rend() const noexcept; // auto(t.rend()) may throw
 } ntmrerr;
@@ -509,14 +657,16 @@ static_assert(!noexcept(cuda::std::ranges::rend(ntmrerr)));
 static_assert(!noexcept(cuda::std::ranges::crend(ntmrerr)));
 #endif // !TEST_COMPILER_ICC
 
-_LIBCUDACXX_CPO_ACCESSIBILITY struct REndReturnsArrayRef {
-  __host__ __device__ auto rbegin() const noexcept -> int(&)[10];
-  __host__ __device__ auto rend() const noexcept -> int(&)[10];
+_LIBCUDACXX_CPO_ACCESSIBILITY struct REndReturnsArrayRef
+{
+  __host__ __device__ auto rbegin() const noexcept -> int (&)[10];
+  __host__ __device__ auto rend() const noexcept -> int (&)[10];
 } rerar;
 static_assert(noexcept(cuda::std::ranges::rend(rerar)));
 static_assert(noexcept(cuda::std::ranges::crend(rerar)));
 
-_LIBCUDACXX_CPO_ACCESSIBILITY struct NoThrowBeginThrowingEnd {
+_LIBCUDACXX_CPO_ACCESSIBILITY struct NoThrowBeginThrowingEnd
+{
   __host__ __device__ int* begin() const noexcept;
   __host__ __device__ int* end() const;
 } ntbte;
@@ -524,7 +674,8 @@ static_assert(noexcept(cuda::std::ranges::rend(ntbte)));
 static_assert(noexcept(cuda::std::ranges::crend(ntbte)));
 
 #if !defined(TEST_COMPILER_ICC)
-_LIBCUDACXX_CPO_ACCESSIBILITY struct NoThrowEndThrowingBegin {
+_LIBCUDACXX_CPO_ACCESSIBILITY struct NoThrowEndThrowingBegin
+{
   __host__ __device__ int* begin() const;
   __host__ __device__ int* end() const noexcept;
 } ntetb;
@@ -535,14 +686,19 @@ static_assert(!noexcept(cuda::std::ranges::crend(ntetb)));
 #if TEST_STD_VER > 2017
 // Test ADL-proofing.
 struct Incomplete;
-template<class T> struct Holder { T t; };
+template <class T>
+struct Holder
+{
+  T t;
+};
 static_assert(!cuda::std::is_invocable_v<RangeREndT, Holder<Incomplete>*>);
 static_assert(!cuda::std::is_invocable_v<RangeREndT, Holder<Incomplete>*&>);
 static_assert(!cuda::std::is_invocable_v<RangeCREndT, Holder<Incomplete>*>);
 static_assert(!cuda::std::is_invocable_v<RangeCREndT, Holder<Incomplete>*&>);
 #endif // TEST_STD_VER > 2017
 
-int main(int, char**) {
+int main(int, char**)
+{
   static_assert(testReturnTypes());
 
   testArray();
