@@ -15,17 +15,19 @@
 // template<class>
 //  inline constexpr bool enable_borrowed_range = false;
 
-#include <cuda/std/ranges>
 #include <cuda/std/array>
+#include <cuda/std/ranges>
 #if defined(_LIBCUDACXX_HAS_VECTOR)
-#include <cuda/std/vector>
+#  include <cuda/std/vector>
 #endif
 
 #include "test_macros.h"
 
-struct S {};
+struct S
+{};
 
-__host__ __device__ void test() {
+__host__ __device__ void test()
+{
   using cuda::std::ranges::enable_borrowed_range;
   static_assert(!enable_borrowed_range<char>);
   static_assert(!enable_borrowed_range<int>);
@@ -33,15 +35,16 @@ __host__ __device__ void test() {
   static_assert(!enable_borrowed_range<S>);
 
   // Sequence containers
-  static_assert(!enable_borrowed_range<cuda::std::array<int, 0> >);
-  static_assert(!enable_borrowed_range<cuda::std::array<int, 42> >);
+  static_assert(!enable_borrowed_range<cuda::std::array<int, 0>>);
+  static_assert(!enable_borrowed_range<cuda::std::array<int, 42>>);
 #if defined(_LIBCUDACXX_HAS_VECTOR)
-  static_assert(!enable_borrowed_range<cuda::std::vector<int> >);
+  static_assert(!enable_borrowed_range<cuda::std::vector<int>>);
 #endif
 
   // Both cuda::std::span and cuda::std::string_view have their own test.
 }
 
-int main(int, char**) {
+int main(int, char**)
+{
   return 0;
 }
