@@ -18,30 +18,36 @@
 
 #include <cuda/std/barrier>
 
-#include "test_macros.h"
 #include "concurrent_agents.h"
 #include "cuda_space_selector.h"
+#include "test_macros.h"
 
-template<template<typename> typename Barrier,
-    template<typename, typename> typename Selector,
-    typename Initializer = constructor_initializer>
-__host__ __device__
-void test()
+template <template <typename> typename Barrier,
+          template <typename, typename>
+          typename Selector,
+          typename Initializer = constructor_initializer>
+__host__ __device__ void test()
 {
   global_memory_selector<int> int_sel;
-  SHARED int * x;
+  SHARED int* x;
   x = int_sel.construct(0);
 
-  auto comp = LAMBDA () { *x += 1; };
+  auto comp = LAMBDA()
+  {
+    *x += 1;
+  };
 
   Selector<Barrier<decltype(comp)>, Initializer> sel;
-  SHARED Barrier<decltype(comp)> * b;
+  SHARED Barrier<decltype(comp)>* b;
   b = sel.construct(2, comp);
 
-  auto worker = LAMBDA () {
-      for(int i = 0; i < 10; ++i)
-        b->arrive_and_wait();
-      assert(*x == 10);
+  auto worker = LAMBDA()
+  {
+    for (int i = 0; i < 10; ++i)
+    {
+      b->arrive_and_wait();
+    }
+    assert(*x == 10);
   };
 
   concurrent_agents_launch(worker, worker);
@@ -49,35 +55,33 @@ void test()
   assert(*x == 10);
 }
 
-template<typename Comp>
+template <typename Comp>
 using std_barrier = cuda::std::barrier<Comp>;
-template<typename Comp>
+template <typename Comp>
 using block_barrier = cuda::barrier<cuda::thread_scope_block, Comp>;
-template<typename Comp>
+template <typename Comp>
 using device_barrier = cuda::barrier<cuda::thread_scope_device, Comp>;
-template<typename Comp>
+template <typename Comp>
 using system_barrier = cuda::barrier<cuda::thread_scope_system, Comp>;
 
 int main(int, char**)
 {
-    NV_IF_ELSE_TARGET(NV_IS_HOST,(
-        cuda_thread_count = 2;
+  NV_IF_ELSE_TARGET(
+    NV_IS_HOST,
+    (cuda_thread_count = 2;
 
-        test<std_barrier, local_memory_selector>();
-        test<block_barrier, local_memory_selector>();
-        test<device_barrier, local_memory_selector>();
-        test<system_barrier, local_memory_selector>();
-    ),(
-        test<std_barrier, shared_memory_selector>();
-        test<block_barrier, shared_memory_selector>();
-        test<device_barrier, shared_memory_selector>();
-        test<system_barrier, shared_memory_selector>();
+     test<std_barrier, local_memory_selector>();
+     test<block_barrier, local_memory_selector>();
+     test<device_barrier, local_memory_selector>();
+     test<system_barrier, local_memory_selector>();),
+    (test<std_barrier, shared_memory_selector>(); test<block_barrier, shared_memory_selector>();
+     test<device_barrier, shared_memory_selector>();
+     test<system_barrier, shared_memory_selector>();
 
-        test<std_barrier, global_memory_selector>();
-        test<block_barrier, global_memory_selector>();
-        test<device_barrier, global_memory_selector>();
-        test<system_barrier, global_memory_selector>();
-    ))
+     test<std_barrier, global_memory_selector>();
+     test<block_barrier, global_memory_selector>();
+     test<device_barrier, global_memory_selector>();
+     test<system_barrier, global_memory_selector>();))
 
-    return 0;
+  return 0;
 }
