@@ -9,6 +9,7 @@
 
 // UNSUPPORTED: c++03, c++11
 // UNSUPPORTED: libcpp-no-exceptions
+// UNSUPPORTED: nvrtc
 
 // explicit bad_expected_access(E e);
 
@@ -19,16 +20,16 @@
 #include <cuda/std/expected>
 #include <cuda/std/utility>
 
-#include "test_macros.h"
 #include "MoveOnly.h"
+#include "test_macros.h"
 
 // test explicit
-static_assert(cuda::std::convertible_to<int, int>);
-static_assert(!cuda::std::convertible_to<int, cuda::std::bad_expected_access<int>>);
+static_assert(cuda::std::convertible_to<int, int>, "");
+static_assert(!cuda::std::convertible_to<int, cuda::std::bad_expected_access<int>>, "");
 
-int main(int, char**) {
-  cuda::std::bad_expected_access<MoveOnly> b(MoveOnly{3});
-  assert(b.error().get() == 3);
+int main(int, char**)
+{
+  NV_IF_TARGET(NV_IS_HOST, (cuda::std::bad_expected_access<MoveOnly> b(MoveOnly{3}); assert(b.error().get() == 3);))
 
   return 0;
 }
