@@ -38,12 +38,14 @@
 #include "../../types.h"
 #include "test_macros.h"
 
-struct NotCopyConstructible {
+struct NotCopyConstructible
+{
   NotCopyConstructible(const NotCopyConstructible&)            = delete;
   NotCopyConstructible& operator=(const NotCopyConstructible&) = default;
 };
 
-struct NotCopyAssignable {
+struct NotCopyAssignable
+{
   NotCopyAssignable(const NotCopyAssignable&)            = default;
   NotCopyAssignable& operator=(const NotCopyAssignable&) = delete;
 };
@@ -60,21 +62,24 @@ static_assert(cuda::std::is_assignable_v<cuda::std::expected<int, int>&, cuda::s
 static_assert(cuda::std::is_assignable_v<cuda::std::expected<int, int>&, cuda::std::unexpected<int>>, "");
 
 // !is_constructible_v<T, U>
-struct NoCtorFromInt {
+struct NoCtorFromInt
+{
   __host__ __device__ NoCtorFromInt(int) = delete;
   __host__ __device__ NoCtorFromInt& operator=(int);
 };
 static_assert(!cuda::std::is_assignable_v<cuda::std::expected<NoCtorFromInt, int>&, int>, "");
 
 // !is_assignable_v<T&, U>
-struct NoAssignFromInt {
+struct NoAssignFromInt
+{
   __host__ __device__ explicit NoAssignFromInt(int);
   __host__ __device__ NoAssignFromInt& operator=(int) = delete;
 };
 static_assert(!cuda::std::is_assignable_v<cuda::std::expected<NoAssignFromInt, int>&, int>, "");
 
 template <bool moveNoexcept, bool convertNoexcept>
-struct MaybeNoexcept {
+struct MaybeNoexcept
+{
   __host__ __device__ explicit MaybeNoexcept(int) noexcept(convertNoexcept);
   __host__ __device__ MaybeNoexcept(MaybeNoexcept&&) noexcept(moveNoexcept);
   MaybeNoexcept& operator=(MaybeNoexcept&&) = default;
@@ -87,19 +92,23 @@ static_assert(cuda::std::is_assignable_v<cuda::std::expected<MaybeNoexcept<false
 
 // is_nothrow_constructible_v<T, U> && !is_nothrow_move_constructible_v<T> &&
 // !is_nothrow_move_constructible_v<E>
-static_assert(cuda::std::is_assignable_v<cuda::std::expected<MaybeNoexcept<false, true>, MaybeNoexcept<false, false>>&, int>, "");
+static_assert(
+  cuda::std::is_assignable_v<cuda::std::expected<MaybeNoexcept<false, true>, MaybeNoexcept<false, false>>&, int>, "");
 
 // !is_nothrow_constructible_v<T, U> && is_nothrow_move_constructible_v<T> &&
 // !is_nothrow_move_constructible_v<E>
-static_assert(cuda::std::is_assignable_v<cuda::std::expected<MaybeNoexcept<true, false>, MaybeNoexcept<false, false>>&, int>, "");
+static_assert(
+  cuda::std::is_assignable_v<cuda::std::expected<MaybeNoexcept<true, false>, MaybeNoexcept<false, false>>&, int>, "");
 
 #ifndef TEST_COMPILER_ICC
 // !is_nothrow_constructible_v<T, U> && !is_nothrow_move_constructible_v<T> &&
 // !is_nothrow_move_constructible_v<E>
-static_assert(!cuda::std::is_assignable_v<cuda::std::expected<MaybeNoexcept<false, false>, MaybeNoexcept<false, false>>&, int>, "");
+static_assert(
+  !cuda::std::is_assignable_v<cuda::std::expected<MaybeNoexcept<false, false>, MaybeNoexcept<false, false>>&, int>, "");
 #endif // TEST_COMPILER_ICC
 
-__host__ __device__ TEST_CONSTEXPR_CXX20 bool test() {
+__host__ __device__ TEST_CONSTEXPR_CXX20 bool test()
+{
   // If has_value() is true, equivalent to: val = cuda::std::forward<U>(v);
   // Copy
   {
@@ -304,10 +313,14 @@ __host__ __device__ TEST_CONSTEXPR_CXX20 bool test() {
   // Test default template argument.
   // Without it, the template parameter cannot be deduced from an initializer list
   {
-    struct Bar {
+    struct Bar
+    {
       int i;
       int j;
-      __host__ __device__ constexpr Bar(int ii, int jj) : i(ii), j(jj) {}
+      __host__ __device__ constexpr Bar(int ii, int jj)
+          : i(ii)
+          , j(jj)
+      {}
     };
 
     cuda::std::expected<Bar, int> e({5, 6});
@@ -319,25 +332,31 @@ __host__ __device__ TEST_CONSTEXPR_CXX20 bool test() {
   return true;
 }
 
-__host__ __device__ void testException() {
 #ifndef TEST_HAS_NO_EXCEPTIONS
+void test_exceptions()
+{
   cuda::std::expected<ThrowOnConvert, int> e1(cuda::std::unexpect, 5);
-  try {
+  try
+  {
     e1 = 10;
     assert(false);
-  } catch (Except) {
+  }
+  catch (Except)
+  {
     assert(!e1.has_value());
     assert(e1.error() == 5);
   }
-
-#endif // TEST_HAS_NO_EXCEPTIONS
 }
+#endif // !TEST_HAS_NO_EXCEPTIONS
 
-int main(int, char**) {
+int main(int, char**)
+{
   test();
 #if TEST_STD_VER > 2017 && defined(_LIBCUDACXX_ADDRESSOF)
   static_assert(test());
 #endif // TEST_STD_VER > 2017 && defined(_LIBCUDACXX_ADDRESSOF)
-  testException();
+#ifndef TEST_HAS_NO_EXCEPTIONS
+  NV_IF_TARGET(NV_IS_HOST, (test_exceptions();))
+#endif // !TEST_HAS_NO_EXCEPTIONS
   return 0;
 }
