@@ -41,21 +41,27 @@
 #include "../../types.h"
 #include "test_macros.h"
 
-struct NotCopyConstructible {
+struct NotCopyConstructible
+{
   NotCopyConstructible(const NotCopyConstructible&)            = delete;
   NotCopyConstructible& operator=(const NotCopyConstructible&) = default;
 };
 
-struct NotCopyAssignable {
+struct NotCopyAssignable
+{
   NotCopyAssignable(const NotCopyAssignable&)            = default;
   NotCopyAssignable& operator=(const NotCopyAssignable&) = delete;
 };
 
-struct MoveMayThrow {
+struct MoveMayThrow
+{
   MoveMayThrow(MoveMayThrow const&)            = default;
   MoveMayThrow& operator=(const MoveMayThrow&) = default;
   __host__ __device__ MoveMayThrow(MoveMayThrow&&) noexcept(false) {}
-  __host__ __device__ MoveMayThrow& operator=(MoveMayThrow&&) noexcept(false) { return *this; }
+  __host__ __device__ MoveMayThrow& operator=(MoveMayThrow&&) noexcept(false)
+  {
+    return *this;
+  }
 };
 
 // Test constraints
@@ -81,10 +87,13 @@ static_assert(cuda::std::is_copy_assignable_v<cuda::std::expected<int, MoveMayTh
 
 #ifndef TEST_COMPILER_ICC
 // !is_nothrow_move_constructible_v<T> && !is_nothrow_move_constructible_v<E>
+static_assert(
+  cuda::std::__expected_can_copy_assign<MoveMayThrow, MoveMayThrow> == cuda::std::__smf_availability::__deleted, "");
 static_assert(!cuda::std::is_copy_assignable_v<cuda::std::expected<MoveMayThrow, MoveMayThrow>>, "");
 #endif // TEST_COMPILER_ICC
 
-__host__ __device__ TEST_CONSTEXPR_CXX20 bool test() {
+__host__ __device__ TEST_CONSTEXPR_CXX20 bool test()
+{
   // If this->has_value() && rhs.has_value() is true, equivalent to val = *rhs.
   {
     Traced::state oldState{};
@@ -249,11 +258,16 @@ __host__ __device__ TEST_CONSTEXPR_CXX20 bool test() {
   return true;
 }
 
-__host__ __device__ void testException() {
 #ifndef TEST_HAS_NO_EXCEPTIONS
-  struct ThrowOnCopyMoveMayThrow {
+void test_exceptions()
+{
+  struct ThrowOnCopyMoveMayThrow
+  {
     ThrowOnCopyMoveMayThrow() = default;
-    ThrowOnCopyMoveMayThrow(const ThrowOnCopyMoveMayThrow&) { throw Except{}; };
+    ThrowOnCopyMoveMayThrow(const ThrowOnCopyMoveMayThrow&)
+    {
+      throw Except{};
+    };
     ThrowOnCopyMoveMayThrow& operator=(const ThrowOnCopyMoveMayThrow&) = default;
     ThrowOnCopyMoveMayThrow(ThrowOnCopyMoveMayThrow&&) noexcept(false) {}
   };
@@ -262,10 +276,13 @@ __host__ __device__ void testException() {
   {
     cuda::std::expected<ThrowOnCopyMoveMayThrow, int> e1(cuda::std::unexpect, 5);
     const cuda::std::expected<ThrowOnCopyMoveMayThrow, int> e2(cuda::std::in_place);
-    try {
+    try
+    {
       e1 = e2;
       assert(false);
-    } catch (Except) {
+    }
+    catch (Except)
+    {
       assert(!e1.has_value());
       assert(e1.error() == 5);
     }
@@ -275,22 +292,28 @@ __host__ __device__ void testException() {
   {
     cuda::std::expected<int, ThrowOnCopyMoveMayThrow> e1(5);
     const cuda::std::expected<int, ThrowOnCopyMoveMayThrow> e2(cuda::std::unexpect);
-    try {
+    try
+    {
       e1 = e2;
       assert(false);
-    } catch (Except) {
+    }
+    catch (Except)
+    {
       assert(e1.has_value());
       assert(e1.value() == 5);
     }
   }
-#endif // TEST_HAS_NO_EXCEPTIONS
 }
+#endif // !TEST_HAS_NO_EXCEPTIONS
 
-int main(int, char**) {
+int main(int, char**)
+{
   test();
 #if TEST_STD_VER > 2017 && defined(_LIBCUDACXX_ADDRESSOF)
   static_assert(test());
 #endif // TEST_STD_VER > 2017 && defined(_LIBCUDACXX_ADDRESSOF)
-  testException();
+#ifndef TEST_HAS_NO_EXCEPTIONS
+  NV_IF_TARGET(NV_IS_HOST, (test_exceptions();))
+#endif // !TEST_HAS_NO_EXCEPTIONS
   return 0;
 }
