@@ -34,18 +34,15 @@
 #include "test_macros.h"
 
 template <class T, class... Args>
-_LIBCUDACXX_CONCEPT_FRAGMENT(
-  CanEmplace_,
-  requires(T t, Args&&... args)(
-    (t.emplace(cuda::std::forward<Args>(args)...))
-  ));
+_LIBCUDACXX_CONCEPT_FRAGMENT(CanEmplace_, requires(T t, Args&&... args)((t.emplace(cuda::std::forward<Args>(args)...))));
 template <class T, class... Args>
 constexpr bool CanEmplace = _LIBCUDACXX_FRAGMENT(CanEmplace_, T, Args...);
 
 static_assert(CanEmplace<cuda::std::expected<int, int>, int>, "");
 
 template <bool Noexcept>
-struct CtorFromInt {
+struct CtorFromInt
+{
   __host__ __device__ CtorFromInt(int) noexcept(Noexcept);
   __host__ __device__ CtorFromInt(int, int) noexcept(Noexcept);
 };
@@ -57,7 +54,8 @@ static_assert(!CanEmplace<cuda::std::expected<CtorFromInt<false>, int>, int>, ""
 static_assert(!CanEmplace<cuda::std::expected<CtorFromInt<false>, int>, int, int>, "");
 #endif // TEST_COMPILER_ICC
 
-__host__ __device__ TEST_CONSTEXPR_CXX20 bool test() {
+__host__ __device__ TEST_CONSTEXPR_CXX20 bool test()
+{
   // has_value
   {
     BothNoexcept::state oldState{};
@@ -88,7 +86,8 @@ __host__ __device__ TEST_CONSTEXPR_CXX20 bool test() {
   return true;
 }
 
-int main(int, char**) {
+int main(int, char**)
+{
   test();
 #if TEST_STD_VER > 2017 && defined(_LIBCUDACXX_ADDRESSOF)
   static_assert(test());
