@@ -22,7 +22,8 @@
 //
 // Throws: Any exception thrown by the initialization of val or unex.
 //
-// Remarks: The exception specification is equivalent to is_nothrow_move_constructible_v<T> && is_nothrow_move_constructible_v<E>.
+// Remarks: The exception specification is equivalent to is_nothrow_move_constructible_v<T> &&
+// is_nothrow_move_constructible_v<E>.
 //
 // This constructor is trivial if
 // - is_trivially_move_constructible_v<T> is true and
@@ -35,27 +36,40 @@
 
 #include "test_macros.h"
 
-struct NonMovable {
+struct NonMovable
+{
   NonMovable(NonMovable&&) = delete;
 };
 
-struct MovableNonTrivial {
+struct MovableNonTrivial
+{
   int i;
-  __host__ __device__ constexpr MovableNonTrivial(int ii) : i(ii) {}
-  __host__ __device__ constexpr MovableNonTrivial(MovableNonTrivial&& o) : i(o.i) { o.i = 0; }
+  __host__ __device__ constexpr MovableNonTrivial(int ii)
+      : i(ii)
+  {}
+  __host__ __device__ constexpr MovableNonTrivial(MovableNonTrivial&& o)
+      : i(o.i)
+  {
+    o.i = 0;
+  }
 #if TEST_STD_VER > 2017
   __host__ __device__ friend constexpr bool operator==(const MovableNonTrivial&, const MovableNonTrivial&) = default;
 #else
-  __host__ __device__ friend constexpr bool operator==(const MovableNonTrivial& lhs, const MovableNonTrivial& rhs) noexcept {
+  __host__ __device__ friend constexpr bool
+  operator==(const MovableNonTrivial& lhs, const MovableNonTrivial& rhs) noexcept
+  {
     return lhs.i == rhs.i;
   };
-  __host__ __device__ friend constexpr bool operator!=(const MovableNonTrivial& lhs, const MovableNonTrivial& rhs) noexcept {
+  __host__ __device__ friend constexpr bool
+  operator!=(const MovableNonTrivial& lhs, const MovableNonTrivial& rhs) noexcept
+  {
     return lhs.i != rhs.i;
   };
 #endif // TEST_STD_VER > 2017
 };
 
-struct MoveMayThrow {
+struct MoveMayThrow
+{
   __host__ __device__ MoveMayThrow(MoveMayThrow&&) {}
 };
 
@@ -76,7 +90,8 @@ static_assert(!cuda::std::is_move_constructible_v<cuda::std::expected<NonMovable
 static_assert(cuda::std::is_trivially_move_constructible_v<cuda::std::expected<int, int>>, "");
 static_assert(!cuda::std::is_trivially_move_constructible_v<cuda::std::expected<MovableNonTrivial, int>>, "");
 static_assert(!cuda::std::is_trivially_move_constructible_v<cuda::std::expected<int, MovableNonTrivial>>, "");
-static_assert(!cuda::std::is_trivially_move_constructible_v<cuda::std::expected<MovableNonTrivial, MovableNonTrivial>>, "");
+static_assert(!cuda::std::is_trivially_move_constructible_v<cuda::std::expected<MovableNonTrivial, MovableNonTrivial>>,
+              "");
 
 #ifndef TEST_COMPILER_ICC
 // Test: The exception specification is equivalent to
@@ -87,7 +102,8 @@ static_assert(!cuda::std::is_nothrow_move_constructible_v<cuda::std::expected<in
 static_assert(!cuda::std::is_nothrow_move_constructible_v<cuda::std::expected<MoveMayThrow, MoveMayThrow>>, "");
 #endif // TEST_COMPILER_ICC
 
-__host__ __device__ TEST_CONSTEXPR_CXX20 bool test() {
+__host__ __device__ TEST_CONSTEXPR_CXX20 bool test()
+{
   // move the value non-trivial
   {
     cuda::std::expected<MovableNonTrivial, int> e1(5);
@@ -128,45 +144,57 @@ __host__ __device__ TEST_CONSTEXPR_CXX20 bool test() {
   return true;
 }
 
-__host__ __device__ void testException() {
 #ifndef TEST_HAS_NO_EXCEPTIONS
-  struct Except {};
+void test_exceptions()
+{
+  struct Except
+  {};
 
-  struct Throwing {
+  struct Throwing
+  {
     Throwing() = default;
-    __host__ __device__ Throwing(Throwing&&) { throw Except{}; }
+    __host__ __device__ Throwing(Throwing&&)
+    {
+      throw Except{};
+    }
   };
 
   // throw on moving value
   {
     cuda::std::expected<Throwing, int> e1;
-    try {
+    try
+    {
       auto e2 = cuda::std::move(e1);
       unused(e2);
       assert(false);
-    } catch (Except) {
     }
+    catch (Except)
+    {}
   }
 
   // throw on moving error
   {
     cuda::std::expected<int, Throwing> e1(cuda::std::unexpect);
-    try {
+    try
+    {
       auto e2 = cuda::std::move(e1);
       unused(e2);
       assert(false);
-    } catch (Except) {
     }
+    catch (Except)
+    {}
   }
-
-#endif // TEST_HAS_NO_EXCEPTIONS
 }
+#endif // !TEST_HAS_NO_EXCEPTIONS
 
-int main(int, char**) {
+int main(int, char**)
+{
   test();
 #if TEST_STD_VER > 2017 && defined(_LIBCUDACXX_ADDRESSOF)
   static_assert(test(), "");
 #endif // TEST_STD_VER > 2017 && defined(_LIBCUDACXX_ADDRESSOF)
-  testException();
+#ifndef TEST_HAS_NO_EXCEPTIONS
+  NV_IF_TARGET(NV_IS_HOST, (test_exceptions();))
+#endif // !TEST_HAS_NO_EXCEPTIONS
   return 0;
 }
