@@ -36,11 +36,13 @@
 static_assert(cuda::std::is_constructible_v<cuda::std::expected<int, int>, int>, "");
 
 // is_same_v<remove_cvref_t<U>, in_place_t>
-struct FromJustInplace {
+struct FromJustInplace
+{
   __host__ __device__ FromJustInplace(cuda::std::in_place_t);
 };
 static_assert(!cuda::std::is_constructible_v<cuda::std::expected<FromJustInplace, int>, cuda::std::in_place_t>, "");
-static_assert(!cuda::std::is_constructible_v<cuda::std::expected<FromJustInplace, int>, cuda::std::in_place_t const&>, "");
+static_assert(!cuda::std::is_constructible_v<cuda::std::expected<FromJustInplace, int>, cuda::std::in_place_t const&>,
+              "");
 
 // is_same_v<expected, remove_cvref_t<U>>
 // Note that result is true because it is covered by the constructors that take expected
@@ -51,36 +53,49 @@ static_assert(cuda::std::is_constructible_v<cuda::std::expected<int, int>, cuda:
 static_assert(cuda::std::is_constructible_v<cuda::std::expected<int, int>, cuda::std::unexpected<int>&>, "");
 
 // !is_constructible_v<T, U>
-struct foo {};
+struct foo
+{};
 static_assert(!cuda::std::is_constructible_v<cuda::std::expected<int, int>, foo>, "");
 
 // test explicit(!is_convertible_v<U, T>)
-struct NotConvertible {
+struct NotConvertible
+{
   __host__ __device__ explicit NotConvertible(int);
 };
 static_assert(cuda::std::is_convertible_v<int, cuda::std::expected<int, int>>, "");
 static_assert(!cuda::std::is_convertible_v<int, cuda::std::expected<NotConvertible, int>>, "");
 
-struct CopyOnly {
+struct CopyOnly
+{
   int i;
-  __host__ __device__ constexpr CopyOnly(int ii) : i(ii) {}
-  CopyOnly(const CopyOnly&) = default;
-  __host__ __device__ CopyOnly(CopyOnly&&)      = delete;
-  __host__ __device__ friend constexpr bool operator==(const CopyOnly& mi, int ii) { return mi.i == ii; }
+  __host__ __device__ constexpr CopyOnly(int ii)
+      : i(ii)
+  {}
+  CopyOnly(const CopyOnly&)                = default;
+  __host__ __device__ CopyOnly(CopyOnly&&) = delete;
+  __host__ __device__ friend constexpr bool operator==(const CopyOnly& mi, int ii)
+  {
+    return mi.i == ii;
+  }
 #if TEST_STD_VER < 2020
-  __host__ __device__ friend constexpr bool operator!=(const CopyOnly& mi, int ii) { return mi.i != ii; }
+  __host__ __device__ friend constexpr bool operator!=(const CopyOnly& mi, int ii)
+  {
+    return mi.i != ii;
+  }
 #endif // TEST_STD_VER < 2020
 };
 
 template <class T>
-__host__ __device__ constexpr void testInt() {
+__host__ __device__ constexpr void testInt()
+{
   cuda::std::expected<T, int> e(5);
   assert(e.has_value());
   assert(e.value() == 5);
 }
 
 template <class T>
-__host__ __device__ constexpr void testLValue() {
+__host__ __device__ constexpr void testLValue()
+{
   T t(5);
   cuda::std::expected<T, int> e(t);
   assert(e.has_value());
@@ -88,13 +103,15 @@ __host__ __device__ constexpr void testLValue() {
 }
 
 template <class T>
-__host__ __device__ constexpr void testRValue() {
+__host__ __device__ constexpr void testRValue()
+{
   cuda::std::expected<T, int> e(T(5));
   assert(e.has_value());
   assert(e.value() == 5);
 }
 
-__host__ __device__ constexpr bool test() {
+__host__ __device__ constexpr bool test()
+{
   testInt<int>();
   testInt<CopyOnly>();
   testInt<MoveOnly>();
@@ -106,10 +123,14 @@ __host__ __device__ constexpr bool test() {
   // Test default template argument.
   // Without it, the template parameter cannot be deduced from an initializer list
   {
-    struct Bar {
+    struct Bar
+    {
       int i;
       int j;
-      __host__ __device__ constexpr Bar(int ii, int jj) : i(ii), j(jj) {}
+      __host__ __device__ constexpr Bar(int ii, int jj)
+          : i(ii)
+          , j(jj)
+      {}
     };
 
     cuda::std::expected<Bar, int> e({5, 6});
@@ -121,8 +142,10 @@ __host__ __device__ constexpr bool test() {
   // is exactly what is specified in the spec
   // see https://cplusplus.github.io/LWG/issue3836
   {
-    struct BaseError {};
-    struct DerivedError : BaseError {};
+    struct BaseError
+    {};
+    struct DerivedError : BaseError
+    {};
 
     cuda::std::expected<bool, DerivedError> e1(false);
     cuda::std::expected<bool, BaseError> e2(e1);
@@ -132,27 +155,38 @@ __host__ __device__ constexpr bool test() {
   return true;
 }
 
-__host__ __device__ void testException() {
 #ifndef TEST_HAS_NO_EXCEPTIONS
-  struct Except {};
+void test_exceptions()
+{
+  struct Except
+  {};
 
-  struct Throwing {
-    __host__ __device__ Throwing(int) { throw Except{}; };
+  struct Throwing
+  {
+    __host__ __device__ Throwing(int)
+    {
+      throw Except{};
+    };
   };
 
-  try {
+  try
+  {
     cuda::std::expected<Throwing, int> u(5);
     assert(false);
-  } catch (Except) {
   }
-#endif // TEST_HAS_NO_EXCEPTIONS
+  catch (Except)
+  {}
 }
+#endif // !TEST_HAS_NO_EXCEPTIONS
 
-int main(int, char**) {
+int main(int, char**)
+{
   test();
 #if TEST_STD_VER > 2017 && defined(_LIBCUDACXX_ADDRESSOF)
   static_assert(test(), "");
 #endif // TEST_STD_VER > 2017 && defined(_LIBCUDACXX_ADDRESSOF)
-  testException();
+#ifndef TEST_HAS_NO_EXCEPTIONS
+  NV_IF_TARGET(NV_IS_HOST, (test_exceptions();))
+#endif // !TEST_HAS_NO_EXCEPTIONS
   return 0;
 }
