@@ -34,72 +34,89 @@
 static_assert(cuda::std::is_constructible_v<cuda::std::expected<int, int>, const cuda::std::unexpected<int>&>, "");
 
 // !is_constructible_v<E, GF>
-struct foo {};
+struct foo
+{};
 static_assert(!cuda::std::is_constructible_v<cuda::std::expected<int, int>, const cuda::std::unexpected<foo>&>, "");
-static_assert(!cuda::std::is_constructible_v<cuda::std::expected<int, MoveOnly>, const cuda::std::unexpected<MoveOnly>&>, "");
+static_assert(
+  !cuda::std::is_constructible_v<cuda::std::expected<int, MoveOnly>, const cuda::std::unexpected<MoveOnly>&>, "");
 
 // explicit(!is_convertible_v<const G&, E>)
-struct NotConvertible {
+struct NotConvertible
+{
   __host__ __device__ explicit NotConvertible(int);
 };
 static_assert(cuda::std::is_convertible_v<const cuda::std::unexpected<int>&, cuda::std::expected<int, int>>, "");
-static_assert(!cuda::std::is_convertible_v<const cuda::std::unexpected<int>&, cuda::std::expected<int, NotConvertible>>, "");
+static_assert(!cuda::std::is_convertible_v<const cuda::std::unexpected<int>&, cuda::std::expected<int, NotConvertible>>,
+              "");
 
-struct MyInt {
+struct MyInt
+{
   int i;
-  __host__ __device__ constexpr MyInt(int ii) : i(ii) {}
+  __host__ __device__ constexpr MyInt(int ii)
+      : i(ii)
+  {}
 #if TEST_STD_VER > 2017
   __host__ __device__ friend constexpr bool operator==(const MyInt&, const MyInt&) = default;
 #else
-  __host__ __device__ friend constexpr bool operator==(const MyInt& lhs, const MyInt& rhs) noexcept {
+  __host__ __device__ friend constexpr bool operator==(const MyInt& lhs, const MyInt& rhs) noexcept
+  {
     return lhs.i == rhs.i;
   };
-  __host__ __device__ friend constexpr bool operator!=(const MyInt& lhs, const MyInt& rhs) noexcept {
+  __host__ __device__ friend constexpr bool operator!=(const MyInt& lhs, const MyInt& rhs) noexcept
+  {
     return lhs.i != rhs.i;
   };
 #endif // TEST_STD_VER > 2017
 };
 
 template <class T>
-__host__ __device__ constexpr void testUnexpected() {
+__host__ __device__ constexpr void testUnexpected()
+{
   const cuda::std::unexpected<int> u(5);
   cuda::std::expected<int, T> e(u);
   assert(!e.has_value());
   assert(e.error() == 5);
 }
 
-__host__ __device__ constexpr bool test() {
+__host__ __device__ constexpr bool test()
+{
   testUnexpected<int>();
   testUnexpected<MyInt>();
   return true;
 }
 
-__host__ __device__ void testException() {
 #ifndef TEST_HAS_NO_EXCEPTIONS
-  struct Except {};
-
-  struct Throwing {
-    __host__ __device__ Throwing(int) { throw Except{}; }
-  };
-
+struct Except
+{};
+struct Throwing
+{
+  __host__ __device__ Throwing(int)
   {
-    const cuda::std::unexpected<int> u(5);
-    try {
-      cuda::std::expected<int, Throwing> e(u);
-      unused(e);
-      assert(false);
-    } catch (Except) {
-    }
+    throw Except{};
   }
-
-#endif // TEST_HAS_NO_EXCEPTIONS
+};
+void test_exceptions()
+{
+  const cuda::std::unexpected<int> u(5);
+  try
+  {
+    cuda::std::expected<int, Throwing> e(u);
+    unused(e);
+    assert(false);
+  }
+  catch (const Except&)
+  {}
 }
+#endif // !TEST_HAS_NO_EXCEPTIONS
 
-int main(int, char**) {
+int main(int, char**)
+{
   test();
 #if TEST_STD_VER > 2017 && defined(_LIBCUDACXX_ADDRESSOF)
   static_assert(test(), "");
 #endif // TEST_STD_VER > 2017 && defined(_LIBCUDACXX_ADDRESSOF)
-  testException();
+#ifndef TEST_HAS_NO_EXCEPTIONS
+  NV_IF_TARGET(NV_IS_HOST, (test_exceptions();))
+#endif // !TEST_HAS_NO_EXCEPTIONS
   return 0;
 }
