@@ -27,7 +27,8 @@
 
 // Test Remarks: If is_trivially_destructible_v<T> is true, and is_trivially_destructible_v<E> is true,
 // then this destructor is a trivial destructor.
-struct NonTrivial {
+struct NonTrivial
+{
   __host__ __device__ ~NonTrivial() {}
 };
 
@@ -36,13 +37,20 @@ static_assert(!cuda::std::is_trivially_destructible_v<cuda::std::expected<NonTri
 static_assert(!cuda::std::is_trivially_destructible_v<cuda::std::expected<int, NonTrivial>>, "");
 static_assert(!cuda::std::is_trivially_destructible_v<cuda::std::expected<NonTrivial, NonTrivial>>, "");
 
-struct TrackedDestroy {
+struct TrackedDestroy
+{
   bool& destroyed;
-  __host__ __device__ constexpr TrackedDestroy(bool& b) : destroyed(b) {}
-  __host__ __device__ TEST_CONSTEXPR_CXX20 ~TrackedDestroy() { destroyed = true; }
+  __host__ __device__ constexpr TrackedDestroy(bool& b)
+      : destroyed(b)
+  {}
+  __host__ __device__ TEST_CONSTEXPR_CXX20 ~TrackedDestroy()
+  {
+    destroyed = true;
+  }
 };
 
-__host__ __device__ TEST_CONSTEXPR_CXX20 bool test() {
+__host__ __device__ TEST_CONSTEXPR_CXX20 bool test()
+{
   // has value
   {
     bool valueDestroyed = false;
@@ -66,7 +74,8 @@ __host__ __device__ TEST_CONSTEXPR_CXX20 bool test() {
   return true;
 }
 
-int main(int, char**) {
+int main(int, char**)
+{
   test();
 #if TEST_STD_VER > 2017 && defined(_LIBCUDACXX_ADDRESSOF)
   static_assert(test());
