@@ -23,7 +23,8 @@
 #include "test_macros.h"
 
 // Test Constraints:
-struct NotSwappable {
+struct NotSwappable
+{
   __host__ __device__ NotSwappable operator=(const NotSwappable&) = delete;
 };
 __host__ __device__ void swap(NotSwappable&, NotSwappable&) = delete;
@@ -36,7 +37,8 @@ static_assert(!cuda::std::is_swappable_v<cuda::std::expected<NotSwappable, int>>
 // !is_swappable_v<E>
 static_assert(!cuda::std::is_swappable_v<cuda::std::expected<int, NotSwappable>>, "");
 
-struct NotMoveContructible {
+struct NotMoveContructible
+{
   NotMoveContructible(NotMoveContructible&&) = delete;
   __host__ __device__ friend void swap(NotMoveContructible&, NotMoveContructible&) {}
 };
@@ -47,7 +49,8 @@ static_assert(!cuda::std::is_swappable_v<cuda::std::expected<NotMoveContructible
 // !is_move_constructible_v<E>
 static_assert(!cuda::std::is_swappable_v<cuda::std::expected<int, NotMoveContructible>>, "");
 
-struct MoveMayThrow {
+struct MoveMayThrow
+{
   __host__ __device__ MoveMayThrow(MoveMayThrow&&) noexcept(false);
   __host__ __device__ friend void swap(MoveMayThrow&, MoveMayThrow&) noexcept {}
 };
@@ -73,7 +76,8 @@ static_assert(!cuda::std::is_nothrow_swappable_v<cuda::std::expected<MoveMayThro
 // !is_nothrow_move_constructible_v<E>
 static_assert(!cuda::std::is_nothrow_swappable_v<cuda::std::expected<int, MoveMayThrow>>, "");
 
-struct SwapMayThrow {
+struct SwapMayThrow
+{
   __host__ __device__ friend void swap(SwapMayThrow&, SwapMayThrow&) noexcept(false) {}
 };
 
@@ -84,7 +88,8 @@ static_assert(!cuda::std::is_nothrow_swappable_v<cuda::std::expected<SwapMayThro
 static_assert(!cuda::std::is_nothrow_swappable_v<cuda::std::expected<int, SwapMayThrow>>, "");
 #endif // TEST_COMPILER_ICC
 
-__host__ __device__ TEST_CONSTEXPR_CXX20 bool test() {
+__host__ __device__ TEST_CONSTEXPR_CXX20 bool test()
+{
   // this->has_value() && rhs.has_value()
   {
     cuda::std::expected<ADLSwap, int> x(cuda::std::in_place, 5);
@@ -192,16 +197,20 @@ __host__ __device__ TEST_CONSTEXPR_CXX20 bool test() {
   return true;
 }
 
-__host__ __device__ void testException() {
 #ifndef TEST_HAS_NO_EXCEPTIONS
+void test_exceptions()
+{
   // !e1.has_value() && e2.has_value()
   {
     cuda::std::expected<ThrowOnMoveConstruct, int> e1(cuda::std::unexpect, 5);
     cuda::std::expected<ThrowOnMoveConstruct, int> e2(cuda::std::in_place);
-    try {
+    try
+    {
       swap(e1, e2);
       assert(false);
-    } catch (Except) {
+    }
+    catch (Except)
+    {
       assert(!e1.has_value());
       assert(e1.error() == 5);
     }
@@ -211,22 +220,28 @@ __host__ __device__ void testException() {
   {
     cuda::std::expected<int, ThrowOnMoveConstruct> e1(5);
     cuda::std::expected<int, ThrowOnMoveConstruct> e2(cuda::std::unexpect);
-    try {
+    try
+    {
       swap(e1, e2);
       assert(false);
-    } catch (Except) {
+    }
+    catch (Except)
+    {
       assert(e1.has_value());
       assert(*e1 == 5);
     }
   }
-#endif // TEST_HAS_NO_EXCEPTIONS
 }
+#endif // !TEST_HAS_NO_EXCEPTIONS
 
-int main(int, char**) {
+int main(int, char**)
+{
   test();
 #if TEST_STD_VER > 2017 && defined(_LIBCUDACXX_ADDRESSOF)
   static_assert(test());
 #endif // TEST_STD_VER > 2017 && defined(_LIBCUDACXX_ADDRESSOF)
-  testException();
+#ifndef TEST_HAS_NO_EXCEPTIONS
+  NV_IF_TARGET(NV_IS_HOST, (test_exceptions();))
+#endif // !TEST_HAS_NO_EXCEPTIONS
   return 0;
 }
