@@ -32,17 +32,15 @@
 
 // Test Constraints:
 template <class T, class E>
-_LIBCUDACXX_CONCEPT_FRAGMENT(
-  HasMemberSwap_,
-  requires(cuda::std::expected<T, E> x, cuda::std::expected<T, E> y)(
-    (x.swap(y))
-  ));
+_LIBCUDACXX_CONCEPT_FRAGMENT(HasMemberSwap_,
+                             requires(cuda::std::expected<T, E> x, cuda::std::expected<T, E> y)((x.swap(y))));
 template <class T, class E>
 _LIBCUDACXX_CONCEPT HasMemberSwap = _LIBCUDACXX_FRAGMENT(HasMemberSwap_, T, E);
 
 static_assert(HasMemberSwap<int, int>, "");
 
-struct NotSwappable {};
+struct NotSwappable
+{};
 __host__ __device__ void swap(NotSwappable&, NotSwappable&) = delete;
 
 // !is_swappable_v<T>
@@ -51,7 +49,8 @@ static_assert(!HasMemberSwap<NotSwappable, int>, "");
 // !is_swappable_v<E>
 static_assert(!HasMemberSwap<int, NotSwappable>, "");
 
-struct NotMoveContructible {
+struct NotMoveContructible
+{
   NotMoveContructible(NotMoveContructible&&) = delete;
   __host__ __device__ friend void swap(NotMoveContructible&, NotMoveContructible&) {}
 };
@@ -62,7 +61,8 @@ static_assert(!HasMemberSwap<NotMoveContructible, int>, "");
 // !is_move_constructible_v<E>
 static_assert(!HasMemberSwap<int, NotMoveContructible>, "");
 
-struct MoveMayThrow {
+struct MoveMayThrow
+{
   __host__ __device__ MoveMayThrow(MoveMayThrow&&) noexcept(false);
   __host__ __device__ friend void swap(MoveMayThrow&, MoveMayThrow&) noexcept {}
 };
@@ -83,7 +83,8 @@ template <class T, class E, bool = HasMemberSwap<T, E>>
 constexpr bool MemberSwapNoexcept = false;
 
 template <class T, class E>
-constexpr bool MemberSwapNoexcept<T, E, true> = noexcept(cuda::std::declval<cuda::std::expected<T, E>&>().swap(cuda::std::declval<cuda::std::expected<T, E>&>()));
+constexpr bool MemberSwapNoexcept<T, E, true> =
+  noexcept(cuda::std::declval<cuda::std::expected<T, E>&>().swap(cuda::std::declval<cuda::std::expected<T, E>&>()));
 
 static_assert(MemberSwapNoexcept<int, int>, "");
 
@@ -94,7 +95,8 @@ static_assert(!MemberSwapNoexcept<MoveMayThrow, int>, "");
 // !is_nothrow_move_constructible_v<E>
 static_assert(!MemberSwapNoexcept<int, MoveMayThrow>, "");
 
-struct SwapMayThrow {
+struct SwapMayThrow
+{
   __host__ __device__ friend void swap(SwapMayThrow&, SwapMayThrow&) noexcept(false) {}
 };
 
@@ -105,7 +107,8 @@ static_assert(!MemberSwapNoexcept<SwapMayThrow, int>, "");
 static_assert(!MemberSwapNoexcept<int, SwapMayThrow>, "");
 #endif // TEST_COMPILER_ICC
 
-__host__ __device__ TEST_CONSTEXPR_CXX20 bool test() {
+__host__ __device__ TEST_CONSTEXPR_CXX20 bool test()
+{
   // this->has_value() && rhs.has_value()
   {
     cuda::std::expected<ADLSwap, int> x(cuda::std::in_place, 5);
@@ -213,16 +216,20 @@ __host__ __device__ TEST_CONSTEXPR_CXX20 bool test() {
   return true;
 }
 
-__host__ __device__ void testException() {
 #ifndef TEST_HAS_NO_EXCEPTIONS
+void test_exceptions()
+{
   // !e1.has_value() && e2.has_value()
   {
     cuda::std::expected<ThrowOnMoveConstruct, int> e1(cuda::std::unexpect, 5);
     cuda::std::expected<ThrowOnMoveConstruct, int> e2(cuda::std::in_place);
-    try {
+    try
+    {
       e1.swap(e2);
       assert(false);
-    } catch (Except) {
+    }
+    catch (Except)
+    {
       assert(!e1.has_value());
       assert(e1.error() == 5);
     }
@@ -232,22 +239,28 @@ __host__ __device__ void testException() {
   {
     cuda::std::expected<int, ThrowOnMoveConstruct> e1(5);
     cuda::std::expected<int, ThrowOnMoveConstruct> e2(cuda::std::unexpect);
-    try {
+    try
+    {
       e1.swap(e2);
       assert(false);
-    } catch (Except) {
+    }
+    catch (Except)
+    {
       assert(e1.has_value());
       assert(*e1 == 5);
     }
   }
-#endif // TEST_HAS_NO_EXCEPTIONS
 }
+#endif // !TEST_HAS_NO_EXCEPTIONS
 
-int main(int, char**) {
+int main(int, char**)
+{
   test();
 #if TEST_STD_VER > 2017 && defined(_LIBCUDACXX_ADDRESSOF)
   static_assert(test(), "");
 #endif // TEST_STD_VER > 2017 && defined(_LIBCUDACXX_ADDRESSOF)
-  testException();
+#ifndef TEST_HAS_NO_EXCEPTIONS
+  NV_IF_TARGET(NV_IS_HOST, (test_exceptions();))
+#endif // !TEST_HAS_NO_EXCEPTIONS
   return 0;
 }
