@@ -16,12 +16,16 @@
 
 #include "test_macros.h"
 
-struct Error {
+struct Error
+{
   int i;
-  __host__ __device__ constexpr Error(int ii) : i(ii) {}
+  __host__ __device__ constexpr Error(int ii)
+      : i(ii)
+  {}
 };
 
-__host__ __device__ constexpr bool test() {
+__host__ __device__ constexpr bool test()
+{
   cuda::std::unexpected<Error> unex1(4);
   const cuda::std::unexpected<Error> unex2(5);
   unex1 = unex2;
@@ -29,7 +33,8 @@ __host__ __device__ constexpr bool test() {
   return true;
 }
 
-int main(int, char**) {
+int main(int, char**)
+{
   test();
   static_assert(test(), "");
   return 0;
