@@ -17,13 +17,21 @@
 
 #include "test_macros.h"
 
-struct Error {
+struct Error
+{
   int i;
-  __host__ __device__ constexpr Error(int ii) : i(ii) {}
-  __host__ __device__ constexpr Error(Error&& other) : i(other.i) {other.i = 0;}
+  __host__ __device__ constexpr Error(int ii)
+      : i(ii)
+  {}
+  __host__ __device__ constexpr Error(Error&& other)
+      : i(other.i)
+  {
+    other.i = 0;
+  }
 };
 
-__host__ __device__ constexpr bool test() {
+__host__ __device__ constexpr bool test()
+{
   cuda::std::unexpected<Error> unex(5);
   auto unex2 = cuda::std::move(unex);
   assert(unex2.error().i == 5);
@@ -31,7 +39,8 @@ __host__ __device__ constexpr bool test() {
   return true;
 }
 
-int main(int, char**) {
+int main(int, char**)
+{
   test();
   static_assert(test(), "");
   return 0;
