@@ -21,7 +21,8 @@
 //
 // Returns: *this.
 //
-// Remarks: This operator is defined as deleted unless is_copy_assignable_v<E> is true and is_copy_constructible_v<E> is true.
+// Remarks: This operator is defined as deleted unless is_copy_assignable_v<E> is true and is_copy_constructible_v<E> is
+// true.
 
 #include <cuda/std/cassert>
 #include <cuda/std/concepts>
@@ -32,12 +33,14 @@
 #include "../../types.h"
 #include "test_macros.h"
 
-struct NotCopyConstructible {
+struct NotCopyConstructible
+{
   NotCopyConstructible(const NotCopyConstructible&)            = delete;
   NotCopyConstructible& operator=(const NotCopyConstructible&) = default;
 };
 
-struct NotCopyAssignable {
+struct NotCopyAssignable
+{
   NotCopyAssignable(const NotCopyAssignable&)            = default;
   NotCopyAssignable& operator=(const NotCopyAssignable&) = delete;
 };
@@ -51,7 +54,8 @@ static_assert(!cuda::std::is_copy_assignable_v<cuda::std::expected<void, NotCopy
 // !is_copy_constructible_v<E>
 static_assert(!cuda::std::is_copy_assignable_v<cuda::std::expected<void, NotCopyConstructible>>, "");
 
-__host__ __device__ TEST_CONSTEXPR_CXX20 bool test() {
+__host__ __device__ TEST_CONSTEXPR_CXX20 bool test()
+{
   // If this->has_value() && rhs.has_value() is true, no effects.
   {
     cuda::std::expected<void, int> e1;
@@ -106,24 +110,31 @@ __host__ __device__ TEST_CONSTEXPR_CXX20 bool test() {
   return true;
 }
 
-__host__ __device__ void testException() {
 #ifndef TEST_HAS_NO_EXCEPTIONS
+void test_exceptions()
+{
   cuda::std::expected<void, ThrowOnCopyConstruct> e1(cuda::std::in_place);
   cuda::std::expected<void, ThrowOnCopyConstruct> e2(cuda::std::unexpect);
-  try {
+  try
+  {
     e1 = e2;
     assert(false);
-  } catch (Except) {
+  }
+  catch (Except)
+  {
     assert(e1.has_value());
   }
-#endif // TEST_HAS_NO_EXCEPTIONS
 }
+#endif // !TEST_HAS_NO_EXCEPTIONS
 
-int main(int, char**) {
+int main(int, char**)
+{
   test();
 #if TEST_STD_VER > 2017 && defined(_LIBCUDACXX_ADDRESSOF)
   static_assert(test());
 #endif // TEST_STD_VER > 2017 && defined(_LIBCUDACXX_ADDRESSOF)
-  testException();
+#ifndef TEST_HAS_NO_EXCEPTIONS
+  NV_IF_TARGET(NV_IS_HOST, (test_exceptions();))
+#endif // !TEST_HAS_NO_EXCEPTIONS
   return 0;
 }
