@@ -22,7 +22,8 @@
 //
 // Returns: *this.
 //
-// Remarks: The exception specification is equivalent to is_nothrow_move_constructible_v<E> && is_nothrow_move_assignable_v<E>.
+// Remarks: The exception specification is equivalent to is_nothrow_move_constructible_v<E> &&
+// is_nothrow_move_assignable_v<E>.
 //
 // This operator is defined as deleted unless is_move_constructible_v<E> is true and is_move_assignable_v<E> is true.
 
@@ -35,12 +36,14 @@
 #include "../../types.h"
 #include "test_macros.h"
 
-struct NotMoveConstructible {
+struct NotMoveConstructible
+{
   NotMoveConstructible(NotMoveConstructible&&)            = delete;
   NotMoveConstructible& operator=(NotMoveConstructible&&) = default;
 };
 
-struct NotMoveAssignable {
+struct NotMoveAssignable
+{
   NotMoveAssignable(NotMoveAssignable&&)            = default;
   NotMoveAssignable& operator=(NotMoveAssignable&&) = delete;
 };
@@ -55,14 +58,19 @@ static_assert(!cuda::std::is_move_assignable_v<cuda::std::expected<void, NotMove
 static_assert(!cuda::std::is_move_assignable_v<cuda::std::expected<void, NotMoveConstructible>>, "");
 
 // Test noexcept
-struct MoveCtorMayThrow {
+struct MoveCtorMayThrow
+{
   __host__ __device__ MoveCtorMayThrow(MoveCtorMayThrow&&) noexcept(false) {}
   MoveCtorMayThrow& operator=(MoveCtorMayThrow&&) noexcept = default;
 };
 
-struct MoveAssignMayThrow {
+struct MoveAssignMayThrow
+{
   MoveAssignMayThrow(MoveAssignMayThrow&&) noexcept = default;
-  __host__ __device__ MoveAssignMayThrow& operator=(MoveAssignMayThrow&&) noexcept(false) { return *this; }
+  __host__ __device__ MoveAssignMayThrow& operator=(MoveAssignMayThrow&&) noexcept(false)
+  {
+    return *this;
+  }
 };
 
 // Test noexcept
@@ -76,7 +84,8 @@ static_assert(!cuda::std::is_nothrow_move_assignable_v<cuda::std::expected<void,
 static_assert(!cuda::std::is_nothrow_move_assignable_v<cuda::std::expected<void, MoveCtorMayThrow>>, "");
 #endif // TEST_COMPILER_ICC
 
-__host__ __device__ TEST_CONSTEXPR_CXX20 bool test() {
+__host__ __device__ TEST_CONSTEXPR_CXX20 bool test()
+{
   // If this->has_value() && rhs.has_value() is true, no effects.
   {
     cuda::std::expected<void, int> e1;
@@ -133,24 +142,31 @@ __host__ __device__ TEST_CONSTEXPR_CXX20 bool test() {
   return true;
 }
 
-__host__ __device__ void testException() {
 #ifndef TEST_HAS_NO_EXCEPTIONS
+void test_exceptions()
+{
   cuda::std::expected<void, ThrowOnMoveConstruct> e1(cuda::std::in_place);
   cuda::std::expected<void, ThrowOnMoveConstruct> e2(cuda::std::unexpect);
-  try {
+  try
+  {
     e1 = cuda::std::move(e2);
     assert(false);
-  } catch (Except) {
+  }
+  catch (Except)
+  {
     assert(e1.has_value());
   }
-#endif // TEST_HAS_NO_EXCEPTIONS
 }
+#endif // !TEST_HAS_NO_EXCEPTIONS
 
-int main(int, char**) {
+int main(int, char**)
+{
   test();
 #if TEST_STD_VER > 2017 && defined(_LIBCUDACXX_ADDRESSOF)
   static_assert(test());
 #endif // TEST_STD_VER > 2017 && defined(_LIBCUDACXX_ADDRESSOF)
-  testException();
+#ifndef TEST_HAS_NO_EXCEPTIONS
+  NV_IF_TARGET(NV_IS_HOST, (test_exceptions();))
+#endif // !TEST_HAS_NO_EXCEPTIONS
   return 0;
 }
