@@ -28,23 +28,40 @@
 
 #include "test_macros.h"
 
-struct NonMovable {
+struct NonMovable
+{
   NonMovable(NonMovable&&) = delete;
 };
 
-struct MovableNonTrivial {
+struct MovableNonTrivial
+{
   int i;
-  __host__ __device__ constexpr MovableNonTrivial(int ii) : i(ii) {}
-  __host__ __device__ constexpr MovableNonTrivial(MovableNonTrivial&& o) : i(o.i) { o.i = 0; }
+  __host__ __device__ constexpr MovableNonTrivial(int ii)
+      : i(ii)
+  {}
+  __host__ __device__ constexpr MovableNonTrivial(MovableNonTrivial&& o)
+      : i(o.i)
+  {
+    o.i = 0;
+  }
 #if TEST_STD_VER > 2017
   __host__ __device__ friend constexpr bool operator==(const MovableNonTrivial&, const MovableNonTrivial&) = default;
 #else
-  __host__ __device__ friend constexpr bool operator==(const MovableNonTrivial& lhs, const MovableNonTrivial& rhs) noexcept { return lhs.i == rhs.i; }
-  __host__ __device__ friend constexpr bool operator!=(const MovableNonTrivial& lhs, const MovableNonTrivial& rhs) noexcept { return lhs.i != rhs.i; }
+  __host__ __device__ friend constexpr bool
+  operator==(const MovableNonTrivial& lhs, const MovableNonTrivial& rhs) noexcept
+  {
+    return lhs.i == rhs.i;
+  }
+  __host__ __device__ friend constexpr bool
+  operator!=(const MovableNonTrivial& lhs, const MovableNonTrivial& rhs) noexcept
+  {
+    return lhs.i != rhs.i;
+  }
 #endif // TEST_STD_VER > 2017
 };
 
-struct MoveMayThrow {
+struct MoveMayThrow
+{
   __host__ __device__ MoveMayThrow(MoveMayThrow&&) {}
 };
 
@@ -66,7 +83,8 @@ static_assert(!cuda::std::is_nothrow_move_constructible_v<cuda::std::expected<in
 static_assert(!cuda::std::is_nothrow_move_constructible_v<cuda::std::expected<MoveMayThrow, MoveMayThrow>>, "");
 #endif // TEST_COMPILER_ICC
 
-__host__ __device__ TEST_CONSTEXPR_CXX20 bool test() {
+__host__ __device__ TEST_CONSTEXPR_CXX20 bool test()
+{
   // move the error non-trivial
   {
     cuda::std::expected<void, MovableNonTrivial> e1(cuda::std::unexpect, 5);
@@ -88,34 +106,44 @@ __host__ __device__ TEST_CONSTEXPR_CXX20 bool test() {
   return true;
 }
 
-__host__ __device__ void testException() {
 #ifndef TEST_HAS_NO_EXCEPTIONS
-  struct Except {};
+void test_exceptions()
+{
+  struct Except
+  {};
 
-  struct Throwing {
+  struct Throwing
+  {
     Throwing() = default;
-    __host__ __device__ Throwing(Throwing&&) { throw Except{}; }
+    __host__ __device__ Throwing(Throwing&&)
+    {
+      throw Except{};
+    }
   };
 
   // throw on moving error
   {
     cuda::std::expected<void, Throwing> e1(cuda::std::unexpect);
-    try {
+    try
+    {
       auto e2 = cuda::std::move(e1);
       unused(e2);
       assert(false);
-    } catch (Except) {
     }
+    catch (Except)
+    {}
   }
-
-#endif // TEST_HAS_NO_EXCEPTIONS
 }
+#endif // !TEST_HAS_NO_EXCEPTIONS
 
-int main(int, char**) {
+int main(int, char**)
+{
   test();
 #if TEST_STD_VER > 2017 && defined(_LIBCUDACXX_ADDRESSOF)
   static_assert(test(), "");
 #endif // TEST_STD_VER > 2017 && defined(_LIBCUDACXX_ADDRESSOF)
-  testException();
+#ifndef TEST_HAS_NO_EXCEPTIONS
+  NV_IF_TARGET(NV_IS_HOST, (test_exceptions();))
+#endif // !TEST_HAS_NO_EXCEPTIONS
   return 0;
 }
