@@ -34,7 +34,8 @@ static_assert(cuda::std::is_constructible_v<cuda::std::expected<void, int>, cuda
 static_assert(cuda::std::is_constructible_v<cuda::std::expected<void, int>, cuda::std::unexpect_t, int>, "");
 
 // !is_constructible_v<T, Args...>
-struct foo {};
+struct foo
+{};
 static_assert(!cuda::std::is_constructible_v<cuda::std::expected<void, foo>, cuda::std::unexpect_t, int>, "");
 
 // test explicit
@@ -42,11 +43,8 @@ template <class T>
 __host__ __device__ void conversion_test(T);
 
 template <class T, class... Args>
-_LIBCUDACXX_CONCEPT_FRAGMENT(
-  ImplicitlyConstructible_,
-  requires(Args&&... args)(
-    (conversion_test<T>({cuda::std::forward<Args>(args)...}))
-  ));
+_LIBCUDACXX_CONCEPT_FRAGMENT(ImplicitlyConstructible_,
+                             requires(Args&&... args)((conversion_test<T>({cuda::std::forward<Args>(args)...}))));
 
 template <class T, class... Args>
 constexpr bool ImplicitlyConstructible = _LIBCUDACXX_FRAGMENT(ImplicitlyConstructible_, T, Args...);
@@ -55,26 +53,37 @@ static_assert(ImplicitlyConstructible<int, int>, "");
 static_assert(!ImplicitlyConstructible<cuda::std::expected<void, int>, cuda::std::unexpect_t>, "");
 static_assert(!ImplicitlyConstructible<cuda::std::expected<void, int>, cuda::std::unexpect_t, int>, "");
 
-struct CopyOnly {
+struct CopyOnly
+{
   int i;
-  __host__ __device__ constexpr CopyOnly(int ii) : i(ii) {}
-  CopyOnly(const CopyOnly&) = default;
-  __host__ __device__ CopyOnly(CopyOnly&&)      = delete;
-  __host__ __device__ friend constexpr bool operator==(const CopyOnly& mi, int ii) { return mi.i == ii; }
+  __host__ __device__ constexpr CopyOnly(int ii)
+      : i(ii)
+  {}
+  CopyOnly(const CopyOnly&)                = default;
+  __host__ __device__ CopyOnly(CopyOnly&&) = delete;
+  __host__ __device__ friend constexpr bool operator==(const CopyOnly& mi, int ii)
+  {
+    return mi.i == ii;
+  }
 #if TEST_STD_VER < 2020
-  __host__ __device__ friend constexpr bool operator!=(const CopyOnly& mi, int ii) { return mi.i != ii; }
+  __host__ __device__ friend constexpr bool operator!=(const CopyOnly& mi, int ii)
+  {
+    return mi.i != ii;
+  }
 #endif // TEST_STD_VER < 2020
 };
 
 template <class T>
-__host__ __device__ constexpr void testInt() {
+__host__ __device__ constexpr void testInt()
+{
   cuda::std::expected<void, T> e(cuda::std::unexpect, 5);
   assert(!e.has_value());
   assert(e.error() == 5);
 }
 
 template <class T>
-__host__ __device__ constexpr void testLValue() {
+__host__ __device__ constexpr void testLValue()
+{
   T t(5);
   cuda::std::expected<void, T> e(cuda::std::unexpect, t);
   assert(!e.has_value());
@@ -82,13 +91,15 @@ __host__ __device__ constexpr void testLValue() {
 }
 
 template <class T>
-__host__ __device__ constexpr void testRValue() {
+__host__ __device__ constexpr void testRValue()
+{
   cuda::std::expected<void, T> e(cuda::std::unexpect, T(5));
   assert(!e.has_value());
   assert(e.error() == 5);
 }
 
-__host__ __device__ constexpr bool test() {
+__host__ __device__ constexpr bool test()
+{
   testInt<int>();
   testInt<CopyOnly>();
   testInt<MoveOnly>();
@@ -121,27 +132,38 @@ __host__ __device__ constexpr bool test() {
   return true;
 }
 
-__host__ __device__ void testException() {
 #ifndef TEST_HAS_NO_EXCEPTIONS
-  struct Except {};
+void test_exceptions()
+{
+  struct Except
+  {};
 
-  struct Throwing {
-    __host__ __device__ Throwing(int) { throw Except{}; };
+  struct Throwing
+  {
+    __host__ __device__ Throwing(int)
+    {
+      throw Except{};
+    };
   };
 
-  try {
+  try
+  {
     cuda::std::expected<void, Throwing> u(cuda::std::unexpect, 5);
     assert(false);
-  } catch (Except) {
   }
-#endif // TEST_HAS_NO_EXCEPTIONS
+  catch (Except)
+  {}
 }
+#endif // !TEST_HAS_NO_EXCEPTIONS
 
-int main(int, char**) {
+int main(int, char**)
+{
   test();
 #if TEST_STD_VER > 2017 && defined(_LIBCUDACXX_ADDRESSOF)
   static_assert(test(), "");
 #endif // TEST_STD_VER > 2017 && defined(_LIBCUDACXX_ADDRESSOF)
-  testException();
+#ifndef TEST_HAS_NO_EXCEPTIONS
+  NV_IF_TARGET(NV_IS_HOST, (test_exceptions();))
+#endif // !TEST_HAS_NO_EXCEPTIONS
   return 0;
 }
