@@ -35,36 +35,50 @@ static_assert(cuda::std::is_constructible_v<cuda::std::expected<void, int>, cuda
 static_assert(cuda::std::is_constructible_v<cuda::std::expected<void, MoveOnly>, cuda::std::unexpected<MoveOnly>>, "");
 
 // !is_constructible_v<E, GF>
-struct foo {};
+struct foo
+{};
 static_assert(!cuda::std::is_constructible_v<cuda::std::expected<void, int>, cuda::std::unexpected<foo>>, "");
 
 // explicit(!is_convertible_v<G, E>)
-struct NotConvertible {
+struct NotConvertible
+{
   __host__ __device__ explicit NotConvertible(int);
 };
 static_assert(cuda::std::is_convertible_v<cuda::std::unexpected<int>&&, cuda::std::expected<void, int>>, "");
-static_assert(!cuda::std::is_convertible_v<cuda::std::unexpected<int>&&, cuda::std::expected<void, NotConvertible>>, "");
+static_assert(!cuda::std::is_convertible_v<cuda::std::unexpected<int>&&, cuda::std::expected<void, NotConvertible>>,
+              "");
 
-struct MyInt {
+struct MyInt
+{
   int i;
-  __host__ __device__ constexpr MyInt(int ii) : i(ii) {}
+  __host__ __device__ constexpr MyInt(int ii)
+      : i(ii)
+  {}
 #if TEST_STD_VER > 2017
   __host__ __device__ friend constexpr bool operator==(const MyInt&, const MyInt&) = default;
 #else
-  __host__ __device__ friend constexpr bool operator==(const MyInt& lhs, const MyInt& rhs) noexcept { return lhs.i == rhs.i; };
-  __host__ __device__ friend constexpr bool operator!=(const MyInt& lhs, const MyInt& rhs) noexcept { return lhs.i != rhs.i; };
+  __host__ __device__ friend constexpr bool operator==(const MyInt& lhs, const MyInt& rhs) noexcept
+  {
+    return lhs.i == rhs.i;
+  };
+  __host__ __device__ friend constexpr bool operator!=(const MyInt& lhs, const MyInt& rhs) noexcept
+  {
+    return lhs.i != rhs.i;
+  };
 #endif // TEST_STD_VER > 2017
 };
 
 template <class Err>
-__host__ __device__ constexpr void testInt() {
+__host__ __device__ constexpr void testInt()
+{
   cuda::std::unexpected<int> u(5);
   cuda::std::expected<void, Err> e(cuda::std::move(u));
   assert(!e.has_value());
   assert(e.error() == 5);
 }
 
-__host__ __device__ constexpr void testMoveOnly() {
+__host__ __device__ constexpr void testMoveOnly()
+{
   cuda::std::unexpected<MoveOnly> u(MoveOnly(5));
   cuda::std::expected<void, MoveOnly> e(cuda::std::move(u));
   assert(!e.has_value());
@@ -72,7 +86,8 @@ __host__ __device__ constexpr void testMoveOnly() {
   assert(u.error() == 0);
 }
 
-__host__ __device__ constexpr bool test() {
+__host__ __device__ constexpr bool test()
+{
   testInt<int>();
   testInt<MyInt>();
   testInt<MoveOnly>();
@@ -80,32 +95,42 @@ __host__ __device__ constexpr bool test() {
   return true;
 }
 
-__host__ __device__ void testException() {
 #ifndef TEST_HAS_NO_EXCEPTIONS
-  struct Except {};
+void test_exceptions()
+{
+  struct Except
+  {};
 
-  struct Throwing {
-    __host__ __device__ Throwing(int) { throw Except{}; }
+  struct Throwing
+  {
+    __host__ __device__ Throwing(int)
+    {
+      throw Except{};
+    }
   };
 
   {
     cuda::std::unexpected<int> u(5);
-    try {
+    try
+    {
       cuda::std::expected<void, Throwing> e(cuda::std::move(u));
       unused(e);
       assert(false);
-    } catch (Except) {
     }
+    catch (Except)
+    {}
   }
-
-#endif // TEST_HAS_NO_EXCEPTIONS
 }
+#endif // !TEST_HAS_NO_EXCEPTIONS
 
-int main(int, char**) {
+int main(int, char**)
+{
   test();
 #if TEST_STD_VER > 2017 && defined(_LIBCUDACXX_ADDRESSOF)
   static_assert(test(), "");
 #endif // TEST_STD_VER > 2017 && defined(_LIBCUDACXX_ADDRESSOF)
-  testException();
+#ifndef TEST_HAS_NO_EXCEPTIONS
+  NV_IF_TARGET(NV_IS_HOST, (test_exceptions();))
+#endif // !TEST_HAS_NO_EXCEPTIONS
   return 0;
 }
