@@ -24,20 +24,28 @@
 #include "test_macros.h"
 
 // Test Remarks: If is_trivially_destructible_v<E> is true, then this destructor is a trivial destructor.
-struct NonTrivial {
-  __host__ __device__~NonTrivial() {}
+struct NonTrivial
+{
+  __host__ __device__ ~NonTrivial() {}
 };
 
 static_assert(cuda::std::is_trivially_destructible_v<cuda::std::expected<void, int>>, "");
 static_assert(!cuda::std::is_trivially_destructible_v<cuda::std::expected<void, NonTrivial>>, "");
 
-struct TrackedDestroy {
+struct TrackedDestroy
+{
   bool& destroyed;
-  __host__ __device__ constexpr TrackedDestroy(bool& b) : destroyed(b) {}
-  __host__ __device__ TEST_CONSTEXPR_CXX20 ~TrackedDestroy() { destroyed = true; }
+  __host__ __device__ constexpr TrackedDestroy(bool& b)
+      : destroyed(b)
+  {}
+  __host__ __device__ TEST_CONSTEXPR_CXX20 ~TrackedDestroy()
+  {
+    destroyed = true;
+  }
 };
 
-__host__ __device__ TEST_CONSTEXPR_CXX20 bool test() {
+__host__ __device__ TEST_CONSTEXPR_CXX20 bool test()
+{
   // has value
   {
     cuda::std::expected<void, TrackedDestroy> e(cuda::std::in_place);
@@ -57,7 +65,8 @@ __host__ __device__ TEST_CONSTEXPR_CXX20 bool test() {
   return true;
 }
 
-int main(int, char**) {
+int main(int, char**)
+{
   test();
 #if TEST_STD_VER > 2017 && defined(_LIBCUDACXX_ADDRESSOF)
   static_assert(test());
