@@ -19,17 +19,27 @@
 
 #include "test_macros.h"
 
-struct Data {
+struct Data
+{
   int i;
-  __host__ __device__ constexpr Data(int ii) : i(ii) {}
+  __host__ __device__ constexpr Data(int ii)
+      : i(ii)
+  {}
 
-  __host__ __device__ friend constexpr bool operator==(const Data& data, int ii) { return data.i == ii; }
+  __host__ __device__ friend constexpr bool operator==(const Data& data, int ii)
+  {
+    return data.i == ii;
+  }
 #if TEST_STD_VER < 2020
-  __host__ __device__ friend constexpr bool operator!=(const Data& data, int ii) { return data.i != ii; }
+  __host__ __device__ friend constexpr bool operator!=(const Data& data, int ii)
+  {
+    return data.i != ii;
+  }
 #endif // TEST_STD_VER < 2020
 };
 
-__host__ __device__ constexpr bool test() {
+__host__ __device__ constexpr bool test()
+{
   // x.has_value()
   {
     const cuda::std::expected<void, Data> e1;
@@ -51,7 +61,8 @@ __host__ __device__ constexpr bool test() {
   return true;
 }
 
-int main(int, char**) {
+int main(int, char**)
+{
   test();
 #if TEST_STD_VER > 2017 && defined(_LIBCUDACXX_ADDRESSOF)
   static_assert(test(), "");
