@@ -30,23 +30,22 @@
 
 // Test Constraints:
 template <class E>
-_LIBCUDACXX_CONCEPT_FRAGMENT(
-  HasMemberSwap_,
-  requires(cuda::std::expected<void, E> x, cuda::std::expected<void, E> y)(
-    (x.swap(y))
-  ));
+_LIBCUDACXX_CONCEPT_FRAGMENT(HasMemberSwap_,
+                             requires(cuda::std::expected<void, E> x, cuda::std::expected<void, E> y)((x.swap(y))));
 template <class E>
 _LIBCUDACXX_CONCEPT HasMemberSwap = _LIBCUDACXX_FRAGMENT(HasMemberSwap_, E);
 
 static_assert(HasMemberSwap<int>, "");
 
-struct NotSwappable {};
+struct NotSwappable
+{};
 __host__ __device__ void swap(NotSwappable&, NotSwappable&) = delete;
 
 // !is_swappable_v<E>
 static_assert(!HasMemberSwap<NotSwappable>, "");
 
-struct NotMoveContructible {
+struct NotMoveContructible
+{
   NotMoveContructible(NotMoveContructible&&) = delete;
   __host__ __device__ friend void swap(NotMoveContructible&, NotMoveContructible&) {}
 };
@@ -55,7 +54,8 @@ struct NotMoveContructible {
 static_assert(!HasMemberSwap<NotMoveContructible>, "");
 
 // Test noexcept
-struct MoveMayThrow {
+struct MoveMayThrow
+{
   __host__ __device__ MoveMayThrow(MoveMayThrow&&) noexcept(false);
   __host__ __device__ friend void swap(MoveMayThrow&, MoveMayThrow&) noexcept {}
 };
@@ -64,7 +64,8 @@ template <class E, bool = HasMemberSwap<E>>
 constexpr bool MemberSwapNoexcept = false;
 
 template <class E>
-constexpr bool MemberSwapNoexcept<E, true> = noexcept(cuda::std::declval<cuda::std::expected<void, E>&>().swap(cuda::std::declval<cuda::std::expected<void, E>&>()));
+constexpr bool MemberSwapNoexcept<E, true> = noexcept(
+  cuda::std::declval<cuda::std::expected<void, E>&>().swap(cuda::std::declval<cuda::std::expected<void, E>&>()));
 
 static_assert(MemberSwapNoexcept<int>, "");
 
@@ -72,7 +73,8 @@ static_assert(MemberSwapNoexcept<int>, "");
 // !is_nothrow_move_constructible_v<E>
 static_assert(!MemberSwapNoexcept<MoveMayThrow>, "");
 
-struct SwapMayThrow {
+struct SwapMayThrow
+{
   __host__ __device__ friend void swap(SwapMayThrow&, SwapMayThrow&) noexcept(false) {}
 };
 
@@ -80,7 +82,8 @@ struct SwapMayThrow {
 static_assert(!MemberSwapNoexcept<SwapMayThrow>, "");
 #endif // TEST_COMPILER_ICC
 
-__host__ __device__ TEST_CONSTEXPR_CXX20 bool test() {
+__host__ __device__ TEST_CONSTEXPR_CXX20 bool test()
+{
   // this->has_value() && rhs.has_value()
   {
     cuda::std::expected<void, int> x;
@@ -140,17 +143,21 @@ __host__ __device__ TEST_CONSTEXPR_CXX20 bool test() {
   return true;
 }
 
-__host__ __device__ void testException() {
 #ifndef TEST_HAS_NO_EXCEPTIONS
+void test_exceptions()
+{
   // !e1.has_value() && e2.has_value()
   {
     bool e1Destroyed = false;
     cuda::std::expected<void, ThrowOnMove> e1(cuda::std::unexpect, e1Destroyed);
     cuda::std::expected<void, ThrowOnMove> e2(cuda::std::in_place);
-    try {
+    try
+    {
       e1.swap(e2);
       assert(false);
-    } catch (Except) {
+    }
+    catch (Except)
+    {
       assert(!e1.has_value());
       assert(e2.has_value());
       assert(!e1Destroyed);
@@ -162,23 +169,29 @@ __host__ __device__ void testException() {
     bool e2Destroyed = false;
     cuda::std::expected<void, ThrowOnMove> e1(cuda::std::in_place);
     cuda::std::expected<void, ThrowOnMove> e2(cuda::std::unexpect, e2Destroyed);
-    try {
+    try
+    {
       e1.swap(e2);
       assert(false);
-    } catch (Except) {
+    }
+    catch (Except)
+    {
       assert(e1.has_value());
       assert(!e2.has_value());
       assert(!e2Destroyed);
     }
   }
-#endif // TEST_HAS_NO_EXCEPTIONS
 }
+#endif // !TEST_HAS_NO_EXCEPTIONS
 
-int main(int, char**) {
+int main(int, char**)
+{
   test();
 #if TEST_STD_VER > 2017 && defined(_LIBCUDACXX_ADDRESSOF)
   static_assert(test());
 #endif // TEST_STD_VER > 2017 && defined(_LIBCUDACXX_ADDRESSOF)
-  testException();
+#ifndef TEST_HAS_NO_EXCEPTIONS
+  NV_IF_TARGET(NV_IS_HOST, (test_exceptions();))
+#endif // !TEST_HAS_NO_EXCEPTIONS
   return 0;
 }
