@@ -16,8 +16,8 @@
 // template <class F, class... Args>
 // constexpr unspecified bind_front(F&&, Args&&...);
 
-#include <cuda/std/functional>
 #include <cuda/std/cassert>
+#include <cuda/std/functional>
 #include <cuda/std/tuple>
 #include <cuda/std/type_traits>
 #include <cuda/std/utility>
@@ -25,19 +25,32 @@
 #include "callable_types.h"
 #include "test_macros.h"
 
-struct CopyMoveInfo {
-  enum { none, copy, move } copy_kind;
+struct CopyMoveInfo
+{
+  enum
+  {
+    none,
+    copy,
+    move
+  } copy_kind;
 
-  __host__ __device__ constexpr CopyMoveInfo() : copy_kind(none) {}
-  __host__ __device__ constexpr CopyMoveInfo(CopyMoveInfo const&) : copy_kind(copy) {}
-  __host__ __device__ constexpr CopyMoveInfo(CopyMoveInfo&&) : copy_kind(move) {}
+  __host__ __device__ constexpr CopyMoveInfo()
+      : copy_kind(none)
+  {}
+  __host__ __device__ constexpr CopyMoveInfo(CopyMoveInfo const&)
+      : copy_kind(copy)
+  {}
+  __host__ __device__ constexpr CopyMoveInfo(CopyMoveInfo&&)
+      : copy_kind(move)
+  {}
 };
 
-template <class ...Args>
-struct is_bind_frontable {
-  template <class ...LocalArgs>
+template <class... Args>
+struct is_bind_frontable
+{
+  template <class... LocalArgs>
   __host__ __device__ static auto test(int)
-      -> decltype((void)cuda::std::bind_front(cuda::std::declval<LocalArgs>()...), cuda::std::true_type());
+    -> decltype((void) cuda::std::bind_front(cuda::std::declval<LocalArgs>()...), cuda::std::true_type());
 
   template <class...>
   __host__ __device__ static cuda::std::false_type test(...);
@@ -45,44 +58,56 @@ struct is_bind_frontable {
   static constexpr bool value = decltype(test<Args...>(0))::value;
 };
 
-struct NotCopyMove {
-  NotCopyMove() = delete;
+struct NotCopyMove
+{
+  NotCopyMove()                   = delete;
   NotCopyMove(const NotCopyMove&) = delete;
-  NotCopyMove(NotCopyMove&&) = delete;
-  template <class ...Args>
-  __host__ __device__ void operator()(Args&& ...) const { }
+  NotCopyMove(NotCopyMove&&)      = delete;
+  template <class... Args>
+  __host__ __device__ void operator()(Args&&...) const
+  {}
 };
 
-struct NonConstCopyConstructible {
+struct NonConstCopyConstructible
+{
   __host__ __device__ explicit NonConstCopyConstructible() {}
   __host__ __device__ NonConstCopyConstructible(NonConstCopyConstructible&) {}
 };
 
-struct MoveConstructible {
+struct MoveConstructible
+{
   __host__ __device__ explicit MoveConstructible() {}
   __host__ __device__ MoveConstructible(MoveConstructible&&) {}
 };
 
-struct MakeTuple {
-  template <class ...Args>
-  __host__ __device__ constexpr auto operator()(Args&& ...args) const {
+struct MakeTuple
+{
+  template <class... Args>
+  __host__ __device__ constexpr auto operator()(Args&&... args) const
+  {
     return cuda::std::make_tuple(cuda::std::forward<Args>(args)...);
   }
 };
 
 template <int X>
-struct Elem {
+struct Elem
+{
   template <int Y>
   __host__ __device__ constexpr bool operator==(Elem<Y> const&) const
-  { return X == Y; }
+  {
+    return X == Y;
+  }
 };
 
-struct TakeAnything {
-  template<class... Ts>
-  __host__ __device__ constexpr void operator()(Ts&&...) const {}
+struct TakeAnything
+{
+  template <class... Ts>
+  __host__ __device__ constexpr void operator()(Ts&&...) const
+  {}
 };
 
-__host__ __device__ constexpr bool test() {
+__host__ __device__ constexpr bool test()
+{
   // Bind arguments, call without arguments
   {
     {
@@ -144,15 +169,18 @@ __host__ __device__ constexpr bool test() {
     }
     {
       auto f = cuda::std::bind_front(MakeTuple{}, Elem<1>{}, Elem<2>{}, Elem<3>{});
-      assert(f(Elem<10>{}, Elem<11>{}) == cuda::std::make_tuple(Elem<1>{}, Elem<2>{}, Elem<3>{}, Elem<10>{}, Elem<11>{}));
+      assert(f(Elem<10>{}, Elem<11>{})
+             == cuda::std::make_tuple(Elem<1>{}, Elem<2>{}, Elem<3>{}, Elem<10>{}, Elem<11>{}));
     }
   }
 
   // Basic tests with fundamental types
   {
-    int n = 2;
-    int m = 1;
-    auto add = [](int x, int y) { return x + y; };
+    int n    = 2;
+    int m    = 1;
+    auto add = [](int x, int y) {
+      return x + y;
+    };
     auto addN = [](int a, int b, int c, int d, int e, int f) {
       return a + b + c + d + e + f;
     };
@@ -178,23 +206,27 @@ __host__ __device__ constexpr bool test() {
 
   // Make sure we don't treat cuda::std::reference_wrapper specially.
 #if TEST_STD_VER > 2017
-#if defined(TEST_COMPILER_NVRTC) // reference_wrapper requires `addressof` which is currently not supported with nvrtc
-  if (!cuda::std::__libcpp_is_constant_evaluated())
-#endif // TEST_COMPILER_NVRTC
+#  if defined(TEST_COMPILER_NVRTC) // reference_wrapper requires `addressof` which is currently not supported with nvrtc
+  if (!TEST_IS_CONSTANT_EVALUATED())
+#  endif // TEST_COMPILER_NVRTC
   {
-      auto add = [](cuda::std::reference_wrapper<int> a, cuda::std::reference_wrapper<int> b) {
-        return a.get() + b.get();
-      };
-      int i = 1, j = 2;
-      auto f = cuda::std::bind_front(add, cuda::std::ref(i));
-      assert(f(cuda::std::ref(j)) == 3);
+    auto add = [](cuda::std::reference_wrapper<int> a, cuda::std::reference_wrapper<int> b) {
+      return a.get() + b.get();
+    };
+    int i = 1, j = 2;
+    auto f = cuda::std::bind_front(add, cuda::std::ref(i));
+    assert(f(cuda::std::ref(j)) == 3);
   }
 #endif
 
   // Make sure we can call a function that's a pointer to a member function.
   {
-    struct MemberFunction {
-      __host__ __device__ constexpr bool foo(int, int) { return true; }
+    struct MemberFunction
+    {
+      __host__ __device__ constexpr bool foo(int, int)
+      {
+        return true;
+      }
     };
     MemberFunction value{};
     auto fn = cuda::std::bind_front(&MemberFunction::foo, value, 0);
@@ -203,10 +235,12 @@ __host__ __device__ constexpr bool test() {
 
   // Make sure that we copy the bound arguments into the unspecified-type.
   {
-    auto add = [](int x, int y) { return x + y; };
-    int n = 2;
+    auto add = [](int x, int y) {
+      return x + y;
+    };
+    int n  = 2;
     auto i = cuda::std::bind_front(add, n, 1);
-    n = 100;
+    n      = 100;
     assert(i() == 3);
   }
 
@@ -235,13 +269,26 @@ __host__ __device__ constexpr bool test() {
   // Make sure we call the correctly cv-ref qualified operator() based on the
   // value category of the bind_front unspecified-type.
   {
-    struct F {
-      __host__ __device__ constexpr int operator()() & { return 1; }
-      __host__ __device__ constexpr int operator()() const& { return 2; }
-      __host__ __device__ constexpr int operator()() && { return 3; }
-      __host__ __device__ constexpr int operator()() const&& { return 4; }
+    struct F
+    {
+      __host__ __device__ constexpr int operator()() &
+      {
+        return 1;
+      }
+      __host__ __device__ constexpr int operator()() const&
+      {
+        return 2;
+      }
+      __host__ __device__ constexpr int operator()() &&
+      {
+        return 3;
+      }
+      __host__ __device__ constexpr int operator()() const&&
+      {
+        return 4;
+      }
     };
-    auto x = cuda::std::bind_front(F{});
+    auto x  = cuda::std::bind_front(F{});
     using X = decltype(x);
     assert(static_cast<X&>(x)() == 1);
     assert(static_cast<X const&>(x)() == 2);
@@ -259,58 +306,61 @@ __host__ __device__ constexpr bool test() {
   {
     // Make sure we delete the & overload when the underlying call isn't valid
 
-
     // There's no way to make sure we delete the const& overload when the underlying call isn't valid,
     // so we can't check this one.
 
     // Make sure we delete the && overload when the underlying call isn't valid
     {
-      struct F {
+      struct F
+      {
         __host__ __device__ void operator()() & {}
         __host__ __device__ void operator()() const& {}
         void operator()() && = delete;
         __host__ __device__ void operator()() const&& {}
       };
       using X = decltype(cuda::std::bind_front(F{}));
-      static_assert( cuda::std::is_invocable_v<X&>);
-      static_assert( cuda::std::is_invocable_v<X const&>);
-#ifndef TEST_COMPILER_ICC
-#ifndef TEST_COMPILER_MSVC_2017 // ICE during invoke check
+      static_assert(cuda::std::is_invocable_v<X&>);
+      static_assert(cuda::std::is_invocable_v<X const&>);
+#  ifndef TEST_COMPILER_ICC
+#    ifndef TEST_COMPILER_MSVC_2017 // ICE during invoke check
       static_assert(!cuda::std::is_invocable_v<X>);
-#endif // !TEST_COMPILER_MSVC_2017
-#endif // !TEST_COMPILER_ICC
-      static_assert( cuda::std::is_invocable_v<X const>);
+#    endif // !TEST_COMPILER_MSVC_2017
+#  endif // !TEST_COMPILER_ICC
+      static_assert(cuda::std::is_invocable_v<X const>);
     }
 
     // Make sure we delete the const&& overload when the underlying call isn't valid
     {
-      struct F {
+      struct F
+      {
         __host__ __device__ void operator()() & {}
         __host__ __device__ void operator()() const& {}
         __host__ __device__ void operator()() && {}
         void operator()() const&& = delete;
       };
       using X = decltype(cuda::std::bind_front(F{}));
-      static_assert( cuda::std::is_invocable_v<X&>);
-      static_assert( cuda::std::is_invocable_v<X const&>);
-      static_assert( cuda::std::is_invocable_v<X>);
-#ifndef TEST_COMPILER_ICC
-#ifndef TEST_COMPILER_MSVC_2017 // ICE during invoke check
+      static_assert(cuda::std::is_invocable_v<X&>);
+      static_assert(cuda::std::is_invocable_v<X const&>);
+      static_assert(cuda::std::is_invocable_v<X>);
+#  ifndef TEST_COMPILER_ICC
+#    ifndef TEST_COMPILER_MSVC_2017 // ICE during invoke check
       static_assert(!cuda::std::is_invocable_v<X const>);
-#endif // !TEST_COMPILER_MSVC_2017
-#endif // !TEST_COMPILER_ICC
+#    endif // !TEST_COMPILER_MSVC_2017
+#  endif // !TEST_COMPILER_ICC
     }
   }
 #endif
 
   // Some examples by Tim Song
 #ifndef TEST_COMPILER_ICC
-#ifndef TEST_COMPILER_MSVC_2017 // ICE during invoke check
+#  ifndef TEST_COMPILER_MSVC_2017 // ICE during invoke check
   {
     {
-      struct T { };
-      struct F {
-        __host__ __device__ void operator()(T&&) const & {}
+      struct T
+      {};
+      struct F
+      {
+        __host__ __device__ void operator()(T&&) const& {}
         void operator()(T&&) && = delete;
       };
       using X = decltype(cuda::std::bind_front(F{}));
@@ -318,8 +368,10 @@ __host__ __device__ constexpr bool test() {
     }
 
     {
-      struct T { };
-      struct F {
+      struct T
+      {};
+      struct F
+      {
         __host__ __device__ void operator()(T const&) const {}
         void operator()(T&&) const = delete;
       };
@@ -327,7 +379,7 @@ __host__ __device__ constexpr bool test() {
       static_assert(!cuda::std::is_invocable_v<X>);
     }
   }
-#endif // !TEST_COMPILER_MSVC_2017
+#  endif // !TEST_COMPILER_MSVC_2017
 #endif // !TEST_COMPILER_ICC
 
   // Test properties of the constructor of the unspecified-type returned by bind_front.
@@ -344,7 +396,7 @@ __host__ __device__ constexpr bool test() {
       assert(ret1(1, 2, 3));
 
       using RetT = decltype(ret);
-      static_assert( cuda::std::is_move_constructible<RetT>::value);
+      static_assert(cuda::std::is_move_constructible<RetT>::value);
       static_assert(!cuda::std::is_copy_constructible<RetT>::value);
       static_assert(!cuda::std::is_move_assignable<RetT>::value);
       static_assert(!cuda::std::is_copy_assignable<RetT>::value);
@@ -365,8 +417,8 @@ __host__ __device__ constexpr bool test() {
       assert(ret2(1, 2, 3));
 
       using RetT = decltype(ret);
-      static_assert( cuda::std::is_move_constructible<RetT>::value);
-      static_assert( cuda::std::is_copy_constructible<RetT>::value);
+      static_assert(cuda::std::is_move_constructible<RetT>::value);
+      static_assert(cuda::std::is_copy_constructible<RetT>::value);
       static_assert(!cuda::std::is_move_assignable<RetT>::value);
       static_assert(!cuda::std::is_copy_assignable<RetT>::value);
     }
@@ -385,9 +437,9 @@ __host__ __device__ constexpr bool test() {
       MoveAssignableWrapper value(true);
       using RetT = decltype(cuda::std::bind_front(cuda::std::move(value), 1));
 
-      static_assert( cuda::std::is_move_constructible<RetT>::value);
+      static_assert(cuda::std::is_move_constructible<RetT>::value);
       static_assert(!cuda::std::is_copy_constructible<RetT>::value);
-      static_assert( cuda::std::is_move_assignable<RetT>::value);
+      static_assert(cuda::std::is_move_assignable<RetT>::value);
       static_assert(!cuda::std::is_copy_assignable<RetT>::value);
 
       value();
@@ -404,11 +456,11 @@ __host__ __device__ constexpr bool test() {
     static_assert(!is_bind_frontable<NotCopyMove&>::value);
 
     static_assert(!cuda::std::is_constructible_v<MoveConstructible, MoveConstructible&>);
-    static_assert( cuda::std::is_move_constructible_v<MoveConstructible>);
-    static_assert( is_bind_frontable<decltype(takeAnything), MoveConstructible>::value);
+    static_assert(cuda::std::is_move_constructible_v<MoveConstructible>);
+    static_assert(is_bind_frontable<decltype(takeAnything), MoveConstructible>::value);
     static_assert(!is_bind_frontable<decltype(takeAnything), MoveConstructible&>::value);
 
-    static_assert( cuda::std::is_constructible_v<NonConstCopyConstructible, NonConstCopyConstructible&>);
+    static_assert(cuda::std::is_constructible_v<NonConstCopyConstructible, NonConstCopyConstructible&>);
     static_assert(!cuda::std::is_move_constructible_v<NonConstCopyConstructible>);
     static_assert(!is_bind_frontable<decltype(takeAnything), NonConstCopyConstructible&>::value);
     static_assert(!is_bind_frontable<decltype(takeAnything), NonConstCopyConstructible>::value);
@@ -419,9 +471,9 @@ __host__ __device__ constexpr bool test() {
 #if !defined(TEST_COMPILER_ICC) && !defined(TEST_COMPILER_MSVC_2017)
   // Make sure bind_front's unspecified type's operator() is SFINAE-friendly
   {
-    using T = decltype(cuda::std::bind_front(cuda::std::declval<int(*)(int, int)>(), 1));
+    using T = decltype(cuda::std::bind_front(cuda::std::declval<int (*)(int, int)>(), 1));
     static_assert(!cuda::std::is_invocable<T>::value);
-    static_assert( cuda::std::is_invocable<T, int>::value);
+    static_assert(cuda::std::is_invocable<T, int>::value);
     static_assert(!cuda::std::is_invocable<T, void*>::value);
     static_assert(!cuda::std::is_invocable<T, int, int>::value);
   }
@@ -430,7 +482,8 @@ __host__ __device__ constexpr bool test() {
   return true;
 }
 
-int main(int, char**) {
+int main(int, char**)
+{
   test();
   static_assert(test());
 
