@@ -11,29 +11,29 @@
 
 // struct identity;
 
-#include <cuda/std/type_traits>
-
 #include <cuda/std/cassert>
 #include <cuda/std/concepts>
+#include <cuda/std/type_traits>
 
-#include "test_macros.h"
 #include "MoveOnly.h"
+#include "test_macros.h"
 
 static_assert(cuda::std::semiregular<cuda::std::identity>);
 
 #if TEST_STD_VER > 2017
 static_assert(requires { typename cuda::std::identity::is_transparent; });
 #else
-template<class, class = void>
+template <class, class = void>
 constexpr bool is_transparent = false;
 
-template<class T>
+template <class T>
 constexpr bool is_transparent<T, cuda::std::void_t<typename T::is_transparent>> = true;
 
 static_assert(is_transparent<cuda::std::identity>);
 #endif
 
-__host__ __device__ constexpr bool test() {
+__host__ __device__ constexpr bool test()
+{
   cuda::std::identity id{};
   int i = 42;
   assert(id(i) == 42);
@@ -54,22 +54,15 @@ __host__ __device__ constexpr bool test() {
   id = idc; // run-time checks assignment
   static_assert(cuda::std::is_same_v<decltype(id(i)), int&>);
   static_assert(cuda::std::is_same_v<decltype(id(cuda::std::declval<int&&>())), int&&>);
-  static_assert(
-      cuda::std::is_same_v<decltype(id(cuda::std::declval<int const&>())), int const&>);
-  static_assert(
-      cuda::std::is_same_v<decltype(id(cuda::std::declval<int const&&>())), int const&&>);
-  static_assert(cuda::std::is_same_v<decltype(id(cuda::std::declval<int volatile&>())),
-                               int volatile&>);
-  static_assert(cuda::std::is_same_v<decltype(id(cuda::std::declval<int volatile&&>())),
-                               int volatile&&>);
-  static_assert(
-      cuda::std::is_same_v<decltype(id(cuda::std::declval<int const volatile&>())),
-                     int const volatile&>);
-  static_assert(
-      cuda::std::is_same_v<decltype(id(cuda::std::declval<int const volatile&&>())),
-                     int const volatile&&>);
+  static_assert(cuda::std::is_same_v<decltype(id(cuda::std::declval<int const&>())), int const&>);
+  static_assert(cuda::std::is_same_v<decltype(id(cuda::std::declval<int const&&>())), int const&&>);
+  static_assert(cuda::std::is_same_v<decltype(id(cuda::std::declval<int volatile&>())), int volatile&>);
+  static_assert(cuda::std::is_same_v<decltype(id(cuda::std::declval<int volatile&&>())), int volatile&&>);
+  static_assert(cuda::std::is_same_v<decltype(id(cuda::std::declval<int const volatile&>())), int const volatile&>);
+  static_assert(cuda::std::is_same_v<decltype(id(cuda::std::declval<int const volatile&&>())), int const volatile&&>);
 
-  struct S {
+  struct S
+  {
     constexpr S() = default;
     __host__ __device__ constexpr S(S&&) noexcept(false) {}
     __host__ __device__ constexpr S(S const&) noexcept(false) {}
@@ -82,7 +75,8 @@ __host__ __device__ constexpr bool test() {
   return true;
 }
 
-int main(int, char**) {
+int main(int, char**)
+{
   test();
 #if TEST_STD_VER > 2017
   static_assert(test());
