@@ -10,20 +10,18 @@
 
 // template<Returnable R, class T> unspecified mem_fn(R T::* pm);
 
-#include <cuda/std/functional>
 #include <cuda/std/cassert>
+#include <cuda/std/functional>
 
 struct A
 {
-    double data_;
+  double data_;
 };
 
 template <class F>
-__host__ __device__
-void
-test(F f)
+__host__ __device__ void test(F f)
 {
-    {
+  {
     A a;
     f(a) = 5;
     assert(a.data_ == 5);
@@ -34,12 +32,12 @@ test(F f)
     assert(f(cap) == f(ap));
     const F& cf = f;
     assert(cf(ap) == f(ap));
-    }
+  }
 }
 
 int main(int, char**)
 {
-    test(cuda::std::mem_fn(&A::data_));
+  test(cuda::std::mem_fn(&A::data_));
 
   return 0;
 }
