@@ -19,15 +19,20 @@
 
 #include "test_macros.h"
 
-struct Predicate {
-    typedef int first_argument_type;
-    typedef int second_argument_type;
-    bool operator()(first_argument_type, second_argument_type) const { return true; }
+struct Predicate
+{
+  typedef int first_argument_type;
+  typedef int second_argument_type;
+  bool operator()(first_argument_type, second_argument_type) const
+  {
+    return true;
+  }
 };
 
-int main(int, char**) {
-    cuda::std::binary_negate<Predicate> f((Predicate())); // expected-error{{'binary_negate<Predicate>' is deprecated}}
-    (void)f;
+int main(int, char**)
+{
+  cuda::std::binary_negate<Predicate> f((Predicate())); // expected-error{{'binary_negate<Predicate>' is deprecated}}
+  (void) f;
 
   return 0;
 }
