@@ -13,16 +13,17 @@
 
 // ranges::not_equal_to
 
+#include <cuda/std/cassert>
 #include <cuda/std/functional>
 #include <cuda/std/type_traits>
-#include <cuda/std/cassert>
 
-#include "test_macros.h"
 #include "compare_types.h"
 #include "MoveOnly.h"
 #include "pointer_comparison_test_helper.h"
+#include "test_macros.h"
 
-struct NotEqualityComparable {
+struct NotEqualityComparable
+{
   __host__ __device__ friend bool operator==(const NotEqualityComparable&, const NotEqualityComparable&);
   __host__ __device__ friend bool operator!=(const NotEqualityComparable&, const NotEqualityComparable&) = delete;
 };
@@ -43,13 +44,21 @@ inline constexpr bool is_transparent<T, cuda::std::void_t<typename T::is_transpa
 static_assert(is_transparent<cuda::std::ranges::not_equal_to>);
 #endif
 
-struct PtrAndNotEqOperator {
-  __host__ __device__ constexpr operator void*() const { return nullptr; }
+struct PtrAndNotEqOperator
+{
+  __host__ __device__ constexpr operator void*() const
+  {
+    return nullptr;
+  }
   // We *don't* want operator!= to be picked here.
-  __host__ __device__ friend constexpr bool operator!=(PtrAndNotEqOperator, PtrAndNotEqOperator) { return true; }
+  __host__ __device__ friend constexpr bool operator!=(PtrAndNotEqOperator, PtrAndNotEqOperator)
+  {
+    return true;
+  }
 };
 
-__host__ __device__ constexpr bool test() {
+__host__ __device__ constexpr bool test()
+{
   auto fn = cuda::std::ranges::not_equal_to();
 
 #if !defined(TEST_COMPILER_CUDACC_BELOW_11_3) && !defined(TEST_COMPILER_MSVC_2017)
@@ -75,8 +84,8 @@ __host__ __device__ constexpr bool test() {
   return true;
 }
 
-int main(int, char**) {
-
+int main(int, char**)
+{
   test();
   static_assert(test());
 
