@@ -15,21 +15,30 @@
 //   reference_wrapper(U&&);
 
 // #include <cuda/std/functional>
-#include <cuda/std/utility>
 #include <cuda/std/cassert>
+#include <cuda/std/utility>
 
 #include "test_macros.h"
 
-struct B {};
+struct B
+{};
 
-struct A1 {
+struct A1
+{
   mutable B b_;
-  __host__ __device__ TEST_CONSTEXPR operator B&() const { return b_; }
+  __host__ __device__ TEST_CONSTEXPR operator B&() const
+  {
+    return b_;
+  }
 };
 
-struct A2 {
+struct A2
+{
   mutable B b_;
-  __host__ __device__ TEST_CONSTEXPR operator B&() const TEST_NOEXCEPT { return b_; }
+  __host__ __device__ TEST_CONSTEXPR operator B&() const TEST_NOEXCEPT
+  {
+    return b_;
+  }
 };
 
 __host__ __device__ void implicitly_convert(cuda::std::reference_wrapper<B>) TEST_NOEXCEPT;
@@ -61,9 +70,10 @@ __host__ __device__ TEST_CONSTEXPR_CXX20 bool test()
   return true;
 }
 
-int main(int, char**) {
+int main(int, char**)
+{
   test();
-#if TEST_STD_VER > 2017 && !defined(__CUDACC_RTC__)
+#if TEST_STD_VER > 2017 && !defined(TEST_COMPILER_NVRTC)
   static_assert(test());
 #endif
 
