@@ -14,14 +14,14 @@
 // template <ObjectType T> reference_wrapper<const T> cref(const T& t);
 
 // #include <cuda/std/functional>
-#include <cuda/std/utility>
 #include <cuda/std/cassert>
+#include <cuda/std/utility>
 
 #include "test_macros.h"
 
 __host__ __device__ TEST_CONSTEXPR_CXX20 bool test()
 {
-  int i = 0;
+  int i                                     = 0;
   cuda::std::reference_wrapper<const int> r = cuda::std::cref(i);
   assert(&r.get() == &i);
   return true;
@@ -30,7 +30,7 @@ __host__ __device__ TEST_CONSTEXPR_CXX20 bool test()
 int main(int, char**)
 {
   test();
-#if TEST_STD_VER > 2017 && !defined(__CUDACC_RTC__)
+#if TEST_STD_VER > 2017 && !defined(TEST_COMPILER_NVRTC)
   static_assert(test());
 #endif
 
