@@ -18,30 +18,33 @@
 //  where T is an incomplete type (since C++20)
 
 // #include <cuda/std/functional>
-#include <cuda/std/utility>
 #include <cuda/std/cassert>
+#include <cuda/std/utility>
 
 #include "test_macros.h"
 
-
 struct Foo;
 
 __host__ __device__ Foo& get_foo();
 
-__host__ __device__ void test() {
-    Foo& foo = get_foo();
-    cuda::std::reference_wrapper<Foo> ref = cuda::std::ref(foo);
-    assert(&ref.get() == &foo);
+__host__ __device__ void test()
+{
+  Foo& foo                              = get_foo();
+  cuda::std::reference_wrapper<Foo> ref = cuda::std::ref(foo);
+  assert(&ref.get() == &foo);
 }
 
-struct Foo { };
+struct Foo
+{};
 
-__host__ __device__ Foo& get_foo() {
-    static Foo foo;
-    return foo;
+__host__ __device__ Foo& get_foo()
+{
+  static Foo foo;
+  return foo;
 }
 
-int main(int, char**) {
-    test();
-    return 0;
+int main(int, char**)
+{
+  test();
+  return 0;
 }
