@@ -18,14 +18,18 @@
 // #include <cuda/std/functional>
 #include <cuda/std/utility>
 
-struct A {};
+struct A
+{};
 
-__host__ __device__ const A source() {return A();}
+__host__ __device__ const A source()
+{
+  return A();
+}
 
 int main(int, char**)
 {
-    cuda::std::reference_wrapper<const A> r = cuda::std::ref(source());
-    (void)r;
+  cuda::std::reference_wrapper<const A> r = cuda::std::ref(source());
+  (void) r;
 
-    return 0;
+  return 0;
 }
