@@ -17,23 +17,24 @@
 //   operator()(ArgTypes&&... args) const;
 
 // #include <cuda/std/functional>
-#include <cuda/std/utility>
 #include <cuda/std/cassert>
+#include <cuda/std/utility>
 
 // member data pointer:  cv qualifiers should transfer from argument to return type
 
 struct A_int_1
 {
-    __host__ __device__ A_int_1() : data_(5) {}
+  __host__ __device__ A_int_1()
+      : data_(5)
+  {}
 
-    int data_;
+  int data_;
 };
 
-__host__ __device__ void
-test_int_1()
+__host__ __device__ void test_int_1()
 {
-    // member data pointer
-    {
+  // member data pointer
+  {
     int A_int_1::*fp = &A_int_1::data_;
     cuda::std::reference_wrapper<int A_int_1::*> r1(fp);
     A_int_1 a;
@@ -44,12 +45,12 @@ test_int_1()
     assert(r1(ap) == 6);
     r1(ap) = 7;
     assert(r1(ap) == 7);
-    }
+  }
 }
 
 int main(int, char**)
 {
-    test_int_1();
+  test_int_1();
 
   return 0;
 }
