@@ -22,19 +22,27 @@
 // #include <cuda/std/functional>
 #include <cuda/std/utility>
 
-
 struct Foo;
 __host__ __device__ Foo& get_foo();
 
-__host__ __device__ void test() {
-    cuda::std::reference_wrapper<Foo> ref = get_foo();
-    ref(0); // incomplete at the point of call
+__host__ __device__ void test()
+{
+  cuda::std::reference_wrapper<Foo> ref = get_foo();
+  ref(0); // incomplete at the point of call
 }
 
-struct Foo { __host__ __device__ void operator()(int) const { } };
-__host__ __device__ Foo& get_foo() { static Foo foo; return foo; }
+struct Foo
+{
+  __host__ __device__ void operator()(int) const {}
+};
+__host__ __device__ Foo& get_foo()
+{
+  static Foo foo;
+  return foo;
+}
 
-int main(int, char**) {
-    test();
-    return 0;
+int main(int, char**)
+{
+  test();
+  return 0;
 }
