@@ -26,9 +26,10 @@
 
 #include "test_macros.h"
 
-int main(int, char**) {
-    // Should fail to compile, since float is not an integral type
-    using floatmix = cuda::std::integer_sequence<float>;
-    floatmix::value_type I;
-    return 0;
+int main(int, char**)
+{
+  // Should fail to compile, since float is not an integral type
+  using floatmix = cuda::std::integer_sequence<float>;
+  floatmix::value_type I;
+  return 0;
 }
