@@ -17,9 +17,9 @@
 // This test hangs during recursive template instantiation with libstdc++
 // UNSUPPORTED: stdlib=libstdc++
 
-#include <cuda/std/utility>
-#include <cuda/std/type_traits>
 #include <cuda/std/cassert>
+#include <cuda/std/type_traits>
+#include <cuda/std/utility>
 
 #include "test_macros.h"
 
@@ -32,7 +32,8 @@ int main(int, char**)
 #if TEST_HAS_BUILTIN(__make_integer_seq) && !defined(_LIBCUDACXX_TESTING_FALLBACK_MAKE_INTEGER_SEQUENCE)
   MakeSeqT i; // expected-error@*:* {{integer sequences must have non-negative sequence length}}
 #else
-  MakeSeqT i; // expected-error-re@*:* {{{{(static_assert|static assertion)}} failed{{.*}}cuda::std::make_integer_sequence must have a non-negative sequence length}}
+  MakeSeqT i; // expected-error-re@*:* {{{{(static_assert|static assertion)}}
+              // failed{{.*}}cuda::std::make_integer_sequence must have a non-negative sequence length}}
 #endif
 
   return 0;
