@@ -13,22 +13,27 @@
 
 // template <ObjectType T> constexpr T* addressof(T& r);
 
-#include <cuda/std/type_traits>
 #include <cuda/std/cassert>
+#include <cuda/std/type_traits>
 
 #include "test_macros.h"
 
 #if defined(_LIBCUDACXX_ADDRESSOF) || defined(__NVCOMPILER)
-struct Pointer {
-  __host__ __device__ constexpr Pointer(void* v) : value(v) {}
+struct Pointer
+{
+  __host__ __device__ constexpr Pointer(void* v)
+      : value(v)
+  {}
   void* value;
 };
 
 struct A
 {
-    __host__ __device__ constexpr A() : n(42) {}
-    __host__ __device__ void operator&() const { }
-    int n;
+  __host__ __device__ constexpr A()
+      : n(42)
+  {}
+  __host__ __device__ void operator&() const {}
+  int n;
 };
 
 constexpr int global_integer = 0;
@@ -37,11 +42,11 @@ static_assert(cuda::std::addressof(global_integer) == &global_integer, "");
 constexpr double global_double = 0.0;
 static_assert(cuda::std::addressof(global_double) == &global_double, "");
 
-#ifndef __CUDA_ARCH__ // fails in __cudaRegisterVariable
+#  ifndef __CUDA_ARCH__ // fails in __cudaRegisterVariable
 constexpr A global_struct{};
 constexpr const A* address = cuda::std::addressof(global_struct);
 static_assert(&(address->n) == &(global_struct.n), "");
-#endif
+#  endif
 #endif
 
 int main(int, char**)
