@@ -12,20 +12,22 @@
 
 // constexpr bool is_constant_evaluated() noexcept; // C++20
 
-#include <cuda/std/type_traits>
 #include <cuda/std/cassert>
+#include <cuda/std/type_traits>
 
 #include "test_macros.h"
 
 #if TEST_STD_VER > 2017
-#ifndef __cccl_lib_is_constant_evaluated
-#if TEST_HAS_BUILTIN(__builtin_is_constant_evaluated)
-# error __cccl_lib_is_constant_evaluated should be defined
-#endif
-#endif // __cccl_lib_is_constant_evaluated
+#  ifndef __cccl_lib_is_constant_evaluated
+#    if TEST_HAS_BUILTIN(__builtin_is_constant_evaluated)
+#      error __cccl_lib_is_constant_evaluated should be defined
+#    endif
+#  endif // __cccl_lib_is_constant_evaluated
 #endif // TEST_STD_VER > 2017
 
-template <bool> struct InTemplate {};
+template <bool>
+struct InTemplate
+{};
 
 int main(int, char**)
 {
