@@ -12,53 +12,63 @@
 
 // is_nothrow_invocable
 
-#include <cuda/std/type_traits>
 #include <cuda/std/functional>
+#include <cuda/std/type_traits>
 #ifdef _LIBCUDACXX_HAS_VECTOR
-#include <cuda/std/vector>
+#  include <cuda/std/vector>
 #endif // _LIBCUDACXX_HAS_VECTOR
 
 #include "test_macros.h"
 
-struct Tag {};
+struct Tag
+{};
 
-struct Implicit {
+struct Implicit
+{
   __host__ __device__ Implicit(int) noexcept {}
 };
 
-struct ThrowsImplicit {
+struct ThrowsImplicit
+{
   __host__ __device__ ThrowsImplicit(int) {}
 };
 
-struct Explicit {
+struct Explicit
+{
   __host__ __device__ explicit Explicit(int) noexcept {}
 };
 
 template <bool IsNoexcept, class Ret, class... Args>
-struct CallObject {
+struct CallObject
+{
   __host__ __device__ Ret operator()(Args&&...) const noexcept(IsNoexcept);
 };
 
-struct Sink {
+struct Sink
+{
   template <class... Args>
-  __host__ __device__ void operator()(Args&&...) const noexcept {}
+  __host__ __device__ void operator()(Args&&...) const noexcept
+  {}
 };
 
 template <class Fn, class... Args>
-__host__ __device__ constexpr bool throws_invocable() {
-  return cuda::std::is_invocable<Fn, Args...>::value &&
-         !cuda::std::is_nothrow_invocable<Fn, Args...>::value;
+__host__ __device__ constexpr bool throws_invocable()
+{
+  return cuda::std::is_invocable<Fn, Args...>::value && !cuda::std::is_nothrow_invocable<Fn, Args...>::value;
 }
 
 template <class Ret, class Fn, class... Args>
-__host__ __device__ constexpr bool throws_invocable_r() {
-  return cuda::std::is_invocable_r<Ret, Fn, Args...>::value &&
-         !cuda::std::is_nothrow_invocable_r<Ret, Fn, Args...>::value;
+__host__ __device__ constexpr bool throws_invocable_r()
+{
+  return cuda::std::is_invocable_r<Ret, Fn, Args...>::value
+      && !cuda::std::is_nothrow_invocable_r<Ret, Fn, Args...>::value;
 }
 
-__host__ __device__ void test_noexcept_function_pointers() {
+__host__ __device__ void test_noexcept_function_pointers()
+{
 #if !defined(TEST_COMPILER_NVCC) || TEST_STD_VER >= 2017 // nvbug4360046
-  struct Dummy {
+  struct Dummy
+  {
     __host__ __device__ void foo() noexcept {}
     __host__ __device__ static void bar() noexcept {}
   };
@@ -70,7 +80,8 @@ __host__ __device__ void test_noexcept_function_pointers() {
 #endif // !defined(TEST_COMPILER_NVCC) || TEST_STD_VER >= 2017
 }
 
-int main(int, char**) {
+int main(int, char**)
+{
 #if TEST_STD_VER >= 2017
   using AbominableFunc = void(...) const noexcept;
 #endif // TEST_STD_VER >= 2017
@@ -96,12 +107,9 @@ int main(int, char**) {
     static_assert(!cuda::std::is_nothrow_invocable<int&&>::value, "");
 
 #ifdef _LIBCUDACXX_HAS_VECTOR
-    static_assert(!cuda::std::is_nothrow_invocable<int, cuda::std::vector<int> >::value,
-                  "");
-    static_assert(!cuda::std::is_nothrow_invocable<int, cuda::std::vector<int*> >::value,
-                  "");
-    static_assert(!cuda::std::is_nothrow_invocable<int, cuda::std::vector<int**> >::value,
-                  "");
+    static_assert(!cuda::std::is_nothrow_invocable<int, cuda::std::vector<int>>::value, "");
+    static_assert(!cuda::std::is_nothrow_invocable<int, cuda::std::vector<int*>>::value, "");
+    static_assert(!cuda::std::is_nothrow_invocable<int, cuda::std::vector<int**>>::value, "");
 #endif // _LIBCUDACXX_HAS_VECTOR
 
 #if TEST_STD_VER >= 2017
@@ -111,20 +119,17 @@ int main(int, char**) {
     //  with parameters
     static_assert(!cuda::std::is_nothrow_invocable<int, int>::value, "");
     static_assert(!cuda::std::is_nothrow_invocable<int, double, float>::value, "");
-    static_assert(!cuda::std::is_nothrow_invocable<int, char, float, double>::value,
-                  "");
+    static_assert(!cuda::std::is_nothrow_invocable<int, char, float, double>::value, "");
 #if TEST_STD_VER >= 2017
     static_assert(!cuda::std::is_nothrow_invocable<Sink, AbominableFunc>::value, "");
 #endif // TEST_STD_VER >= 2017
     static_assert(!cuda::std::is_nothrow_invocable<Sink, void>::value, "");
-    static_assert(!cuda::std::is_nothrow_invocable<Sink, const volatile void>::value,
-                  "");
+    static_assert(!cuda::std::is_nothrow_invocable<Sink, const volatile void>::value, "");
 
     static_assert(!cuda::std::is_nothrow_invocable_r<int, void>::value, "");
     static_assert(!cuda::std::is_nothrow_invocable_r<int, const void>::value, "");
     static_assert(!cuda::std::is_nothrow_invocable_r<int, volatile void>::value, "");
-    static_assert(!cuda::std::is_nothrow_invocable_r<int, const volatile void>::value,
-                  "");
+    static_assert(!cuda::std::is_nothrow_invocable_r<int, const volatile void>::value, "");
     static_assert(!cuda::std::is_nothrow_invocable_r<int, cuda::std::nullptr_t>::value, "");
     static_assert(!cuda::std::is_nothrow_invocable_r<int, int>::value, "");
     static_assert(!cuda::std::is_nothrow_invocable_r<int, double>::value, "");
@@ -141,32 +146,23 @@ int main(int, char**) {
     static_assert(!cuda::std::is_nothrow_invocable_r<int, int&&>::value, "");
 
 #ifdef _LIBCUDACXX_HAS_VECTOR
-    static_assert(!cuda::std::is_nothrow_invocable_r<int, cuda::std::vector<int> >::value,
-                  "");
-    static_assert(!cuda::std::is_nothrow_invocable_r<int, cuda::std::vector<int*> >::value,
-                  "");
-    static_assert(!cuda::std::is_nothrow_invocable_r<int, cuda::std::vector<int**> >::value,
-                  "");
+    static_assert(!cuda::std::is_nothrow_invocable_r<int, cuda::std::vector<int>>::value, "");
+    static_assert(!cuda::std::is_nothrow_invocable_r<int, cuda::std::vector<int*>>::value, "");
+    static_assert(!cuda::std::is_nothrow_invocable_r<int, cuda::std::vector<int**>>::value, "");
 #endif // _LIBCUDACXX_HAS_VECTOR
 #if TEST_STD_VER >= 2017
-    static_assert(!cuda::std::is_nothrow_invocable_r<void, AbominableFunc>::value,
-                  "");
+    static_assert(!cuda::std::is_nothrow_invocable_r<void, AbominableFunc>::value, "");
 #endif // TEST_STD_VER >= 2017
 
     //  with parameters
     static_assert(!cuda::std::is_nothrow_invocable_r<int, int, int>::value, "");
-    static_assert(!cuda::std::is_nothrow_invocable_r<int, int, double, float>::value,
-                  "");
-    static_assert(
-        !cuda::std::is_nothrow_invocable_r<int, int, char, float, double>::value, "");
+    static_assert(!cuda::std::is_nothrow_invocable_r<int, int, double, float>::value, "");
+    static_assert(!cuda::std::is_nothrow_invocable_r<int, int, char, float, double>::value, "");
 #if TEST_STD_VER >= 2017
-    static_assert(
-        !cuda::std::is_nothrow_invocable_r<void, Sink, AbominableFunc>::value, "");
+    static_assert(!cuda::std::is_nothrow_invocable_r<void, Sink, AbominableFunc>::value, "");
 #endif // TEST_STD_VER >= 2017
     static_assert(!cuda::std::is_nothrow_invocable_r<void, Sink, void>::value, "");
-    static_assert(
-        !cuda::std::is_nothrow_invocable_r<void, Sink, const volatile void>::value,
-        "");
+    static_assert(!cuda::std::is_nothrow_invocable_r<void, Sink, const volatile void>::value, "");
   }
 
   {
@@ -174,8 +170,7 @@ int main(int, char**) {
     using Fn = CallObject<true, int>;
     static_assert(cuda::std::is_nothrow_invocable_r<Implicit, Fn>::value, "");
     static_assert(cuda::std::is_nothrow_invocable_r<double, Fn>::value, "");
-    static_assert(cuda::std::is_nothrow_invocable_r<const volatile void, Fn>::value,
-                  "");
+    static_assert(cuda::std::is_nothrow_invocable_r<const volatile void, Fn>::value, "");
 #ifndef TEST_COMPILER_ICC
     static_assert(throws_invocable_r<ThrowsImplicit, Fn>(), "");
 #endif // TEST_COMPILER_ICC
@@ -184,10 +179,8 @@ int main(int, char**) {
   {
     // Check that the conversion to the parameters is properly checked
     using Fn = CallObject<true, void, const Implicit&, const ThrowsImplicit&>;
-    static_assert(
-        cuda::std::is_nothrow_invocable<Fn, Implicit&, ThrowsImplicit&>::value, "");
-    static_assert(cuda::std::is_nothrow_invocable<Fn, int, ThrowsImplicit&>::value,
-                  "");
+    static_assert(cuda::std::is_nothrow_invocable<Fn, Implicit&, ThrowsImplicit&>::value, "");
+    static_assert(cuda::std::is_nothrow_invocable<Fn, int, ThrowsImplicit&>::value, "");
 #ifndef TEST_COMPILER_ICC
     static_assert(throws_invocable<Fn, int, int>(), "");
 #endif // TEST_COMPILER_ICC
@@ -195,7 +188,7 @@ int main(int, char**) {
   }
   {
     // Check that the noexcept-ness of function objects is checked.
-    using Fn = CallObject<true, void>;
+    using Fn  = CallObject<true, void>;
     using Fn2 = CallObject<false, void>;
     static_assert(cuda::std::is_nothrow_invocable<Fn>::value, "");
 #ifndef TEST_COMPILER_ICC
@@ -214,8 +207,9 @@ int main(int, char**) {
 #if TEST_STD_VER >= 2017
   {
     // Check that it's fine if the result type is non-moveable.
-    struct CantMove {
-      CantMove() = default;
+    struct CantMove
+    {
+      CantMove()                               = default;
       __host__ __device__ CantMove(CantMove&&) = delete;
     };
 
@@ -224,15 +218,15 @@ int main(int, char**) {
 
     using Fn = CantMove() noexcept;
 
-#if !defined(TEST_COMPILER_MSVC_2017)
+#  if !defined(TEST_COMPILER_MSVC_2017)
     static_assert(cuda::std::is_nothrow_invocable_r<CantMove, Fn>::value, "");
-#endif // !TEST_COMPILER_MSVC_2017
+#  endif // !TEST_COMPILER_MSVC_2017
     static_assert(!cuda::std::is_nothrow_invocable_r<CantMove, Fn, int>::value, "");
 
-#ifndef TEST_COMPILER_MSVC_2017
+#  ifndef TEST_COMPILER_MSVC_2017
     static_assert(cuda::std::is_nothrow_invocable_r_v<CantMove, Fn>, "");
     static_assert(!cuda::std::is_nothrow_invocable_r_v<CantMove, Fn, int>, "");
-#endif // TEST_COMPILER_MSVC_2017
+#  endif // TEST_COMPILER_MSVC_2017
   }
 #endif // TEST_STD_VER >= 2017
   {
