@@ -13,28 +13,32 @@
 
 // result_of<Fn(ArgTypes...)>
 
-#include <cuda/std/type_traits>
 #include <cuda/std/cassert>
+#include <cuda/std/type_traits>
+
 #include "test_macros.h"
 
 template <class Ret, class Fn>
-__host__ __device__
-void test_lambda(Fn &&)
+__host__ __device__ void test_lambda(Fn&&)
 {
-    ASSERT_SAME_TYPE(Ret, typename cuda::std::result_of<Fn()>::type);
+  ASSERT_SAME_TYPE(Ret, typename cuda::std::result_of<Fn()>::type);
 
 #if TEST_STD_VER > 2011
-    ASSERT_SAME_TYPE(Ret, typename cuda::std::invoke_result<Fn>::type);
+  ASSERT_SAME_TYPE(Ret, typename cuda::std::invoke_result<Fn>::type);
 #endif
 }
 
 int main(int, char**)
 {
-#if defined(TEST_COMPILER_NVCC) || defined (TEST_COMPILER_NVRTC)
-    { // extended device lambda
-    test_lambda<int>([] __device__ () -> int { return 42; });
-    test_lambda<double>([] __device__ () -> double { return 42.0; });
-    }
+#if defined(TEST_COMPILER_NVCC) || defined(TEST_COMPILER_NVRTC)
+  { // extended device lambda
+    test_lambda<int>([] __device__() {
+      return 42;
+    });
+    test_lambda<double>([] __device__() {
+      return 42.0;
+    });
+  }
 #endif
 
   return 0;
