@@ -21,149 +21,205 @@
 
 #include "test_macros.h"
 
-struct LVal {
-  __host__ __device__
-  constexpr cuda::std::optional<int> operator()(int&) { return 1; }
-  cuda::std::optional<int> operator()(const int&) = delete;
-  cuda::std::optional<int> operator()(int&&) = delete;
+struct LVal
+{
+  __host__ __device__ constexpr cuda::std::optional<int> operator()(int&)
+  {
+    return 1;
+  }
+  cuda::std::optional<int> operator()(const int&)  = delete;
+  cuda::std::optional<int> operator()(int&&)       = delete;
   cuda::std::optional<int> operator()(const int&&) = delete;
 };
 
-struct CLVal {
+struct CLVal
+{
   cuda::std::optional<int> operator()(int&) = delete;
-  __host__ __device__
-  constexpr cuda::std::optional<int> operator()(const int&) { return 1; }
-  cuda::std::optional<int> operator()(int&&) = delete;
+  __host__ __device__ constexpr cuda::std::optional<int> operator()(const int&)
+  {
+    return 1;
+  }
+  cuda::std::optional<int> operator()(int&&)       = delete;
   cuda::std::optional<int> operator()(const int&&) = delete;
 };
 
-struct RVal {
-  cuda::std::optional<int> operator()(int&) = delete;
+struct RVal
+{
+  cuda::std::optional<int> operator()(int&)       = delete;
   cuda::std::optional<int> operator()(const int&) = delete;
-  __host__ __device__
-  constexpr cuda::std::optional<int> operator()(int&&) { return 1; }
+  __host__ __device__ constexpr cuda::std::optional<int> operator()(int&&)
+  {
+    return 1;
+  }
   cuda::std::optional<int> operator()(const int&&) = delete;
 };
 
-struct CRVal {
-  cuda::std::optional<int> operator()(int&) = delete;
+struct CRVal
+{
+  cuda::std::optional<int> operator()(int&)       = delete;
   cuda::std::optional<int> operator()(const int&) = delete;
-  cuda::std::optional<int> operator()(int&&) = delete;
-  __host__ __device__
-  constexpr cuda::std::optional<int> operator()(const int&&) { return 1; }
+  cuda::std::optional<int> operator()(int&&)      = delete;
+  __host__ __device__ constexpr cuda::std::optional<int> operator()(const int&&)
+  {
+    return 1;
+  }
 };
 
-struct RefQual {
-  __host__ __device__
-  constexpr cuda::std::optional<int> operator()(int) & { return 1; }
-  cuda::std::optional<int> operator()(int) const& = delete;
-  cuda::std::optional<int> operator()(int) && = delete;
+struct RefQual
+{
+  __host__ __device__ constexpr cuda::std::optional<int> operator()(int) &
+  {
+    return 1;
+  }
+  cuda::std::optional<int> operator()(int) const&  = delete;
+  cuda::std::optional<int> operator()(int) &&      = delete;
   cuda::std::optional<int> operator()(int) const&& = delete;
 };
 
-struct CRefQual {
+struct CRefQual
+{
   cuda::std::optional<int> operator()(int) & = delete;
-  __host__ __device__
-  constexpr cuda::std::optional<int> operator()(int) const& { return 1; }
-  cuda::std::optional<int> operator()(int) && = delete;
+  __host__ __device__ constexpr cuda::std::optional<int> operator()(int) const&
+  {
+    return 1;
+  }
+  cuda::std::optional<int> operator()(int) &&      = delete;
   cuda::std::optional<int> operator()(int) const&& = delete;
 };
 
-struct RVRefQual {
-  cuda::std::optional<int> operator()(int) & = delete;
+struct RVRefQual
+{
+  cuda::std::optional<int> operator()(int) &      = delete;
   cuda::std::optional<int> operator()(int) const& = delete;
-  __host__ __device__
-  constexpr cuda::std::optional<int> operator()(int) && { return 1; }
+  __host__ __device__ constexpr cuda::std::optional<int> operator()(int) &&
+  {
+    return 1;
+  }
   cuda::std::optional<int> operator()(int) const&& = delete;
 };
 
-struct RVCRefQual {
-  cuda::std::optional<int> operator()(int) & = delete;
+struct RVCRefQual
+{
+  cuda::std::optional<int> operator()(int) &      = delete;
   cuda::std::optional<int> operator()(int) const& = delete;
-  cuda::std::optional<int> operator()(int) && = delete;
-  __host__ __device__
-  constexpr cuda::std::optional<int> operator()(int) const&& { return 1; }
+  cuda::std::optional<int> operator()(int) &&     = delete;
+  __host__ __device__ constexpr cuda::std::optional<int> operator()(int) const&&
+  {
+    return 1;
+  }
 };
 
-struct NOLVal {
-  __host__ __device__
-  constexpr cuda::std::optional<int> operator()(int&) { return cuda::std::nullopt; }
-  cuda::std::optional<int> operator()(const int&) = delete;
-  cuda::std::optional<int> operator()(int&&) = delete;
+struct NOLVal
+{
+  __host__ __device__ constexpr cuda::std::optional<int> operator()(int&)
+  {
+    return cuda::std::nullopt;
+  }
+  cuda::std::optional<int> operator()(const int&)  = delete;
+  cuda::std::optional<int> operator()(int&&)       = delete;
   cuda::std::optional<int> operator()(const int&&) = delete;
 };
 
-struct NOCLVal {
+struct NOCLVal
+{
   cuda::std::optional<int> operator()(int&) = delete;
-  __host__ __device__
-  constexpr cuda::std::optional<int> operator()(const int&) { return cuda::std::nullopt; }
-  cuda::std::optional<int> operator()(int&&) = delete;
+  __host__ __device__ constexpr cuda::std::optional<int> operator()(const int&)
+  {
+    return cuda::std::nullopt;
+  }
+  cuda::std::optional<int> operator()(int&&)       = delete;
   cuda::std::optional<int> operator()(const int&&) = delete;
 };
 
-struct NORVal {
-  cuda::std::optional<int> operator()(int&) = delete;
+struct NORVal
+{
+  cuda::std::optional<int> operator()(int&)       = delete;
   cuda::std::optional<int> operator()(const int&) = delete;
-  __host__ __device__
-  constexpr cuda::std::optional<int> operator()(int&&) { return cuda::std::nullopt; }
+  __host__ __device__ constexpr cuda::std::optional<int> operator()(int&&)
+  {
+    return cuda::std::nullopt;
+  }
   cuda::std::optional<int> operator()(const int&&) = delete;
 };
 
-struct NOCRVal {
-  cuda::std::optional<int> operator()(int&) = delete;
+struct NOCRVal
+{
+  cuda::std::optional<int> operator()(int&)       = delete;
   cuda::std::optional<int> operator()(const int&) = delete;
-  cuda::std::optional<int> operator()(int&&) = delete;
-  __host__ __device__
-  constexpr cuda::std::optional<int> operator()(const int&&) { return cuda::std::nullopt; }
+  cuda::std::optional<int> operator()(int&&)      = delete;
+  __host__ __device__ constexpr cuda::std::optional<int> operator()(const int&&)
+  {
+    return cuda::std::nullopt;
+  }
 };
 
-struct NORefQual {
-  __host__ __device__
-  constexpr cuda::std::optional<int> operator()(int) & { return cuda::std::nullopt; }
-  cuda::std::optional<int> operator()(int) const& = delete;
-  cuda::std::optional<int> operator()(int) && = delete;
+struct NORefQual
+{
+  __host__ __device__ constexpr cuda::std::optional<int> operator()(int) &
+  {
+    return cuda::std::nullopt;
+  }
+  cuda::std::optional<int> operator()(int) const&  = delete;
+  cuda::std::optional<int> operator()(int) &&      = delete;
   cuda::std::optional<int> operator()(int) const&& = delete;
 };
 
-struct NOCRefQual {
+struct NOCRefQual
+{
   cuda::std::optional<int> operator()(int) & = delete;
-  __host__ __device__
-  constexpr cuda::std::optional<int> operator()(int) const& { return cuda::std::nullopt; }
-  cuda::std::optional<int> operator()(int) && = delete;
+  __host__ __device__ constexpr cuda::std::optional<int> operator()(int) const&
+  {
+    return cuda::std::nullopt;
+  }
+  cuda::std::optional<int> operator()(int) &&      = delete;
   cuda::std::optional<int> operator()(int) const&& = delete;
 };
 
-struct NORVRefQual {
-  cuda::std::optional<int> operator()(int) & = delete;
+struct NORVRefQual
+{
+  cuda::std::optional<int> operator()(int) &      = delete;
   cuda::std::optional<int> operator()(int) const& = delete;
-  __host__ __device__
-  constexpr cuda::std::optional<int> operator()(int) && { return cuda::std::nullopt; }
+  __host__ __device__ constexpr cuda::std::optional<int> operator()(int) &&
+  {
+    return cuda::std::nullopt;
+  }
   cuda::std::optional<int> operator()(int) const&& = delete;
 };
 
-struct NORVCRefQual {
-  cuda::std::optional<int> operator()(int) & = delete;
+struct NORVCRefQual
+{
+  cuda::std::optional<int> operator()(int) &      = delete;
   cuda::std::optional<int> operator()(int) const& = delete;
-  cuda::std::optional<int> operator()(int) && = delete;
-  __host__ __device__
-  constexpr cuda::std::optional<int> operator()(int) const&& { return cuda::std::nullopt; }
+  cuda::std::optional<int> operator()(int) &&     = delete;
+  __host__ __device__ constexpr cuda::std::optional<int> operator()(int) const&&
+  {
+    return cuda::std::nullopt;
+  }
 };
 
-struct NoCopy {
+struct NoCopy
+{
   NoCopy() = default;
-  __host__ __device__
-  NoCopy(const NoCopy&) { assert(false); }
-  __host__ __device__
-  cuda::std::optional<int> operator()(const NoCopy&&) { return 1; }
+  __host__ __device__ NoCopy(const NoCopy&)
+  {
+    assert(false);
+  }
+  __host__ __device__ cuda::std::optional<int> operator()(const NoCopy&&)
+  {
+    return 1;
+  }
 };
 
-struct NonConst {
-  __host__ __device__
-  cuda::std::optional<int> non_const() { return 1; }
+struct NonConst
+{
+  __host__ __device__ cuda::std::optional<int> non_const()
+  {
+    return 1;
+  }
 };
 
-__host__ __device__
-constexpr void test_val_types() {
+__host__ __device__ constexpr void test_val_types()
+{
   // Test & overload
   {
     // Without & qualifier on F's operator()
@@ -174,7 +230,7 @@ constexpr void test_val_types() {
       ASSERT_SAME_TYPE(decltype(i.and_then(LVal{})), cuda::std::optional<int>);
     }
 
-    //With & qualifier on F's operator()
+    // With & qualifier on F's operator()
     {
       cuda::std::optional<int> i{0};
       RefQual l{};
@@ -195,7 +251,7 @@ constexpr void test_val_types() {
       ASSERT_SAME_TYPE(decltype(i.and_then(CLVal{})), cuda::std::optional<int>);
     }
 
-    //With & qualifier on F's operator()
+    // With & qualifier on F's operator()
     {
       const cuda::std::optional<int> i{0};
       const CRefQual l{};
@@ -216,7 +272,7 @@ constexpr void test_val_types() {
       ASSERT_SAME_TYPE(decltype(cuda::std::move(i).and_then(RVal{})), cuda::std::optional<int>);
     }
 
-    //With & qualifier on F's operator()
+    // With & qualifier on F's operator()
     {
       cuda::std::optional<int> i{0};
       assert(i.and_then(RVRefQual{}) == 1);
@@ -235,7 +291,7 @@ constexpr void test_val_types() {
       ASSERT_SAME_TYPE(decltype(cuda::std::move(i).and_then(CRVal{})), cuda::std::optional<int>);
     }
 
-    //With & qualifier on F's operator()
+    // With & qualifier on F's operator()
     {
       const cuda::std::optional<int> i{0};
       const RVCRefQual l{};
@@ -247,27 +303,28 @@ constexpr void test_val_types() {
   }
 }
 
-// For a generic lambda, nvrtc appears to not know what to do and claims it needs an annotation (when normal lambdas don't).
-// This is an expanded lambda from the original test.
-struct nvrtc_workaround {
-    template<typename T>
-    __host__ __device__
-    cuda::std::optional<int> operator()(T && t) {
-        return t.non_const();
-    }
+// For a generic lambda, nvrtc appears to not know what to do and claims it needs an annotation (when normal lambdas
+// don't). This is an expanded lambda from the original test.
+struct nvrtc_workaround
+{
+  template <typename T>
+  __host__ __device__ cuda::std::optional<int> operator()(T&& t)
+  {
+    return t.non_const();
+  }
 };
 
 // check that the lambda body is not instantiated during overload resolution
-__host__ __device__
-TEST_CONSTEXPR_CXX17 void test_sfinae() {
+__host__ __device__ TEST_CONSTEXPR_CXX17 void test_sfinae()
+{
   cuda::std::optional<NonConst> opt{};
   auto l = nvrtc_workaround(); // [](auto&& x) { return x.non_const(); };
   opt.and_then(l);
   cuda::std::move(opt).and_then(l);
 }
 
-__host__ __device__
-TEST_CONSTEXPR_CXX17 bool test() {
+__host__ __device__ TEST_CONSTEXPR_CXX17 bool test()
+{
   test_val_types();
   cuda::std::optional<int> opt{};
   const auto& copt = opt;
@@ -290,7 +347,8 @@ TEST_CONSTEXPR_CXX17 bool test() {
   return true;
 }
 
-int main(int, char**) {
+int main(int, char**)
+{
   test();
 #if TEST_STD_VER > 2017
   static_assert(test());
