@@ -22,89 +22,121 @@
 
 #include "test_macros.h"
 
-struct LVal {
-  __host__ __device__
-  constexpr int operator()(int&) { return 1; }
-  int operator()(const int&) = delete;
-  int operator()(int&&) = delete;
+struct LVal
+{
+  __host__ __device__ constexpr int operator()(int&)
+  {
+    return 1;
+  }
+  int operator()(const int&)  = delete;
+  int operator()(int&&)       = delete;
   int operator()(const int&&) = delete;
 };
 
-struct CLVal {
+struct CLVal
+{
   int operator()(int&) = delete;
-  __host__ __device__
-  constexpr int operator()(const int&) { return 1; }
-  int operator()(int&&) = delete;
+  __host__ __device__ constexpr int operator()(const int&)
+  {
+    return 1;
+  }
+  int operator()(int&&)       = delete;
   int operator()(const int&&) = delete;
 };
 
-struct RVal {
-  int operator()(int&) = delete;
+struct RVal
+{
+  int operator()(int&)       = delete;
   int operator()(const int&) = delete;
-  __host__ __device__
-  constexpr int operator()(int&&) { return 1; }
+  __host__ __device__ constexpr int operator()(int&&)
+  {
+    return 1;
+  }
   int operator()(const int&&) = delete;
 };
 
-struct CRVal {
-  int operator()(int&) = delete;
+struct CRVal
+{
+  int operator()(int&)       = delete;
   int operator()(const int&) = delete;
-  int operator()(int&&) = delete;
-  __host__ __device__
-  constexpr int operator()(const int&&) { return 1; }
+  int operator()(int&&)      = delete;
+  __host__ __device__ constexpr int operator()(const int&&)
+  {
+    return 1;
+  }
 };
 
-struct RefQual {
-  __host__ __device__
-  constexpr int operator()(int) & { return 1; }
-  int operator()(int) const& = delete;
-  int operator()(int) && = delete;
+struct RefQual
+{
+  __host__ __device__ constexpr int operator()(int) &
+  {
+    return 1;
+  }
+  int operator()(int) const&  = delete;
+  int operator()(int) &&      = delete;
   int operator()(int) const&& = delete;
 };
 
-struct CRefQual {
+struct CRefQual
+{
   int operator()(int) & = delete;
-  __host__ __device__
-  constexpr int operator()(int) const& { return 1; }
-  int operator()(int) && = delete;
+  __host__ __device__ constexpr int operator()(int) const&
+  {
+    return 1;
+  }
+  int operator()(int) &&      = delete;
   int operator()(int) const&& = delete;
 };
 
-struct RVRefQual {
-  int operator()(int) & = delete;
+struct RVRefQual
+{
+  int operator()(int) &      = delete;
   int operator()(int) const& = delete;
-  __host__ __device__
-  constexpr int operator()(int) && { return 1; }
+  __host__ __device__ constexpr int operator()(int) &&
+  {
+    return 1;
+  }
   int operator()(int) const&& = delete;
 };
 
-struct RVCRefQual {
-  int operator()(int) & = delete;
+struct RVCRefQual
+{
+  int operator()(int) &      = delete;
   int operator()(int) const& = delete;
-  int operator()(int) && = delete;
-  __host__ __device__
-  constexpr int operator()(int) const&& { return 1; }
+  int operator()(int) &&     = delete;
+  __host__ __device__ constexpr int operator()(int) const&&
+  {
+    return 1;
+  }
 };
 
 #if TEST_STD_VER >= 2017
-struct NoCopy {
+struct NoCopy
+{
   NoCopy() = default;
-  __host__ __device__
-  NoCopy(const NoCopy&) { assert(false); }
-  __host__ __device__
-  int operator()(const NoCopy&&) { return 1; }
+  __host__ __device__ NoCopy(const NoCopy&)
+  {
+    assert(false);
+  }
+  __host__ __device__ int operator()(const NoCopy&&)
+  {
+    return 1;
+  }
 };
 
-struct NoMove {
-  NoMove() = default;
+struct NoMove
+{
+  NoMove()         = default;
   NoMove(NoMove&&) = delete;
-  __host__ __device__
-  NoMove operator()(const NoCopy&&) { return NoMove{}; }
+  __host__ __device__ NoMove operator()(const NoCopy&&)
+  {
+    return NoMove{};
+  }
 };
 #endif
 
-__host__ __device__
-constexpr void test_val_types() {
+__host__ __device__ constexpr void test_val_types()
+{
   // Test & overload
   {
     // Without & qualifier on F's operator()
@@ -114,7 +146,7 @@ constexpr void test_val_types() {
       ASSERT_SAME_TYPE(decltype(i.transform(LVal{})), cuda::std::optional<int>);
     }
 
-    //With & qualifier on F's operator()
+    // With & qualifier on F's operator()
     {
       cuda::std::optional<int> i{0};
       RefQual l{};
@@ -132,7 +164,7 @@ constexpr void test_val_types() {
       ASSERT_SAME_TYPE(decltype(i.transform(CLVal{})), cuda::std::optional<int>);
     }
 
-    //With & qualifier on F's operator()
+    // With & qualifier on F's operator()
     {
       const cuda::std::optional<int> i{0};
       const CRefQual l{};
@@ -150,7 +182,7 @@ constexpr void test_val_types() {
       ASSERT_SAME_TYPE(decltype(cuda::std::move(i).transform(RVal{})), cuda::std::optional<int>);
     }
 
-    //With & qualifier on F's operator()
+    // With & qualifier on F's operator()
     {
       cuda::std::optional<int> i{0};
       assert(i.transform(RVRefQual{}) == 1);
@@ -167,7 +199,7 @@ constexpr void test_val_types() {
       ASSERT_SAME_TYPE(decltype(cuda::std::move(i).transform(CRVal{})), cuda::std::optional<int>);
     }
 
-    //With & qualifier on F's operator()
+    // With & qualifier on F's operator()
     {
       const cuda::std::optional<int> i{0};
       const RVCRefQual l{};
@@ -177,32 +209,36 @@ constexpr void test_val_types() {
   }
 }
 
-struct NonConst {
-  __host__ __device__
-  int non_const() { return 1; }
+struct NonConst
+{
+  __host__ __device__ int non_const()
+  {
+    return 1;
+  }
 };
 
-// For a generic lambda, nvrtc appears to not know what to do and claims it needs an annotation (when normal lambdas don't).
-// This is an expanded lambda from the original test.
-struct nvrtc_workaround {
-    template<typename T>
-    __host__ __device__
-    int operator()(T && t) {
-        return t.non_const();
-    }
+// For a generic lambda, nvrtc appears to not know what to do and claims it needs an annotation (when normal lambdas
+// don't). This is an expanded lambda from the original test.
+struct nvrtc_workaround
+{
+  template <typename T>
+  __host__ __device__ int operator()(T&& t)
+  {
+    return t.non_const();
+  }
 };
 
 // check that the lambda body is not instantiated during overload resolution
-__host__ __device__
-TEST_CONSTEXPR_CXX17 void test_sfinae() {
+__host__ __device__ TEST_CONSTEXPR_CXX17 void test_sfinae()
+{
   cuda::std::optional<NonConst> opt{};
   auto l = nvrtc_workaround(); // [](auto&& x) { return x.non_const(); };
   opt.transform(l);
   cuda::std::move(opt).transform(l);
 }
 
-__host__ __device__
-TEST_CONSTEXPR_CXX17 bool test() {
+__host__ __device__ TEST_CONSTEXPR_CXX17 bool test()
+{
   test_sfinae();
   test_val_types();
   cuda::std::optional<int> opt;
@@ -232,7 +268,8 @@ TEST_CONSTEXPR_CXX17 bool test() {
   return true;
 }
 
-int main(int, char**) {
+int main(int, char**)
+{
   test();
 #if TEST_STD_VER > 2017
   static_assert(test());
