@@ -16,23 +16,26 @@
 // in_place_t constructor with no arguments when the Clang is trying to check
 // copy constructor.
 
+#include <cuda/std/cassert>
 #include <cuda/std/optional>
 #include <cuda/std/type_traits>
-#include <cuda/std/cassert>
 
-#include "test_macros.h"
 #include "archetypes.h"
+#include "test_macros.h"
 
 using cuda::std::optional;
 
-struct Wrapped {
-  struct Inner {
+struct Wrapped
+{
+  struct Inner
+  {
     bool Dummy = true;
   };
   cuda::std::optional<Inner> inner;
 };
 
-int main(int, char**) {
+int main(int, char**)
+{
   static_assert(cuda::std::is_default_constructible<Wrapped::Inner>::value, "");
   Wrapped w;
   w.inner.emplace();
