@@ -13,24 +13,30 @@
 
 // constexpr const T& optional<T>::value() const &;
 
+#include <cuda/std/cassert>
 #include <cuda/std/optional>
 #include <cuda/std/type_traits>
-#include <cuda/std/cassert>
 
 using cuda::std::optional;
 
 struct X
 {
-    constexpr int test() const {return 3;}
-    int test() {return 4;}
+  constexpr int test() const
+  {
+    return 3;
+  }
+  int test()
+  {
+    return 4;
+  }
 };
 
 int main(int, char**)
 {
-    {
-        constexpr optional<X> opt;
-        static_assert(opt.value().test() == 3, "");
-    }
+  {
+    constexpr optional<X> opt;
+    static_assert(opt.value().test() == 3, "");
+  }
 
   return 0;
 }
