@@ -18,9 +18,10 @@
 
 int main(int, char**)
 {
-    using cuda::std::optional;
+  using cuda::std::optional;
 
-    cuda::std::initializer_list<int> list; unused(list);
+  cuda::std::initializer_list<int> list;
+  unused(list);
 
   return 0;
 }
