@@ -12,20 +12,22 @@
 // using days = duration<signed integer type of at least 25 bits, ratio_multiply<ratio<24>, hours::period>>;
 
 #include <cuda/std/chrono>
-#include <cuda/std/type_traits>
 #include <cuda/std/limits>
+#include <cuda/std/type_traits>
 
 #include "test_macros.h"
 
 int main(int, char**)
 {
-    typedef cuda::std::chrono::days D;
-    typedef D::rep Rep;
-    typedef D::period Period;
-    static_assert(cuda::std::is_signed<Rep>::value, "");
-    static_assert(cuda::std::is_integral<Rep>::value, "");
-    static_assert(cuda::std::numeric_limits<Rep>::digits >= 25, "");
-    static_assert(cuda::std::is_same_v<Period, cuda::std::ratio_multiply<cuda::std::ratio<24>, cuda::std::chrono::hours::period>>, "");
+  typedef cuda::std::chrono::days D;
+  typedef D::rep Rep;
+  typedef D::period Period;
+  static_assert(cuda::std::is_signed<Rep>::value, "");
+  static_assert(cuda::std::is_integral<Rep>::value, "");
+  static_assert(cuda::std::numeric_limits<Rep>::digits >= 25, "");
+  static_assert(
+    cuda::std::is_same_v<Period, cuda::std::ratio_multiply<cuda::std::ratio<24>, cuda::std::chrono::hours::period>>,
+    "");
 
   return 0;
 }
