@@ -12,35 +12,33 @@
 
 //  constexpr unsigned c_encoding() const noexcept;
 
-
+#include <cuda/std/cassert>
 #include <cuda/std/chrono>
 #include <cuda/std/type_traits>
-#include <cuda/std/cassert>
 
 #include "test_macros.h"
 
 template <typename WD>
-__host__ __device__
-constexpr bool testConstexpr()
+__host__ __device__ constexpr bool testConstexpr()
 {
-    WD wd{5};
-    return wd.c_encoding() == 5;
+  WD wd{5};
+  return wd.c_encoding() == 5;
 }
 
 int main(int, char**)
 {
-    using weekday = cuda::std::chrono::weekday;
+  using weekday = cuda::std::chrono::weekday;
 
-    ASSERT_NOEXCEPT(                    cuda::std::declval<weekday&>().c_encoding());
-    ASSERT_SAME_TYPE(unsigned, decltype(cuda::std::declval<weekday&>().c_encoding()));
+  ASSERT_NOEXCEPT(cuda::std::declval<weekday&>().c_encoding());
+  ASSERT_SAME_TYPE(unsigned, decltype(cuda::std::declval<weekday&>().c_encoding()));
 
-    static_assert(testConstexpr<weekday>(), "");
+  static_assert(testConstexpr<weekday>(), "");
 
-    for (unsigned i = 0; i <= 10; ++i)
-    {
-        weekday wd(i);
-        assert(wd.c_encoding() == (i == 7 ? 0 : i));
-    }
+  for (unsigned i = 0; i <= 10; ++i)
+  {
+    weekday wd(i);
+    assert(wd.c_encoding() == (i == 7 ? 0 : i));
+  }
 
   return 0;
 }
