@@ -13,40 +13,45 @@
 // constexpr year operator+() const noexcept;
 // constexpr year operator-() const noexcept;
 
+#include <cuda/std/cassert>
 #include <cuda/std/chrono>
 #include <cuda/std/type_traits>
-#include <cuda/std/cassert>
 
 #include "test_macros.h"
 
 template <typename Y>
-__host__ __device__
-constexpr bool testConstexpr()
+__host__ __device__ constexpr bool testConstexpr()
 {
-    Y y1{1};
-    if (static_cast<int>(+y1) !=  1) return false;
-    if (static_cast<int>(-y1) != -1) return false;
-    return true;
+  Y y1{1};
+  if (static_cast<int>(+y1) != 1)
+  {
+    return false;
+  }
+  if (static_cast<int>(-y1) != -1)
+  {
+    return false;
+  }
+  return true;
 }
 
 int main(int, char**)
 {
-    using year  = cuda::std::chrono::year;
+  using year = cuda::std::chrono::year;
 
-    ASSERT_NOEXCEPT(+cuda::std::declval<year>());
-    ASSERT_NOEXCEPT(-cuda::std::declval<year>());
+  ASSERT_NOEXCEPT(+cuda::std::declval<year>());
+  ASSERT_NOEXCEPT(-cuda::std::declval<year>());
 
-    ASSERT_SAME_TYPE(year, decltype(+cuda::std::declval<year>()));
-    ASSERT_SAME_TYPE(year, decltype(-cuda::std::declval<year>()));
+  ASSERT_SAME_TYPE(year, decltype(+cuda::std::declval<year>()));
+  ASSERT_SAME_TYPE(year, decltype(-cuda::std::declval<year>()));
 
-    static_assert(testConstexpr<year>(), "");
+  static_assert(testConstexpr<year>(), "");
 
-    for (int i = 10000; i <= 10020; ++i)
-    {
-        year year(i);
-        assert(static_cast<int>(+year) ==  i);
-        assert(static_cast<int>(-year) == -i);
-    }
+  for (int i = 10000; i <= 10020; ++i)
+  {
+    year year(i);
+    assert(static_cast<int>(+year) == i);
+    assert(static_cast<int>(-year) == -i);
+  }
 
   return 0;
 }
