@@ -25,18 +25,18 @@
 #include <cuda/std/chrono>
 
 template <class T>
-__host__ __device__
-void test(const T &) {}
+__host__ __device__ void test(const T&)
+{}
 
 int main(int, char**)
 {
-    typedef cuda::std::chrono::file_clock C;
-    static_assert((cuda::std::is_same<C::rep, C::duration::rep>::value), "");
-    static_assert((cuda::std::is_same<C::period, C::duration::period>::value), "");
-    static_assert((cuda::std::is_same<C::duration, C::time_point::duration>::value), "");
-    static_assert((cuda::std::is_same<C::time_point::clock, C>::value), "");
-    static_assert(!C::is_steady, "");
-    test(cuda::std::chrono::file_clock::is_steady);
+  typedef cuda::std::chrono::file_clock C;
+  static_assert((cuda::std::is_same<C::rep, C::duration::rep>::value), "");
+  static_assert((cuda::std::is_same<C::period, C::duration::period>::value), "");
+  static_assert((cuda::std::is_same<C::duration, C::time_point::duration>::value), "");
+  static_assert((cuda::std::is_same<C::time_point::clock, C>::value), "");
+  static_assert(!C::is_steady, "");
+  test(cuda::std::chrono::file_clock::is_steady);
 
   return 0;
 }
