@@ -12,31 +12,30 @@
 
 // constexpr duration& operator++();  // constexpr in C++17
 
-#include <cuda/std/chrono>
 #include <cuda/std/cassert>
+#include <cuda/std/chrono>
 
 #include "test_macros.h"
 
 #if TEST_STD_VER > 2014
-__host__ __device__
-constexpr bool test_constexpr()
+__host__ __device__ constexpr bool test_constexpr()
 {
-    cuda::std::chrono::hours h(3);
-    return (++h).count() == 4;
+  cuda::std::chrono::hours h(3);
+  return (++h).count() == 4;
 }
 #endif
 
 int main(int, char**)
 {
-    {
+  {
     cuda::std::chrono::hours h(3);
     cuda::std::chrono::hours& href = ++h;
     assert(&href == &h);
     assert(h.count() == 4);
-    }
+  }
 
 #if TEST_STD_VER > 2014
-    static_assert(test_constexpr(), "");
+  static_assert(test_constexpr(), "");
 #endif
 
   return 0;
