@@ -12,31 +12,30 @@
 
 // duration& operator%=(const rep& rhs)
 
-#include <cuda/std/chrono>
 #include <cuda/std/cassert>
+#include <cuda/std/chrono>
 
 #include "test_macros.h"
 
 #if TEST_STD_VER > 2014
-__host__ __device__
-constexpr bool test_constexpr()
+__host__ __device__ constexpr bool test_constexpr()
 {
-    cuda::std::chrono::seconds s(11);
-    s %= 3;
-    return s.count() == 2;
+  cuda::std::chrono::seconds s(11);
+  s %= 3;
+  return s.count() == 2;
 }
 #endif
 
 int main(int, char**)
 {
-    {
+  {
     cuda::std::chrono::microseconds us(11);
     us %= 3;
     assert(us.count() == 2);
-    }
+  }
 
 #if TEST_STD_VER > 2014
-    static_assert(test_constexpr(), "");
+  static_assert(test_constexpr(), "");
 #endif
 
   return 0;
