@@ -9,17 +9,17 @@
 
 // UNSUPPORTED: c++98, c++03
 
-
 //  Tuples of smart pointers; based on bug #18350
 //  auto_ptr doesn't have a copy constructor that takes a const &, but tuple does.
 
 #include <cuda/std/tuple>
 // cuda::std::___ptr not supported
-//#include <memory>
+// #include <memory>
 
 #include "test_macros.h"
 
-int main(int, char**) {
+int main(int, char**)
+{
   // cuda::std::___ptr not supported
   /*
     {
@@ -33,9 +33,9 @@ int main(int, char**) {
     cuda::std::tuple<cuda::std::weak_ptr  <char[]>> wp;
     }
   */
-    // Smart pointers of type 'T[N]' are not tested here since they are not
-    // supported by the standard nor by libc++'s implementation.
-    // See https://reviews.llvm.org/D21320 for more information.
+  // Smart pointers of type 'T[N]' are not tested here since they are not
+  // supported by the standard nor by libc++'s implementation.
+  // See https://reviews.llvm.org/D21320 for more information.
 
   return 0;
 }
