@@ -8,7 +8,6 @@
 
 // UNSUPPORTED: c++98, c++03
 
-
 // <cuda/std/tuple>
 
 // template <class... Types> class tuple;
@@ -21,13 +20,18 @@
 
 #include <cuda/std/tuple>
 
+struct ExplicitDefault
+{
+  __host__ __device__ explicit ExplicitDefault() {}
+};
 
-struct ExplicitDefault { __host__ __device__ explicit ExplicitDefault() { } };
-
-__host__ __device__ std::tuple<ExplicitDefault> explicit_default_test() {
-    return {cuda::std::allocator_arg, cuda::std::allocator<int>()}; // expected-error {{chosen constructor is explicit in copy-initialization}}
+__host__ __device__ std::tuple<ExplicitDefault> explicit_default_test()
+{
+  return {cuda::std::allocator_arg, cuda::std::allocator<int>()}; // expected-error {{chosen constructor is explicit in
+                                                                  // copy-initialization}}
 }
 
-int main(int, char**) {
-    return 0;
+int main(int, char**)
+{
+  return 0;
 }
