@@ -9,13 +9,15 @@
 
 // UNSUPPORTED: c++03, c++11
 
-
 // template <class T> constexpr add_const<T>& as_const(T& t) noexcept;      // C++17
 // template <class T>           add_const<T>& as_const(const T&&) = delete; // C++17
 
 #include <cuda/std/utility>
 
-struct S {int i;};
+struct S
+{
+  int i;
+};
 
 int main(int, char**)
 {
