@@ -6,8 +6,6 @@
 //
 //===----------------------------------------------------------------------===//
 
-
-
 // <utility>
 
 // template <class T1, class T2> struct pair
@@ -18,8 +16,9 @@
 
 int main(int, char**)
 {
-    typedef cuda::std::pair<int, short> T;
-    cuda::std::tuple_element<2, T>::type foo; // expected-error@__utility/pair.h:* {{Index out of bounds in cuda::std::tuple_element<cuda::std::pair<T1, T2>>}}
+  typedef cuda::std::pair<int, short> T;
+  cuda::std::tuple_element<2, T>::type foo; // expected-error@__utility/pair.h:* {{Index out of bounds in
+                                            // cuda::std::tuple_element<cuda::std::pair<T1, T2>>}}
 
   return 0;
 }
