@@ -17,9 +17,10 @@
 
 #include "test_macros.h"
 
-int main(int, char**) {
-    cuda::std::piecewise_construct_t x = cuda::std::piecewise_construct;
-    unused(x);
+int main(int, char**)
+{
+  cuda::std::piecewise_construct_t x = cuda::std::piecewise_construct;
+  unused(x);
 
-    return 0;
+  return 0;
 }
