@@ -12,34 +12,40 @@
 
 // pair(const T1& x, const T2& y);
 
-#include <cuda/std/utility>
 #include <cuda/std/cassert>
+#include <cuda/std/utility>
 
 #include "test_macros.h"
 
 class A
 {
-    int data_;
-public:
-    __host__ __device__ A(int data) : data_(data) {}
+  int data_;
 
-    __host__ __device__ bool operator==(const A& a) const {return data_ == a.data_;}
+public:
+  __host__ __device__ A(int data)
+      : data_(data)
+  {}
+
+  __host__ __device__ bool operator==(const A& a) const
+  {
+    return data_ == a.data_;
+  }
 };
 
 int main(int, char**)
 {
-    {
-        typedef cuda::std::pair<float, short*> P;
-        P p(3.5f, 0);
-        assert(p.first == 3.5f);
-        assert(p.second == nullptr);
-    }
-    {
-        typedef cuda::std::pair<A, int> P;
-        P p(1, 2);
-        assert(p.first == A(1));
-        assert(p.second == 2);
-    }
+  {
+    typedef cuda::std::pair<float, short*> P;
+    P p(3.5f, 0);
+    assert(p.first == 3.5f);
+    assert(p.second == nullptr);
+  }
+  {
+    typedef cuda::std::pair<A, int> P;
+    P p(1, 2);
+    assert(p.first == A(1));
+    assert(p.second == 2);
+  }
 
   return 0;
 }
