@@ -9,16 +9,17 @@
 
 // UNSUPPORTED: c++03, c++11, c++14, c++17, c++20
 
-
 // [utility.underlying], to_underlying
 // template <class T>
 //     constexpr underlying_type_t<T> to_underlying( T value ) noexcept; // C++2b
 
 #include <cuda/std/utility>
 
-struct S {};
+struct S
+{};
 
-int main(int, char**) {
+int main(int, char**)
+{
   cuda::std::to_underlying(125); // expected-error {{no matching function for call}}
   cuda::std::to_underlying(S{}); // expected-error {{no matching function for call}}
 
