@@ -11,8 +11,12 @@
 
 #include <cuda/std/utility>
 
-[[noreturn]] void unreachable() { cuda::std::unreachable(); } // expected-no-diagnostics
+[[noreturn]] void unreachable()
+{
+  cuda::std::unreachable();
+} // expected-no-diagnostics
 
-int main(int, char**) {
+int main(int, char**)
+{
   return 0;
 }
