@@ -18,7 +18,8 @@
 
 #include "test_macros.h"
 
-int main(int, char**) {
+int main(int, char**)
+{
   static_assert(cuda::std::variant_npos == static_cast<cuda::std::size_t>(-1), "");
 
   return 0;
