@@ -10,13 +10,15 @@
 #ifndef TEST_SUPPORT_ITERATOR_TRAITS_ITERATOR_TRAITS_CPP17_ITERATORS
 #define TEST_SUPPORT_ITERATOR_TRAITS_ITERATOR_TRAITS_CPP17_ITERATORS
 
-struct iterator_traits_cpp17_iterator {
+struct iterator_traits_cpp17_iterator
+{
   __host__ __device__ int& operator*();
   __host__ __device__ iterator_traits_cpp17_iterator& operator++();
   __host__ __device__ iterator_traits_cpp17_iterator operator++(int);
 };
 
-struct iterator_traits_cpp17_proxy_iterator {
+struct iterator_traits_cpp17_proxy_iterator
+{
   __host__ __device__ int operator*();
   __host__ __device__ iterator_traits_cpp17_proxy_iterator& operator++();
 
@@ -24,9 +26,10 @@ struct iterator_traits_cpp17_proxy_iterator {
   __host__ __device__ iterator_traits_cpp17_iterator operator++(int);
 };
 
-struct iterator_traits_cpp17_input_iterator {
+struct iterator_traits_cpp17_input_iterator
+{
   using difference_type = int;
-  using value_type = long;
+  using value_type      = long;
 
   __host__ __device__ int& operator*();
   __host__ __device__ iterator_traits_cpp17_input_iterator& operator++();
@@ -38,9 +41,10 @@ struct iterator_traits_cpp17_input_iterator {
 #endif
 };
 
-struct iterator_traits_cpp17_proxy_input_iterator {
+struct iterator_traits_cpp17_proxy_input_iterator
+{
   using difference_type = int;
-  using value_type = long;
+  using value_type      = long;
 
   __host__ __device__ int operator*();
   __host__ __device__ iterator_traits_cpp17_proxy_input_iterator& operator++();
@@ -54,9 +58,10 @@ struct iterator_traits_cpp17_proxy_input_iterator {
 #endif
 };
 
-struct iterator_traits_cpp17_forward_iterator {
+struct iterator_traits_cpp17_forward_iterator
+{
   using difference_type = int;
-  using value_type = int;
+  using value_type      = int;
 
   __host__ __device__ int& operator*();
   __host__ __device__ iterator_traits_cpp17_forward_iterator& operator++();
@@ -68,9 +73,10 @@ struct iterator_traits_cpp17_forward_iterator {
 #endif
 };
 
-struct iterator_traits_cpp17_bidirectional_iterator {
+struct iterator_traits_cpp17_bidirectional_iterator
+{
   using difference_type = int;
-  using value_type = int;
+  using value_type      = int;
 
   __host__ __device__ int& operator*();
   __host__ __device__ iterator_traits_cpp17_bidirectional_iterator& operator++();
@@ -84,9 +90,10 @@ struct iterator_traits_cpp17_bidirectional_iterator {
 #endif
 };
 
-struct iterator_traits_cpp17_random_access_iterator {
+struct iterator_traits_cpp17_random_access_iterator
+{
   using difference_type = int;
-  using value_type = int;
+  using value_type      = int;
 
   __host__ __device__ int& operator*();
   __host__ __device__ int& operator[](difference_type);
@@ -107,14 +114,14 @@ struct iterator_traits_cpp17_random_access_iterator {
   __host__ __device__ iterator_traits_cpp17_random_access_iterator& operator+=(difference_type);
   __host__ __device__ iterator_traits_cpp17_random_access_iterator& operator-=(difference_type);
 
-  __host__ __device__ friend iterator_traits_cpp17_random_access_iterator operator+(iterator_traits_cpp17_random_access_iterator,
-                                                                difference_type);
-  __host__ __device__ friend iterator_traits_cpp17_random_access_iterator operator+(difference_type,
-                                                                iterator_traits_cpp17_random_access_iterator);
-  __host__ __device__ friend iterator_traits_cpp17_random_access_iterator operator-(iterator_traits_cpp17_random_access_iterator,
-                                                                difference_type);
-  __host__ __device__ friend difference_type operator-(iterator_traits_cpp17_random_access_iterator,
-                                   iterator_traits_cpp17_random_access_iterator);
+  __host__ __device__ friend iterator_traits_cpp17_random_access_iterator
+  operator+(iterator_traits_cpp17_random_access_iterator, difference_type);
+  __host__ __device__ friend iterator_traits_cpp17_random_access_iterator
+  operator+(difference_type, iterator_traits_cpp17_random_access_iterator);
+  __host__ __device__ friend iterator_traits_cpp17_random_access_iterator
+  operator-(iterator_traits_cpp17_random_access_iterator, difference_type);
+  __host__ __device__ friend difference_type
+  operator-(iterator_traits_cpp17_random_access_iterator, iterator_traits_cpp17_random_access_iterator);
 };
 
 #endif // TEST_SUPPORT_ITERATOR_TRAITS_ITERATOR_TRAITS_CPP17_ITERATORS
