@@ -9,28 +9,33 @@
 #ifndef LIBCUDACXX_TEST_SUPPORT_READ_WRITE_H
 #define LIBCUDACXX_TEST_SUPPORT_READ_WRITE_H
 
-struct value_type_indirection {
+struct value_type_indirection
+{
   using value_type = int;
   __host__ __device__ value_type& operator*() const;
 };
 
-struct element_type_indirection {
+struct element_type_indirection
+{
   using element_type = long;
   __host__ __device__ element_type& operator*() const;
 };
 
-struct proxy_indirection {
+struct proxy_indirection
+{
   using value_type = int;
   __host__ __device__ value_type operator*() const;
 };
 
-struct read_only_indirection {
+struct read_only_indirection
+{
   using value_type = int const;
   __host__ __device__ value_type& operator*() const;
 };
 
 // doubles as missing_iter_reference_t
-struct missing_dereference {
+struct missing_dereference
+{
   using value_type = int;
 };
 
