@@ -15,32 +15,30 @@
 #include "test_macros.h"
 #include "test_workarounds.h"
 
-struct X {
-    __host__ __device__
-    X(int) {}
+struct X
+{
+  __host__ __device__ X(int) {}
 
-    X(X&&) = default;
-    X& operator=(X&&) = default;
+  X(X&&)            = default;
+  X& operator=(X&&) = default;
 
 private:
-    X(const X&) = default;
-    X& operator=(const X&) = default;
+  X(const X&)            = default;
+  X& operator=(const X&) = default;
 };
 
-__host__ __device__
-void PushFront(X&&) {}
+__host__ __device__ void PushFront(X&&) {}
 
-template<class T = int>
-__host__ __device__
-auto test(int) -> decltype(PushFront(cuda::std::declval<T>()), cuda::std::true_type{});
-__host__ __device__
-auto test(long) -> cuda::std::false_type;
+template <class T = int>
+__host__ __device__ auto test(int) -> decltype(PushFront(cuda::std::declval<T>()), cuda::std::true_type{});
+__host__ __device__ auto test(long) -> cuda::std::false_type;
 
-int main(int, char**) {
+int main(int, char**)
+{
 #if defined(TEST_WORKAROUND_C1XX_BROKEN_ZA_CTOR_CHECK)
-    static_assert(!decltype(test(0))::value, "");
+  static_assert(!decltype(test(0))::value, "");
 #else
-    static_assert(decltype(test(0))::value, "");
+  static_assert(decltype(test(0))::value, "");
 #endif
 
   return 0;
