@@ -18,21 +18,29 @@
 
 #include "test_macros.h"
 
+namespace detail
+{
+template <class Tp>
+__host__ __device__ void eat_type(Tp);
 
-namespace detail {
-    template <class Tp> __host__ __device__ void eat_type(Tp);
-
-    template <class Tp, class ...Args>
-    __host__ __device__ constexpr auto test_convertible_imp(int)
-        -> decltype(eat_type<Tp>({cuda::std::declval<Args>()...}), true)
-    { return true; }
-
-    template <class Tp, class ...Args>
-    __host__ __device__ constexpr auto test_convertible_imp(long) -> bool { return false; }
+template <class Tp, class... Args>
+__host__ __device__ constexpr auto test_convertible_imp(int)
+  -> decltype(eat_type<Tp>({cuda::std::declval<Args>()...}), true)
+{
+  return true;
 }
 
-template <class Tp, class ...Args>
+template <class Tp, class... Args>
+__host__ __device__ constexpr auto test_convertible_imp(long) -> bool
+{
+  return false;
+}
+} // namespace detail
+
+template <class Tp, class... Args>
 __host__ __device__ constexpr bool test_convertible()
-{ return detail::test_convertible_imp<Tp, Args...>(0); }
+{
+  return detail::test_convertible_imp<Tp, Args...>(0);
+}
 
 #endif // SUPPORT_TEST_CONVERTIBLE_H
