@@ -6,20 +6,20 @@
 //
 //===----------------------------------------------------------------------===//
 
-__host__ __device__
-inline long double truncate_fp(long double val) {
+__host__ __device__ inline long double truncate_fp(long double val)
+{
   volatile long double sink = val;
   return sink;
 }
 
-__host__ __device__
-inline double truncate_fp(double val) {
+__host__ __device__ inline double truncate_fp(double val)
+{
   volatile double sink = val;
   return sink;
 }
 
-__host__ __device__
-inline float truncate_fp(float val) {
+__host__ __device__ inline float truncate_fp(float val)
+{
   volatile float sink = val;
   return sink;
 }
