@@ -14,33 +14,38 @@
 #include "test_macros.h"
 
 #ifndef TEST_COMPILER_NVRTC
-#include <typeinfo>
-#include <string>
+#  include <string>
+#  include <typeinfo>
 
-#include "demangle.h"
+#  include "demangle.h"
 #endif // TEST_COMPILER_NVRTC
 
 // TypeID - Represent a unique identifier for a type. TypeID allows equality
 // comparisons between different types.
-struct TypeID {
+struct TypeID
+{
   __host__ __device__ friend bool operator==(TypeID const& LHS, TypeID const& RHS)
-  {return LHS.m_id == RHS.m_id; }
+  {
+    return LHS.m_id == RHS.m_id;
+  }
   __host__ __device__ friend bool operator!=(TypeID const& LHS, TypeID const& RHS)
-  {return LHS.m_id != RHS.m_id; }
+  {
+    return LHS.m_id != RHS.m_id;
+  }
 
 #if 0
   std::string name() const {
     return demangle(m_id);
   }
 #else
-  __host__ __device__
-  const char * name() const {
+  __host__ __device__ const char* name() const
+  {
     return m_id;
   }
 #endif
 
-  __host__ __device__
-  void dump() const {
+  __host__ __device__ void dump() const
+  {
 #if 0
     std::string s = name();
     std::printf("TypeID: %s\n", s.c_str());
@@ -50,57 +55,66 @@ struct TypeID {
   }
 
 private:
-  __host__ __device__ explicit constexpr TypeID(const char* xid) : m_id(xid) {}
+  __host__ __device__ explicit constexpr TypeID(const char* xid)
+      : m_id(xid)
+  {}
 
-  TypeID(const TypeID&) = delete;
+  TypeID(const TypeID&)            = delete;
   TypeID& operator=(TypeID const&) = delete;
 
   const char* const m_id;
-  template <class T> __host__ __device__ friend TypeID const& makeTypeIDImp();
+  template <class T>
+  __host__ __device__ friend TypeID const& makeTypeIDImp();
 };
 
 // makeTypeID - Return the TypeID for the specified type 'T'.
 template <class T>
-__host__ __device__ inline TypeID const& makeTypeIDImp() {
-  #ifdef __CUDA_ARCH__
+__host__ __device__ inline TypeID const& makeTypeIDImp()
+{
+#ifdef __CUDA_ARCH__
   __constant__ static const TypeID id{__PRETTY_FUNCTION__};
-  #elif defined(_MSC_VER)
+#elif defined(_MSC_VER)
   static const TypeID id(__FUNCDNAME__);
-  #else
+#else
   static const TypeID id(__PRETTY_FUNCTION__);
-  #endif
+#endif
 
   return id;
 }
 
 template <class T>
-struct TypeWrapper {};
+struct TypeWrapper
+{};
 
 template <class T>
-__host__ __device__ inline  TypeID const& makeTypeID() {
+__host__ __device__ inline TypeID const& makeTypeID()
+{
   return makeTypeIDImp<TypeWrapper<T>>();
 }
 
-template <class ...Args>
-struct ArgumentListID {};
+template <class... Args>
+struct ArgumentListID
+{};
 
 // makeArgumentID - Create and return a unique identifier for a given set
 // of arguments.
-template <class ...Args>
-__host__ __device__ inline  TypeID const& makeArgumentID() {
+template <class... Args>
+__host__ __device__ inline TypeID const& makeArgumentID()
+{
   return makeTypeIDImp<ArgumentListID<Args...>>();
 }
 
-
 // COMPARE_TYPEID(...) is a utility macro for generating diagnostics when
 // two typeid's are expected to be equal
 #define COMPARE_TYPEID(LHS, RHS) CompareTypeIDVerbose(#LHS, LHS, #RHS, RHS)
 
-__host__ __device__
-inline bool CompareTypeIDVerbose(const char* LHSString, TypeID const* LHS,
-                                 const char* RHSString, TypeID const* RHS) {
+__host__ __device__ inline bool
+CompareTypeIDVerbose(const char* LHSString, TypeID const* LHS, const char* RHSString, TypeID const* RHS)
+{
   if (*LHS == *RHS)
+  {
     return true;
+  }
 #if 0
   std::printf("TypeID's not equal:\n");
   std::printf("%s: %s\n----------\n%s: %s\n",
@@ -108,9 +122,7 @@ inline bool CompareTypeIDVerbose(const char* LHSString, TypeID const* LHS,
               RHSString, RHS->name().c_str());
 #else
   printf("TypeID's not equal:\n");
-  printf("%s: %s\n----------\n%s: %s\n",
-              LHSString, LHS->name(),
-              RHSString, RHS->name());
+  printf("%s: %s\n----------\n%s: %s\n", LHSString, LHS->name(), RHSString, RHS->name());
 #endif
   return false;
 }
