@@ -31,22 +31,19 @@
 #  pragma system_header
 #endif // no system header
 
-#include <cmath>
-#include <complex>
-#include <sstream>
 #include <thrust/detail/type_traits.h>
 #include <thrust/type_traits/is_trivially_relocatable.h>
 
+#include <cmath>
+#include <complex>
+#include <sstream>
+
 #if THRUST_CPP_DIALECT >= 2011
 #  define THRUST_STD_COMPLEX_REAL(z) \
-    reinterpret_cast< \
-      const typename thrust::detail::remove_reference<decltype(z)>::type::value_type (&)[2] \
-    >(z)[0]
+    reinterpret_cast<const typename ::cuda::std::__libcpp_remove_reference_t<decltype(z)>::value_type(&)[2]>(z)[0]
 #  define THRUST_STD_COMPLEX_IMAG(z) \
-    reinterpret_cast< \
-      const typename thrust::detail::remove_reference<decltype(z)>::type::value_type (&)[2] \
-    >(z)[1]
-#  define THRUST_STD_COMPLEX_DEVICE __device__
+    reinterpret_cast<const typename ::cuda::std::__libcpp_remove_reference_t<decltype(z)>::value_type(&)[2]>(z)[1]
+#  define THRUST_STD_COMPLEX_DEVICE _CCCL_DEVICE
 #else
 #  define THRUST_STD_COMPLEX_REAL(z) (z).real()
 #  define THRUST_STD_COMPLEX_IMAG(z) (z).imag()
@@ -62,7 +59,6 @@ THRUST_NAMESPACE_BEGIN
  *  fail to match the template, and give up looking for other scopes.
  */
 
-
 /*! \addtogroup numerics
  *  \{
  */
@@ -80,70 +76,84 @@ namespace detail
 template <typename T, std::size_t Align>
 struct complex_storage;
 
-#if THRUST_CPP_DIALECT >= 2011                                                    \
-  && (THRUST_HOST_COMPILER == THRUST_HOST_COMPILER_GCC)                       \
-  && (THRUST_GCC_VERSION >= 40800)
-  // C++11 implementation, excluding GCC 4.7, which doesn't have `alignas`.
-  template <typename T, std::size_t Align>
-  struct complex_storage
+#if THRUST_CPP_DIALECT >= 2011 && (THRUST_HOST_COMPILER == THRUST_HOST_COMPILER_GCC) && (THRUST_GCC_VERSION >= 40800)
+// C++11 implementation, excluding GCC 4.7, which doesn't have `alignas`.
+template <typename T, std::size_t Align>
+struct complex_storage
+{
+  struct alignas(Align) type
   {
-    struct alignas(Align) type { T x; T y; };
+    T x;
+    T y;
   };
-#elif  (THRUST_HOST_COMPILER == THRUST_HOST_COMPILER_MSVC)                    \
-    || (   (THRUST_HOST_COMPILER == THRUST_HOST_COMPILER_GCC)                 \
-        && (THRUST_GCC_VERSION < 40600))
-  // C++03 implementation for MSVC and GCC <= 4.5.
-  //
-  // We have to implement `aligned_type` with specializations for MSVC
-  // and GCC 4.2 and older because they require literals as arguments to
-  // their alignment attribute.
+};
+#elif (THRUST_HOST_COMPILER == THRUST_HOST_COMPILER_MSVC) \
+  || ((THRUST_HOST_COMPILER == THRUST_HOST_COMPILER_GCC) && (THRUST_GCC_VERSION < 40600))
+// C++03 implementation for MSVC and GCC <= 4.5.
+//
+// We have to implement `aligned_type` with specializations for MSVC
+// and GCC 4.2 and older because they require literals as arguments to
+// their alignment attribute.
 
-  #if (THRUST_HOST_COMPILER == THRUST_HOST_COMPILER_MSVC)
-    // MSVC implementation.
-    #define THRUST_DEFINE_COMPLEX_STORAGE_SPECIALIZATION(X)                   \
-      template <typename T>                                                   \
-      struct complex_storage<T, X>                                            \
-      {                                                                       \
-        __declspec(align(X)) struct type { T x; T y; };                       \
-      };                                                                      \
+#  if (THRUST_HOST_COMPILER == THRUST_HOST_COMPILER_MSVC)
+// MSVC implementation.
+#    define THRUST_DEFINE_COMPLEX_STORAGE_SPECIALIZATION(X) \
+      template <typename T>                                 \
+      struct complex_storage<T, X>                          \
+      {                                                     \
+        __declspec(align(X)) struct type                    \
+        {                                                   \
+          T x;                                              \
+          T y;                                              \
+        };                                                  \
+      };                                                    \
       /**/
-  #else
-    // GCC <= 4.2 implementation.
-    #define THRUST_DEFINE_COMPLEX_STORAGE_SPECIALIZATION(X)                   \
-      template <typename T>                                                   \
-      struct complex_storage<T, X>                                            \
-      {                                                                       \
-        struct type { T x; T y; } __attribute__((aligned(X)));                \
-      };                                                                      \
+#  else
+// GCC <= 4.2 implementation.
+#    define THRUST_DEFINE_COMPLEX_STORAGE_SPECIALIZATION(X) \
+      template <typename T>                                 \
+      struct complex_storage<T, X>                          \
+      {                                                     \
+        struct type                                         \
+        {                                                   \
+          T x;                                              \
+          T y;                                              \
+        } __attribute__((aligned(X)));                      \
+      };                                                    \
       /**/
-  #endif
+#  endif
 
-  // The primary template is a fallback, which doesn't specify any alignment.
-  // It's only used when T is very large and we're using an older compilers
-  // which we have to fully specialize each alignment case.
-  template <typename T, std::size_t Align>
-  struct complex_storage
-  {
-    T x; T y;
-  };
+// The primary template is a fallback, which doesn't specify any alignment.
+// It's only used when T is very large and we're using an older compilers
+// which we have to fully specialize each alignment case.
+template <typename T, std::size_t Align>
+struct complex_storage
+{
+  T x;
+  T y;
+};
 
-  THRUST_DEFINE_COMPLEX_STORAGE_SPECIALIZATION(1);
-  THRUST_DEFINE_COMPLEX_STORAGE_SPECIALIZATION(2);
-  THRUST_DEFINE_COMPLEX_STORAGE_SPECIALIZATION(4);
-  THRUST_DEFINE_COMPLEX_STORAGE_SPECIALIZATION(8);
-  THRUST_DEFINE_COMPLEX_STORAGE_SPECIALIZATION(16);
-  THRUST_DEFINE_COMPLEX_STORAGE_SPECIALIZATION(32);
-  THRUST_DEFINE_COMPLEX_STORAGE_SPECIALIZATION(64);
-  THRUST_DEFINE_COMPLEX_STORAGE_SPECIALIZATION(128);
+THRUST_DEFINE_COMPLEX_STORAGE_SPECIALIZATION(1);
+THRUST_DEFINE_COMPLEX_STORAGE_SPECIALIZATION(2);
+THRUST_DEFINE_COMPLEX_STORAGE_SPECIALIZATION(4);
+THRUST_DEFINE_COMPLEX_STORAGE_SPECIALIZATION(8);
+THRUST_DEFINE_COMPLEX_STORAGE_SPECIALIZATION(16);
+THRUST_DEFINE_COMPLEX_STORAGE_SPECIALIZATION(32);
+THRUST_DEFINE_COMPLEX_STORAGE_SPECIALIZATION(64);
+THRUST_DEFINE_COMPLEX_STORAGE_SPECIALIZATION(128);
 
-  #undef THRUST_DEFINE_COMPLEX_STORAGE_SPECIALIZATION
+#  undef THRUST_DEFINE_COMPLEX_STORAGE_SPECIALIZATION
 #else
-  // C++03 implementation for GCC > 4.5, Clang, PGI, ICPC, and xlC.
-  template <typename T, std::size_t Align>
-  struct complex_storage
+// C++03 implementation for GCC > 4.5, Clang, PGI, ICPC, and xlC.
+template <typename T, std::size_t Align>
+struct complex_storage
+{
+  struct type
   {
-    struct type { T x; T y; } __attribute__((aligned(Align)));
-  };
+    T x;
+    T y;
+  } __attribute__((aligned(Align)));
+};
 #endif
 
 } // end namespace detail
@@ -163,29 +173,24 @@ template <typename T>
 struct complex
 {
 public:
-
   /*! \p value_type is the type of \p complex's real and imaginary parts.
    */
   typedef T value_type;
 
-
-
   /* --- Constructors --- */
 
   /*! Construct a complex number with an imaginary part of 0.
    *
    *  \param re The real part of the number.
    */
-  _CCCL_HOST_DEVICE
-  complex(const T& re);
+  _CCCL_HOST_DEVICE complex(const T& re);
 
   /*! Construct a complex number from its real and imaginary parts.
    *
    *  \param re The real part of the number.
    *  \param im The imaginary part of the number.
    */
-  _CCCL_HOST_DEVICE
-  complex(const T& re, const T& im);
+  _CCCL_HOST_DEVICE complex(const T& re, const T& im);
 
 #if THRUST_CPP_DIALECT >= 2011
   /*! Default construct a complex number.
@@ -201,16 +206,14 @@ public:
 #else
   /*! Default construct a complex number.
    */
-  _CCCL_HOST_DEVICE
-  complex();
+  _CCCL_HOST_DEVICE complex();
 
   /*! This copy constructor copies from a \p complex with a type that is
    *  convertible to this \p complex's \c value_type.
    *
    *  \param z The \p complex to copy from.
    */
-  _CCCL_HOST_DEVICE
-  complex(const complex<T>& z);
+  _CCCL_HOST_DEVICE complex(const complex<T>& z);
 #endif
 
   /*! This converting copy constructor copies from a \p complex with a type
@@ -221,16 +224,14 @@ public:
    *  \tparam U is convertible to \c value_type.
    */
   template <typename U>
-  _CCCL_HOST_DEVICE
-  complex(const complex<U>& z);
+  _CCCL_HOST_DEVICE complex(const complex<U>& z);
 
   /*! This converting copy constructor copies from a <tt>std::complex</tt> with
    *  a type that is convertible to this \p complex's \c value_type.
    *
    *  \param z The \p complex to copy from.
    */
-  __host__ THRUST_STD_COMPLEX_DEVICE
-  complex(const std::complex<T>& z);
+  _CCCL_HOST THRUST_STD_COMPLEX_DEVICE complex(const std::complex<T>& z);
 
   /*! This converting copy constructor copies from a <tt>std::complex</tt> with
    *  a type that is convertible to this \p complex's \c value_type.
@@ -240,10 +241,7 @@ public:
    *  \tparam U is convertible to \c value_type.
    */
   template <typename U>
-  __host__ THRUST_STD_COMPLEX_DEVICE
-  complex(const std::complex<U>& z);
-
-
+  _CCCL_HOST THRUST_STD_COMPLEX_DEVICE complex(const std::complex<U>& z);
 
   /* --- Assignment Operators --- */
 
@@ -252,8 +250,7 @@ public:
    *
    *  \param re The real part of the number.
    */
-  _CCCL_HOST_DEVICE
-  complex& operator=(const T& re);
+  _CCCL_HOST_DEVICE complex& operator=(const T& re);
 
 #if THRUST_CPP_DIALECT >= 2011
   /*! Assign `z.real()` and `z.imag()` to the real and imaginary parts of this
@@ -268,8 +265,7 @@ public:
    *
    *  \param z The \p complex to copy from.
    */
-  _CCCL_HOST_DEVICE
-  complex& operator=(const complex<T>& z);
+  _CCCL_HOST_DEVICE complex& operator=(const complex<T>& z);
 #endif
 
   /*! Assign `z.real()` and `z.imag()` to the real and imaginary parts of this
@@ -280,16 +276,14 @@ public:
    *  \tparam U is convertible to \c value_type.
    */
   template <typename U>
-  _CCCL_HOST_DEVICE
-  complex& operator=(const complex<U>& z);
+  _CCCL_HOST_DEVICE complex& operator=(const complex<U>& z);
 
   /*! Assign `z.real()` and `z.imag()` to the real and imaginary parts of this
    *  \p complex respectively.
    *
    *  \param z The \p complex to copy from.
    */
-  __host__ THRUST_STD_COMPLEX_DEVICE
-  complex& operator=(const std::complex<T>& z);
+  _CCCL_HOST THRUST_STD_COMPLEX_DEVICE complex& operator=(const std::complex<T>& z);
 
   /*! Assign `z.real()` and `z.imag()` to the real and imaginary parts of this
    *  \p complex respectively.
@@ -299,9 +293,7 @@ public:
    *  \tparam U is convertible to \c value_type.
    */
   template <typename U>
-  __host__ THRUST_STD_COMPLEX_DEVICE
-  complex& operator=(const std::complex<U>& z);
-
+  _CCCL_HOST THRUST_STD_COMPLEX_DEVICE complex& operator=(const std::complex<U>& z);
 
   /* --- Compound Assignment Operators --- */
 
@@ -313,8 +305,7 @@ public:
    *  \tparam U is convertible to \c value_type.
    */
   template <typename U>
-  _CCCL_HOST_DEVICE
-  complex<T>& operator+=(const complex<U>& z);
+  _CCCL_HOST_DEVICE complex<T>& operator+=(const complex<U>& z);
 
   /*! Subtracts a \p complex from this \p complex and assigns the result to
    *  this \p complex.
@@ -324,8 +315,7 @@ public:
    *  \tparam U is convertible to \c value_type.
    */
   template <typename U>
-  _CCCL_HOST_DEVICE
-  complex<T>& operator-=(const complex<U>& z);
+  _CCCL_HOST_DEVICE complex<T>& operator-=(const complex<U>& z);
 
   /*! Multiplies this \p complex by another \p complex and assigns the result
    *  to this \p complex.
@@ -335,8 +325,7 @@ public:
    *  \tparam U is convertible to \c value_type.
    */
   template <typename U>
-  _CCCL_HOST_DEVICE
-  complex<T>& operator*=(const complex<U>& z);
+  _CCCL_HOST_DEVICE complex<T>& operator*=(const complex<U>& z);
 
   /*! Divides this \p complex by another \p complex and assigns the result to
    *  this \p complex.
@@ -346,8 +335,7 @@ public:
    *  \tparam U is convertible to \c value_type.
    */
   template <typename U>
-  _CCCL_HOST_DEVICE
-  complex<T>& operator/=(const complex<U>& z);
+  _CCCL_HOST_DEVICE complex<T>& operator/=(const complex<U>& z);
 
   /*! Adds a scalar to this \p complex and assigns the result to this
    *  \p complex.
@@ -357,8 +345,7 @@ public:
    *  \tparam U is convertible to \c value_type.
    */
   template <typename U>
-  _CCCL_HOST_DEVICE
-  complex<T>& operator+=(const U& z);
+  _CCCL_HOST_DEVICE complex<T>& operator+=(const U& z);
 
   /*! Subtracts a scalar from this \p complex and assigns the result to
    *  this \p complex.
@@ -368,8 +355,7 @@ public:
    *  \tparam U is convertible to \c value_type.
    */
   template <typename U>
-  _CCCL_HOST_DEVICE
-  complex<T>& operator-=(const U& z);
+  _CCCL_HOST_DEVICE complex<T>& operator-=(const U& z);
 
   /*! Multiplies this \p complex by a scalar and assigns the result
    *  to this \p complex.
@@ -379,8 +365,7 @@ public:
    *  \tparam U is convertible to \c value_type.
    */
   template <typename U>
-  _CCCL_HOST_DEVICE
-  complex<T>& operator*=(const U& z);
+  _CCCL_HOST_DEVICE complex<T>& operator*=(const U& z);
 
   /*! Divides this \p complex by a scalar and assigns the result to
    *  this \p complex.
@@ -390,10 +375,7 @@ public:
    *  \tparam U is convertible to \c value_type.
    */
   template <typename U>
-  _CCCL_HOST_DEVICE
-  complex<T>& operator/=(const U& z);
-
-
+  _CCCL_HOST_DEVICE complex<T>& operator/=(const U& z);
 
   /* --- Getter functions ---
    * The volatile ones are there to help for example
@@ -402,25 +384,31 @@ public:
 
   /*! Returns the real part of this \p complex.
    */
-  _CCCL_HOST_DEVICE
-  T real() const volatile { return data.x; }
+  _CCCL_HOST_DEVICE T real() const volatile
+  {
+    return data.x;
+  }
 
   /*! Returns the imaginary part of this \p complex.
    */
-  _CCCL_HOST_DEVICE
-  T imag() const volatile { return data.y; }
+  _CCCL_HOST_DEVICE T imag() const volatile
+  {
+    return data.y;
+  }
 
   /*! Returns the real part of this \p complex.
    */
-  _CCCL_HOST_DEVICE
-  T real() const { return data.x; }
+  _CCCL_HOST_DEVICE T real() const
+  {
+    return data.x;
+  }
 
   /*! Returns the imaginary part of this \p complex.
    */
-  _CCCL_HOST_DEVICE
-  T imag() const { return data.y; }
-
-
+  _CCCL_HOST_DEVICE T imag() const
+  {
+    return data.y;
+  }
 
   /* --- Setter functions ---
    * The volatile ones are there to help for example
@@ -431,77 +419,80 @@ public:
    *
    *  \param re The new real part of this \p complex.
    */
-  _CCCL_HOST_DEVICE
-  void real(T re) volatile { data.x = re; }
+  _CCCL_HOST_DEVICE void real(T re) volatile
+  {
+    data.x = re;
+  }
 
   /*! Sets the imaginary part of this \p complex.
    *
    *  \param im The new imaginary part of this \p complex.e
    */
-  _CCCL_HOST_DEVICE
-  void imag(T im) volatile { data.y = im; }
+  _CCCL_HOST_DEVICE void imag(T im) volatile
+  {
+    data.y = im;
+  }
 
   /*! Sets the real part of this \p complex.
    *
    *  \param re The new real part of this \p complex.
    */
-  _CCCL_HOST_DEVICE
-  void real(T re) { data.x = re; }
+  _CCCL_HOST_DEVICE void real(T re)
+  {
+    data.x = re;
+  }
 
   /*! Sets the imaginary part of this \p complex.
    *
    *  \param im The new imaginary part of this \p complex.
    */
-  _CCCL_HOST_DEVICE
-  void imag(T im) { data.y = im; }
-
-
+  _CCCL_HOST_DEVICE void imag(T im)
+  {
+    data.y = im;
+  }
 
   /* --- Casting functions --- */
 
   /*! Casts this \p complex to a <tt>std::complex</tt> of the same type.
    */
-  __host__
-  operator std::complex<T>() const { return std::complex<T>(real(), imag()); }
+  _CCCL_HOST operator std::complex<T>() const
+  {
+    return std::complex<T>(real(), imag());
+  }
 
 private:
   typename detail::complex_storage<T, sizeof(T) * 2>::type data;
 };
 
-
 /* --- General Functions --- */
 
 /*! Returns the magnitude (also known as absolute value) of a \p complex.
  *
  *  \param z The \p complex from which to calculate the absolute value.
  */
-template<typename T>
-_CCCL_HOST_DEVICE
-T abs(const complex<T>& z);
+template <typename T>
+_CCCL_HOST_DEVICE T abs(const complex<T>& z);
 
 /*! Returns the phase angle (also known as argument) in radians of a \p complex.
  *
  *  \param z The \p complex from which to calculate the phase angle.
  */
 template <typename T>
-_CCCL_HOST_DEVICE
-T arg(const complex<T>& z);
+_CCCL_HOST_DEVICE T arg(const complex<T>& z);
 
 /*! Returns the square of the magnitude of a \p complex.
  *
  *  \param z The \p complex from which to calculate the norm.
  */
 template <typename T>
-_CCCL_HOST_DEVICE
-T norm(const complex<T>& z);
+_CCCL_HOST_DEVICE T norm(const complex<T>& z);
 
 /*! Returns the complex conjugate of a \p complex.
  *
  *  \param z The \p complex from which to calculate the complex conjugate.
  */
 template <typename T>
-_CCCL_HOST_DEVICE
-complex<T> conj(const complex<T>& z);
+_CCCL_HOST_DEVICE complex<T> conj(const complex<T>& z);
 
 /*! Returns a \p complex with the specified magnitude and phase.
  *
@@ -509,9 +500,7 @@ complex<T> conj(const complex<T>& z);
  *  \param theta The phase of the returned \p complex in radians.
  */
 template <typename T0, typename T1>
-_CCCL_HOST_DEVICE
-complex<typename detail::promoted_numerical_type<T0, T1>::type>
-polar(const T0& m, const T1& theta = T1());
+_CCCL_HOST_DEVICE complex<::cuda::std::__common_type_t<T0, T1>> polar(const T0& m, const T1& theta = T1());
 
 /*! Returns the projection of a \p complex on the Riemann sphere.
  *  For all finite \p complex it returns the argument. For \p complexs
@@ -521,10 +510,7 @@ polar(const T0& m, const T1& theta = T1());
  *  \param z The \p complex argument.
  */
 template <typename T>
-_CCCL_HOST_DEVICE
-complex<T> proj(const T& z);
-
-
+_CCCL_HOST_DEVICE complex<T> proj(const T& z);
 
 /* --- Binary Arithmetic operators --- */
 
@@ -537,9 +523,7 @@ complex<T> proj(const T& z);
  *  \param y The second \p complex.
  */
 template <typename T0, typename T1>
-_CCCL_HOST_DEVICE
-complex<typename detail::promoted_numerical_type<T0, T1>::type>
-operator+(const complex<T0>& x, const complex<T1>& y);
+_CCCL_HOST_DEVICE complex<::cuda::std::__common_type_t<T0, T1>> operator+(const complex<T0>& x, const complex<T1>& y);
 
 /*! Adds a scalar to a \p complex number.
  *
@@ -550,9 +534,7 @@ operator+(const complex<T0>& x, const complex<T1>& y);
  *  \param y The scalar.
  */
 template <typename T0, typename T1>
-_CCCL_HOST_DEVICE
-complex<typename detail::promoted_numerical_type<T0, T1>::type>
-operator+(const complex<T0>& x, const T1& y);
+_CCCL_HOST_DEVICE complex<::cuda::std::__common_type_t<T0, T1>> operator+(const complex<T0>& x, const T1& y);
 
 /*! Adds a \p complex number to a scalar.
  *
@@ -563,9 +545,7 @@ operator+(const complex<T0>& x, const T1& y);
  *  \param y The \p complex.
  */
 template <typename T0, typename T1>
-_CCCL_HOST_DEVICE
-complex<typename detail::promoted_numerical_type<T0, T1>::type>
-operator+(const T0& x, const complex<T1>& y);
+_CCCL_HOST_DEVICE complex<::cuda::std::__common_type_t<T0, T1>> operator+(const T0& x, const complex<T1>& y);
 
 /*! Subtracts two \p complex numbers.
  *
@@ -576,9 +556,7 @@ operator+(const T0& x, const complex<T1>& y);
  *  \param y The second \p complex (subtrahend).
  */
 template <typename T0, typename T1>
-_CCCL_HOST_DEVICE
-complex<typename detail::promoted_numerical_type<T0, T1>::type>
-operator-(const complex<T0>& x, const complex<T1>& y);
+_CCCL_HOST_DEVICE complex<::cuda::std::__common_type_t<T0, T1>> operator-(const complex<T0>& x, const complex<T1>& y);
 
 /*! Subtracts a scalar from a \p complex number.
  *
@@ -589,9 +567,7 @@ operator-(const complex<T0>& x, const complex<T1>& y);
  *  \param y The scalar (subtrahend).
  */
 template <typename T0, typename T1>
-_CCCL_HOST_DEVICE
-complex<typename detail::promoted_numerical_type<T0, T1>::type>
-operator-(const complex<T0>& x, const T1& y);
+_CCCL_HOST_DEVICE complex<::cuda::std::__common_type_t<T0, T1>> operator-(const complex<T0>& x, const T1& y);
 
 /*! Subtracts a \p complex number from a scalar.
  *
@@ -602,9 +578,7 @@ operator-(const complex<T0>& x, const T1& y);
  *  \param y The \p complex (subtrahend).
  */
 template <typename T0, typename T1>
-_CCCL_HOST_DEVICE
-complex<typename detail::promoted_numerical_type<T0, T1>::type>
-operator-(const T0& x, const complex<T1>& y);
+_CCCL_HOST_DEVICE complex<::cuda::std::__common_type_t<T0, T1>> operator-(const T0& x, const complex<T1>& y);
 
 /*! Multiplies two \p complex numbers.
  *
@@ -615,9 +589,7 @@ operator-(const T0& x, const complex<T1>& y);
  *  \param y The second \p complex.
  */
 template <typename T0, typename T1>
-_CCCL_HOST_DEVICE
-complex<typename detail::promoted_numerical_type<T0, T1>::type>
-operator*(const complex<T0>& x, const complex<T1>& y);
+_CCCL_HOST_DEVICE complex<::cuda::std::__common_type_t<T0, T1>> operator*(const complex<T0>& x, const complex<T1>& y);
 
 /*! Multiplies a \p complex number by a scalar.
  *
@@ -625,9 +597,7 @@ operator*(const complex<T0>& x, const complex<T1>& y);
  *  \param y The scalar.
  */
 template <typename T0, typename T1>
-_CCCL_HOST_DEVICE
-complex<typename detail::promoted_numerical_type<T0, T1>::type>
-operator*(const complex<T0>& x, const T1& y);
+_CCCL_HOST_DEVICE complex<::cuda::std::__common_type_t<T0, T1>> operator*(const complex<T0>& x, const T1& y);
 
 /*! Multiplies a scalar by a \p complex number.
  *
@@ -638,9 +608,7 @@ operator*(const complex<T0>& x, const T1& y);
  *  \param y The \p complex.
  */
 template <typename T0, typename T1>
-_CCCL_HOST_DEVICE
-complex<typename detail::promoted_numerical_type<T0, T1>::type>
-operator*(const T0& x, const complex<T1>& y);
+_CCCL_HOST_DEVICE complex<::cuda::std::__common_type_t<T0, T1>> operator*(const T0& x, const complex<T1>& y);
 
 /*! Divides two \p complex numbers.
  *
@@ -651,9 +619,7 @@ operator*(const T0& x, const complex<T1>& y);
  *  \param y The denomimator (divisor).
  */
 template <typename T0, typename T1>
-_CCCL_HOST_DEVICE
-complex<typename detail::promoted_numerical_type<T0, T1>::type>
-operator/(const complex<T0>& x, const complex<T1>& y);
+_CCCL_HOST_DEVICE complex<::cuda::std::__common_type_t<T0, T1>> operator/(const complex<T0>& x, const complex<T1>& y);
 
 /*! Divides a \p complex number by a scalar.
  *
@@ -664,9 +630,7 @@ operator/(const complex<T0>& x, const complex<T1>& y);
  *  \param y The scalar denomimator (divisor).
  */
 template <typename T0, typename T1>
-_CCCL_HOST_DEVICE
-complex<typename detail::promoted_numerical_type<T0, T1>::type>
-operator/(const complex<T0>& x, const T1& y);
+_CCCL_HOST_DEVICE complex<::cuda::std::__common_type_t<T0, T1>> operator/(const complex<T0>& x, const T1& y);
 
 /*! Divides a scalar by a \p complex number.
  *
@@ -677,11 +641,7 @@ operator/(const complex<T0>& x, const T1& y);
  *  \param y The complex denomimator (divisor).
  */
 template <typename T0, typename T1>
-_CCCL_HOST_DEVICE
-complex<typename detail::promoted_numerical_type<T0, T1>::type>
-operator/(const T0& x, const complex<T1>& y);
-
-
+_CCCL_HOST_DEVICE complex<::cuda::std::__common_type_t<T0, T1>> operator/(const T0& x, const complex<T1>& y);
 
 /* --- Unary Arithmetic operators --- */
 
@@ -690,9 +650,7 @@ operator/(const T0& x, const complex<T1>& y);
  *  \param y The \p complex argument.
  */
 template <typename T>
-_CCCL_HOST_DEVICE
-complex<T>
-operator+(const complex<T>& y);
+_CCCL_HOST_DEVICE complex<T> operator+(const complex<T>& y);
 
 /*! Unary minus, returns the additive inverse (negation) of its \p complex
  * argument.
@@ -700,11 +658,7 @@ operator+(const complex<T>& y);
  *  \param y The \p complex argument.
  */
 template <typename T>
-_CCCL_HOST_DEVICE
-complex<T>
-operator-(const complex<T>& y);
-
-
+_CCCL_HOST_DEVICE complex<T> operator-(const complex<T>& y);
 
 /* --- Exponential Functions --- */
 
@@ -713,26 +667,21 @@ operator-(const complex<T>& y);
  *  \param z The \p complex argument.
  */
 template <typename T>
-_CCCL_HOST_DEVICE
-complex<T> exp(const complex<T>& z);
+_CCCL_HOST_DEVICE complex<T> exp(const complex<T>& z);
 
 /*! Returns the complex natural logarithm of a \p complex number.
  *
  *  \param z The \p complex argument.
  */
 template <typename T>
-_CCCL_HOST_DEVICE
-complex<T> log(const complex<T>& z);
+_CCCL_HOST_DEVICE complex<T> log(const complex<T>& z);
 
 /*! Returns the complex base 10 logarithm of a \p complex number.
  *
  *  \param z The \p complex argument.
  */
 template <typename T>
-_CCCL_HOST_DEVICE
-complex<T> log10(const complex<T>& z);
-
-
+_CCCL_HOST_DEVICE complex<T> log10(const complex<T>& z);
 
 /* --- Power Functions --- */
 
@@ -745,9 +694,7 @@ complex<T> log10(const complex<T>& z);
  *  \param y The exponent.
  */
 template <typename T0, typename T1>
-_CCCL_HOST_DEVICE
-complex<typename detail::promoted_numerical_type<T0, T1>::type>
-pow(const complex<T0>& x, const complex<T1>& y);
+_CCCL_HOST_DEVICE complex<::cuda::std::__common_type_t<T0, T1>> pow(const complex<T0>& x, const complex<T1>& y);
 
 /*! Returns a \p complex number raised to a scalar.
  *
@@ -758,9 +705,7 @@ pow(const complex<T0>& x, const complex<T1>& y);
  *  \param y The exponent.
  */
 template <typename T0, typename T1>
-_CCCL_HOST_DEVICE
-complex<typename detail::promoted_numerical_type<T0, T1>::type>
-pow(const complex<T0>& x, const T1& y);
+_CCCL_HOST_DEVICE complex<::cuda::std::__common_type_t<T0, T1>> pow(const complex<T0>& x, const T1& y);
 
 /*! Returns a scalar raised to a \p complex number.
  *
@@ -771,18 +716,14 @@ pow(const complex<T0>& x, const T1& y);
  *  \param y The exponent.
  */
 template <typename T0, typename T1>
-_CCCL_HOST_DEVICE
-complex<typename detail::promoted_numerical_type<T0, T1>::type>
-pow(const T0& x, const complex<T1>& y);
+_CCCL_HOST_DEVICE complex<::cuda::std::__common_type_t<T0, T1>> pow(const T0& x, const complex<T1>& y);
 
 /*! Returns the complex square root of a \p complex number.
  *
  *  \param z The \p complex argument.
  */
 template <typename T>
-_CCCL_HOST_DEVICE
-complex<T> sqrt(const complex<T>& z);
-
+_CCCL_HOST_DEVICE complex<T> sqrt(const complex<T>& z);
 
 /* --- Trigonometric Functions --- */
 
@@ -791,26 +732,21 @@ complex<T> sqrt(const complex<T>& z);
  *  \param z The \p complex argument.
  */
 template <typename T>
-_CCCL_HOST_DEVICE
-complex<T> cos(const complex<T>& z);
+_CCCL_HOST_DEVICE complex<T> cos(const complex<T>& z);
 
 /*! Returns the complex sine of a \p complex number.
  *
  *  \param z The \p complex argument.
  */
 template <typename T>
-_CCCL_HOST_DEVICE
-complex<T> sin(const complex<T>& z);
+_CCCL_HOST_DEVICE complex<T> sin(const complex<T>& z);
 
 /*! Returns the complex tangent of a \p complex number.
  *
  *  \param z The \p complex argument.
  */
 template <typename T>
-_CCCL_HOST_DEVICE
-complex<T> tan(const complex<T>& z);
-
-
+_CCCL_HOST_DEVICE complex<T> tan(const complex<T>& z);
 
 /* --- Hyperbolic Functions --- */
 
@@ -819,26 +755,21 @@ complex<T> tan(const complex<T>& z);
  *  \param z The \p complex argument.
  */
 template <typename T>
-_CCCL_HOST_DEVICE
-complex<T> cosh(const complex<T>& z);
+_CCCL_HOST_DEVICE complex<T> cosh(const complex<T>& z);
 
 /*! Returns the complex hyperbolic sine of a \p complex number.
  *
  *  \param z The \p complex argument.
  */
 template <typename T>
-_CCCL_HOST_DEVICE
-complex<T> sinh(const complex<T>& z);
+_CCCL_HOST_DEVICE complex<T> sinh(const complex<T>& z);
 
 /*! Returns the complex hyperbolic tangent of a \p complex number.
  *
  *  \param z The \p complex argument.
  */
 template <typename T>
-_CCCL_HOST_DEVICE
-complex<T> tanh(const complex<T>& z);
-
-
+_CCCL_HOST_DEVICE complex<T> tanh(const complex<T>& z);
 
 /* --- Inverse Trigonometric Functions --- */
 
@@ -850,8 +781,7 @@ complex<T> tanh(const complex<T>& z);
  *  \param z The \p complex argument.
  */
 template <typename T>
-_CCCL_HOST_DEVICE
-complex<T> acos(const complex<T>& z);
+_CCCL_HOST_DEVICE complex<T> acos(const complex<T>& z);
 
 /*! Returns the complex arc sine of a \p complex number.
  *
@@ -861,8 +791,7 @@ complex<T> acos(const complex<T>& z);
  *  \param z The \p complex argument.
  */
 template <typename T>
-_CCCL_HOST_DEVICE
-complex<T> asin(const complex<T>& z);
+_CCCL_HOST_DEVICE complex<T> asin(const complex<T>& z);
 
 /*! Returns the complex arc tangent of a \p complex number.
  *
@@ -872,10 +801,7 @@ complex<T> asin(const complex<T>& z);
  *  \param z The \p complex argument.
  */
 template <typename T>
-_CCCL_HOST_DEVICE
-complex<T> atan(const complex<T>& z);
-
-
+_CCCL_HOST_DEVICE complex<T> atan(const complex<T>& z);
 
 /* --- Inverse Hyperbolic Functions --- */
 
@@ -887,8 +813,7 @@ complex<T> atan(const complex<T>& z);
  *  \param z The \p complex argument.
  */
 template <typename T>
-_CCCL_HOST_DEVICE
-complex<T> acosh(const complex<T>& z);
+_CCCL_HOST_DEVICE complex<T> acosh(const complex<T>& z);
 
 /*! Returns the complex inverse hyperbolic sine of a \p complex number.
  *
@@ -898,8 +823,7 @@ complex<T> acosh(const complex<T>& z);
  *  \param z The \p complex argument.
  */
 template <typename T>
-_CCCL_HOST_DEVICE
-complex<T> asinh(const complex<T>& z);
+_CCCL_HOST_DEVICE complex<T> asinh(const complex<T>& z);
 
 /*! Returns the complex inverse hyperbolic tangent of a \p complex number.
  *
@@ -909,10 +833,7 @@ complex<T> asinh(const complex<T>& z);
  *  \param z The \p complex argument.
  */
 template <typename T>
-_CCCL_HOST_DEVICE
-complex<T> atanh(const complex<T>& z);
-
-
+_CCCL_HOST_DEVICE complex<T> atanh(const complex<T>& z);
 
 /* --- Stream Operators --- */
 
@@ -922,8 +843,7 @@ complex<T> atanh(const complex<T>& z);
  *  \param z The \p complex number to output.
  */
 template <typename T, typename CharT, typename Traits>
-std::basic_ostream<CharT, Traits>&
-operator<<(std::basic_ostream<CharT, Traits>& os, const complex<T>& z);
+std::basic_ostream<CharT, Traits>& operator<<(std::basic_ostream<CharT, Traits>& os, const complex<T>& z);
 
 /*! Reads a \p complex number from an input stream.
  *
@@ -938,11 +858,7 @@ operator<<(std::basic_ostream<CharT, Traits>& os, const complex<T>& z);
  *  \param z The \p complex number to set.
  */
 template <typename T, typename CharT, typename Traits>
-__host__
-std::basic_istream<CharT, Traits>&
-operator>>(std::basic_istream<CharT, Traits>& is, complex<T>& z);
-
-
+_CCCL_HOST std::basic_istream<CharT, Traits>& operator>>(std::basic_istream<CharT, Traits>& is, complex<T>& z);
 
 /* --- Equality Operators --- */
 
@@ -952,8 +868,7 @@ operator>>(std::basic_istream<CharT, Traits>& is, complex<T>& z);
  *  \param y The second \p complex.
  */
 template <typename T0, typename T1>
-_CCCL_HOST_DEVICE
-bool operator==(const complex<T0>& x, const complex<T1>& y);
+_CCCL_HOST_DEVICE bool operator==(const complex<T0>& x, const complex<T1>& y);
 
 /*! Returns true if two \p complex numbers are equal and false otherwise.
  *
@@ -961,8 +876,7 @@ bool operator==(const complex<T0>& x, const complex<T1>& y);
  *  \param y The second \p complex.
  */
 template <typename T0, typename T1>
-__host__ THRUST_STD_COMPLEX_DEVICE
-bool operator==(const complex<T0>& x, const std::complex<T1>& y);
+_CCCL_HOST THRUST_STD_COMPLEX_DEVICE bool operator==(const complex<T0>& x, const std::complex<T1>& y);
 
 /*! Returns true if two \p complex numbers are equal and false otherwise.
  *
@@ -970,8 +884,7 @@ bool operator==(const complex<T0>& x, const std::complex<T1>& y);
  *  \param y The second \p complex.
  */
 template <typename T0, typename T1>
-__host__ THRUST_STD_COMPLEX_DEVICE
-bool operator==(const std::complex<T0>& x, const complex<T1>& y);
+_CCCL_HOST THRUST_STD_COMPLEX_DEVICE bool operator==(const std::complex<T0>& x, const complex<T1>& y);
 
 /*! Returns true if the imaginary part of the \p complex number is zero and
  *  the real part is equal to the scalar. Returns false otherwise.
@@ -980,8 +893,7 @@ bool operator==(const std::complex<T0>& x, const complex<T1>& y);
  *  \param y The \p complex.
  */
 template <typename T0, typename T1>
-_CCCL_HOST_DEVICE
-bool operator==(const T0& x, const complex<T1>& y);
+_CCCL_HOST_DEVICE bool operator==(const T0& x, const complex<T1>& y);
 
 /*! Returns true if the imaginary part of the \p complex number is zero and
  *  the real part is equal to the scalar. Returns false otherwise.
@@ -990,8 +902,7 @@ bool operator==(const T0& x, const complex<T1>& y);
  *  \param y The scalar.
  */
 template <typename T0, typename T1>
-_CCCL_HOST_DEVICE
-bool operator==(const complex<T0>& x, const T1& y);
+_CCCL_HOST_DEVICE bool operator==(const complex<T0>& x, const T1& y);
 
 /*! Returns true if two \p complex numbers are different and false otherwise.
  *
@@ -999,8 +910,7 @@ bool operator==(const complex<T0>& x, const T1& y);
  *  \param y The second \p complex.
  */
 template <typename T0, typename T1>
-_CCCL_HOST_DEVICE
-bool operator!=(const complex<T0>& x, const complex<T1>& y);
+_CCCL_HOST_DEVICE bool operator!=(const complex<T0>& x, const complex<T1>& y);
 
 /*! Returns true if two \p complex numbers are different and false otherwise.
  *
@@ -1008,8 +918,7 @@ bool operator!=(const complex<T0>& x, const complex<T1>& y);
  *  \param y The second \p complex.
  */
 template <typename T0, typename T1>
-__host__ THRUST_STD_COMPLEX_DEVICE
-bool operator!=(const complex<T0>& x, const std::complex<T1>& y);
+_CCCL_HOST THRUST_STD_COMPLEX_DEVICE bool operator!=(const complex<T0>& x, const std::complex<T1>& y);
 
 /*! Returns true if two \p complex numbers are different and false otherwise.
  *
@@ -1017,8 +926,7 @@ bool operator!=(const complex<T0>& x, const std::complex<T1>& y);
  *  \param y The second \p complex.
  */
 template <typename T0, typename T1>
-__host__ THRUST_STD_COMPLEX_DEVICE
-bool operator!=(const std::complex<T0>& x, const complex<T1>& y);
+_CCCL_HOST THRUST_STD_COMPLEX_DEVICE bool operator!=(const std::complex<T0>& x, const complex<T1>& y);
 
 /*! Returns true if the imaginary part of the \p complex number is not zero or
  *  the real part is different from the scalar. Returns false otherwise.
@@ -1027,8 +935,7 @@ bool operator!=(const std::complex<T0>& x, const complex<T1>& y);
  *  \param y The \p complex.
  */
 template <typename T0, typename T1>
-_CCCL_HOST_DEVICE
-bool operator!=(const T0& x, const complex<T1>& y);
+_CCCL_HOST_DEVICE bool operator!=(const T0& x, const complex<T1>& y);
 
 /*! Returns true if the imaginary part of the \p complex number is not zero or
  *  the real part is different from the scalar. Returns false otherwise.
@@ -1037,8 +944,7 @@ bool operator!=(const T0& x, const complex<T1>& y);
  *  \param y The scalar.
  */
 template <typename T0, typename T1>
-_CCCL_HOST_DEVICE
-bool operator!=(const complex<T0>& x, const T1& y);
+_CCCL_HOST_DEVICE bool operator!=(const complex<T0>& x, const T1& y);
 
 THRUST_NAMESPACE_END
 
@@ -1053,4 +959,3 @@ THRUST_NAMESPACE_END
 
 /*! \} // numerics
  */
-
