@@ -25,19 +25,17 @@
 #elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_MSVC)
 #  pragma system_header
 #endif // no system header
-#include <thrust/detail/execute_with_allocator_fwd.h>
 #include <thrust/detail/alignment.h>
+#include <thrust/detail/execute_with_allocator_fwd.h>
 
-#if _CCCL_STD_VER >= 2011
-  #include <type_traits>
-#endif
+#include <type_traits>
 
 THRUST_NAMESPACE_BEGIN
 
 namespace mr
 {
 
-template<typename T, class MR>
+template <typename T, class MR>
 class allocator;
 
 }
@@ -45,63 +43,49 @@ class allocator;
 namespace detail
 {
 
-template<template <typename> class ExecutionPolicyCRTPBase>
+template <template <typename> class ExecutionPolicyCRTPBase>
 struct allocator_aware_execution_policy
 {
-  template<typename MemoryResource>
+  template <typename MemoryResource>
   struct execute_with_memory_resource_type
   {
-    typedef thrust::detail::execute_with_allocator<
-      thrust::mr::allocator<
-        thrust::detail::max_align_t,
-        MemoryResource
-      >,
-      ExecutionPolicyCRTPBase
-    > type;
+    typedef thrust::detail::execute_with_allocator<thrust::mr::allocator<thrust::detail::max_align_t, MemoryResource>,
+                                                   ExecutionPolicyCRTPBase>
+      type;
   };
 
-  template<typename Allocator>
+  template <typename Allocator>
   struct execute_with_allocator_type
   {
-      typedef thrust::detail::execute_with_allocator<
-        Allocator,
-        ExecutionPolicyCRTPBase
-      > type;
+    typedef thrust::detail::execute_with_allocator<Allocator, ExecutionPolicyCRTPBase> type;
   };
 
-  template<typename MemoryResource>
-    typename execute_with_memory_resource_type<MemoryResource>::type
-      operator()(MemoryResource * mem_res) const
+  template <typename MemoryResource>
+  typename execute_with_memory_resource_type<MemoryResource>::type operator()(MemoryResource* mem_res) const
   {
     return typename execute_with_memory_resource_type<MemoryResource>::type(mem_res);
   }
 
-  template<typename Allocator>
-    typename execute_with_allocator_type<Allocator&>::type
-      operator()(Allocator &alloc) const
+  template <typename Allocator>
+  typename execute_with_allocator_type<Allocator&>::type operator()(Allocator& alloc) const
   {
     return typename execute_with_allocator_type<Allocator&>::type(alloc);
   }
 
-  template<typename Allocator>
-    typename execute_with_allocator_type<Allocator>::type
-      operator()(const Allocator &alloc) const
+  template <typename Allocator>
+  typename execute_with_allocator_type<Allocator>::type operator()(const Allocator& alloc) const
   {
     return typename execute_with_allocator_type<Allocator>::type(alloc);
   }
 
-#if _CCCL_STD_VER >= 2011
   // just the rvalue overload
   // perfect forwarding doesn't help, because a const reference has to be turned
   // into a value by copying for the purpose of storing it in execute_with_allocator
-  template<typename Allocator,
-      typename std::enable_if<!std::is_lvalue_reference<Allocator>::value>::type * = nullptr>
-    typename execute_with_allocator_type<Allocator>::type
-      operator()(Allocator &&alloc) const
+  template <typename Allocator, typename std::enable_if<!std::is_lvalue_reference<Allocator>::value>::type* = nullptr>
+  typename execute_with_allocator_type<Allocator>::type operator()(Allocator&& alloc) const
   {
     return typename execute_with_allocator_type<Allocator>::type(std::move(alloc));
   }
-#endif
 };
 
 } // end namespace detail
