@@ -29,43 +29,53 @@
 #include <thrust/detail/preprocessor.h>
 
 // TODO: Enable this or remove this file once nvGRAPH/CUSP migrates off of it.
-//#if defined(_CCCL_COMPILER_MSVC)
-//  #pragma message("warning: The functionality in this header is unsafe, deprecated, and will soon be removed. Use C++11 or C11 atomics instead.")
-//#else
-//  #warning The functionality in this header is unsafe, deprecated, and will soon be removed. Use C++11 or C11 atomics instead.
-//#endif
+// #if defined(_CCCL_COMPILER_MSVC)
+//  #pragma message("warning: The functionality in this header is unsafe, deprecated, and will soon be removed. Use
+//  C++11 or C11 atomics instead.")
+// #else
+//  #warning The functionality in this header is unsafe, deprecated, and will soon be removed. Use C++11 or C11 atomics
+//  instead.
+// #endif
 
 // msvc case
 #if defined(_CCCL_COMPILER_MSVC)
 
-#ifndef _DEBUG
+#  ifndef _DEBUG
 
-#include <intrin.h>
-#pragma intrinsic(_ReadWriteBarrier)
-#define __thrust_compiler_fence() _ReadWriteBarrier()
-#else
+#    include <intrin.h>
+#    pragma intrinsic(_ReadWriteBarrier)
+#    define __thrust_compiler_fence() _ReadWriteBarrier()
+#  else
 
-#define __thrust_compiler_fence() do {} while (0)
+#    define __thrust_compiler_fence() \
+      do                              \
+      {                               \
+      } while (0)
 
-#endif // _DEBUG
+#  endif // _DEBUG
 
 // gcc case
 #elif defined(_CCCL_COMPILER_GCC)
 
-#if THRUST_GCC_VERSION >= 40200 // atomic built-ins were introduced ~4.2
-#define __thrust_compiler_fence() __sync_synchronize()
-#else
+#  if THRUST_GCC_VERSION >= 40200 // atomic built-ins were introduced ~4.2
+#    define __thrust_compiler_fence() __sync_synchronize()
+#  else
 // allow the code to compile without any guarantees
-#define __thrust_compiler_fence() do {} while (0)
-#endif // THRUST_GCC_VERSION
+#    define __thrust_compiler_fence() \
+      do                              \
+      {                               \
+      } while (0)
+#  endif // THRUST_GCC_VERSION
 
 // unknown case
 #elif defined(_CCCL_COMPILER_CLANG)
-#define __thrust_compiler_fence() __sync_synchronize()
+#  define __thrust_compiler_fence() __sync_synchronize()
 #elif THRUST_HOST_COMPILER == THRUST_HOST_COMPILER_UNKNOWN
 
 // allow the code to compile without any guarantees
-#define __thrust_compiler_fence() do {} while (0)
+#  define __thrust_compiler_fence() \
+    do                              \
+    {                               \
+    } while (0)
 
 #endif
-
