@@ -32,14 +32,15 @@
 #endif // no system header
 #include <thrust/detail/reference_forward_declaration.h>
 #include <thrust/iterator/iterator_traits.h>
-#include <thrust/system/detail/generic/select_system.h>
-#include <thrust/system/detail/generic/memory.h>
-#include <thrust/system/detail/adl/get_value.h>
 #include <thrust/system/detail/adl/assign_value.h>
+#include <thrust/system/detail/adl/get_value.h>
 #include <thrust/system/detail/adl/iter_swap.h>
+#include <thrust/system/detail/generic/memory.h>
+#include <thrust/system/detail/generic/select_system.h>
 #include <thrust/type_traits/remove_cvref.h>
-#include <type_traits>
+
 #include <ostream>
+#include <type_traits>
 
 THRUST_NAMESPACE_BEGIN
 
@@ -56,9 +57,7 @@ template <typename Element, typename Pointer, typename Derived>
 class reference
 {
 private:
-  using derived_type = typename std::conditional<
-    std::is_same<Derived, use_default>::value, reference, Derived
-  >::type;
+  using derived_type = typename std::conditional<std::is_same<Derived, use_default>::value, reference, Derived>::type;
 
 public:
   using pointer    = Pointer;
@@ -78,21 +77,17 @@ public:
    *  \param  other        A \p reference to copy from.
    */
   template <typename OtherElement, typename OtherPointer, typename OtherDerived>
-  _CCCL_HOST_DEVICE
-  reference(
+  _CCCL_HOST_DEVICE reference(
     reference<OtherElement, OtherPointer, OtherDerived> const& other
-  /*! \cond
-   */
-  , typename std::enable_if<
-      std::is_convertible<
-        typename reference<OtherElement, OtherPointer, OtherDerived>::pointer
-      , pointer
-      >::value
-    >::type* = nullptr
-  /*! \endcond
-   */
-  )
-    : ptr(other.ptr)
+    /*! \cond
+     */
+    ,
+    typename std::enable_if<std::is_convertible<typename reference<OtherElement, OtherPointer, OtherDerived>::pointer,
+                                                pointer>::value>::type* = nullptr
+    /*! \endcond
+     */
+    )
+      : ptr(other.ptr)
   {}
 
   /*! Construct a \p reference that refers to an object pointed to by the given
@@ -101,8 +96,9 @@ public:
    *
    *  \param ptr A \p pointer to construct from.
    */
-  _CCCL_HOST_DEVICE
-  explicit reference(pointer const& p) : ptr(p) {}
+  _CCCL_HOST_DEVICE explicit reference(pointer const& p)
+      : ptr(p)
+  {}
 
   /*! Assign the object referred to \p other to the object referred to by
    *  this \p reference.
@@ -111,8 +107,7 @@ public:
    *
    *  \return <tt>*this</tt>.
    */
-  _CCCL_HOST_DEVICE
-  derived_type& operator=(reference const& other)
+  _CCCL_HOST_DEVICE derived_type& operator=(reference const& other)
   {
     assign_from(&other);
     return derived();
@@ -131,22 +126,19 @@ public:
    */
   template <typename OtherElement, typename OtherPointer, typename OtherDerived>
   _CCCL_HOST_DEVICE
-  /*! \cond
-   */
-  typename std::enable_if<
-    std::is_convertible<
-      typename reference<OtherElement, OtherPointer, OtherDerived>::pointer
-    , pointer
-    >::value,
-  /*! \endcond
-   */
-    derived_type&
-  /*! \cond
-   */
-  >::type
-  /*! \endcond
-   */
-  operator=(reference<OtherElement, OtherPointer, OtherDerived> const& other)
+    /*! \cond
+     */
+    typename std::enable_if<
+      std::is_convertible<typename reference<OtherElement, OtherPointer, OtherDerived>::pointer, pointer>::value,
+      /*! \endcond
+       */
+      derived_type&
+      /*! \cond
+       */
+      >::type
+    /*! \endcond
+     */
+    operator=(reference<OtherElement, OtherPointer, OtherDerived> const& other)
   {
     assign_from(&other);
     return derived();
@@ -158,8 +150,7 @@ public:
    *
    *  \return <tt>*this</tt>.
    */
-  _CCCL_HOST_DEVICE
-  derived_type& operator=(value_type const& rhs)
+  _CCCL_HOST_DEVICE derived_type& operator=(value_type const& rhs)
   {
     assign_from(&rhs);
     return derived();
@@ -170,8 +161,7 @@ public:
    *
    *  \param other The \p tagged_reference to swap with.
    */
-  _CCCL_HOST_DEVICE
-  void swap(derived_type& other)
+  _CCCL_HOST_DEVICE void swap(derived_type& other)
   {
     // Avoid default-constructing a system; instead, just use a null pointer
     // for dispatch. This assumes that `get_value` will not access any system
@@ -180,7 +170,10 @@ public:
     swap(system, other);
   }
 
-  _CCCL_HOST_DEVICE pointer operator&() const { return ptr; }
+  _CCCL_HOST_DEVICE pointer operator&() const
+  {
+    return ptr;
+  }
 
   // This is inherently hazardous, as it discards the strong type information
   // about what system the object is on.
@@ -193,8 +186,7 @@ public:
     return convert_to_value_type(system);
   }
 
-  _CCCL_HOST_DEVICE
-  derived_type& operator++()
+  _CCCL_HOST_DEVICE derived_type& operator++()
   {
     // Sadly, this has to make a copy. The only mechanism we have for
     // modifying the value, which may be in memory inaccessible to this
@@ -205,12 +197,11 @@ public:
     return derived();
   }
 
-  _CCCL_HOST_DEVICE
-  value_type operator++(int)
+  _CCCL_HOST_DEVICE value_type operator++(int)
   {
-    value_type tmp = *this;
+    value_type tmp    = *this;
     value_type result = tmp++;
-    *this = std::move(tmp);
+    *this             = std::move(tmp);
     return result;
   }
 
@@ -227,14 +218,13 @@ public:
 
   value_type operator--(int)
   {
-    value_type tmp = *this;
+    value_type tmp    = *this;
     value_type result = tmp--;
-    *this = std::move(tmp);
+    *this             = std::move(tmp);
     return derived();
   }
 
-  _CCCL_HOST_DEVICE
-  derived_type& operator+=(value_type const& rhs)
+  _CCCL_HOST_DEVICE derived_type& operator+=(value_type const& rhs)
   {
     value_type tmp = *this;
     tmp += rhs;
@@ -320,57 +310,55 @@ private:
   // `thrust::detail::is_wrapped_reference` is a trait that indicates whether
   // a type is a fancy reference. It detects such types by loooking for a
   // nested `wrapped_reference_hint` type.
-  struct wrapped_reference_hint {};
+  struct wrapped_reference_hint
+  {};
   template <typename>
   friend struct thrust::detail::is_wrapped_reference;
 
   template <typename OtherElement, typename OtherPointer, typename OtherDerived>
   friend class reference;
 
-  _CCCL_HOST_DEVICE
-  derived_type& derived() { return static_cast<derived_type&>(*this); }
+  _CCCL_HOST_DEVICE derived_type& derived()
+  {
+    return static_cast<derived_type&>(*this);
+  }
 
-  template<typename System>
-  _CCCL_HOST_DEVICE
-  value_type convert_to_value_type(System* system) const
+  template <typename System>
+  _CCCL_HOST_DEVICE value_type convert_to_value_type(System* system) const
   {
     using thrust::system::detail::generic::select_system;
     return strip_const_get_value(select_system(*system));
   }
 
   template <typename System>
-  _CCCL_HOST_DEVICE
-  value_type strip_const_get_value(System const& system) const
+  _CCCL_HOST_DEVICE value_type strip_const_get_value(System const& system) const
   {
-    System &non_const_system = const_cast<System&>(system);
+    System& non_const_system = const_cast<System&>(system);
 
     using thrust::system::detail::generic::get_value;
     return get_value(thrust::detail::derived_cast(non_const_system), ptr);
   }
 
   template <typename System0, typename System1, typename OtherPointer>
-  _CCCL_HOST_DEVICE
-  void assign_from(System0* system0, System1* system1, OtherPointer src)
+  _CCCL_HOST_DEVICE void assign_from(System0* system0, System1* system1, OtherPointer src)
   {
     using thrust::system::detail::generic::select_system;
     strip_const_assign_value(select_system(*system0, *system1), src);
   }
 
   template <typename OtherPointer>
-  _CCCL_HOST_DEVICE
-  void assign_from(OtherPointer src)
+  _CCCL_HOST_DEVICE void assign_from(OtherPointer src)
   {
     // Avoid default-constructing systems; instead, just use a null pointer
     // for dispatch. This assumes that `get_value` will not access any system
     // state.
-    typename thrust::iterator_system<pointer>::type*      system0 = nullptr;
+    typename thrust::iterator_system<pointer>::type* system0      = nullptr;
     typename thrust::iterator_system<OtherPointer>::type* system1 = nullptr;
     assign_from(system0, system1, src);
   }
 
   template <typename System, typename OtherPointer>
-  _CCCL_HOST_DEVICE
-  void strip_const_assign_value(System const& system, OtherPointer src)
+  _CCCL_HOST_DEVICE void strip_const_assign_value(System const& system, OtherPointer src)
   {
     System& non_const_system = const_cast<System&>(system);
 
@@ -379,30 +367,27 @@ private:
   }
 
   template <typename System>
-  _CCCL_HOST_DEVICE
-  void swap(System* system, derived_type& other)
+  _CCCL_HOST_DEVICE void swap(System* system, derived_type& other)
   {
-    using thrust::system::detail::generic::select_system;
     using thrust::system::detail::generic::iter_swap;
+    using thrust::system::detail::generic::select_system;
 
     iter_swap(select_system(*system, *system), ptr, other.ptr);
   }
 };
 
 template <typename Pointer, typename Derived>
-class reference<void, Pointer, Derived> {};
+class reference<void, Pointer, Derived>
+{};
 
 template <typename Pointer, typename Derived>
-class reference<void const, Pointer, Derived> {};
+class reference<void const, Pointer, Derived>
+{};
 
-template <
-  typename Element, typename Pointer, typename Derived
-, typename CharT, typename Traits
->
-std::basic_ostream<CharT, Traits>& operator<<(
-  std::basic_ostream<CharT, Traits>&os
-, reference<Element, Pointer, Derived> const& r
-) {
+template <typename Element, typename Pointer, typename Derived, typename CharT, typename Traits>
+std::basic_ostream<CharT, Traits>&
+operator<<(std::basic_ostream<CharT, Traits>& os, reference<Element, Pointer, Derived> const& r)
+{
   using value_type = typename reference<Element, Pointer, Derived>::value_type;
   return os << static_cast<value_type>(r);
 }
@@ -415,18 +400,12 @@ class tagged_reference;
  */
 template <typename Element, typename Tag>
 class tagged_reference
-  : public thrust::reference<
-      Element
-    , thrust::pointer<Element, Tag, tagged_reference<Element, Tag>>
-    , tagged_reference<Element, Tag>
-    >
+    : public thrust::
+        reference<Element, thrust::pointer<Element, Tag, tagged_reference<Element, Tag>>, tagged_reference<Element, Tag>>
 {
 private:
-  using base_type = thrust::reference<
-    Element
-  , thrust::pointer<Element, Tag, tagged_reference<Element, Tag>>
-  , tagged_reference<Element, Tag>
-  >;
+  using base_type = thrust::
+    reference<Element, thrust::pointer<Element, Tag, tagged_reference<Element, Tag>>, tagged_reference<Element, Tag>>;
 
 public:
   using value_type = typename base_type::value_type;
@@ -445,9 +424,8 @@ public:
    *  \param  other        A \p tagged_reference to copy from.
    */
   template <typename OtherElement, typename OtherTag>
-  _CCCL_HOST_DEVICE
-  tagged_reference(tagged_reference<OtherElement, OtherTag> const& other)
-    : base_type(other)
+  _CCCL_HOST_DEVICE tagged_reference(tagged_reference<OtherElement, OtherTag> const& other)
+      : base_type(other)
   {}
 
   /*! Construct a \p tagged_reference that refers to an object pointed to by
@@ -457,7 +435,7 @@ public:
    *  \param ptr A \p pointer to construct from.
    */
   _CCCL_HOST_DEVICE explicit tagged_reference(pointer const& p)
-    : base_type(p)
+      : base_type(p)
   {}
 
   /*! Assign the object referred to \p other to the object referred to by
@@ -467,8 +445,7 @@ public:
    *
    *  \return <tt>*this</tt>.
    */
-  _CCCL_HOST_DEVICE
-  tagged_reference& operator=(tagged_reference const& other)
+  _CCCL_HOST_DEVICE tagged_reference& operator=(tagged_reference const& other)
   {
     return base_type::operator=(other);
   }
@@ -484,9 +461,7 @@ public:
    *  \return <tt>*this</tt>.
    */
   template <typename OtherElement, typename OtherTag>
-  _CCCL_HOST_DEVICE
-  tagged_reference&
-  operator=(tagged_reference<OtherElement, OtherTag> const& other)
+  _CCCL_HOST_DEVICE tagged_reference& operator=(tagged_reference<OtherElement, OtherTag> const& other)
   {
     return base_type::operator=(other);
   }
@@ -497,18 +472,19 @@ public:
    *
    *  \return <tt>*this</tt>.
    */
-  _CCCL_HOST_DEVICE
-  tagged_reference& operator=(value_type const& rhs)
+  _CCCL_HOST_DEVICE tagged_reference& operator=(value_type const& rhs)
   {
     return base_type::operator=(rhs);
   }
 };
 
 template <typename Tag>
-class tagged_reference<void, Tag> {};
+class tagged_reference<void, Tag>
+{};
 
 template <typename Tag>
-class tagged_reference<void const, Tag> {};
+class tagged_reference<void const, Tag>
+{};
 
 /*! Exchanges the values of two objects referred to by \p tagged_reference.
  *
@@ -516,11 +492,9 @@ class tagged_reference<void const, Tag> {};
  *  \param y The second \p tagged_reference of interest.
  */
 template <typename Element, typename Tag>
-_CCCL_HOST_DEVICE
-void swap(tagged_reference<Element, Tag>& x, tagged_reference<Element, Tag>& y)
+_CCCL_HOST_DEVICE void swap(tagged_reference<Element, Tag>& x, tagged_reference<Element, Tag>& y)
 {
   x.swap(y);
 }
 
 THRUST_NAMESPACE_END
-
