@@ -30,9 +30,9 @@
 #elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_MSVC)
 #  pragma system_header
 #endif // no system header
-#include <thrust/device_ptr.h>
-#include <thrust/detail/type_traits.h>
 #include <thrust/detail/reference.h>
+#include <thrust/detail/type_traits.h>
+#include <thrust/device_ptr.h>
 
 THRUST_NAMESPACE_BEGIN
 
@@ -52,7 +52,7 @@ THRUST_NAMESPACE_BEGIN
  *  \code
  *  #include <thrust/device_vector.h>
  *
- *  int main(void)
+ *  int main()
  *  {
  *    thrust::device_vector<int> vec(1, 13);
  *
@@ -73,7 +73,7 @@ THRUST_NAMESPACE_BEGIN
  *  #include <thrust/device_vector.h>
  *  #include <iostream>
  *
- *  int main(void)
+ *  int main()
  *  {
  *    thrust::device_vector<int> vec(1, 13);
  *
@@ -95,7 +95,7 @@ THRUST_NAMESPACE_BEGIN
  *  #include <thrust/device_vector.h>
  *  #include <iostream>
  *
- *  int main(void)
+ *  int main()
  *  {
  *    thrust::device_vector<int> vec(1, 13);
  *
@@ -125,7 +125,7 @@ THRUST_NAMESPACE_BEGIN
  *    int x;
  *  };
  *
- *  int main(void)
+ *  int main()
  *  {
  *    thrust::device_vector<foo> foo_vec(1);
  *
@@ -147,7 +147,7 @@ THRUST_NAMESPACE_BEGIN
  *    int x;
  *  };
  *
- *  int main(void)
+ *  int main()
  *  {
  *    thrust::device_vector<foo> foo_vec(1);
  *
@@ -174,7 +174,7 @@ THRUST_NAMESPACE_BEGIN
  *  #include <stdio.h>
  *  #include <thrust/device_vector.h>
  *
- *  int main(void)
+ *  int main()
  *  {
  *    thrust::device_vector<int> vec(1,13);
  *
@@ -188,129 +188,114 @@ THRUST_NAMESPACE_BEGIN
  *  \see device_ptr
  *  \see device_vector
  */
-template<typename T>
-  class device_reference
-    : public thrust::reference<
-               T,
-               thrust::device_ptr<T>,
-               thrust::device_reference<T>
-             >
+template <typename T>
+class device_reference : public thrust::reference<T, thrust::device_ptr<T>, thrust::device_reference<T>>
 {
-  private:
-    typedef thrust::reference<
-      T,
-      thrust::device_ptr<T>,
-      thrust::device_reference<T>
-    > super_t;
+private:
+  typedef thrust::reference<T, thrust::device_ptr<T>, thrust::device_reference<T>> super_t;
 
-  public:
-    /*! The type of the value referenced by this type of \p device_reference.
-     */
-    typedef typename super_t::value_type value_type;
+public:
+  /*! The type of the value referenced by this type of \p device_reference.
+   */
+  typedef typename super_t::value_type value_type;
 
-    /*! The type of the expression <tt>&ref</tt>, where <tt>ref</tt> is a \p device_reference.
-     */
-    typedef typename super_t::pointer    pointer;
+  /*! The type of the expression <tt>&ref</tt>, where <tt>ref</tt> is a \p device_reference.
+   */
+  typedef typename super_t::pointer pointer;
 
-    /*! This copy constructor accepts a const reference to another
-     *  \p device_reference. After this \p device_reference is constructed,
-     *  it shall refer to the same object as \p other.
-     *
-     *  \param other A \p device_reference to copy from.
-     *
-     *  The following code snippet demonstrates the semantics of this
-     *  copy constructor.
-     *
-     *  \code
-     *  #include <thrust/device_vector.h>
-     *  #include <assert.h>
-     *  ...
-     *  thrust::device_vector<int> v(1,0);
-     *  thrust::device_reference<int> ref = v[0];
-     *
-     *  // ref equals the object at v[0]
-     *  assert(ref == v[0]);
-     *
-     *  // the address of ref equals the address of v[0]
-     *  assert(&ref == &v[0]);
-     *
-     *  // modifying v[0] modifies ref
-     *  v[0] = 13;
-     *  assert(ref == 13);
-     *  \endcode
-     *
-     *  \note This constructor is templated primarily to allow initialization of
-     *  <tt>device_reference<const T></tt> from <tt>device_reference<T></tt>.
-     */
-    template<typename OtherT>
-    __host__ __device__
-    device_reference(const device_reference<OtherT> &other,
-                     typename thrust::detail::enable_if_convertible<
-                       typename device_reference<OtherT>::pointer,
-                       pointer
-                     >::type * = 0)
+  /*! This copy constructor accepts a const reference to another
+   *  \p device_reference. After this \p device_reference is constructed,
+   *  it shall refer to the same object as \p other.
+   *
+   *  \param other A \p device_reference to copy from.
+   *
+   *  The following code snippet demonstrates the semantics of this
+   *  copy constructor.
+   *
+   *  \code
+   *  #include <thrust/device_vector.h>
+   *  #include <assert.h>
+   *  ...
+   *  thrust::device_vector<int> v(1,0);
+   *  thrust::device_reference<int> ref = v[0];
+   *
+   *  // ref equals the object at v[0]
+   *  assert(ref == v[0]);
+   *
+   *  // the address of ref equals the address of v[0]
+   *  assert(&ref == &v[0]);
+   *
+   *  // modifying v[0] modifies ref
+   *  v[0] = 13;
+   *  assert(ref == 13);
+   *  \endcode
+   *
+   *  \note This constructor is templated primarily to allow initialization of
+   *  <tt>device_reference<const T></tt> from <tt>device_reference<T></tt>.
+   */
+  template <typename OtherT>
+  _CCCL_HOST_DEVICE
+  device_reference(const device_reference<OtherT>& other,
+                   thrust::detail::enable_if_convertible_t<typename device_reference<OtherT>::pointer, pointer>* = 0)
       : super_t(other)
-    {}
+  {}
 
-    /*! This copy constructor initializes this \p device_reference
-     *  to refer to an object pointed to by the given \p device_ptr. After
-     *  this \p device_reference is constructed, it shall refer to the
-     *  object pointed to by \p ptr.
-     *
-     *  \param ptr A \p device_ptr to copy from.
-     *
-     *  The following code snippet demonstrates the semantic of this
-     *  copy constructor.
-     *
-     *  \code
-     *  #include <thrust/device_vector.h>
-     *  #include <assert.h>
-     *  ...
-     *  thrust::device_vector<int> v(1,0);
-     *  thrust::device_ptr<int> ptr = &v[0];
-     *  thrust::device_reference<int> ref(ptr);
-     *
-     *  // ref equals the object pointed to by ptr
-     *  assert(ref == *ptr);
-     *
-     *  // the address of ref equals ptr
-     *  assert(&ref == ptr);
-     *
-     *  // modifying *ptr modifies ref
-     *  *ptr = 13;
-     *  assert(ref == 13);
-     *  \endcode
-     */
-    __host__ __device__
-    explicit device_reference(const pointer &ptr)
+  /*! This copy constructor initializes this \p device_reference
+   *  to refer to an object pointed to by the given \p device_ptr. After
+   *  this \p device_reference is constructed, it shall refer to the
+   *  object pointed to by \p ptr.
+   *
+   *  \param ptr A \p device_ptr to copy from.
+   *
+   *  The following code snippet demonstrates the semantic of this
+   *  copy constructor.
+   *
+   *  \code
+   *  #include <thrust/device_vector.h>
+   *  #include <assert.h>
+   *  ...
+   *  thrust::device_vector<int> v(1,0);
+   *  thrust::device_ptr<int> ptr = &v[0];
+   *  thrust::device_reference<int> ref(ptr);
+   *
+   *  // ref equals the object pointed to by ptr
+   *  assert(ref == *ptr);
+   *
+   *  // the address of ref equals ptr
+   *  assert(&ref == ptr);
+   *
+   *  // modifying *ptr modifies ref
+   *  *ptr = 13;
+   *  assert(ref == 13);
+   *  \endcode
+   */
+  _CCCL_HOST_DEVICE explicit device_reference(const pointer& ptr)
       : super_t(ptr)
-    {}
+  {}
 
-    /*! This assignment operator assigns the value of the object referenced by
-     *  the given \p device_reference to the object referenced by this
-     *  \p device_reference.
-     *
-     *  \param other The \p device_reference to assign from.
-     *  \return <tt>*this</tt>
-     */
-    template<typename OtherT>
-    __host__ __device__
-    device_reference &operator=(const device_reference<OtherT> &other)
-    {
-      return super_t::operator=(other);
-    }
+  /*! This assignment operator assigns the value of the object referenced by
+   *  the given \p device_reference to the object referenced by this
+   *  \p device_reference.
+   *
+   *  \param other The \p device_reference to assign from.
+   *  \return <tt>*this</tt>
+   */
+  template <typename OtherT>
+  _CCCL_HOST_DEVICE device_reference& operator=(const device_reference<OtherT>& other)
+  {
+    return super_t::operator=(other);
+  }
 
-    /*! Assignment operator assigns the value of the given value to the
-     *  value referenced by this \p device_reference.
-     *
-     *  \param x The value to assign from.
-     *  \return <tt>*this</tt>
-     */
-    __host__ __device__
-    device_reference &operator=(const value_type &x)
-    {
-      return super_t::operator=(x);
-    }
+  /*! Assignment operator assigns the value of the given value to the
+   *  value referenced by this \p device_reference.
+   *
+   *  \param x The value to assign from.
+   *  \return <tt>*this</tt>
+   */
+  _CCCL_HOST_DEVICE device_reference& operator=(const value_type& x)
+  {
+    return super_t::operator=(x);
+  }
 
 // declare these members for the purpose of Doxygenating them
 // they actually exist in a derived-from class
@@ -322,7 +307,7 @@ template<typename T>
      *  \return A \p device_ptr pointing to the object this
      *  \p device_reference references.
      */
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     pointer operator&(void) const;
 
     /*! Conversion operator converts this \p device_reference to T
@@ -331,13 +316,13 @@ template<typename T>
      *
      *  \return A copy of the object referenced by this \p device_reference.
      */
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     operator value_type (void) const;
 
     /*! swaps the value this \p device_reference references with another.
      *  \p other The other \p device_reference with which to swap.
      */
-    __host__ __device__
+    _CCCL_HOST_DEVICE
     void swap(device_reference &other);
 
     /*! Prefix increment operator increments the object referenced by this
@@ -968,9 +953,8 @@ template<typename T>
  *  \p x The first \p device_reference of interest.
  *  \p y The second \p device_reference of interest.
  */
-template<typename T>
-__host__ __device__
-void swap(device_reference<T>& x, device_reference<T>& y)
+template <typename T>
+_CCCL_HOST_DEVICE void swap(device_reference<T>& x, device_reference<T>& y)
 {
   x.swap(y);
 }
@@ -984,9 +968,8 @@ void swap(device_reference<T>& x, device_reference<T>& y)
  *  \param y The \p device_reference to output.
  *  \return os.
  */
-template<typename T, typename charT, typename traits>
-std::basic_ostream<charT, traits> &
-operator<<(std::basic_ostream<charT, traits> &os, const device_reference<T> &y);
+template <typename T, typename charT, typename traits>
+std::basic_ostream<charT, traits>& operator<<(std::basic_ostream<charT, traits>& os, const device_reference<T>& y);
 #endif
 
 /*! \} // memory_management
