@@ -39,33 +39,35 @@ THRUST_NAMESPACE_BEGIN
 namespace detail
 {
 
-template <typename... Ts >
+template <typename... Ts>
 class tuple_of_iterator_references;
 
-template<class U, class T>
-struct maybe_unwrap_nested {
-  _CCCL_HOST_DEVICE U operator()(const T& t) const {
+template <class U, class T>
+struct maybe_unwrap_nested
+{
+  _CCCL_HOST_DEVICE U operator()(const T& t) const
+  {
     return t;
   }
 };
 
-template<class... Us, class... Ts>
-struct maybe_unwrap_nested<thrust::tuple<Us...>, tuple_of_iterator_references<Ts...>> {
-  _CCCL_HOST_DEVICE thrust::tuple<Us...> operator()(const tuple_of_iterator_references<Ts...>& t) const {
+template <class... Us, class... Ts>
+struct maybe_unwrap_nested<thrust::tuple<Us...>, tuple_of_iterator_references<Ts...>>
+{
+  _CCCL_HOST_DEVICE thrust::tuple<Us...> operator()(const tuple_of_iterator_references<Ts...>& t) const
+  {
     return t.template __to_tuple<Us...>(typename ::cuda::std::__make_tuple_indices<sizeof...(Ts)>::type{});
   }
 };
 
-template < typename... Ts >
+template <typename... Ts>
 class tuple_of_iterator_references : public thrust::tuple<Ts...>
 {
 public:
   using super_t = thrust::tuple<Ts...>;
   using super_t::super_t;
 
-  inline _CCCL_HOST_DEVICE tuple_of_iterator_references()
-      : super_t()
-  {}
+  tuple_of_iterator_references() = default;
 
   // allow implicit construction from tuple<refs>
   inline _CCCL_HOST_DEVICE tuple_of_iterator_references(const super_t& other)
@@ -134,15 +136,15 @@ public:
 
 } // namespace detail
 
+template <class... Ts>
+struct __is_tuple_of_iterator_references<THRUST_NS_QUALIFIER::detail::tuple_of_iterator_references<Ts...>>
+    : _CUDA_VSTD::true_type
+{};
+
 THRUST_NAMESPACE_END
 
 _LIBCUDACXX_BEGIN_NAMESPACE_STD
 
-template<class... Ts>
-struct __is_tuple_of_iterator_references<THRUST_NS_QUALIFIER::detail::tuple_of_iterator_references<Ts...>>
-    : integral_constant<bool, true>
-{};
-
 // define tuple_size, tuple_element, etc.
 template <class... Ts>
 struct tuple_size<THRUST_NS_QUALIFIER::detail::tuple_of_iterator_references<Ts...>>
