@@ -14,7 +14,6 @@
  *  limitations under the License.
  */
 
-
 /*! \file thrust/iterator/reverse_iterator.h
  *  \brief An iterator adaptor which adapts another iterator to traverse backwards
  */
@@ -148,86 +147,76 @@ THRUST_NAMESPACE_BEGIN
  *
  *  \see make_reverse_iterator
  */
-template<typename BidirectionalIterator>
-  class reverse_iterator
-    : public detail::reverse_iterator_base<BidirectionalIterator>::type
+template <typename BidirectionalIterator>
+class reverse_iterator : public detail::reverse_iterator_base<BidirectionalIterator>::type
 {
   /*! \cond
    */
-  private:
-    typedef typename thrust::detail::reverse_iterator_base<
-      BidirectionalIterator
-    >::type super_t;
 
-    friend class thrust::iterator_core_access;
+private:
+  typedef typename thrust::detail::reverse_iterator_base<BidirectionalIterator>::type super_t;
+
+  friend class thrust::iterator_core_access;
   /*! \endcond
    */
 
-  public:
-    /*! Default constructor does nothing.
-     */
+public:
+  /*! Default constructor does nothing.
+   */
 #if defined(_CCCL_COMPILER_MSVC_2017)
-    _CCCL_HOST_DEVICE reverse_iterator() {}
+  _CCCL_HOST_DEVICE reverse_iterator() {}
 #else // ^^^ _CCCL_COMPILER_MSVC_2017 ^^^ / vvv !_CCCL_COMPILER_MSVC_2017 vvv
-    reverse_iterator() = default;
+  reverse_iterator() = default;
 #endif // !_CCCL_COMPILER_MSVC_2017
 
-    /*! \p Constructor accepts a \c BidirectionalIterator pointing to a range
-     *  for this \p reverse_iterator to reverse.
-     *
-     *  \param x A \c BidirectionalIterator pointing to a range to reverse.
-     */
-    _CCCL_HOST_DEVICE
-    explicit reverse_iterator(BidirectionalIterator x)
+  /*! \p Constructor accepts a \c BidirectionalIterator pointing to a range
+   *  for this \p reverse_iterator to reverse.
+   *
+   *  \param x A \c BidirectionalIterator pointing to a range to reverse.
+   */
+  _CCCL_HOST_DEVICE explicit reverse_iterator(BidirectionalIterator x)
       : super_t(x)
-    {}
+  {}
 
-    /*! \p Copy constructor allows construction from a related compatible
-     *  \p reverse_iterator.
-     *
-     *  \param r A \p reverse_iterator to copy from.
-     */
-    template <typename OtherBidirectionalIterator,
-              detail::enable_if_convertible_t<OtherBidirectionalIterator, BidirectionalIterator, int> = 0>
-    _CCCL_HOST_DEVICE reverse_iterator(reverse_iterator<OtherBidirectionalIterator> const& rhs)
-        : super_t(rhs.base())
-    {}
+  /*! \p Copy constructor allows construction from a related compatible
+   *  \p reverse_iterator.
+   *
+   *  \param r A \p reverse_iterator to copy from.
+   */
+  template <typename OtherBidirectionalIterator,
+            detail::enable_if_convertible_t<OtherBidirectionalIterator, BidirectionalIterator, int> = 0>
+  _CCCL_HOST_DEVICE reverse_iterator(reverse_iterator<OtherBidirectionalIterator> const& rhs)
+      : super_t(rhs.base())
+  {}
 
   /*! \cond
    */
-  private:
-    _CCCL_EXEC_CHECK_DISABLE
-    _CCCL_HOST_DEVICE
-    typename super_t::reference dereference() const;
 
-    _CCCL_HOST_DEVICE
-    void increment();
+private:
+  _CCCL_EXEC_CHECK_DISABLE
+  _CCCL_HOST_DEVICE typename super_t::reference dereference() const;
 
-    _CCCL_HOST_DEVICE
-    void decrement();
+  _CCCL_HOST_DEVICE void increment();
 
-    _CCCL_HOST_DEVICE
-    void advance(typename super_t::difference_type n);
+  _CCCL_HOST_DEVICE void decrement();
 
-    template<typename OtherBidirectionalIterator>
-    _CCCL_HOST_DEVICE
-    typename super_t::difference_type
-    distance_to(reverse_iterator<OtherBidirectionalIterator> const &y) const;
+  _CCCL_HOST_DEVICE void advance(typename super_t::difference_type n);
+
+  template <typename OtherBidirectionalIterator>
+  _CCCL_HOST_DEVICE typename super_t::difference_type
+  distance_to(reverse_iterator<OtherBidirectionalIterator> const& y) const;
   /*! \endcond
    */
 }; // end reverse_iterator
 
-
 /*! \p make_reverse_iterator creates a \p reverse_iterator
  *  from a \c BidirectionalIterator pointing to a range of elements to reverse.
  *
  *  \param x A \c BidirectionalIterator pointing to a range to reverse.
  *  \return A new \p reverse_iterator which reverses the range \p x.
  */
-template<typename BidirectionalIterator>
-_CCCL_HOST_DEVICE
-reverse_iterator<BidirectionalIterator> make_reverse_iterator(BidirectionalIterator x);
-
+template <typename BidirectionalIterator>
+_CCCL_HOST_DEVICE reverse_iterator<BidirectionalIterator> make_reverse_iterator(BidirectionalIterator x);
 
 /*! \} // end fancyiterators
  */
@@ -238,4 +227,3 @@ reverse_iterator<BidirectionalIterator> make_reverse_iterator(BidirectionalItera
 THRUST_NAMESPACE_END
 
 #include <thrust/iterator/detail/reverse_iterator.inl>
-
