@@ -14,7 +14,6 @@
  *  limitations under the License.
  */
 
-
 /*! \file thrust/iterator/transform_iterator.h
  *  \brief An iterator which adapts another iterator by applying a function to the result of its dereference
  */
@@ -43,10 +42,10 @@
 #endif // no system header
 
 // #include the details first
+#include <thrust/detail/type_traits.h>
 #include <thrust/iterator/detail/transform_iterator.inl>
 #include <thrust/iterator/iterator_facade.h>
 #include <thrust/iterator/iterator_traits.h>
-#include <thrust/detail/type_traits.h>
 
 THRUST_NAMESPACE_BEGIN
 
@@ -194,145 +193,131 @@ THRUST_NAMESPACE_BEGIN
  *  \see make_transform_iterator
  */
 template <class AdaptableUnaryFunction, class Iterator, class Reference = use_default, class Value = use_default>
-  class transform_iterator
+class transform_iterator
     : public detail::transform_iterator_base<AdaptableUnaryFunction, Iterator, Reference, Value>::type
 {
   /*! \cond
    */
-  public:
-    typedef typename
-    detail::transform_iterator_base<AdaptableUnaryFunction, Iterator, Reference, Value>::type
-    super_t;
 
-    friend class thrust::iterator_core_access;
+public:
+  typedef typename detail::transform_iterator_base<AdaptableUnaryFunction, Iterator, Reference, Value>::type super_t;
+
+  friend class thrust::iterator_core_access;
   /*! \endcond
    */
 
-  public:
-    /*! Null constructor does nothing.
-     */
-    transform_iterator() = default;
+public:
+  /*! Null constructor does nothing.
+   */
+  transform_iterator() = default;
 
-#if _CCCL_STD_VER >= 2011
-    transform_iterator(transform_iterator const&) = default;
-#endif
+  transform_iterator(transform_iterator const&) = default;
 
-    /*! This constructor takes as arguments an \c Iterator and an \c AdaptableUnaryFunction
-     *  and copies them to a new \p transform_iterator.
-     *
-     *  \param x An \c Iterator pointing to the input to this \p transform_iterator's \c AdaptableUnaryFunction.
-     *  \param f An \c AdaptableUnaryFunction used to transform the objects pointed to by \p x.
-     */
-    _CCCL_HOST_DEVICE
-    transform_iterator(Iterator const& x, AdaptableUnaryFunction f)
-      : super_t(x), m_f(f) {
-    }
+  /*! This constructor takes as arguments an \c Iterator and an \c AdaptableUnaryFunction
+   *  and copies them to a new \p transform_iterator.
+   *
+   *  \param x An \c Iterator pointing to the input to this \p transform_iterator's \c AdaptableUnaryFunction.
+   *  \param f An \c AdaptableUnaryFunction used to transform the objects pointed to by \p x.
+   */
+  _CCCL_HOST_DEVICE transform_iterator(Iterator const& x, AdaptableUnaryFunction f)
+      : super_t(x)
+      , m_f(f)
+  {}
 
-    /*! This explicit constructor copies the value of a given \c Iterator and creates
-     *  this \p transform_iterator's \c AdaptableUnaryFunction using its null constructor.
-     *
-     *  \param x An \c Iterator to copy.
-     */
-    _CCCL_HOST_DEVICE
-    explicit transform_iterator(Iterator const& x)
-      : super_t(x) { }
+  /*! This explicit constructor copies the value of a given \c Iterator and creates
+   *  this \p transform_iterator's \c AdaptableUnaryFunction using its null constructor.
+   *
+   *  \param x An \c Iterator to copy.
+   */
+  _CCCL_HOST_DEVICE explicit transform_iterator(Iterator const& x)
+      : super_t(x)
+  {}
 
-    /*! This copy constructor creates a new \p transform_iterator from another
-     *  \p transform_iterator.
-     *
-     *  \param other The \p transform_iterator to copy.
-     */
-    template<typename OtherAdaptableUnaryFunction,
-             typename OtherIterator,
-             typename OtherReference,
-             typename OtherValue>
-    _CCCL_HOST_DEVICE
-    transform_iterator(const transform_iterator<OtherAdaptableUnaryFunction, OtherIterator, OtherReference, OtherValue> &other,
-                       typename thrust::detail::enable_if_convertible<OtherIterator, Iterator>::type* = 0,
-                       typename thrust::detail::enable_if_convertible<OtherAdaptableUnaryFunction, AdaptableUnaryFunction>::type* = 0)
-      : super_t(other.base()), m_f(other.functor()) {}
+  /*! This copy constructor creates a new \p transform_iterator from another
+   *  \p transform_iterator.
+   *
+   *  \param other The \p transform_iterator to copy.
+   */
+  template <typename OtherAdaptableUnaryFunction, typename OtherIterator, typename OtherReference, typename OtherValue>
+  _CCCL_HOST_DEVICE transform_iterator(
+    const transform_iterator<OtherAdaptableUnaryFunction, OtherIterator, OtherReference, OtherValue>& other,
+    thrust::detail::enable_if_convertible_t<OtherIterator, Iterator>*                             = 0,
+    thrust::detail::enable_if_convertible_t<OtherAdaptableUnaryFunction, AdaptableUnaryFunction>* = 0)
+      : super_t(other.base())
+      , m_f(other.functor())
+  {}
 
-    /*! Copy assignment operator copies from another \p transform_iterator.
-     *  \p other The other \p transform_iterator to copy
-     *  \return <tt>*this</tt>
-     *
-     *  \note If the type of this \p transform_iterator's functor is not copy assignable
-     *        (for example, if it is a lambda) it is not an error to call this function.
-     *        In this case, however, the functor will not be modified.
-     *
-     *        In any case, this \p transform_iterator's underlying iterator will be copy assigned.
-     */
-    _CCCL_HOST_DEVICE
-    transform_iterator &operator=(const transform_iterator &other)
-    {
-      return do_assign(other,
-      // XXX gcc 4.2.1 crashes on is_copy_assignable; just assume the functor is assignable as a WAR
-#if defined(_CCCL_COMPILER_GCC) && (THRUST_GCC_VERSION <= 40201)
-          thrust::detail::true_type()
-#else
-          typename thrust::detail::is_copy_assignable<AdaptableUnaryFunction>::type()
-#endif // THRUST_HOST_COMPILER
-      );
-    }
+  /*! Copy assignment operator copies from another \p transform_iterator.
+   *  \p other The other \p transform_iterator to copy
+   *  \return <tt>*this</tt>
+   *
+   *  \note If the type of this \p transform_iterator's functor is not copy assignable
+   *        (for example, if it is a lambda) it is not an error to call this function.
+   *        In this case, however, the functor will not be modified.
+   *
+   *        In any case, this \p transform_iterator's underlying iterator will be copy assigned.
+   */
+  _CCCL_HOST_DEVICE transform_iterator& operator=(const transform_iterator& other)
+  {
+    return do_assign(other, ::cuda::std::is_copy_assignable<AdaptableUnaryFunction>());
+  }
 
-    /*! This method returns a copy of this \p transform_iterator's \c AdaptableUnaryFunction.
-     *  \return A copy of this \p transform_iterator's \c AdaptableUnaryFunction.
-     */
-    _CCCL_HOST_DEVICE
-    AdaptableUnaryFunction functor() const
-      { return m_f; }
+  /*! This method returns a copy of this \p transform_iterator's \c AdaptableUnaryFunction.
+   *  \return A copy of this \p transform_iterator's \c AdaptableUnaryFunction.
+   */
+  _CCCL_HOST_DEVICE AdaptableUnaryFunction functor() const
+  {
+    return m_f;
+  }
 
-    /*! \cond
-     */
-  private:
-    _CCCL_HOST_DEVICE
-    transform_iterator &do_assign(const transform_iterator &other, thrust::detail::true_type)
-    {
-      super_t::operator=(other);
+  /*! \cond
+   */
 
-      // do assign to m_f
-      m_f = other.functor();
+private:
+  _CCCL_HOST_DEVICE transform_iterator& do_assign(const transform_iterator& other, thrust::detail::true_type)
+  {
+    super_t::operator=(other);
 
-      return *this;
-    }
+    // do assign to m_f
+    m_f = other.functor();
 
-    _CCCL_HOST_DEVICE
-    transform_iterator &do_assign(const transform_iterator &other, thrust::detail::false_type)
-    {
-      super_t::operator=(other);
+    return *this;
+  }
 
-      // don't assign to m_f
+  _CCCL_HOST_DEVICE transform_iterator& do_assign(const transform_iterator& other, thrust::detail::false_type)
+  {
+    super_t::operator=(other);
 
-      return *this;
-    }
+    // don't assign to m_f
 
-    // MSVC 2013 and 2015 incorrectly warning about returning a reference to
-    // a local/temporary here.
-    // See goo.gl/LELTNp
-    THRUST_DISABLE_MSVC_WARNING_BEGIN(4172)
+    return *this;
+  }
 
-    _CCCL_EXEC_CHECK_DISABLE
-    _CCCL_HOST_DEVICE
-    typename super_t::reference dereference() const
-    {
-      // Create a temporary to allow iterators with wrapped references to
-      // convert to their value type before calling m_f. Note that this
-      // disallows non-constant operations through m_f.
-      typename thrust::iterator_value<Iterator>::type const& x = *this->base();
-      return m_f(x);
-    }
+  // MSVC 2013 and 2015 incorrectly warning about returning a reference to
+  // a local/temporary here.
+  // See goo.gl/LELTNp
+  THRUST_DISABLE_MSVC_WARNING_BEGIN(4172)
 
-    THRUST_DISABLE_MSVC_WARNING_END(4172)
+  _CCCL_EXEC_CHECK_DISABLE
+  _CCCL_HOST_DEVICE typename super_t::reference dereference() const
+  {
+    // Create a temporary to allow iterators with wrapped references to
+    // convert to their value type before calling m_f. Note that this
+    // disallows non-constant operations through m_f.
+    typename thrust::iterator_value<Iterator>::type const& x = *this->base();
+    return m_f(x);
+  }
 
-    // tag this as mutable per Dave Abrahams in this thread:
-    // http://lists.boost.org/Archives/boost/2004/05/65332.php
-    mutable AdaptableUnaryFunction m_f;
+  THRUST_DISABLE_MSVC_WARNING_END(4172)
 
-    /*! \endcond
-     */
+  // tag this as mutable per Dave Abrahams in this thread:
+  // http://lists.boost.org/Archives/boost/2004/05/65332.php
+  mutable AdaptableUnaryFunction m_f;
+
+  /*! \endcond
+   */
 }; // end transform_iterator
 
-
 /*! \p make_transform_iterator creates a \p transform_iterator
  *  from an \c Iterator and \c AdaptableUnaryFunction.
  *
@@ -345,8 +330,7 @@ template <class AdaptableUnaryFunction, class Iterator, class Reference = use_de
  *  \see transform_iterator
  */
 template <class AdaptableUnaryFunction, class Iterator>
-inline _CCCL_HOST_DEVICE
-transform_iterator<AdaptableUnaryFunction, Iterator>
+inline _CCCL_HOST_DEVICE transform_iterator<AdaptableUnaryFunction, Iterator>
 make_transform_iterator(Iterator it, AdaptableUnaryFunction fun)
 {
   return transform_iterator<AdaptableUnaryFunction, Iterator>(it, fun);
@@ -359,4 +343,3 @@ make_transform_iterator(Iterator it, AdaptableUnaryFunction fun)
  */
 
 THRUST_NAMESPACE_END
-
