@@ -95,20 +95,15 @@ THRUST_NAMESPACE_BEGIN
  */
 
 template <typename UnaryFunction, typename OutputIterator>
-  class transform_output_iterator
-    : public detail::transform_output_iterator_base<UnaryFunction, OutputIterator>::type
+class transform_output_iterator : public detail::transform_output_iterator_base<UnaryFunction, OutputIterator>::type
 {
-
   /*! \cond
    */
 
-  public:
+public:
+  typedef typename detail::transform_output_iterator_base<UnaryFunction, OutputIterator>::type super_t;
 
-    typedef typename
-    detail::transform_output_iterator_base<UnaryFunction, OutputIterator>::type
-    super_t;
-
-    friend class thrust::iterator_core_access;
+  friend class thrust::iterator_core_access;
   /*! \endcond
    */
 
@@ -122,27 +117,24 @@ template <typename UnaryFunction, typename OutputIterator>
    * \param fun An \c UnaryFunction used to transform the objects assigned to
    *            this \p transform_output_iterator.
    */
-    _CCCL_HOST_DEVICE
-    transform_output_iterator(OutputIterator const& out, UnaryFunction fun) : super_t(out), fun(fun)
-    {
-    }
+  _CCCL_HOST_DEVICE transform_output_iterator(OutputIterator const& out, UnaryFunction fun)
+      : super_t(out)
+      , fun(fun)
+  {}
 
-    /*! \cond
-     */
-  private:
+  /*! \cond
+   */
 
-    _CCCL_HOST_DEVICE
-    typename super_t::reference dereference() const
-    {
-      return detail::transform_output_iterator_proxy<
-        UnaryFunction, OutputIterator
-      >(this->base_reference(), fun);
-    }
+private:
+  _CCCL_HOST_DEVICE typename super_t::reference dereference() const
+  {
+    return detail::transform_output_iterator_proxy<UnaryFunction, OutputIterator>(this->base_reference(), fun);
+  }
 
-    UnaryFunction fun;
+  UnaryFunction fun;
 
-    /*! \endcond
-     */
+  /*! \endcond
+   */
 }; // end transform_output_iterator
 
 /*! \p make_transform_output_iterator creates a \p transform_output_iterator from
@@ -155,11 +147,10 @@ template <typename UnaryFunction, typename OutputIterator>
  *  \see transform_output_iterator
  */
 template <typename UnaryFunction, typename OutputIterator>
-transform_output_iterator<UnaryFunction, OutputIterator>
-_CCCL_HOST_DEVICE
+transform_output_iterator<UnaryFunction, OutputIterator> _CCCL_HOST_DEVICE
 make_transform_output_iterator(OutputIterator out, UnaryFunction fun)
 {
-    return transform_output_iterator<UnaryFunction, OutputIterator>(out, fun);
+  return transform_output_iterator<UnaryFunction, OutputIterator>(out, fun);
 } // end make_transform_output_iterator
 
 /*! \} // end fancyiterators
@@ -169,4 +160,3 @@ make_transform_output_iterator(OutputIterator out, UnaryFunction fun)
  */
 
 THRUST_NAMESPACE_END
-
