@@ -30,9 +30,6 @@
 #  pragma system_header
 #endif // no system header
 #include <thrust/detail/cpp11_required.h>
-
-#if _CCCL_STD_VER >= 2011
-
 #include <thrust/mr/disjoint_pool.h>
 
 THRUST_NAMESPACE_BEGIN
@@ -53,25 +50,20 @@ namespace mr
  *  \param upstream the first argument to the constructor, if invoked
  *  \param bookkeeper the second argument to the constructor, if invoked
  */
-template<typename Upstream, typename Bookkeeper>
-_CCCL_HOST
-thrust::mr::disjoint_unsynchronized_pool_resource<Upstream, Bookkeeper> & tls_disjoint_pool(
-    Upstream * upstream = NULL,
-    Bookkeeper * bookkeeper = NULL)
+template <typename Upstream, typename Bookkeeper>
+_CCCL_HOST thrust::mr::disjoint_unsynchronized_pool_resource<Upstream, Bookkeeper>&
+tls_disjoint_pool(Upstream* upstream = NULL, Bookkeeper* bookkeeper = NULL)
 {
-    static thread_local auto adaptor = [&]{
-        assert(upstream && bookkeeper);
-        return thrust::mr::disjoint_unsynchronized_pool_resource<Upstream, Bookkeeper>(upstream, bookkeeper);
-    }();
+  static thread_local auto adaptor = [&] {
+    assert(upstream && bookkeeper);
+    return thrust::mr::disjoint_unsynchronized_pool_resource<Upstream, Bookkeeper>(upstream, bookkeeper);
+  }();
 
-    return adaptor;
+  return adaptor;
 }
 
 /*! \}
  */
 
-} // end mr
+} // namespace mr
 THRUST_NAMESPACE_END
-
-#endif // _CCCL_STD_VER >= 2011
-
