@@ -37,41 +37,37 @@ namespace random
 namespace detail
 {
 
-
-template<typename UIntType, UIntType a, unsigned long long c, UIntType m>
-  struct linear_congruential_engine_discard_implementation
+template <typename UIntType, UIntType a, unsigned long long c, UIntType m>
+struct linear_congruential_engine_discard_implementation
 {
-  _CCCL_HOST_DEVICE
-  static void discard(UIntType &state, unsigned long long z)
+  _CCCL_HOST_DEVICE static void discard(UIntType& state, unsigned long long z)
   {
-    for(; z > 0; --z)
+    for (; z > 0; --z)
     {
-      state = detail::mod<UIntType,a,c,m>(state);
+      state = detail::mod<UIntType, a, c, m>(state);
     }
   }
 }; // end linear_congruential_engine_discard
 
-
 // specialize for small integers and c == 0
 // XXX figure out a robust implemenation of this for any unsigned integer type later
-template<thrust::detail::uint32_t a, thrust::detail::uint32_t m>
-  struct linear_congruential_engine_discard_implementation<thrust::detail::uint32_t,a,0,m>
+template <thrust::detail::uint32_t a, thrust::detail::uint32_t m>
+struct linear_congruential_engine_discard_implementation<thrust::detail::uint32_t, a, 0, m>
 {
-  _CCCL_HOST_DEVICE
-  static void discard(thrust::detail::uint32_t &state, unsigned long long z)
+  _CCCL_HOST_DEVICE static void discard(thrust::detail::uint32_t& state, unsigned long long z)
   {
     const thrust::detail::uint32_t modulus = m;
 
     // XXX we need to use unsigned long long here or we will encounter overflow in the
     //     multiplies below
     //     figure out a robust implementation of this later
-    unsigned long long multiplier = a;
+    unsigned long long multiplier      = a;
     unsigned long long multiplier_to_z = 1;
 
     // see http://en.wikipedia.org/wiki/Modular_exponentiation
-    while(z > 0)
+    while (z > 0)
     {
-      if(z & 1)
+      if (z & 1)
       {
         // multiply in this bit's contribution while using modulus to keep result small
         multiplier_to_z = (multiplier_to_z * multiplier) % modulus;
@@ -86,12 +82,10 @@ template<thrust::detail::uint32_t a, thrust::detail::uint32_t m>
   }
 }; // end linear_congruential_engine_discard
 
-
 struct linear_congruential_engine_discard
 {
-  template<typename LinearCongruentialEngine>
-  _CCCL_HOST_DEVICE
-  static void discard(LinearCongruentialEngine &lcg, unsigned long long z)
+  template <typename LinearCongruentialEngine>
+  _CCCL_HOST_DEVICE static void discard(LinearCongruentialEngine& lcg, unsigned long long z)
   {
     typedef typename LinearCongruentialEngine::result_type result_type;
     const result_type c = LinearCongruentialEngine::increment;
@@ -103,14 +97,12 @@ struct linear_congruential_engine_discard
     (void) a;
     (void) m;
 
-    linear_congruential_engine_discard_implementation<result_type,a,c,m>::discard(lcg.m_x, z);
+    linear_congruential_engine_discard_implementation<result_type, a, c, m>::discard(lcg.m_x, z);
   }
 }; // end linear_congruential_engine_discard
 
+} // namespace detail
 
-} // end detail
-
-} // end random
+} // namespace random
 
 THRUST_NAMESPACE_END
-
