@@ -14,7 +14,6 @@
  *  limitations under the License.
  */
 
-
 /*! \file replace.h
  *  \brief Functions for replacing elements in a range with a particular value
  */
@@ -40,7 +39,6 @@ THRUST_NAMESPACE_BEGIN
  *  \{
  */
 
-
 /*! \p replace replaces every element in the range [first, last) equal to \p old_value
  *  with \p new_value. That is: for every iterator \c i, if <tt>*i == old_value</tt>
  *  then it performs the <tt>assignment *i = new_value</tt>.
@@ -54,13 +52,12 @@ THRUST_NAMESPACE_BEGIN
  *  \param new_value The new value to replace \p old_value.
  *
  *  \tparam DerivedPolicy The name of the derived execution policy.
- *  \tparam ForwardIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/forward_iterator">Forward Iterator</a>,
- *          and \p ForwardIterator is mutable.
- *  \tparam T is a model of <a href="https://en.cppreference.com/w/cpp/named_req/CopyAssignable>Assignable">Assignable</a>,
- *          \p T is a model of <a href="https://en.cppreference.com/w/cpp/concepts/equality_comparable">EqualityComparable</a>,
- *          objects of \p T may be compared for equality with objects of
- *          \p ForwardIterator's \c value_type,
- *          and \p T is convertible to \p ForwardIterator's \c value_type.
+ *  \tparam ForwardIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/forward_iterator">Forward
+ * Iterator</a>, and \p ForwardIterator is mutable. \tparam T is a model of <a
+ * href="https://en.cppreference.com/w/cpp/named_req/CopyAssignable>Assignable">Assignable</a>, \p T is a model of <a
+ * href="https://en.cppreference.com/w/cpp/concepts/equality_comparable">EqualityComparable</a>, objects of \p T may be
+ * compared for equality with objects of \p ForwardIterator's \c value_type, and \p T is convertible to \p
+ * ForwardIterator's \c value_type.
  *
  *  The following code snippet demonstrates how to use \p replace to replace
  *  a value of interest in a \c device_vector with another using the \p thrust::device
@@ -89,13 +86,13 @@ THRUST_NAMESPACE_BEGIN
  *  \see \c replace_copy
  *  \see \c replace_copy_if
  */
-template<typename DerivedPolicy, typename ForwardIterator, typename T>
-_CCCL_HOST_DEVICE
-  void replace(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
-               ForwardIterator first, ForwardIterator last,
-               const T &old_value,
-               const T &new_value);
-
+template <typename DerivedPolicy, typename ForwardIterator, typename T>
+_CCCL_HOST_DEVICE void
+replace(const thrust::detail::execution_policy_base<DerivedPolicy>& exec,
+        ForwardIterator first,
+        ForwardIterator last,
+        const T& old_value,
+        const T& new_value);
 
 /*! \p replace replaces every element in the range [first, last) equal to \p old_value
  *  with \p new_value. That is: for every iterator \c i, if <tt>*i == old_value</tt>
@@ -106,13 +103,12 @@ _CCCL_HOST_DEVICE
  *  \param old_value The value to replace.
  *  \param new_value The new value to replace \p old_value.
  *
- *  \tparam ForwardIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/forward_iterator">Forward Iterator</a>,
- *          and \p ForwardIterator is mutable.
- *  \tparam T is a model of <a href="https://en.cppreference.com/w/cpp/named_req/CopyAssignable>Assignable">Assignable</a>,
- *          \p T is a model of <a href="https://en.cppreference.com/w/cpp/concepts/equality_comparable">EqualityComparable</a>,
- *          objects of \p T may be compared for equality with objects of
- *          \p ForwardIterator's \c value_type,
- *          and \p T is convertible to \p ForwardIterator's \c value_type.
+ *  \tparam ForwardIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/forward_iterator">Forward
+ * Iterator</a>, and \p ForwardIterator is mutable. \tparam T is a model of <a
+ * href="https://en.cppreference.com/w/cpp/named_req/CopyAssignable>Assignable">Assignable</a>, \p T is a model of <a
+ * href="https://en.cppreference.com/w/cpp/concepts/equality_comparable">EqualityComparable</a>, objects of \p T may be
+ * compared for equality with objects of \p ForwardIterator's \c value_type, and \p T is convertible to \p
+ * ForwardIterator's \c value_type.
  *
  *  The following code snippet demonstrates how to use \p replace to replace
  *  a value of interest in a \c device_vector with another.
@@ -139,10 +135,8 @@ _CCCL_HOST_DEVICE
  *  \see \c replace_copy
  *  \see \c replace_copy_if
  */
-template<typename ForwardIterator, typename T>
-  void replace(ForwardIterator first, ForwardIterator last, const T &old_value,
-               const T &new_value);
-
+template <typename ForwardIterator, typename T>
+void replace(ForwardIterator first, ForwardIterator last, const T& old_value, const T& new_value);
 
 /*! \p replace_if replaces every element in the range <tt>[first, last)</tt> for which
  *  \p pred returns \c true with \p new_value. That is: for every iterator \c i, if
@@ -158,12 +152,12 @@ template<typename ForwardIterator, typename T>
  *         to \c true.
  *
  *  \tparam DerivedPolicy The name of the derived execution policy.
- *  \tparam ForwardIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/forward_iterator">Forward Iterator</a>,
- *          \p ForwardIterator is mutable,
- *          and \p ForwardIterator's \c value_type is convertible to \p Predicate's \c argument_type.
- *  \tparam Predicate is a model of <a href="https://en.cppreference.com/w/cpp/concepts/predicate">Predicate</a>.
- *  \tparam T is a model of <a href="https://en.cppreference.com/w/cpp/named_req/CopyAssignable">Assignable</a>,
- *          and \p T is convertible to \p ForwardIterator's \c value_type.
+ *  \tparam ForwardIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/forward_iterator">Forward
+ * Iterator</a>, \p ForwardIterator is mutable, and \p ForwardIterator's \c value_type is convertible to \p Predicate's
+ * \c argument_type. \tparam Predicate is a model of <a
+ * href="https://en.cppreference.com/w/cpp/concepts/predicate">Predicate</a>. \tparam T is a model of <a
+ * href="https://en.cppreference.com/w/cpp/named_req/CopyAssignable">Assignable</a>, and \p T is convertible to \p
+ * ForwardIterator's \c value_type.
  *
  *  The following code snippet demonstrates how to use \p replace_if to replace
  *  a \c device_vector's negative elements with \c 0 using the \p thrust::device execution policy
@@ -203,13 +197,13 @@ template<typename ForwardIterator, typename T>
  *  \see \c replace_copy
  *  \see \c replace_copy_if
  */
-template<typename DerivedPolicy, typename ForwardIterator, typename Predicate, typename T>
-_CCCL_HOST_DEVICE
-  void replace_if(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
-                  ForwardIterator first, ForwardIterator last,
-                  Predicate pred,
-                  const T &new_value);
-
+template <typename DerivedPolicy, typename ForwardIterator, typename Predicate, typename T>
+_CCCL_HOST_DEVICE void replace_if(
+  const thrust::detail::execution_policy_base<DerivedPolicy>& exec,
+  ForwardIterator first,
+  ForwardIterator last,
+  Predicate pred,
+  const T& new_value);
 
 /*! \p replace_if replaces every element in the range <tt>[first, last)</tt> for which
  *  \p pred returns \c true with \p new_value. That is: for every iterator \c i, if
@@ -221,12 +215,12 @@ _CCCL_HOST_DEVICE
  *  \param new_value The new value to replace elements which <tt>pred(*i)</tt> evaluates
  *         to \c true.
  *
- *  \tparam ForwardIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/forward_iterator">Forward Iterator</a>,
- *          \p ForwardIterator is mutable,
- *          and \p ForwardIterator's \c value_type is convertible to \p Predicate's \c argument_type.
- *  \tparam Predicate is a model of <a href="https://en.cppreference.com/w/cpp/concepts/predicate">Predicate</a>.
- *  \tparam T is a model of <a href="https://en.cppreference.com/w/cpp/named_req/CopyAssignable">Assignable</a>,
- *          and \p T is convertible to \p ForwardIterator's \c value_type.
+ *  \tparam ForwardIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/forward_iterator">Forward
+ * Iterator</a>, \p ForwardIterator is mutable, and \p ForwardIterator's \c value_type is convertible to \p Predicate's
+ * \c argument_type. \tparam Predicate is a model of <a
+ * href="https://en.cppreference.com/w/cpp/concepts/predicate">Predicate</a>. \tparam T is a model of <a
+ * href="https://en.cppreference.com/w/cpp/named_req/CopyAssignable">Assignable</a>, and \p T is convertible to \p
+ * ForwardIterator's \c value_type.
  *
  *  The following code snippet demonstrates how to use \p replace_if to replace
  *  a \c device_vector's negative elements with \c 0.
@@ -264,11 +258,8 @@ _CCCL_HOST_DEVICE
  *  \see \c replace_copy
  *  \see \c replace_copy_if
  */
-template<typename ForwardIterator, typename Predicate, typename T>
-  void replace_if(ForwardIterator first, ForwardIterator last,
-                  Predicate pred,
-                  const T &new_value);
-
+template <typename ForwardIterator, typename Predicate, typename T>
+void replace_if(ForwardIterator first, ForwardIterator last, Predicate pred, const T& new_value);
 
 /*! \p replace_if replaces every element in the range <tt>[first, last)</tt> for which
  *  <tt>pred(*s)</tt> returns \c true with \p new_value. That is: for every iterator
@@ -286,13 +277,13 @@ template<typename ForwardIterator, typename Predicate, typename T>
  *         to \c true.
  *
  *  \tparam DerivedPolicy The name of the derived execution policy.
- *  \tparam ForwardIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/forward_iterator">Forward Iterator</a>,
- *          and \p ForwardIterator is mutable.
- *  \tparam InputIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/input_iterator">Input Iterator</a>,
- *          and \p InputIterator's \c value_type is convertible to \p Predicate's \c argument_type.
- *  \tparam Predicate is a model of <a href="https://en.cppreference.com/w/cpp/concepts/predicate">Predicate</a>.
- *  \tparam T is a model of <a href="https://en.cppreference.com/w/cpp/named_req/CopyAssignable">Assignable</a>,
- *          and \p T is convertible to \p ForwardIterator's \c value_type.
+ *  \tparam ForwardIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/forward_iterator">Forward
+ * Iterator</a>, and \p ForwardIterator is mutable. \tparam InputIterator is a model of <a
+ * href="https://en.cppreference.com/w/cpp/iterator/input_iterator">Input Iterator</a>, and \p InputIterator's \c
+ * value_type is convertible to \p Predicate's \c argument_type. \tparam Predicate is a model of <a
+ * href="https://en.cppreference.com/w/cpp/concepts/predicate">Predicate</a>. \tparam T is a model of <a
+ * href="https://en.cppreference.com/w/cpp/named_req/CopyAssignable">Assignable</a>, and \p T is convertible to \p
+ * ForwardIterator's \c value_type.
  *
  *  The following code snippet demonstrates how to use \p replace_if to replace
  *  a \c device_vector's element with \c 0 when its corresponding stencil element is less than zero
@@ -337,14 +328,14 @@ template<typename ForwardIterator, typename Predicate, typename T>
  *  \see \c replace_copy
  *  \see \c replace_copy_if
  */
-template<typename DerivedPolicy, typename ForwardIterator, typename InputIterator, typename Predicate, typename T>
-_CCCL_HOST_DEVICE
-  void replace_if(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
-                  ForwardIterator first, ForwardIterator last,
-                  InputIterator stencil,
-                  Predicate pred,
-                  const T &new_value);
-
+template <typename DerivedPolicy, typename ForwardIterator, typename InputIterator, typename Predicate, typename T>
+_CCCL_HOST_DEVICE void replace_if(
+  const thrust::detail::execution_policy_base<DerivedPolicy>& exec,
+  ForwardIterator first,
+  ForwardIterator last,
+  InputIterator stencil,
+  Predicate pred,
+  const T& new_value);
 
 /*! \p replace_if replaces every element in the range <tt>[first, last)</tt> for which
  *  <tt>pred(*s)</tt> returns \c true with \p new_value. That is: for every iterator
@@ -358,13 +349,13 @@ _CCCL_HOST_DEVICE
  *  \param new_value The new value to replace elements which <tt>pred(*i)</tt> evaluates
  *         to \c true.
  *
- *  \tparam ForwardIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/forward_iterator">Forward Iterator</a>,
- *          and \p ForwardIterator is mutable.
- *  \tparam InputIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/input_iterator">Input Iterator</a>,
- *          and \p InputIterator's \c value_type is convertible to \p Predicate's \c argument_type.
- *  \tparam Predicate is a model of <a href="https://en.cppreference.com/w/cpp/concepts/predicate">Predicate</a>.
- *  \tparam T is a model of <a href="https://en.cppreference.com/w/cpp/named_req/CopyAssignable">Assignable</a>,
- *          and \p T is convertible to \p ForwardIterator's \c value_type.
+ *  \tparam ForwardIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/forward_iterator">Forward
+ * Iterator</a>, and \p ForwardIterator is mutable. \tparam InputIterator is a model of <a
+ * href="https://en.cppreference.com/w/cpp/iterator/input_iterator">Input Iterator</a>, and \p InputIterator's \c
+ * value_type is convertible to \p Predicate's \c argument_type. \tparam Predicate is a model of <a
+ * href="https://en.cppreference.com/w/cpp/concepts/predicate">Predicate</a>. \tparam T is a model of <a
+ * href="https://en.cppreference.com/w/cpp/named_req/CopyAssignable">Assignable</a>, and \p T is convertible to \p
+ * ForwardIterator's \c value_type.
  *
  *  The following code snippet demonstrates how to use \p replace_if to replace
  *  a \c device_vector's element with \c 0 when its corresponding stencil element is less than zero.
@@ -407,12 +398,8 @@ _CCCL_HOST_DEVICE
  *  \see \c replace_copy
  *  \see \c replace_copy_if
  */
-template<typename ForwardIterator, typename InputIterator, typename Predicate, typename T>
-  void replace_if(ForwardIterator first, ForwardIterator last,
-                  InputIterator stencil,
-                  Predicate pred,
-                  const T &new_value);
-
+template <typename ForwardIterator, typename InputIterator, typename Predicate, typename T>
+void replace_if(ForwardIterator first, ForwardIterator last, InputIterator stencil, Predicate pred, const T& new_value);
 
 /*! \p replace_copy copies elements from the range <tt>[first, last)</tt> to the range
  *  <tt>[result, result + (last-first))</tt>, except that any element equal to \p old_value
@@ -433,14 +420,15 @@ template<typename ForwardIterator, typename InputIterator, typename Predicate, t
  *  \return <tt>result + (last-first)</tt>
  *
  *  \tparam DerivedPolicy The name of the derived execution policy.
- *  \tparam InputIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/input_iterator">Input Iterator</a>.
- *  \tparam OutputIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/output_iterator">Output Iterator</a>.
- *  \tparam T is a model of <a href="https://en.cppreference.com/w/cpp/named_req/CopyAssignable">Assignable</a>,
- *          \p T is a model of <a href="https://en.cppreference.com/w/cpp/concepts/equality_comparable">Equality Comparable</a>,
- *          \p T may be compared for equality with \p InputIterator's \c value_type,
- *          and \p T is convertible to \p OutputIterator's \c value_type.
+ *  \tparam InputIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/input_iterator">Input
+ * Iterator</a>. \tparam OutputIterator is a model of <a
+ * href="https://en.cppreference.com/w/cpp/iterator/output_iterator">Output Iterator</a>. \tparam T is a model of <a
+ * href="https://en.cppreference.com/w/cpp/named_req/CopyAssignable">Assignable</a>, \p T is a model of <a
+ * href="https://en.cppreference.com/w/cpp/concepts/equality_comparable">Equality Comparable</a>, \p T may be compared
+ * for equality with \p InputIterator's \c value_type, and \p T is convertible to \p OutputIterator's \c value_type.
  *
- *  \pre \p first may equal \p result, but the ranges <tt>[first, last)</tt> and <tt>[result, result + (last - first))</tt> shall not overlap otherwise.
+ *  \pre \p first may equal \p result, but the ranges <tt>[first, last)</tt> and <tt>[result, result + (last -
+ * first))</tt> shall not overlap otherwise.
  *
  *  \code
  *  #include <thrust/replace.h>
@@ -466,14 +454,14 @@ template<typename ForwardIterator, typename InputIterator, typename Predicate, t
  *  \see \c replace_if
  *  \see \c replace_copy_if
  */
-template<typename DerivedPolicy, typename InputIterator, typename OutputIterator, typename T>
-_CCCL_HOST_DEVICE
-  OutputIterator replace_copy(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
-                              InputIterator first, InputIterator last,
-                              OutputIterator result,
-                              const T &old_value,
-                              const T &new_value);
-
+template <typename DerivedPolicy, typename InputIterator, typename OutputIterator, typename T>
+_CCCL_HOST_DEVICE OutputIterator replace_copy(
+  const thrust::detail::execution_policy_base<DerivedPolicy>& exec,
+  InputIterator first,
+  InputIterator last,
+  OutputIterator result,
+  const T& old_value,
+  const T& new_value);
 
 /*! \p replace_copy copies elements from the range <tt>[first, last)</tt> to the range
  *  <tt>[result, result + (last-first))</tt>, except that any element equal to \p old_value
@@ -490,14 +478,15 @@ _CCCL_HOST_DEVICE
  *  \param new_value The replacement value for which <tt>*i == old_value</tt> evaluates to \c true.
  *  \return <tt>result + (last-first)</tt>
  *
- *  \tparam InputIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/input_iterator">Input Iterator</a>.
- *  \tparam OutputIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/output_iterator">Output Iterator</a>.
- *  \tparam T is a model of <a href="https://en.cppreference.com/w/cpp/named_req/CopyAssignable">Assignable</a>,
- *          \p T is a model of <a href="https://en.cppreference.com/w/cpp/concepts/equality_comparable">Equality Comparable</a>,
- *          \p T may be compared for equality with \p InputIterator's \c value_type,
- *          and \p T is convertible to \p OutputIterator's \c value_type.
+ *  \tparam InputIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/input_iterator">Input
+ * Iterator</a>. \tparam OutputIterator is a model of <a
+ * href="https://en.cppreference.com/w/cpp/iterator/output_iterator">Output Iterator</a>. \tparam T is a model of <a
+ * href="https://en.cppreference.com/w/cpp/named_req/CopyAssignable">Assignable</a>, \p T is a model of <a
+ * href="https://en.cppreference.com/w/cpp/concepts/equality_comparable">Equality Comparable</a>, \p T may be compared
+ * for equality with \p InputIterator's \c value_type, and \p T is convertible to \p OutputIterator's \c value_type.
  *
- *  \pre \p first may equal \p result, but the ranges <tt>[first, last)</tt> and <tt>[result, result + (last - first))</tt> shall not overlap otherwise.
+ *  \pre \p first may equal \p result, but the ranges <tt>[first, last)</tt> and <tt>[result, result + (last -
+ * first))</tt> shall not overlap otherwise.
  *
  *  \code
  *  #include <thrust/replace.h>
@@ -522,11 +511,9 @@ _CCCL_HOST_DEVICE
  *  \see \c replace_if
  *  \see \c replace_copy_if
  */
-template<typename InputIterator, typename OutputIterator, typename T>
-  OutputIterator replace_copy(InputIterator first, InputIterator last,
-                              OutputIterator result, const T &old_value,
-                              const T &new_value);
-
+template <typename InputIterator, typename OutputIterator, typename T>
+OutputIterator
+replace_copy(InputIterator first, InputIterator last, OutputIterator result, const T& old_value, const T& new_value);
 
 /*! \p replace_copy_if copies elements from the range <tt>[first, last)</tt> to the range
  *  <tt>[result, result + (last-first))</tt>, except that any element for which \p pred
@@ -547,14 +534,17 @@ template<typename InputIterator, typename OutputIterator, typename T>
  *  \return <tt>result + (last-first)</tt>
  *
  *  \tparam DerivedPolicy The name of the derived execution policy.
- *  \tparam InputIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/input_iterator">Input Iterator</a>,
+ *  \tparam InputIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/input_iterator">Input
+ Iterator</a>,
  *          and \p InputIterator's \c value_type is convertible to \p Predicate's \c argument_type.
- *  \tparam OutputIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/output_iterator">Output Iterator</a>.
+ *  \tparam OutputIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/output_iterator">Output
+ Iterator</a>.
  *  \tparam Predicate is a model of <a href="https://en.cppreference.com/w/cpp/concepts/predicate">Predicate</a>.
  *  \tparam T is a model of <a href="https://en.cppreference.com/w/cpp/named_req/CopyAssignable">Assignable</a>,
  *          and \p T is convertible to \p OutputIterator's \c value_type.
  *
- *  \pre \p first may equal \p result, but the ranges <tt>[first, last)</tt> and <tt>[result, result + (last - first))</tt> shall not overlap otherwise.
+ *  \pre \p first may equal \p result, but the ranges <tt>[first, last)</tt> and <tt>[result, result + (last -
+ first))</tt> shall not overlap otherwise.
  *
  *  \code
  *  #include <thrust/replace.h>
@@ -591,14 +581,14 @@ template<typename InputIterator, typename OutputIterator, typename T>
  *  \see \c replace_if
  *  \see \c replace_copy
  */
-template<typename DerivedPolicy, typename InputIterator, typename OutputIterator, typename Predicate, typename T>
-_CCCL_HOST_DEVICE
-  OutputIterator replace_copy_if(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
-                                 InputIterator first, InputIterator last,
-                                 OutputIterator result,
-                                 Predicate pred,
-                                 const T &new_value);
-
+template <typename DerivedPolicy, typename InputIterator, typename OutputIterator, typename Predicate, typename T>
+_CCCL_HOST_DEVICE OutputIterator replace_copy_if(
+  const thrust::detail::execution_policy_base<DerivedPolicy>& exec,
+  InputIterator first,
+  InputIterator last,
+  OutputIterator result,
+  Predicate pred,
+  const T& new_value);
 
 /*! \p replace_copy_if copies elements from the range <tt>[first, last)</tt> to the range
  *  <tt>[result, result + (last-first))</tt>, except that any element for which \p pred
@@ -615,14 +605,17 @@ _CCCL_HOST_DEVICE
  *  \param new_value The replacement value to assign <tt>pred(*i)</tt> evaluates to \c true.
  *  \return <tt>result + (last-first)</tt>
  *
- *  \tparam InputIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/input_iterator">Input Iterator</a>,
+ *  \tparam InputIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/input_iterator">Input
+ Iterator</a>,
  *          and \p InputIterator's \c value_type is convertible to \p Predicate's \c argument_type.
- *  \tparam OutputIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/output_iterator">Output Iterator</a>.
+ *  \tparam OutputIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/output_iterator">Output
+ Iterator</a>.
  *  \tparam Predicate is a model of <a href="https://en.cppreference.com/w/cpp/concepts/predicate">Predicate</a>.
  *  \tparam T is a model of <a href="https://en.cppreference.com/w/cpp/named_req/CopyAssignable">Assignable</a>,
  *          and \p T is convertible to \p OutputIterator's \c value_type.
  *
- *  \pre \p first may equal \p result, but the ranges <tt>[first, last)</tt> and <tt>[result, result + (last - first))</tt> shall not overlap otherwise.
+ *  \pre \p first may equal \p result, but the ranges <tt>[first, last)</tt> and <tt>[result, result + (last -
+ first))</tt> shall not overlap otherwise.
  *
  *  \code
  *  #include <thrust/replace.h>
@@ -658,12 +651,9 @@ _CCCL_HOST_DEVICE
  *  \see \c replace_if
  *  \see \c replace_copy
  */
-template<typename InputIterator, typename OutputIterator, typename Predicate, typename T>
-  OutputIterator replace_copy_if(InputIterator first, InputIterator last,
-                                 OutputIterator result,
-                                 Predicate pred,
-                                 const T &new_value);
-
+template <typename InputIterator, typename OutputIterator, typename Predicate, typename T>
+OutputIterator
+replace_copy_if(InputIterator first, InputIterator last, OutputIterator result, Predicate pred, const T& new_value);
 
 /*! This version of \p replace_copy_if copies elements from the range <tt>[first, last)</tt> to the range
  *  <tt>[result, result + (last-first))</tt>, except that any element whose corresponding stencil
@@ -685,16 +675,18 @@ template<typename InputIterator, typename OutputIterator, typename Predicate, ty
  *  \return <tt>result + (last-first)</tt>
  *
  *  \tparam DerivedPolicy The name of the derived execution policy.
- *  \tparam InputIterator1 is a model of <a href="https://en.cppreference.com/w/cpp/iterator/input_iterator">Input Iterator</a>.
- *  \tparam InputIterator2 is a model of <a href="https://en.cppreference.com/w/cpp/iterator/input_iterator">Input Iterator</a>
- *                         and \p InputIterator2's \c value_type is convertible to \p Predicate's \c argument_type.
- *  \tparam OutputIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/output_iterator">Output Iterator</a>.
- *  \tparam Predicate is a model of <a href="https://en.cppreference.com/w/cpp/concepts/predicate">Predicate</a>.
- *  \tparam T is a model of <a href="https://en.cppreference.com/w/cpp/named_req/CopyAssignable">Assignable</a>,
- *          and \p T is convertible to \p OutputIterator's \c value_type.
+ *  \tparam InputIterator1 is a model of <a href="https://en.cppreference.com/w/cpp/iterator/input_iterator">Input
+ * Iterator</a>. \tparam InputIterator2 is a model of <a
+ * href="https://en.cppreference.com/w/cpp/iterator/input_iterator">Input Iterator</a> and \p InputIterator2's \c
+ * value_type is convertible to \p Predicate's \c argument_type. \tparam OutputIterator is a model of <a
+ * href="https://en.cppreference.com/w/cpp/iterator/output_iterator">Output Iterator</a>. \tparam Predicate is a model
+ * of <a href="https://en.cppreference.com/w/cpp/concepts/predicate">Predicate</a>. \tparam T is a model of <a
+ * href="https://en.cppreference.com/w/cpp/named_req/CopyAssignable">Assignable</a>, and \p T is convertible to \p
+ * OutputIterator's \c value_type.
  *
- *  \pre \p first may equal \p result, but the ranges <tt>[first, last)</tt> and <tt>[result, result + (last - first))</tt> shall not overlap otherwise.
- *  \pre \p stencil may equal \p result, but the ranges <tt>[stencil, stencil + (last - first))</tt> and <tt>[result, result + (last - first))</tt> shall not overlap otherwise.
+ *  \pre \p first may equal \p result, but the ranges <tt>[first, last)</tt> and <tt>[result, result + (last -
+ * first))</tt> shall not overlap otherwise. \pre \p stencil may equal \p result, but the ranges <tt>[stencil, stencil +
+ * (last - first))</tt> and <tt>[result, result + (last - first))</tt> shall not overlap otherwise.
  *
  *  \code
  *  #include <thrust/replace.h>
@@ -735,15 +727,20 @@ template<typename InputIterator, typename OutputIterator, typename Predicate, ty
  *  \see \c replace_copy
  *  \see \c replace_if
  */
-template<typename DerivedPolicy, typename InputIterator1, typename InputIterator2, typename OutputIterator, typename Predicate, typename T>
-_CCCL_HOST_DEVICE
-  OutputIterator replace_copy_if(const thrust::detail::execution_policy_base<DerivedPolicy> &exec,
-                                 InputIterator1 first, InputIterator1 last,
-                                 InputIterator2 stencil,
-                                 OutputIterator result,
-                                 Predicate pred,
-                                 const T &new_value);
-
+template <typename DerivedPolicy,
+          typename InputIterator1,
+          typename InputIterator2,
+          typename OutputIterator,
+          typename Predicate,
+          typename T>
+_CCCL_HOST_DEVICE OutputIterator replace_copy_if(
+  const thrust::detail::execution_policy_base<DerivedPolicy>& exec,
+  InputIterator1 first,
+  InputIterator1 last,
+  InputIterator2 stencil,
+  OutputIterator result,
+  Predicate pred,
+  const T& new_value);
 
 /*! This version of \p replace_copy_if copies elements from the range <tt>[first, last)</tt> to the range
  *  <tt>[result, result + (last-first))</tt>, except that any element whose corresponding stencil
@@ -761,16 +758,18 @@ _CCCL_HOST_DEVICE
  *  \param new_value The replacement value to assign when <tt>pred(*s)</tt> evaluates to \c true.
  *  \return <tt>result + (last-first)</tt>
  *
- *  \tparam InputIterator1 is a model of <a href="https://en.cppreference.com/w/cpp/iterator/input_iterator">Input Iterator</a>.
- *  \tparam InputIterator2 is a model of <a href="https://en.cppreference.com/w/cpp/iterator/input_iterator">Input Iterator</a>
- *                         and \p InputIterator2's \c value_type is convertible to \p Predicate's \c argument_type.
- *  \tparam OutputIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/output_iterator">Output Iterator</a>.
- *  \tparam Predicate is a model of <a href="https://en.cppreference.com/w/cpp/concepts/predicate">Predicate</a>.
- *  \tparam T is a model of <a href="https://en.cppreference.com/w/cpp/named_req/CopyAssignable">Assignable</a>,
- *          and \p T is convertible to \p OutputIterator's \c value_type.
+ *  \tparam InputIterator1 is a model of <a href="https://en.cppreference.com/w/cpp/iterator/input_iterator">Input
+ * Iterator</a>. \tparam InputIterator2 is a model of <a
+ * href="https://en.cppreference.com/w/cpp/iterator/input_iterator">Input Iterator</a> and \p InputIterator2's \c
+ * value_type is convertible to \p Predicate's \c argument_type. \tparam OutputIterator is a model of <a
+ * href="https://en.cppreference.com/w/cpp/iterator/output_iterator">Output Iterator</a>. \tparam Predicate is a model
+ * of <a href="https://en.cppreference.com/w/cpp/concepts/predicate">Predicate</a>. \tparam T is a model of <a
+ * href="https://en.cppreference.com/w/cpp/named_req/CopyAssignable">Assignable</a>, and \p T is convertible to \p
+ * OutputIterator's \c value_type.
  *
- *  \pre \p first may equal \p result, but the ranges <tt>[first, last)</tt> and <tt>[result, result + (last - first))</tt> shall not overlap otherwise.
- *  \pre \p stencil may equal \p result, but the ranges <tt>[stencil, stencil + (last - first))</tt> and <tt>[result, result + (last - first))</tt> shall not overlap otherwise.
+ *  \pre \p first may equal \p result, but the ranges <tt>[first, last)</tt> and <tt>[result, result + (last -
+ * first))</tt> shall not overlap otherwise. \pre \p stencil may equal \p result, but the ranges <tt>[stencil, stencil +
+ * (last - first))</tt> and <tt>[result, result + (last - first))</tt> shall not overlap otherwise.
  *
  *  \code
  *  #include <thrust/replace.h>
@@ -810,13 +809,14 @@ _CCCL_HOST_DEVICE
  *  \see \c replace_copy
  *  \see \c replace_if
  */
-template<typename InputIterator1, typename InputIterator2, typename OutputIterator, typename Predicate, typename T>
-  OutputIterator replace_copy_if(InputIterator1 first, InputIterator1 last,
-                                 InputIterator2 stencil,
-                                 OutputIterator result,
-                                 Predicate pred,
-                                 const T &new_value);
-
+template <typename InputIterator1, typename InputIterator2, typename OutputIterator, typename Predicate, typename T>
+OutputIterator replace_copy_if(
+  InputIterator1 first,
+  InputIterator1 last,
+  InputIterator2 stencil,
+  OutputIterator result,
+  Predicate pred,
+  const T& new_value);
 
 /*! \} // end replacing
  *  \} // transformations
