@@ -27,32 +27,31 @@
 #endif // no system header
 
 #if THRUST_DEVICE_COMPILER == THRUST_DEVICE_COMPILER_NVCC
-#include <thrust/system/cuda/config.h>
-#include <thrust/system/cuda/detail/cross_system.h>
-#include <thrust/detail/raw_pointer_cast.h>
-#include <thrust/iterator/iterator_traits.h>
+#  include <thrust/system/cuda/config.h>
 
-#include <nv/target>
+#  include <thrust/detail/raw_pointer_cast.h>
+#  include <thrust/iterator/iterator_traits.h>
+#  include <thrust/system/cuda/detail/cross_system.h>
+
+#  include <nv/target>
 
 THRUST_NAMESPACE_BEGIN
-namespace cuda_cub {
-
+namespace cuda_cub
+{
 
 namespace
 {
 
-
-template<typename DerivedPolicy, typename Pointer>
-inline _CCCL_HOST_DEVICE
-  typename thrust::iterator_value<Pointer>::type
-    get_value_msvc2005_war(execution_policy<DerivedPolicy> &exec, Pointer ptr)
+template <typename DerivedPolicy, typename Pointer>
+inline _CCCL_HOST_DEVICE typename thrust::iterator_value<Pointer>::type
+get_value_msvc2005_war(execution_policy<DerivedPolicy>& exec, Pointer ptr)
 {
   typedef typename thrust::iterator_value<Pointer>::type result_type;
 
   // XXX war nvbugs/881631
   struct war_nvbugs_881631
   {
-    _CCCL_HOST inline static result_type host_path(execution_policy<DerivedPolicy> &exec, Pointer ptr)
+    _CCCL_HOST inline static result_type host_path(execution_policy<DerivedPolicy>& exec, Pointer ptr)
     {
       // when called from host code, implement with assign_value
       // note that this requires a type with default constructor
@@ -65,30 +64,26 @@ inline _CCCL_HOST_DEVICE
       return result;
     }
 
-    _CCCL_DEVICE inline static result_type device_path(execution_policy<DerivedPolicy> &, Pointer ptr)
+    _CCCL_DEVICE inline static result_type device_path(execution_policy<DerivedPolicy>&, Pointer ptr)
     {
       // when called from device code, just do simple deref
       return *thrust::raw_pointer_cast(ptr);
     }
   };
 
-  NV_IF_TARGET(NV_IS_HOST,
-               (return war_nvbugs_881631::host_path(exec, ptr);),
-               (return war_nvbugs_881631::device_path(exec, ptr);))
+  NV_IF_TARGET(
+    NV_IS_HOST, (return war_nvbugs_881631::host_path(exec, ptr);), (return war_nvbugs_881631::device_path(exec, ptr);))
 } // end get_value_msvc2005_war()
-} // end anon namespace
+} // namespace
 
-
-template<typename DerivedPolicy, typename Pointer>
-inline _CCCL_HOST_DEVICE
-  typename thrust::iterator_value<Pointer>::type
-    get_value(execution_policy<DerivedPolicy> &exec, Pointer ptr)
+template <typename DerivedPolicy, typename Pointer>
+inline _CCCL_HOST_DEVICE typename thrust::iterator_value<Pointer>::type
+get_value(execution_policy<DerivedPolicy>& exec, Pointer ptr)
 {
-  return get_value_msvc2005_war(exec,ptr);
+  return get_value_msvc2005_war(exec, ptr);
 } // end get_value()
 
-
-} // end cuda_cub
+} // namespace cuda_cub
 THRUST_NAMESPACE_END
 
 #endif
