@@ -37,66 +37,42 @@
 #endif // no system header
 
 #if THRUST_DEVICE_COMPILER == THRUST_DEVICE_COMPILER_NVCC
-#include <iterator>
-#include <thrust/system/cuda/detail/reduce.h>
-#include <thrust/detail/minmax.h>
-#include <thrust/distance.h>
+#  include <thrust/detail/minmax.h>
+#  include <thrust/distance.h>
+#  include <thrust/system/cuda/detail/reduce.h>
+
+#  include <iterator>
 
 THRUST_NAMESPACE_BEGIN
 
-namespace cuda_cub {
+namespace cuda_cub
+{
 
-template <class Derived,
-          class InputIt1,
-          class InputIt2,
-          class T,
-          class ReduceOp,
-          class ProductOp>
-T _CCCL_HOST_DEVICE
-inner_product(execution_policy<Derived> &policy,
-              InputIt1                   first1,
-              InputIt1                   last1,
-              InputIt2                   first2,
-              T                          init,
-              ReduceOp                   reduce_op,
-              ProductOp                  product_op)
+template <class Derived, class InputIt1, class InputIt2, class T, class ReduceOp, class ProductOp>
+T _CCCL_HOST_DEVICE inner_product(
+  execution_policy<Derived>& policy,
+  InputIt1 first1,
+  InputIt1 last1,
+  InputIt2 first2,
+  T init,
+  ReduceOp reduce_op,
+  ProductOp product_op)
 {
   typedef typename iterator_traits<InputIt1>::difference_type size_type;
   size_type num_items = static_cast<size_type>(thrust::distance(first1, last1));
-  typedef transform_pair_of_input_iterators_t<T,
-                                              InputIt1,
-                                              InputIt2,
-                                              ProductOp>
-      binop_iterator_t;
+  typedef transform_pair_of_input_iterators_t<T, InputIt1, InputIt2, ProductOp> binop_iterator_t;
 
-  return cuda_cub::reduce_n(policy,
-                            binop_iterator_t(first1, first2, product_op),
-                            num_items,
-                            init,
-                            reduce_op);
+  return cuda_cub::reduce_n(policy, binop_iterator_t(first1, first2, product_op), num_items, init, reduce_op);
 }
 
-template <class Derived,
-          class InputIt1,
-          class InputIt2,
-          class T>
+template <class Derived, class InputIt1, class InputIt2, class T>
 T _CCCL_HOST_DEVICE
-inner_product(execution_policy<Derived> &policy,
-              InputIt1                   first1,
-              InputIt1                   last1,
-              InputIt2                   first2,
-              T                          init)
+inner_product(execution_policy<Derived>& policy, InputIt1 first1, InputIt1 last1, InputIt2 first2, T init)
 {
-  return cuda_cub::inner_product(policy,
-                                 first1,
-                                 last1,
-                                 first2,
-                                 init,
-                                 plus<T>(),
-                                 multiplies<T>());
+  return cuda_cub::inner_product(policy, first1, last1, first2, init, plus<T>(), multiplies<T>());
 }
 
-}    // namespace cuda_cub
+} // namespace cuda_cub
 
 THRUST_NAMESPACE_END
 #endif
