@@ -28,21 +28,20 @@
 
 #if THRUST_DEVICE_COMPILER == THRUST_DEVICE_COMPILER_NVCC
 
-#include <thrust/system/cuda/config.h>
+#  include <thrust/system/cuda/config.h>
 
-#include <thrust/detail/raw_pointer_cast.h>
-#include <thrust/system/cuda/detail/execution_policy.h>
-#include <thrust/swap.h>
+#  include <thrust/detail/raw_pointer_cast.h>
+#  include <thrust/swap.h>
+#  include <thrust/system/cuda/detail/execution_policy.h>
 
-#include <nv/target>
+#  include <nv/target>
 
 THRUST_NAMESPACE_BEGIN
-namespace cuda_cub {
+namespace cuda_cub
+{
 
-
-template<typename DerivedPolicy, typename Pointer1, typename Pointer2>
-inline _CCCL_HOST_DEVICE
-void iter_swap(thrust::cuda::execution_policy<DerivedPolicy> &, Pointer1 a, Pointer2 b)
+template <typename DerivedPolicy, typename Pointer1, typename Pointer2>
+inline _CCCL_HOST_DEVICE void iter_swap(thrust::cuda::execution_policy<DerivedPolicy>&, Pointer1 a, Pointer2 b)
 {
   // XXX war nvbugs/881631
   struct war_nvbugs_881631
@@ -55,20 +54,14 @@ void iter_swap(thrust::cuda::execution_policy<DerivedPolicy> &, Pointer1 a, Poin
     _CCCL_DEVICE inline static void device_path(Pointer1 a, Pointer2 b)
     {
       using thrust::swap;
-      swap(*thrust::raw_pointer_cast(a),
-           *thrust::raw_pointer_cast(b));
+      swap(*thrust::raw_pointer_cast(a), *thrust::raw_pointer_cast(b));
     }
   };
 
-  NV_IF_TARGET(NV_IS_HOST, (
-    war_nvbugs_881631::host_path(a, b);
-  ), (
-    war_nvbugs_881631::device_path(a, b);
-  ));
+  NV_IF_TARGET(NV_IS_HOST, (war_nvbugs_881631::host_path(a, b);), (war_nvbugs_881631::device_path(a, b);));
 
 } // end iter_swap()
 
-
-} // end cuda_cub
+} // namespace cuda_cub
 THRUST_NAMESPACE_END
 #endif
