@@ -37,88 +37,55 @@
 #endif // no system header
 
 #if THRUST_DEVICE_COMPILER == THRUST_DEVICE_COMPILER_NVCC
-#include <thrust/system/cuda/config.h>
-#include <thrust/system/cuda/detail/execution_policy.h>
-#include <thrust/pair.h>
-#include <thrust/distance.h>
+#  include <thrust/system/cuda/config.h>
+
+#  include <thrust/distance.h>
+#  include <thrust/pair.h>
+#  include <thrust/system/cuda/detail/execution_policy.h>
 
 THRUST_NAMESPACE_BEGIN
-namespace cuda_cub {
+namespace cuda_cub
+{
 
-template <class Derived,
-          class InputIt1,
-          class InputIt2,
-          class BinaryPred>
+template <class Derived, class InputIt1, class InputIt2, class BinaryPred>
 pair<InputIt1, InputIt2> _CCCL_HOST_DEVICE
-mismatch(execution_policy<Derived>& policy,
-         InputIt1                   first1,
-         InputIt1                   last1,
-         InputIt2                   first2,
-         BinaryPred                 binary_pred);
+mismatch(execution_policy<Derived>& policy, InputIt1 first1, InputIt1 last1, InputIt2 first2, BinaryPred binary_pred);
 
-template <class Derived,
-          class InputIt1,
-          class InputIt2>
+template <class Derived, class InputIt1, class InputIt2>
 pair<InputIt1, InputIt2> _CCCL_HOST_DEVICE
-mismatch(execution_policy<Derived>& policy,
-         InputIt1                   first1,
-         InputIt1                   last1,
-         InputIt2                   first2);
-} // namespace cuda_
+mismatch(execution_policy<Derived>& policy, InputIt1 first1, InputIt1 last1, InputIt2 first2);
+} // namespace cuda_cub
 THRUST_NAMESPACE_END
 
-#include <thrust/system/cuda/detail/find.h>
+#  include <thrust/system/cuda/detail/find.h>
 
 THRUST_NAMESPACE_BEGIN
-namespace cuda_cub {
-
-template <class Derived,
-          class InputIt1,
-          class InputIt2,
-          class BinaryPred>
-pair<InputIt1, InputIt2> _CCCL_HOST_DEVICE
-mismatch(execution_policy<Derived>& policy,
-         InputIt1                   first1,
-         InputIt1                   last1,
-         InputIt2                   first2,
-         BinaryPred                 binary_pred)
+namespace cuda_cub
 {
-  typedef transform_pair_of_input_iterators_t<bool,
-                                              InputIt1,
-                                              InputIt2,
-                                              BinaryPred>
-      transform_t;
+
+template <class Derived, class InputIt1, class InputIt2, class BinaryPred>
+pair<InputIt1, InputIt2> _CCCL_HOST_DEVICE
+mismatch(execution_policy<Derived>& policy, InputIt1 first1, InputIt1 last1, InputIt2 first2, BinaryPred binary_pred)
+{
+  typedef transform_pair_of_input_iterators_t<bool, InputIt1, InputIt2, BinaryPred> transform_t;
 
   transform_t transform_first = transform_t(first1, first2, binary_pred);
 
-  transform_t result = cuda_cub::find_if_not(policy,
-                                          transform_first,
-                                          transform_first + thrust::distance(first1, last1),
-                                          identity());
+  transform_t result =
+    cuda_cub::find_if_not(policy, transform_first, transform_first + thrust::distance(first1, last1), identity());
 
-  return thrust::make_pair(first1 + thrust::distance(transform_first,result),
-                           first2 + thrust::distance(transform_first,result));
+  return thrust::make_pair(first1 + thrust::distance(transform_first, result),
+                           first2 + thrust::distance(transform_first, result));
 }
 
-template <class Derived,
-          class InputIt1,
-          class InputIt2>
+template <class Derived, class InputIt1, class InputIt2>
 pair<InputIt1, InputIt2> _CCCL_HOST_DEVICE
-mismatch(execution_policy<Derived>& policy,
-         InputIt1                   first1,
-         InputIt1                   last1,
-         InputIt2                   first2)
+mismatch(execution_policy<Derived>& policy, InputIt1 first1, InputIt1 last1, InputIt2 first2)
 {
   typedef typename thrust::iterator_value<InputIt1>::type InputType1;
-  return cuda_cub::mismatch(policy,
-                         first1,
-                         last1,
-                         first2,
-                         equal_to<InputType1>());
+  return cuda_cub::mismatch(policy, first1, last1, first2, equal_to<InputType1>());
 }
 
-
-
 } // namespace cuda_cub
 THRUST_NAMESPACE_END
 #endif
