@@ -40,25 +40,27 @@
 #include <thrust/system/cuda/detail/par.h>
 
 THRUST_NAMESPACE_BEGIN
-namespace cuda_cub {
+namespace cuda_cub
+{
 
 template <int PAR>
-struct has_par : thrust::detail::true_type {};
+struct has_par : thrust::detail::true_type
+{};
 
 template <>
-struct has_par<0> : thrust::detail::false_type {};
+struct has_par<0> : thrust::detail::false_type
+{};
 
-template<class Policy>
+template <class Policy>
 struct cvt_to_seq_impl
 {
   typedef thrust::detail::seq_t seq_t;
 
-  static seq_t _CCCL_HOST_DEVICE
-  doit(Policy&)
+  static seq_t _CCCL_HOST_DEVICE doit(Policy&)
   {
     return seq_t();
   }
-};    // cvt_to_seq_impl
+}; // cvt_to_seq_impl
 
 #if 0
 template <class Allocator>
@@ -84,11 +86,10 @@ struct cvt_to_seq_impl<
 #endif
 
 template <class Policy>
-typename cvt_to_seq_impl<Policy>::seq_t _CCCL_HOST_DEVICE
-cvt_to_seq(Policy& policy)
+typename cvt_to_seq_impl<Policy>::seq_t _CCCL_HOST_DEVICE cvt_to_seq(Policy& policy)
 {
   return cvt_to_seq_impl<Policy>::doit(policy);
 }
 
-} // namespace cuda_
+} // namespace cuda_cub
 THRUST_NAMESPACE_END
