@@ -37,74 +37,69 @@
 #endif // no system header
 
 #if THRUST_DEVICE_COMPILER == THRUST_DEVICE_COMPILER_NVCC
-#include <iterator>
-#include <thrust/system/cuda/detail/transform.h>
-#include <thrust/system/cuda/detail/par_to_seq.h>
-#include <thrust/swap.h>
-#include <thrust/system/cuda/detail/parallel_for.h>
-#include <thrust/distance.h>
+#  include <thrust/distance.h>
+#  include <thrust/swap.h>
+#  include <thrust/system/cuda/detail/par_to_seq.h>
+#  include <thrust/system/cuda/detail/parallel_for.h>
+#  include <thrust/system/cuda/detail/transform.h>
+
+#  include <iterator>
 
 THRUST_NAMESPACE_BEGIN
 
-namespace cuda_cub {
+namespace cuda_cub
+{
 
-namespace __swap_ranges {
+namespace __swap_ranges
+{
 
+template <class ItemsIt1, class ItemsIt2>
+struct swap_f
+{
+  ItemsIt1 items1;
+  ItemsIt2 items2;
 
-  template <class ItemsIt1, class ItemsIt2>
-  struct swap_f
+  typedef typename iterator_traits<ItemsIt1>::value_type value1_type;
+  typedef typename iterator_traits<ItemsIt2>::value_type value2_type;
+
+  THRUST_FUNCTION
+  swap_f(ItemsIt1 items1_, ItemsIt2 items2_)
+      : items1(items1_)
+      , items2(items2_)
+  {}
+
+  template <class Size>
+  void THRUST_DEVICE_FUNCTION operator()(Size idx)
   {
-    ItemsIt1 items1;
-    ItemsIt2 items2;
+    value1_type item1 = items1[idx];
+    value2_type item2 = items2[idx];
+    // XXX thrust::swap is buggy
+    // if reference_type of ItemIt1/ItemsIt2
+    // is a proxy reference, then KABOOM!
+    // to avoid this, just copy the value first before swap
+    // *todo* specialize on real & proxy references
+    using thrust::swap;
+    swap(item1, item2);
+    items1[idx] = item1;
+    items2[idx] = item2;
+  }
+};
+} // namespace __swap_ranges
 
-    typedef  typename iterator_traits<ItemsIt1>::value_type value1_type;
-    typedef  typename iterator_traits<ItemsIt2>::value_type value2_type;
-
-    THRUST_FUNCTION
-    swap_f(ItemsIt1 items1_, ItemsIt2 items2_)
-        : items1(items1_), items2(items2_) {}
-
-    template<class Size>
-    void THRUST_DEVICE_FUNCTION operator()(Size idx)
-    {
-      value1_type item1 = items1[idx];
-      value2_type item2 = items2[idx];
-      // XXX thrust::swap is buggy
-      // if reference_type of ItemIt1/ItemsIt2
-      // is a proxy reference, then KABOOM!
-      // to avoid this, just copy the value first before swap
-      // *todo* specialize on real & proxy references
-      using thrust::swap;
-      swap(item1, item2);
-      items1[idx] = item1;
-      items2[idx] = item2;
-    }
-  };
-}    // namespace __swap_ranges
-
-template <class Derived,
-          class ItemsIt1,
-          class ItemsIt2>
+template <class Derived, class ItemsIt1, class ItemsIt2>
 ItemsIt2 _CCCL_HOST_DEVICE
-swap_ranges(execution_policy<Derived> &policy,
-            ItemsIt1                   first1,
-            ItemsIt1                   last1,
-            ItemsIt2                   first2)
+swap_ranges(execution_policy<Derived>& policy, ItemsIt1 first1, ItemsIt1 last1, ItemsIt2 first2)
 {
   typedef typename iterator_traits<ItemsIt1>::difference_type size_type;
 
   size_type num_items = static_cast<size_type>(thrust::distance(first1, last1));
 
-  cuda_cub::parallel_for(policy,
-                         __swap_ranges::swap_f<ItemsIt1,
-                                               ItemsIt2>(first1, first2),
-                         num_items);
+  cuda_cub::parallel_for(policy, __swap_ranges::swap_f<ItemsIt1, ItemsIt2>(first1, first2), num_items);
 
   return first2 + num_items;
 }
 
-
-}    // namespace cuda_cub
+} // namespace cuda_cub
 
 THRUST_NAMESPACE_END
 #endif
