@@ -37,83 +37,72 @@
 #endif // no system header
 
 #if THRUST_DEVICE_COMPILER == THRUST_DEVICE_COMPILER_NVCC
-#include <iterator>
-#include <thrust/distance.h>
-#include <thrust/system/cuda/detail/execution_policy.h>
-#include <thrust/system/cuda/detail/util.h>
-#include <thrust/system/cuda/detail/parallel_for.h>
+#  include <thrust/distance.h>
+#  include <thrust/system/cuda/detail/execution_policy.h>
+#  include <thrust/system/cuda/detail/parallel_for.h>
+#  include <thrust/system/cuda/detail/util.h>
+
+#  include <iterator>
 
 THRUST_NAMESPACE_BEGIN
 
-namespace cuda_cub {
-
-namespace __uninitialized_copy {
-
-  template <class InputIt, class OutputIt>
-  struct functor
-  {
-    InputIt  input;
-    OutputIt output;
-
-    typedef typename iterator_traits<InputIt>::value_type  InputType;
-    typedef typename iterator_traits<OutputIt>::value_type OutputType;
-
-    THRUST_FUNCTION
-    functor(InputIt input_, OutputIt output_)
-        : input(input_), output(output_) {}
-
-    template<class Size>
-    void THRUST_DEVICE_FUNCTION operator()(Size idx)
-    {
-      InputType const &in  = raw_reference_cast(input[idx]);
-      OutputType &     out = raw_reference_cast(output[idx]);
-
-#if defined(__CUDA__) && defined(__clang__)
-      // XXX unsafe, but clang is seemngly unable to call in-place new
-      out = in;
-#else
-      ::new (static_cast<void *>(&out)) OutputType(in);
-#endif
-    }
-  };    // struct functor
-
-}    // namespace __uninitialized_copy
-
-template <class Derived,
-          class InputIt,
-          class Size,
-          class OutputIt>
-OutputIt _CCCL_HOST_DEVICE
-uninitialized_copy_n(execution_policy<Derived> &policy,
-                     InputIt                    first,
-                     Size                       count,
-                     OutputIt                   result)
+namespace cuda_cub
 {
-  typedef __uninitialized_copy::functor<InputIt,OutputIt> functor_t;
 
-  cuda_cub::parallel_for(policy,
-                         functor_t(first, result),
-                         count);
+namespace __uninitialized_copy
+{
+
+template <class InputIt, class OutputIt>
+struct functor
+{
+  InputIt input;
+  OutputIt output;
+
+  typedef typename iterator_traits<InputIt>::value_type InputType;
+  typedef typename iterator_traits<OutputIt>::value_type OutputType;
+
+  THRUST_FUNCTION
+  functor(InputIt input_, OutputIt output_)
+      : input(input_)
+      , output(output_)
+  {}
+
+  template <class Size>
+  void THRUST_DEVICE_FUNCTION operator()(Size idx)
+  {
+    InputType const& in = raw_reference_cast(input[idx]);
+    OutputType& out     = raw_reference_cast(output[idx]);
+
+#  if defined(__CUDA__) && defined(__clang__)
+    // XXX unsafe, but clang is seemngly unable to call in-place new
+    out = in;
+#  else
+    ::new (static_cast<void*>(&out)) OutputType(in);
+#  endif
+  }
+}; // struct functor
+
+} // namespace __uninitialized_copy
+
+template <class Derived, class InputIt, class Size, class OutputIt>
+OutputIt _CCCL_HOST_DEVICE
+uninitialized_copy_n(execution_policy<Derived>& policy, InputIt first, Size count, OutputIt result)
+{
+  typedef __uninitialized_copy::functor<InputIt, OutputIt> functor_t;
+
+  cuda_cub::parallel_for(policy, functor_t(first, result), count);
 
   return result + count;
 }
 
-template <class Derived,
-          class InputIt,
-          class OutputIt>
+template <class Derived, class InputIt, class OutputIt>
 OutputIt _CCCL_HOST_DEVICE
-uninitialized_copy(execution_policy<Derived>& policy,
-                   InputIt                    first,
-                   InputIt                    last,
-                   OutputIt                   result)
+uninitialized_copy(execution_policy<Derived>& policy, InputIt first, InputIt last, OutputIt result)
 {
-  return cuda_cub::uninitialized_copy_n(policy,
-                                        first,
-                                        thrust::distance(first, last),
-                                        result);
+  return cuda_cub::uninitialized_copy_n(policy, first, thrust::distance(first, last), result);
 }
 
-}    // namespace cuda_
+} // namespace cuda_cub
 
 THRUST_NAMESPACE_END
 #endif
