@@ -25,10 +25,10 @@
 #elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_MSVC)
 #  pragma system_header
 #endif // no system header
-#include <thrust/system/detail/generic/tag.h>
 #include <thrust/detail/internal_functional.h>
 #include <thrust/find.h>
 #include <thrust/logical.h>
+#include <thrust/system/detail/generic/tag.h>
 
 THRUST_NAMESPACE_BEGIN
 namespace system
@@ -38,33 +38,28 @@ namespace detail
 namespace generic
 {
 
-
-template<typename ExecutionPolicy, typename InputIterator, typename Predicate>
-_CCCL_HOST_DEVICE
-bool all_of(thrust::execution_policy<ExecutionPolicy> &exec, InputIterator first, InputIterator last, Predicate pred)
+template <typename ExecutionPolicy, typename InputIterator, typename Predicate>
+_CCCL_HOST_DEVICE bool
+all_of(thrust::execution_policy<ExecutionPolicy>& exec, InputIterator first, InputIterator last, Predicate pred)
 {
   return thrust::find_if(exec, first, last, thrust::detail::not1(pred)) == last;
 }
 
-
-template<typename ExecutionPolicy, typename InputIterator, typename Predicate>
-_CCCL_HOST_DEVICE
-bool any_of(thrust::execution_policy<ExecutionPolicy> &exec, InputIterator first, InputIterator last, Predicate pred)
+template <typename ExecutionPolicy, typename InputIterator, typename Predicate>
+_CCCL_HOST_DEVICE bool
+any_of(thrust::execution_policy<ExecutionPolicy>& exec, InputIterator first, InputIterator last, Predicate pred)
 {
   return thrust::find_if(exec, first, last, pred) != last;
 }
 
-
-template<typename ExecutionPolicy, typename InputIterator, typename Predicate>
-_CCCL_HOST_DEVICE
-bool none_of(thrust::execution_policy<ExecutionPolicy> &exec, InputIterator first, InputIterator last, Predicate pred)
+template <typename ExecutionPolicy, typename InputIterator, typename Predicate>
+_CCCL_HOST_DEVICE bool
+none_of(thrust::execution_policy<ExecutionPolicy>& exec, InputIterator first, InputIterator last, Predicate pred)
 {
   return !thrust::any_of(exec, first, last, pred);
 }
 
-
-} // end generic
-} // end detail
-} // end system
+} // namespace generic
+} // namespace detail
+} // namespace system
 THRUST_NAMESPACE_END
-
