@@ -40,26 +40,25 @@ namespace detail
 namespace sequential
 {
 
-
 _CCCL_EXEC_CHECK_DISABLE
-template<typename DerivedPolicy,
-         typename InputIterator1,
-         typename InputIterator2,
-         typename OutputIterator,
-         typename Predicate>
-_CCCL_HOST_DEVICE
-  OutputIterator copy_if(sequential::execution_policy<DerivedPolicy> &,
-                         InputIterator1 first,
-                         InputIterator1 last,
-                         InputIterator2 stencil,
-                         OutputIterator result,
-                         Predicate pred)
+template <typename DerivedPolicy,
+          typename InputIterator1,
+          typename InputIterator2,
+          typename OutputIterator,
+          typename Predicate>
+_CCCL_HOST_DEVICE OutputIterator copy_if(
+  sequential::execution_policy<DerivedPolicy>&,
+  InputIterator1 first,
+  InputIterator1 last,
+  InputIterator2 stencil,
+  OutputIterator result,
+  Predicate pred)
 {
-  thrust::detail::wrapped_function<Predicate,bool> wrapped_pred(pred);
+  thrust::detail::wrapped_function<Predicate, bool> wrapped_pred(pred);
 
-  while(first != last)
+  while (first != last)
   {
-    if(wrapped_pred(*stencil))
+    if (wrapped_pred(*stencil))
     {
       *result = *first;
       ++result;
@@ -72,9 +71,7 @@ _CCCL_HOST_DEVICE
   return result;
 } // end copy_if()
 
-
 } // end namespace sequential
 } // end namespace detail
 } // end namespace system
 THRUST_NAMESPACE_END
-
