@@ -14,7 +14,6 @@
  *  limitations under the License.
  */
 
-
 /*! \file extrema.h
  *  \brief Sequential implementations of extrema functions.
  */
@@ -30,8 +29,8 @@
 #elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_MSVC)
 #  pragma system_header
 #endif // no system header
-#include <thrust/pair.h>
 #include <thrust/detail/function.h>
+#include <thrust/pair.h>
 #include <thrust/system/detail/sequential/execution_policy.h>
 
 THRUST_NAMESPACE_BEGIN
@@ -42,28 +41,19 @@ namespace detail
 namespace sequential
 {
 
-
 _CCCL_EXEC_CHECK_DISABLE
-template<typename DerivedPolicy,
-         typename ForwardIterator,
-         typename BinaryPredicate>
-_CCCL_HOST_DEVICE
-ForwardIterator min_element(sequential::execution_policy<DerivedPolicy> &,
-                            ForwardIterator first,
-                            ForwardIterator last,
-                            BinaryPredicate comp)
+template <typename DerivedPolicy, typename ForwardIterator, typename BinaryPredicate>
+_CCCL_HOST_DEVICE ForwardIterator min_element(
+  sequential::execution_policy<DerivedPolicy>&, ForwardIterator first, ForwardIterator last, BinaryPredicate comp)
 {
   // wrap comp
-  thrust::detail::wrapped_function<
-    BinaryPredicate,
-    bool
-  > wrapped_comp(comp);
+  thrust::detail::wrapped_function<BinaryPredicate, bool> wrapped_comp(comp);
 
   ForwardIterator imin = first;
 
-  for(; first != last; ++first)
+  for (; first != last; ++first)
   {
-    if(wrapped_comp(*first, *imin))
+    if (wrapped_comp(*first, *imin))
     {
       imin = first;
     }
@@ -72,28 +62,19 @@ ForwardIterator min_element(sequential::execution_policy<DerivedPolicy> &,
   return imin;
 }
 
-
 _CCCL_EXEC_CHECK_DISABLE
-template<typename DerivedPolicy,
-         typename ForwardIterator,
-         typename BinaryPredicate>
-_CCCL_HOST_DEVICE
-ForwardIterator max_element(sequential::execution_policy<DerivedPolicy> &,
-                            ForwardIterator first,
-                            ForwardIterator last,
-                            BinaryPredicate comp)
+template <typename DerivedPolicy, typename ForwardIterator, typename BinaryPredicate>
+_CCCL_HOST_DEVICE ForwardIterator max_element(
+  sequential::execution_policy<DerivedPolicy>&, ForwardIterator first, ForwardIterator last, BinaryPredicate comp)
 {
   // wrap comp
-  thrust::detail::wrapped_function<
-    BinaryPredicate,
-    bool
-  > wrapped_comp(comp);
+  thrust::detail::wrapped_function<BinaryPredicate, bool> wrapped_comp(comp);
 
   ForwardIterator imax = first;
 
-  for(; first != last; ++first)
+  for (; first != last; ++first)
   {
-    if(wrapped_comp(*imax, *first))
+    if (wrapped_comp(*imax, *first))
     {
       imax = first;
     }
@@ -102,34 +83,25 @@ ForwardIterator max_element(sequential::execution_policy<DerivedPolicy> &,
   return imax;
 }
 
-
 _CCCL_EXEC_CHECK_DISABLE
-template<typename DerivedPolicy,
-         typename ForwardIterator,
-         typename BinaryPredicate>
-_CCCL_HOST_DEVICE
-thrust::pair<ForwardIterator,ForwardIterator> minmax_element(sequential::execution_policy<DerivedPolicy> &,
-                                                             ForwardIterator first,
-                                                             ForwardIterator last,
-                                                             BinaryPredicate comp)
+template <typename DerivedPolicy, typename ForwardIterator, typename BinaryPredicate>
+_CCCL_HOST_DEVICE thrust::pair<ForwardIterator, ForwardIterator> minmax_element(
+  sequential::execution_policy<DerivedPolicy>&, ForwardIterator first, ForwardIterator last, BinaryPredicate comp)
 {
   // wrap comp
-  thrust::detail::wrapped_function<
-    BinaryPredicate,
-    bool
-  > wrapped_comp(comp);
+  thrust::detail::wrapped_function<BinaryPredicate, bool> wrapped_comp(comp);
 
   ForwardIterator imin = first;
   ForwardIterator imax = first;
 
-  for(; first != last; ++first)
+  for (; first != last; ++first)
   {
-    if(wrapped_comp(*first, *imin))
+    if (wrapped_comp(*first, *imin))
     {
       imin = first;
     }
 
-    if(wrapped_comp(*imax, *first))
+    if (wrapped_comp(*imax, *first))
     {
       imax = first;
     }
@@ -138,9 +110,7 @@ thrust::pair<ForwardIterator,ForwardIterator> minmax_element(sequential::executi
   return thrust::make_pair(imin, imax);
 }
 
-
 } // end namespace sequential
 } // end namespace detail
 } // end namespace system
 THRUST_NAMESPACE_END
-
