@@ -14,7 +14,6 @@
  *  limitations under the License.
  */
 
-
 /*! \file find.h
  *  \brief Sequential implementation of find_if.
  */
@@ -41,27 +40,20 @@ namespace detail
 namespace sequential
 {
 
-
 _CCCL_EXEC_CHECK_DISABLE
-template<typename DerivedPolicy,
-         typename InputIterator,
-         typename Predicate>
-_CCCL_HOST_DEVICE
-InputIterator find_if(execution_policy<DerivedPolicy> &,
-                      InputIterator first,
-                      InputIterator last,
-                      Predicate pred)
+template <typename DerivedPolicy, typename InputIterator, typename Predicate>
+_CCCL_HOST_DEVICE InputIterator
+find_if(execution_policy<DerivedPolicy>&, InputIterator first, InputIterator last, Predicate pred)
 {
   // wrap pred
-  thrust::detail::wrapped_function<
-    Predicate,
-    bool
-  > wrapped_pred(pred);
+  thrust::detail::wrapped_function<Predicate, bool> wrapped_pred(pred);
 
-  while(first != last)
+  while (first != last)
   {
     if (wrapped_pred(*first))
+    {
       return first;
+    }
 
     ++first;
   }
@@ -70,9 +62,7 @@ InputIterator find_if(execution_policy<DerivedPolicy> &,
   return first;
 }
 
-
 } // end namespace sequential
 } // end namespace detail
 } // end namespace system
 THRUST_NAMESPACE_END
-
