@@ -14,7 +14,6 @@
  *  limitations under the License.
  */
 
-
 /*! \file scan.h
  *  \brief Sequential implementations of scan functions.
  */
@@ -30,12 +29,12 @@
 #elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_MSVC)
 #  pragma system_header
 #endif // no system header
-#include <thrust/system/detail/sequential/execution_policy.h>
-#include <thrust/iterator/iterator_traits.h>
+#include <thrust/detail/function.h>
 #include <thrust/detail/type_traits.h>
 #include <thrust/detail/type_traits/function_traits.h>
 #include <thrust/detail/type_traits/iterator/is_output_iterator.h>
-#include <thrust/detail/function.h>
+#include <thrust/iterator/iterator_traits.h>
+#include <thrust/system/detail/sequential/execution_policy.h>
 
 THRUST_NAMESPACE_BEGIN
 namespace system
@@ -45,18 +44,14 @@ namespace detail
 namespace sequential
 {
 
-
 _CCCL_EXEC_CHECK_DISABLE
-template<typename DerivedPolicy,
-         typename InputIterator,
-         typename OutputIterator,
-         typename BinaryFunction>
-_CCCL_HOST_DEVICE
-  OutputIterator inclusive_scan(sequential::execution_policy<DerivedPolicy> &,
-                                InputIterator first,
-                                InputIterator last,
-                                OutputIterator result,
-                                BinaryFunction binary_op)
+template <typename DerivedPolicy, typename InputIterator, typename OutputIterator, typename BinaryFunction>
+_CCCL_HOST_DEVICE OutputIterator inclusive_scan(
+  sequential::execution_policy<DerivedPolicy>&,
+  InputIterator first,
+  InputIterator last,
+  OutputIterator result,
+  BinaryFunction binary_op)
 {
   using namespace thrust::detail;
 
@@ -64,66 +59,62 @@ _CCCL_HOST_DEVICE
   using ValueType = typename thrust::iterator_value<InputIterator>::type;
 
   // wrap binary_op
-  thrust::detail::wrapped_function<
-    BinaryFunction,
-    ValueType
-  > wrapped_binary_op(binary_op);
+  thrust::detail::wrapped_function<BinaryFunction, ValueType> wrapped_binary_op(binary_op);
 
-  if(first != last)
+  if (first != last)
   {
     ValueType sum = *first;
 
     *result = *first;
 
-    for(++first, ++result; first != last; ++first, ++result)
-      *result = sum = wrapped_binary_op(sum,*first);
-  }
-
-  return result;
-}
-
-
-_CCCL_EXEC_CHECK_DISABLE
-template<typename DerivedPolicy,
-         typename InputIterator,
-         typename OutputIterator,
-         typename InitialValueType,
-         typename BinaryFunction>
-_CCCL_HOST_DEVICE
-  OutputIterator exclusive_scan(sequential::execution_policy<DerivedPolicy> &,
-                                InputIterator first,
-                                InputIterator last,
-                                OutputIterator result,
-                                InitialValueType init,
-                                BinaryFunction binary_op)
-{
-  using namespace thrust::detail;
-
-  // Use the initial value type per https://wg21.link/P0571
-  using ValueType = InitialValueType;
-
-  if(first != last)
-  {
-    ValueType tmp = *first;  // temporary value allows in-situ scan
-    ValueType sum = init;
-
-    *result = sum;
-    sum = binary_op(sum, tmp);
-
-    for(++first, ++result; first != last; ++first, ++result)
+    for (++first, ++result; first != last; ++first, ++result)
     {
-      tmp = *first;
-      *result = sum;
-      sum = binary_op(sum, tmp);
+      *result = sum = wrapped_binary_op(sum, *first);
     }
   }
 
   return result;
 }
 
+_CCCL_EXEC_CHECK_DISABLE
+template <typename DerivedPolicy,
+          typename InputIterator,
+          typename OutputIterator,
+          typename InitialValueType,
+          typename BinaryFunction>
+_CCCL_HOST_DEVICE OutputIterator exclusive_scan(
+  sequential::execution_policy<DerivedPolicy>&,
+  InputIterator first,
+  InputIterator last,
+  OutputIterator result,
+  InitialValueType init,
+  BinaryFunction binary_op)
+{
+  using namespace thrust::detail;
+
+  // Use the initial value type per https://wg21.link/P0571
+  using ValueType = InitialValueType;
+
+  if (first != last)
+  {
+    ValueType tmp = *first; // temporary value allows in-situ scan
+    ValueType sum = init;
+
+    *result = sum;
+    sum     = binary_op(sum, tmp);
+
+    for (++first, ++result; first != last; ++first, ++result)
+    {
+      tmp     = *first;
+      *result = sum;
+      sum     = binary_op(sum, tmp);
+    }
+  }
+
+  return result;
+}
 
 } // end namespace sequential
 } // end namespace detail
 } // end namespace system
 THRUST_NAMESPACE_END
-
