@@ -25,10 +25,10 @@
 #elif defined(_CCCL_IMPLICIT_SYSTEM_HEADER_MSVC)
 #  pragma system_header
 #endif // no system header
+#include <thrust/detail/type_traits.h>
+#include <thrust/iterator/detail/any_system_tag.h>
 #include <thrust/system/cpp/detail/execution_policy.h>
 #include <thrust/system/tbb/detail/execution_policy.h>
-#include <thrust/iterator/detail/any_system_tag.h>
-#include <thrust/detail/type_traits.h>
 
 THRUST_NAMESPACE_BEGIN
 namespace system
@@ -49,58 +49,58 @@ namespace detail
 struct tag;
 
 // forward declaration of execution_policy
-template<typename> struct execution_policy;
+template <typename>
+struct execution_policy;
 
 // specialize execution_policy for tag
-template<>
-  struct execution_policy<tag>
-    : thrust::system::cpp::detail::execution_policy<tag>
+template <>
+struct execution_policy<tag> : thrust::system::cpp::detail::execution_policy<tag>
 {};
 
 // tag's definition comes before the
 // generic definition of execution_policy
-struct tag : execution_policy<tag> {};
+struct tag : execution_policy<tag>
+{};
 
 // allow conversion to tag when it is not a successor
-template<typename Derived>
-  struct execution_policy
-    : thrust::system::cpp::detail::execution_policy<Derived>
+template <typename Derived>
+struct execution_policy : thrust::system::cpp::detail::execution_policy<Derived>
 {
   typedef tag tag_type;
-  operator tag() const { return tag(); }
+  operator tag() const
+  {
+    return tag();
+  }
 };
 
-
 // overloads of select_system
 
 // XXX select_system(tbb, omp) & select_system(omp, tbb) are ambiguous
 //     because both convert to cpp without these overloads, which we
 //     arbitrarily define in the omp backend
 
-template<typename System1, typename System2>
-inline _CCCL_HOST_DEVICE
-  System1 select_system(execution_policy<System1> s, thrust::system::tbb::detail::execution_policy<System2>)
+template <typename System1, typename System2>
+inline _CCCL_HOST_DEVICE System1
+select_system(execution_policy<System1> s, thrust::system::tbb::detail::execution_policy<System2>)
 {
   return thrust::detail::derived_cast(s);
 } // end select_system()
 
-
-template<typename System1, typename System2>
-inline _CCCL_HOST_DEVICE
-  System2 select_system(thrust::system::tbb::detail::execution_policy<System1>, execution_policy<System2> s)
+template <typename System1, typename System2>
+inline _CCCL_HOST_DEVICE System2
+select_system(thrust::system::tbb::detail::execution_policy<System1>, execution_policy<System2> s)
 {
   return thrust::detail::derived_cast(s);
 } // end select_system()
 
-
-} // end detail
+} // namespace detail
 
 // alias execution_policy and tag here
 using thrust::system::omp::detail::execution_policy;
 using thrust::system::omp::detail::tag;
 
-} // end omp
-} // end system
+} // namespace omp
+} // namespace system
 
 // alias items at top-level
 namespace omp
@@ -109,6 +109,5 @@ namespace omp
 using thrust::system::omp::execution_policy;
 using thrust::system::omp::tag;
 
-} // end omp
+} // namespace omp
 THRUST_NAMESPACE_END
-
