@@ -40,13 +40,13 @@
 #include <utility>
 
 #if defined(_CCCL_COMPILER_MSVC) && _MSC_VER < 1916 // MSVC 2017 version 15.9
-  #include <vector>
-  #include <string>
-  #include <array>
+#  include <array>
+#  include <string>
+#  include <vector>
 
-  #if _CCCL_STD_VER >= 2017
-    #include <string_view>
-  #endif
+#  if _CCCL_STD_VER >= 2017
+#    include <string_view>
+#  endif
 #endif
 
 THRUST_NAMESPACE_BEGIN
@@ -84,16 +84,7 @@ struct is_contiguous_iterator_impl;
  * \see THRUST_PROCLAIM_CONTIGUOUS_ITERATOR
  */
 template <typename Iterator>
-#if _CCCL_STD_VER >= 2011
-using is_contiguous_iterator =
-#else
-struct is_contiguous_iterator :
-#endif
-  detail::is_contiguous_iterator_impl<Iterator>
-#if _CCCL_STD_VER < 2011
-{}
-#endif
-;
+using is_contiguous_iterator = detail::is_contiguous_iterator_impl<Iterator>;
 
 #if _CCCL_STD_VER >= 2014
 /*! \brief <tt>constexpr bool</tt> that is \c true if \c Iterator satisfies
@@ -118,7 +109,8 @@ constexpr bool is_contiguous_iterator_v = is_contiguous_iterator<Iterator>::valu
  * \see THRUST_PROCLAIM_CONTIGUOUS_ITERATOR
  */
 template <typename Iterator>
-struct proclaim_contiguous_iterator : false_type {};
+struct proclaim_contiguous_iterator : false_type
+{};
 
 /*! \brief Declares that the iterator \c Iterator is
  *  <a href="https://en.cppreference.com/w/cpp/named_req/ContiguousIterator">ContiguousIterator</a>
@@ -127,12 +119,12 @@ struct proclaim_contiguous_iterator : false_type {};
  * \see is_contiguous_iterator
  * \see proclaim_contiguous_iterator
  */
-#define THRUST_PROCLAIM_CONTIGUOUS_ITERATOR(Iterator)                         \
-  THRUST_NAMESPACE_BEGIN                                                      \
-  template <>                                                                 \
-  struct proclaim_contiguous_iterator<Iterator>                               \
-      : THRUST_NS_QUALIFIER::true_type {};                                    \
-  THRUST_NAMESPACE_END                                                        \
+#define THRUST_PROCLAIM_CONTIGUOUS_ITERATOR(Iterator)                            \
+  THRUST_NAMESPACE_BEGIN                                                         \
+  template <>                                                                    \
+  struct proclaim_contiguous_iterator<Iterator> : THRUST_NS_QUALIFIER::true_type \
+  {};                                                                            \
+  THRUST_NAMESPACE_END                                                           \
   /**/
 
 /*! \cond
@@ -142,7 +134,8 @@ namespace detail
 {
 
 template <typename Iterator>
-struct is_libcxx_wrap_iter : false_type {};
+struct is_libcxx_wrap_iter : false_type
+{};
 
 #if defined(_LIBCPP_VERSION)
 template <typename Iterator>
@@ -152,79 +145,71 @@ struct is_libcxx_wrap_iter<
 #  else
   std::__wrap_iter<Iterator>
 #  endif
-> : true_type {};
+  > : true_type
+{};
 #endif
 
 template <typename Iterator>
-struct is_libstdcxx_normal_iterator : false_type {};
+struct is_libstdcxx_normal_iterator : false_type
+{};
 
 #if defined(__GLIBCXX__)
 template <typename Iterator, typename Container>
-struct is_libstdcxx_normal_iterator<
-  ::__gnu_cxx::__normal_iterator<Iterator, Container>
-> : true_type {};
+struct is_libstdcxx_normal_iterator<::__gnu_cxx::__normal_iterator<Iterator, Container>> : true_type
+{};
 #endif
 
-#if   _MSC_VER >= 1916 // MSVC 2017 version 15.9.
+#if _MSC_VER >= 1916 // MSVC 2017 version 15.9.
 template <typename Iterator>
-struct is_msvc_contiguous_iterator
-  : is_pointer<::std::_Unwrapped_t<Iterator> > {};
+struct is_msvc_contiguous_iterator : ::cuda::std::is_pointer<::std::_Unwrapped_t<Iterator>>
+{};
 #elif _MSC_VER >= 1700 // MSVC 2012.
 template <typename Iterator>
-struct is_msvc_contiguous_iterator : false_type {};
+struct is_msvc_contiguous_iterator : false_type
+{};
 
 template <typename Vector>
-struct is_msvc_contiguous_iterator<
-  ::std::_Vector_const_iterator<Vector>
-> : true_type {};
+struct is_msvc_contiguous_iterator<::std::_Vector_const_iterator<Vector>> : true_type
+{};
 
 template <typename Vector>
-struct is_msvc_contiguous_iterator<
-  ::std::_Vector_iterator<Vector>
-> : true_type {};
+struct is_msvc_contiguous_iterator<::std::_Vector_iterator<Vector>> : true_type
+{};
 
 template <typename String>
-struct is_msvc_contiguous_iterator<
-  ::std::_String_const_iterator<String>
-> : true_type {};
+struct is_msvc_contiguous_iterator<::std::_String_const_iterator<String>> : true_type
+{};
 
 template <typename String>
-struct is_msvc_contiguous_iterator<
-  ::std::_String_iterator<String>
-> : true_type {};
+struct is_msvc_contiguous_iterator<::std::_String_iterator<String>> : true_type
+{};
 
 template <typename T, std::size_t N>
-struct is_msvc_contiguous_iterator<
-  ::std::_Array_const_iterator<T, N>
-> : true_type {};
+struct is_msvc_contiguous_iterator<::std::_Array_const_iterator<T, N>> : true_type
+{};
 
 template <typename T, std::size_t N>
-struct is_msvc_contiguous_iterator<
-  ::std::_Array_iterator<T, N>
-> : true_type {};
+struct is_msvc_contiguous_iterator<::std::_Array_iterator<T, N>> : true_type
+{};
 
-#if _CCCL_STD_VER >= 2017
+#  if _CCCL_STD_VER >= 2017
 template <typename Traits>
-struct is_msvc_contiguous_iterator<
-  ::std::_String_view_iterator<Traits>
-> : true_type {};
-#endif
+struct is_msvc_contiguous_iterator<::std::_String_view_iterator<Traits>> : true_type
+{};
+#  endif
 #else
 template <typename Iterator>
-struct is_msvc_contiguous_iterator : false_type {};
+struct is_msvc_contiguous_iterator : false_type
+{};
 #endif
 
 template <typename Iterator>
 struct is_contiguous_iterator_impl
-  : integral_constant<
-      bool
-    ,    is_pointer<Iterator>::value
-      || is_thrust_pointer<Iterator>::value
-      || is_libcxx_wrap_iter<Iterator>::value
-      || is_libstdcxx_normal_iterator<Iterator>::value
-      || is_msvc_contiguous_iterator<Iterator>::value
-      || proclaim_contiguous_iterator<Iterator>::value
-    >
+    : integral_constant<
+        bool,
+        ::cuda::std::is_pointer<Iterator>::value || is_thrust_pointer<Iterator>::value
+          || is_libcxx_wrap_iter<Iterator>::value || is_libstdcxx_normal_iterator<Iterator>::value
+          || is_msvc_contiguous_iterator<Iterator>::value || proclaim_contiguous_iterator<Iterator>::value>
 {};
 
 // Type traits for contiguous iterators:
@@ -234,64 +219,64 @@ struct contiguous_iterator_traits
   static_assert(thrust::is_contiguous_iterator<Iterator>::value,
                 "contiguous_iterator_traits requires a contiguous iterator.");
 
-  using raw_pointer = typename thrust::detail::pointer_traits<
-    decltype(&*std::declval<Iterator>())>::raw_pointer;
+  using raw_pointer = typename thrust::detail::pointer_traits<decltype(&*std::declval<Iterator>())>::raw_pointer;
 };
+} // namespace detail
 
-template <typename Iterator>
-using contiguous_iterator_raw_pointer_t =
-  typename contiguous_iterator_traits<Iterator>::raw_pointer;
+//! Converts a contiguous iterator type to its underlying raw pointer type.
+template <typename ContiguousIterator>
+using unwrap_contiguous_iterator_t = typename detail::contiguous_iterator_traits<ContiguousIterator>::raw_pointer;
 
-// Converts a contiguous iterator to a raw pointer:
-template <typename Iterator>
-_CCCL_HOST_DEVICE
-contiguous_iterator_raw_pointer_t<Iterator>
-contiguous_iterator_raw_pointer_cast(Iterator it)
+//! Converts a contiguous iterator to its underlying raw pointer.
+template <typename ContiguousIterator>
+_CCCL_HOST_DEVICE auto unwrap_contiguous_iterator(ContiguousIterator it)
+  -> unwrap_contiguous_iterator_t<ContiguousIterator>
 {
-  static_assert(thrust::is_contiguous_iterator<Iterator>::value,
-                "contiguous_iterator_raw_pointer_cast called with "
-                "non-contiguous iterator.");
+  static_assert(thrust::is_contiguous_iterator<ContiguousIterator>::value,
+                "unwrap_contiguous_iterator called with non-contiguous iterator.");
   return thrust::raw_pointer_cast(&*it);
 }
 
+namespace detail
+{
 // Implementation for non-contiguous iterators -- passthrough.
-template <typename Iterator,
-          bool IsContiguous = thrust::is_contiguous_iterator<Iterator>::value>
+template <typename Iterator, bool IsContiguous = thrust::is_contiguous_iterator<Iterator>::value>
 struct try_unwrap_contiguous_iterator_impl
 {
   using type = Iterator;
 
-  static _CCCL_HOST_DEVICE type get(Iterator it) { return it; }
+  static _CCCL_HOST_DEVICE type get(Iterator it)
+  {
+    return it;
+  }
 };
 
 // Implementation for contiguous iterators -- unwraps to raw pointer.
 template <typename Iterator>
 struct try_unwrap_contiguous_iterator_impl<Iterator, true /*is_contiguous*/>
 {
-  using type = contiguous_iterator_raw_pointer_t<Iterator>;
+  using type = unwrap_contiguous_iterator_t<Iterator>;
 
   static _CCCL_HOST_DEVICE type get(Iterator it)
   {
-    return contiguous_iterator_raw_pointer_cast(it);
+    return unwrap_contiguous_iterator(it);
   }
 };
-
-template <typename Iterator>
-using try_unwrap_contiguous_iterator_return_t =
-  typename try_unwrap_contiguous_iterator_impl<Iterator>::type;
-
-// Casts to a raw pointer if iterator is marked as contiguous, otherwise returns
-// the input iterator.
-template <typename Iterator>
-_CCCL_HOST_DEVICE
-try_unwrap_contiguous_iterator_return_t<Iterator>
-try_unwrap_contiguous_iterator(Iterator it)
-{
-  return try_unwrap_contiguous_iterator_impl<Iterator>::get(it);
-}
-
 } // namespace detail
 
+//! Takes an iterator type and, if it is contiguous, yields the raw pointer type it represents. Otherwise returns the
+//! iterator type unmodified.
+template <typename Iterator>
+using try_unwrap_contiguous_iterator_t = typename detail::try_unwrap_contiguous_iterator_impl<Iterator>::type;
+
+//! Takes an iterator and, if it is contiguous, unwraps it to the raw pointer it represents. Otherwise returns the
+//! iterator unmodified.
+template <typename Iterator>
+_CCCL_HOST_DEVICE auto try_unwrap_contiguous_iterator(Iterator it) -> try_unwrap_contiguous_iterator_t<Iterator>
+{
+  return detail::try_unwrap_contiguous_iterator_impl<Iterator>::get(it);
+}
+
 /*! \endcond
  */
 
@@ -304,4 +289,3 @@ try_unwrap_contiguous_iterator(Iterator it)
  */
 
 THRUST_NAMESPACE_END
-
