@@ -35,8 +35,6 @@
 #endif // no system header
 #include <thrust/detail/cpp11_required.h>
 
-#if _CCCL_STD_VER >= 2011
-
 #include <type_traits>
 
 THRUST_NAMESPACE_BEGIN
@@ -67,17 +65,20 @@ struct conjunction;
  */
 
 template <>
-struct conjunction<> : std::true_type {};
+struct conjunction<> : std::true_type
+{};
 
 template <typename T>
-struct conjunction<T> : T {};
+struct conjunction<T> : T
+{};
 
 template <typename T0, typename T1>
-struct conjunction<T0, T1> : std::conditional<T0::value, T1, T0>::type {};
+struct conjunction<T0, T1> : std::conditional<T0::value, T1, T0>::type
+{};
 
-template<typename T0, typename T1, typename T2, typename... TN>
-struct conjunction<T0, T1, T2, TN...>
-  : std::conditional<T0::value, conjunction<T1, T2, TN...>, T0>::type {};
+template <typename T0, typename T1, typename T2, typename... TN>
+struct conjunction<T0, T1, T2, TN...> : std::conditional<T0::value, conjunction<T1, T2, TN...>, T0>::type
+{};
 
 /*! \endcond
  */
@@ -112,14 +113,16 @@ struct disjunction;
  */
 
 template <>
-struct disjunction<> : std::false_type {};
+struct disjunction<> : std::false_type
+{};
 
 template <typename T>
-struct disjunction<T> : T {};
+struct disjunction<T> : T
+{};
 
 template <typename T0, typename... TN>
-struct disjunction<T0, TN...>
-  : std::conditional<T0::value != false, T0, disjunction<TN...> >::type {};
+struct disjunction<T0, TN...> : std::conditional<T0::value != false, T0, disjunction<TN...>>::type
+{};
 
 /*! \endcond
  */
@@ -154,7 +157,8 @@ struct negation;
  */
 
 template <typename T>
-struct negation : std::integral_constant<bool, !T::value> {};
+struct negation : std::integral_constant<bool, !T::value>
+{};
 
 /*! \endcond
  */
@@ -198,14 +202,16 @@ constexpr bool conjunction_value_v = conjunction_value<Bs...>::value;
  */
 
 template <>
-struct conjunction_value<> : std::true_type {};
+struct conjunction_value<> : std::true_type
+{};
 
 template <bool B>
-struct conjunction_value<B> : std::integral_constant<bool, B> {};
+struct conjunction_value<B> : std::integral_constant<bool, B>
+{};
 
 template <bool B, bool... Bs>
-struct conjunction_value<B, Bs...>
-  : std::integral_constant<bool, B && conjunction_value<Bs...>::value> {};
+struct conjunction_value<B, Bs...> : std::integral_constant<bool, B && conjunction_value<Bs...>::value>
+{};
 
 /*! \endcond
  */
@@ -237,14 +243,16 @@ constexpr bool disjunction_value_v = disjunction_value<Bs...>::value;
  */
 
 template <>
-struct disjunction_value<> : std::false_type {};
+struct disjunction_value<> : std::false_type
+{};
 
 template <bool B>
-struct disjunction_value<B> : std::integral_constant<bool, B> {};
+struct disjunction_value<B> : std::integral_constant<bool, B>
+{};
 
 template <bool B, bool... Bs>
-struct disjunction_value<B, Bs...>
-  : std::integral_constant<bool, B || disjunction_value<Bs...>::value> {};
+struct disjunction_value<B, Bs...> : std::integral_constant<bool, B || disjunction_value<Bs...>::value>
+{};
 
 /*! \endcond
  */
@@ -276,7 +284,8 @@ constexpr bool negation_value_v = negation_value<B>::value;
  */
 
 template <bool B>
-struct negation_value : std::integral_constant<bool, !B> {};
+struct negation_value : std::integral_constant<bool, !B>
+{};
 
 /*! \endcond
  */
@@ -290,6 +299,3 @@ struct negation_value : std::integral_constant<bool, !B> {};
  */
 
 THRUST_NAMESPACE_END
-
-#endif // _CCCL_STD_VER >= 2011
-
